/* icon-view-child.c generated by valac 0.38.4, the Vala compiler
 * generated from icon-view-child.vala, do not modify */

/* This file is part of GNOME Boxes. License: LGPLv2+*/

#include <glib.h>
#include <glib-object.h>
#include <gtk/gtk.h>
#include <gdk-pixbuf/gdk-pixbuf.h>
#include <gio/gio.h>
#include <libcommon.h>
#include <stdlib.h>
#include <string.h>


#define BOXES_TYPE_ICON_VIEW_CHILD (boxes_icon_view_child_get_type ())
#define BOXES_ICON_VIEW_CHILD(obj) (G_TYPE_CHECK_INSTANCE_CAST ((obj), BOXES_TYPE_ICON_VIEW_CHILD, BoxesIconViewChild))
#define BOXES_ICON_VIEW_CHILD_CLASS(klass) (G_TYPE_CHECK_CLASS_CAST ((klass), BOXES_TYPE_ICON_VIEW_CHILD, BoxesIconViewChildClass))
#define BOXES_IS_ICON_VIEW_CHILD(obj) (G_TYPE_CHECK_INSTANCE_TYPE ((obj), BOXES_TYPE_ICON_VIEW_CHILD))
#define BOXES_IS_ICON_VIEW_CHILD_CLASS(klass) (G_TYPE_CHECK_CLASS_TYPE ((klass), BOXES_TYPE_ICON_VIEW_CHILD))
#define BOXES_ICON_VIEW_CHILD_GET_CLASS(obj) (G_TYPE_INSTANCE_GET_CLASS ((obj), BOXES_TYPE_ICON_VIEW_CHILD, BoxesIconViewChildClass))

typedef struct _BoxesIconViewChild BoxesIconViewChild;
typedef struct _BoxesIconViewChildClass BoxesIconViewChildClass;
typedef struct _BoxesIconViewChildPrivate BoxesIconViewChildPrivate;

#define BOXES_TYPE_COLLECTION_ITEM (boxes_collection_item_get_type ())
#define BOXES_COLLECTION_ITEM(obj) (G_TYPE_CHECK_INSTANCE_CAST ((obj), BOXES_TYPE_COLLECTION_ITEM, BoxesCollectionItem))
#define BOXES_COLLECTION_ITEM_CLASS(klass) (G_TYPE_CHECK_CLASS_CAST ((klass), BOXES_TYPE_COLLECTION_ITEM, BoxesCollectionItemClass))
#define BOXES_IS_COLLECTION_ITEM(obj) (G_TYPE_CHECK_INSTANCE_TYPE ((obj), BOXES_TYPE_COLLECTION_ITEM))
#define BOXES_IS_COLLECTION_ITEM_CLASS(klass) (G_TYPE_CHECK_CLASS_TYPE ((klass), BOXES_TYPE_COLLECTION_ITEM))
#define BOXES_COLLECTION_ITEM_GET_CLASS(obj) (G_TYPE_INSTANCE_GET_CLASS ((obj), BOXES_TYPE_COLLECTION_ITEM, BoxesCollectionItemClass))

typedef struct _BoxesCollectionItem BoxesCollectionItem;
typedef struct _BoxesCollectionItemClass BoxesCollectionItemClass;

#define BOXES_TYPE_MACHINE_THUMBNAILER (boxes_machine_thumbnailer_get_type ())
#define BOXES_MACHINE_THUMBNAILER(obj) (G_TYPE_CHECK_INSTANCE_CAST ((obj), BOXES_TYPE_MACHINE_THUMBNAILER, BoxesMachineThumbnailer))
#define BOXES_MACHINE_THUMBNAILER_CLASS(klass) (G_TYPE_CHECK_CLASS_CAST ((klass), BOXES_TYPE_MACHINE_THUMBNAILER, BoxesMachineThumbnailerClass))
#define BOXES_IS_MACHINE_THUMBNAILER(obj) (G_TYPE_CHECK_INSTANCE_TYPE ((obj), BOXES_TYPE_MACHINE_THUMBNAILER))
#define BOXES_IS_MACHINE_THUMBNAILER_CLASS(klass) (G_TYPE_CHECK_CLASS_TYPE ((klass), BOXES_TYPE_MACHINE_THUMBNAILER))
#define BOXES_MACHINE_THUMBNAILER_GET_CLASS(obj) (G_TYPE_INSTANCE_GET_CLASS ((obj), BOXES_TYPE_MACHINE_THUMBNAILER, BoxesMachineThumbnailerClass))

typedef struct _BoxesMachineThumbnailer BoxesMachineThumbnailer;
typedef struct _BoxesMachineThumbnailerClass BoxesMachineThumbnailerClass;
enum  {
	BOXES_ICON_VIEW_CHILD_0_PROPERTY,
	BOXES_ICON_VIEW_CHILD_SELECTION_MODE_PROPERTY,
	BOXES_ICON_VIEW_CHILD_SELECTED_PROPERTY,
	BOXES_ICON_VIEW_CHILD_ITEM_PROPERTY,
	BOXES_ICON_VIEW_CHILD_NUM_PROPERTIES
};
static GParamSpec* boxes_icon_view_child_properties[BOXES_ICON_VIEW_CHILD_NUM_PROPERTIES];
#define _g_object_unref0(var) ((var == NULL) ? NULL : (var = (g_object_unref (var), NULL)))

#define BOXES_TYPE_MACHINE (boxes_machine_get_type ())
#define BOXES_MACHINE(obj) (G_TYPE_CHECK_INSTANCE_CAST ((obj), BOXES_TYPE_MACHINE, BoxesMachine))
#define BOXES_MACHINE_CLASS(klass) (G_TYPE_CHECK_CLASS_CAST ((klass), BOXES_TYPE_MACHINE, BoxesMachineClass))
#define BOXES_IS_MACHINE(obj) (G_TYPE_CHECK_INSTANCE_TYPE ((obj), BOXES_TYPE_MACHINE))
#define BOXES_IS_MACHINE_CLASS(klass) (G_TYPE_CHECK_CLASS_TYPE ((klass), BOXES_TYPE_MACHINE))
#define BOXES_MACHINE_GET_CLASS(obj) (G_TYPE_INSTANCE_GET_CLASS ((obj), BOXES_TYPE_MACHINE, BoxesMachineClass))

typedef struct _BoxesMachine BoxesMachine;
typedef struct _BoxesMachineClass BoxesMachineClass;

#define BOXES_TYPE_UI (boxes_ui_get_type ())
#define BOXES_UI(obj) (G_TYPE_CHECK_INSTANCE_CAST ((obj), BOXES_TYPE_UI, BoxesUI))
#define BOXES_IS_UI(obj) (G_TYPE_CHECK_INSTANCE_TYPE ((obj), BOXES_TYPE_UI))
#define BOXES_UI_GET_INTERFACE(obj) (G_TYPE_INSTANCE_GET_INTERFACE ((obj), BOXES_TYPE_UI, BoxesUIIface))

typedef struct _BoxesUI BoxesUI;
typedef struct _BoxesUIIface BoxesUIIface;

#define BOXES_TYPE_UI_STATE (boxes_ui_state_get_type ())
typedef struct _BoxesCollectionItemPrivate BoxesCollectionItemPrivate;

#define BOXES_TYPE_IPROPERTIES_PROVIDER (boxes_iproperties_provider_get_type ())
#define BOXES_IPROPERTIES_PROVIDER(obj) (G_TYPE_CHECK_INSTANCE_CAST ((obj), BOXES_TYPE_IPROPERTIES_PROVIDER, BoxesIPropertiesProvider))
#define BOXES_IS_IPROPERTIES_PROVIDER(obj) (G_TYPE_CHECK_INSTANCE_TYPE ((obj), BOXES_TYPE_IPROPERTIES_PROVIDER))
#define BOXES_IPROPERTIES_PROVIDER_GET_INTERFACE(obj) (G_TYPE_INSTANCE_GET_INTERFACE ((obj), BOXES_TYPE_IPROPERTIES_PROVIDER, BoxesIPropertiesProviderIface))

typedef struct _BoxesIPropertiesProvider BoxesIPropertiesProvider;
typedef struct _BoxesIPropertiesProviderIface BoxesIPropertiesProviderIface;

#define BOXES_TYPE_PROPERTIES_PAGE (boxes_properties_page_get_type ())

#define BOXES_TYPE_PROPERTY (boxes_property_get_type ())
#define BOXES_PROPERTY(obj) (G_TYPE_CHECK_INSTANCE_CAST ((obj), BOXES_TYPE_PROPERTY, BoxesProperty))
#define BOXES_PROPERTY_CLASS(klass) (G_TYPE_CHECK_CLASS_CAST ((klass), BOXES_TYPE_PROPERTY, BoxesPropertyClass))
#define BOXES_IS_PROPERTY(obj) (G_TYPE_CHECK_INSTANCE_TYPE ((obj), BOXES_TYPE_PROPERTY))
#define BOXES_IS_PROPERTY_CLASS(klass) (G_TYPE_CHECK_CLASS_TYPE ((klass), BOXES_TYPE_PROPERTY))
#define BOXES_PROPERTY_GET_CLASS(obj) (G_TYPE_INSTANCE_GET_CLASS ((obj), BOXES_TYPE_PROPERTY, BoxesPropertyClass))

typedef struct _BoxesProperty BoxesProperty;
typedef struct _BoxesPropertyClass BoxesPropertyClass;
typedef struct _BoxesMachinePrivate BoxesMachinePrivate;

#define BOXES_MACHINE_TYPE_CONNECT_FLAGS (boxes_machine_connect_flags_get_type ())

struct _BoxesIconViewChild {
	GtkBox parent_instance;
	BoxesIconViewChildPrivate * priv;
	gboolean _selection_mode;
	gboolean _selected;
	GtkImage* thumbnail;
};

struct _BoxesIconViewChildClass {
	GtkBoxClass parent_class;
};

struct _BoxesIconViewChildPrivate {
	BoxesCollectionItem* _item;
	GtkCheckButton* selection_button;
	GtkStack* stack;
	GtkSpinner* spinner;
	GtkImage* favorite;
	GtkLabel* machine_name;
	BoxesMachineThumbnailer* thumbnailer;
	GBinding* selected_binding;
};

typedef enum  {
	BOXES_UI_STATE_NONE,
	BOXES_UI_STATE_COLLECTION,
	BOXES_UI_STATE_CREDS,
	BOXES_UI_STATE_DISPLAY,
	BOXES_UI_STATE_WIZARD,
	BOXES_UI_STATE_PROPERTIES
} BoxesUIState;

struct _BoxesUIIface {
	GTypeInterface parent_iface;
	BoxesUIState (*get_previous_ui_state) (BoxesUI* self);
	void (*set_previous_ui_state) (BoxesUI* self, BoxesUIState value);
	BoxesUIState (*get_ui_state) (BoxesUI* self);
	void (*set_ui_state) (BoxesUI* self, BoxesUIState value);
};

struct _BoxesCollectionItem {
	GObject parent_instance;
	BoxesCollectionItemPrivate * priv;
};

struct _BoxesCollectionItemClass {
	GObjectClass parent_class;
	gint (*compare) (BoxesCollectionItem* self, BoxesCollectionItem* other);
};

typedef enum  {
	BOXES_PROPERTIES_PAGE_GENERAL,
	BOXES_PROPERTIES_PAGE_SYSTEM,
	BOXES_PROPERTIES_PAGE_DEVICES,
	BOXES_PROPERTIES_PAGE_SNAPSHOTS,
	BOXES_PROPERTIES_PAGE_LAST
} BoxesPropertiesPage;

struct _BoxesIPropertiesProviderIface {
	GTypeInterface parent_iface;
	GList* (*get_properties) (BoxesIPropertiesProvider* self, BoxesPropertiesPage page);
};

typedef enum  {
	BOXES_MACHINE_CONNECT_FLAGS_NONE = 0,
	BOXES_MACHINE_CONNECT_FLAGS_IGNORE_SAVED_STATE = 1 << 0
} BoxesMachineConnectFlags;

struct _BoxesMachine {
	BoxesCollectionItem parent_instance;
	BoxesMachinePrivate * priv;
	BoxesCollectionSource* source;
	BoxesBoxConfig* config;
	gboolean stay_on_display;
};

struct _BoxesMachineClass {
	BoxesCollectionItemClass parent_class;
	void (*save_real) (BoxesMachine* self, GAsyncReadyCallback _callback_, gpointer _user_data_);
	void (*save_real_finish) (BoxesMachine* self, GAsyncResult* _res_, GError** error);
	void (*take_screenshot) (BoxesMachine* self, GAsyncReadyCallback _callback_, gpointer _user_data_);
	GdkPixbuf* (*take_screenshot_finish) (BoxesMachine* self, GAsyncResult* _res_, GError** error);
	GList* (*get_properties) (BoxesMachine* self, BoxesPropertiesPage page);
	void (*connect_display) (BoxesMachine* self, BoxesMachineConnectFlags flags, GAsyncReadyCallback _callback_, gpointer _user_data_);
	void (*connect_display_finish) (BoxesMachine* self, GAsyncResult* _res_, GError** error);
	void (*restart) (BoxesMachine* self);
	void (*clone) (BoxesMachine* self, GAsyncReadyCallback _callback_, gpointer _user_data_);
	void (*clone_finish) (BoxesMachine* self, GAsyncResult* _res_);
	void (*disconnect_display) (BoxesMachine* self);
	void (*update_status) (BoxesMachine* self);
	void (*delete) (BoxesMachine* self, gboolean by_user);
	gboolean (*get_suspend_at_exit) (BoxesMachine* self);
	gboolean (*get_can_save) (BoxesMachine* self);
	gboolean (*get_can_restart) (BoxesMachine* self);
	gboolean (*get_can_clone) (BoxesMachine* self);
	gboolean (*get_should_autosave) (BoxesMachine* self);
	gboolean (*get_is_local) (BoxesMachine* self);
};


static gpointer boxes_icon_view_child_parent_class = NULL;

GType boxes_icon_view_child_get_type (void) G_GNUC_CONST;
GType boxes_collection_item_get_type (void) G_GNUC_CONST;
GType boxes_machine_thumbnailer_get_type (void) G_GNUC_CONST;
#define BOXES_ICON_VIEW_CHILD_GET_PRIVATE(o) (G_TYPE_INSTANCE_GET_PRIVATE ((o), BOXES_TYPE_ICON_VIEW_CHILD, BoxesIconViewChildPrivate))
BoxesIconViewChild* boxes_icon_view_child_new (BoxesCollectionItem* item);
BoxesIconViewChild* boxes_icon_view_child_construct (GType object_type, BoxesCollectionItem* item);
static void boxes_icon_view_child_set_item (BoxesIconViewChild* self, BoxesCollectionItem* value);
GType boxes_machine_get_type (void) G_GNUC_CONST;
static BoxesMachine* boxes_icon_view_child_get_machine (BoxesIconViewChild* self);
BoxesMachineThumbnailer* boxes_machine_get_thumbnailer (BoxesMachine* self);
void boxes_machine_thumbnailer_set_favorite_emblem_enabled (BoxesMachineThumbnailer* self, gboolean value);
static void __lambda199_ (BoxesIconViewChild* self);
GdkPixbuf* boxes_machine_thumbnailer_get_thumbnail (BoxesMachineThumbnailer* self);
static void ___lambda199__g_object_notify (GObject* _sender, GParamSpec* pspec, gpointer self);
GType boxes_ui_state_get_type (void) G_GNUC_CONST;
GType boxes_ui_get_type (void) G_GNUC_CONST;
GType boxes_properties_page_get_type (void) G_GNUC_CONST;
GType boxes_property_get_type (void) G_GNUC_CONST;
GType boxes_iproperties_provider_get_type (void) G_GNUC_CONST;
GType boxes_machine_connect_flags_get_type (void) G_GNUC_CONST;
static void boxes_icon_view_child_update_favorite (BoxesIconViewChild* self);
static void _boxes_icon_view_child_update_favorite_g_object_notify (GObject* _sender, GParamSpec* pspec, gpointer self);
static void boxes_icon_view_child_update_thumbnail (BoxesIconViewChild* self);
static void _boxes_icon_view_child_update_thumbnail_g_object_notify (GObject* _sender, GParamSpec* pspec, gpointer self);
gboolean boxes_machine_get_under_construction (BoxesMachine* self);
static gboolean _vala_string_array_contains (gchar* * stack, int stack_length, gchar* needle);
gboolean boxes_icon_view_child_get_selection_mode (BoxesIconViewChild* self);
void boxes_icon_view_child_set_selection_mode (BoxesIconViewChild* self, gboolean value);
void boxes_icon_view_child_set_selected (BoxesIconViewChild* self, gboolean value);
gboolean boxes_icon_view_child_get_selected (BoxesIconViewChild* self);
BoxesCollectionItem* boxes_icon_view_child_get_item (BoxesIconViewChild* self);
static void boxes_icon_view_child_finalize (GObject * obj);
static void _vala_boxes_icon_view_child_get_property (GObject * object, guint property_id, GValue * value, GParamSpec * pspec);
static void _vala_boxes_icon_view_child_set_property (GObject * object, guint property_id, const GValue * value, GParamSpec * pspec);
static void _vala_array_destroy (gpointer array, gint array_length, GDestroyNotify destroy_func);
static void _vala_array_free (gpointer array, gint array_length, GDestroyNotify destroy_func);


static gpointer _g_object_ref0 (gpointer self) {
#line 54 "/home/fborges/checkout/gnome-boxes/src/icon-view-child.vala"
	return self ? g_object_ref (self) : NULL;
#line 244 "icon-view-child.c"
}


static void __lambda199_ (BoxesIconViewChild* self) {
	GtkImage* _tmp0_;
	BoxesMachineThumbnailer* _tmp1_;
	GdkPixbuf* _tmp2_;
	GdkPixbuf* _tmp3_;
#line 58 "/home/fborges/checkout/gnome-boxes/src/icon-view-child.vala"
	_tmp0_ = self->thumbnail;
#line 58 "/home/fborges/checkout/gnome-boxes/src/icon-view-child.vala"
	_tmp1_ = self->priv->thumbnailer;
#line 58 "/home/fborges/checkout/gnome-boxes/src/icon-view-child.vala"
	_tmp2_ = boxes_machine_thumbnailer_get_thumbnail (_tmp1_);
#line 58 "/home/fborges/checkout/gnome-boxes/src/icon-view-child.vala"
	_tmp3_ = _tmp2_;
#line 58 "/home/fborges/checkout/gnome-boxes/src/icon-view-child.vala"
	gtk_image_set_from_pixbuf (_tmp0_, _tmp3_);
#line 263 "icon-view-child.c"
}


static void ___lambda199__g_object_notify (GObject* _sender, GParamSpec* pspec, gpointer self) {
#line 57 "/home/fborges/checkout/gnome-boxes/src/icon-view-child.vala"
	__lambda199_ ((BoxesIconViewChild*) self);
#line 270 "icon-view-child.c"
}


static void _boxes_icon_view_child_update_favorite_g_object_notify (GObject* _sender, GParamSpec* pspec, gpointer self) {
#line 64 "/home/fborges/checkout/gnome-boxes/src/icon-view-child.vala"
	boxes_icon_view_child_update_favorite ((BoxesIconViewChild*) self);
#line 277 "icon-view-child.c"
}


static void _boxes_icon_view_child_update_thumbnail_g_object_notify (GObject* _sender, GParamSpec* pspec, gpointer self) {
#line 65 "/home/fborges/checkout/gnome-boxes/src/icon-view-child.vala"
	boxes_icon_view_child_update_thumbnail ((BoxesIconViewChild*) self);
#line 284 "icon-view-child.c"
}


BoxesIconViewChild* boxes_icon_view_child_construct (GType object_type, BoxesCollectionItem* item) {
	BoxesIconViewChild * self = NULL;
	BoxesCollectionItem* _tmp0_;
	BoxesMachine* _tmp1_;
	BoxesMachine* _tmp2_;
	BoxesMachineThumbnailer* _tmp3_;
	BoxesMachineThumbnailer* _tmp4_;
	BoxesMachineThumbnailer* _tmp5_;
	BoxesMachineThumbnailer* _tmp6_;
	BoxesMachineThumbnailer* _tmp7_;
	GtkImage* _tmp8_;
	BoxesMachineThumbnailer* _tmp9_;
	GdkPixbuf* _tmp10_;
	GdkPixbuf* _tmp11_;
	GtkCheckButton* _tmp12_;
	GBinding* _tmp13_;
	GBinding* _tmp14_;
	BoxesMachine* _tmp15_;
	BoxesMachine* _tmp16_;
	BoxesBoxConfig* _tmp17_;
	BoxesMachine* _tmp18_;
	BoxesMachine* _tmp19_;
	BoxesMachine* _tmp20_;
	BoxesMachine* _tmp21_;
	GtkLabel* _tmp22_;
#line 51 "/home/fborges/checkout/gnome-boxes/src/icon-view-child.vala"
	g_return_val_if_fail (item != NULL, NULL);
#line 51 "/home/fborges/checkout/gnome-boxes/src/icon-view-child.vala"
	self = (BoxesIconViewChild*) g_object_new (object_type, NULL);
#line 52 "/home/fborges/checkout/gnome-boxes/src/icon-view-child.vala"
	_tmp0_ = item;
#line 52 "/home/fborges/checkout/gnome-boxes/src/icon-view-child.vala"
	boxes_icon_view_child_set_item (self, _tmp0_);
#line 54 "/home/fborges/checkout/gnome-boxes/src/icon-view-child.vala"
	_tmp1_ = boxes_icon_view_child_get_machine (self);
#line 54 "/home/fborges/checkout/gnome-boxes/src/icon-view-child.vala"
	_tmp2_ = _tmp1_;
#line 54 "/home/fborges/checkout/gnome-boxes/src/icon-view-child.vala"
	_tmp3_ = boxes_machine_get_thumbnailer (_tmp2_);
#line 54 "/home/fborges/checkout/gnome-boxes/src/icon-view-child.vala"
	_tmp4_ = _tmp3_;
#line 54 "/home/fborges/checkout/gnome-boxes/src/icon-view-child.vala"
	_tmp5_ = _g_object_ref0 (_tmp4_);
#line 54 "/home/fborges/checkout/gnome-boxes/src/icon-view-child.vala"
	_g_object_unref0 (self->priv->thumbnailer);
#line 54 "/home/fborges/checkout/gnome-boxes/src/icon-view-child.vala"
	self->priv->thumbnailer = _tmp5_;
#line 56 "/home/fborges/checkout/gnome-boxes/src/icon-view-child.vala"
	_tmp6_ = self->priv->thumbnailer;
#line 56 "/home/fborges/checkout/gnome-boxes/src/icon-view-child.vala"
	boxes_machine_thumbnailer_set_favorite_emblem_enabled (_tmp6_, FALSE);
#line 57 "/home/fborges/checkout/gnome-boxes/src/icon-view-child.vala"
	_tmp7_ = self->priv->thumbnailer;
#line 57 "/home/fborges/checkout/gnome-boxes/src/icon-view-child.vala"
	g_signal_connect_object ((GObject*) _tmp7_, "notify::thumbnail", (GCallback) ___lambda199__g_object_notify, self, 0);
#line 60 "/home/fborges/checkout/gnome-boxes/src/icon-view-child.vala"
	_tmp8_ = self->thumbnail;
#line 60 "/home/fborges/checkout/gnome-boxes/src/icon-view-child.vala"
	_tmp9_ = self->priv->thumbnailer;
#line 60 "/home/fborges/checkout/gnome-boxes/src/icon-view-child.vala"
	_tmp10_ = boxes_machine_thumbnailer_get_thumbnail (_tmp9_);
#line 60 "/home/fborges/checkout/gnome-boxes/src/icon-view-child.vala"
	_tmp11_ = _tmp10_;
#line 60 "/home/fborges/checkout/gnome-boxes/src/icon-view-child.vala"
	gtk_image_set_from_pixbuf (_tmp8_, _tmp11_);
#line 62 "/home/fborges/checkout/gnome-boxes/src/icon-view-child.vala"
	_tmp12_ = self->priv->selection_button;
#line 62 "/home/fborges/checkout/gnome-boxes/src/icon-view-child.vala"
	_tmp13_ = g_object_bind_property_with_closures ((GObject*) self, "selected", (GObject*) _tmp12_, "active", G_BINDING_BIDIRECTIONAL, (GClosure*) ((NULL == NULL) ? NULL : g_cclosure_new ((GCallback) NULL, NULL, (GClosureNotify) NULL)), (GClosure*) ((NULL == NULL) ? NULL : g_cclosure_new ((GCallback) NULL, NULL, (GClosureNotify) NULL)));
#line 62 "/home/fborges/checkout/gnome-boxes/src/icon-view-child.vala"
	_tmp14_ = _g_object_ref0 (_tmp13_);
#line 62 "/home/fborges/checkout/gnome-boxes/src/icon-view-child.vala"
	_g_object_unref0 (self->priv->selected_binding);
#line 62 "/home/fborges/checkout/gnome-boxes/src/icon-view-child.vala"
	self->priv->selected_binding = _tmp14_;
#line 64 "/home/fborges/checkout/gnome-boxes/src/icon-view-child.vala"
	_tmp15_ = boxes_icon_view_child_get_machine (self);
#line 64 "/home/fborges/checkout/gnome-boxes/src/icon-view-child.vala"
	_tmp16_ = _tmp15_;
#line 64 "/home/fborges/checkout/gnome-boxes/src/icon-view-child.vala"
	_tmp17_ = _tmp16_->config;
#line 64 "/home/fborges/checkout/gnome-boxes/src/icon-view-child.vala"
	g_signal_connect_object ((GObject*) _tmp17_, "notify::categories", (GCallback) _boxes_icon_view_child_update_favorite_g_object_notify, self, 0);
#line 65 "/home/fborges/checkout/gnome-boxes/src/icon-view-child.vala"
	_tmp18_ = boxes_icon_view_child_get_machine (self);
#line 65 "/home/fborges/checkout/gnome-boxes/src/icon-view-child.vala"
	_tmp19_ = _tmp18_;
#line 65 "/home/fborges/checkout/gnome-boxes/src/icon-view-child.vala"
	g_signal_connect_object ((GObject*) _tmp19_, "notify::under-construction", (GCallback) _boxes_icon_view_child_update_thumbnail_g_object_notify, self, 0);
#line 67 "/home/fborges/checkout/gnome-boxes/src/icon-view-child.vala"
	boxes_icon_view_child_update_thumbnail (self);
#line 68 "/home/fborges/checkout/gnome-boxes/src/icon-view-child.vala"
	boxes_icon_view_child_update_favorite (self);
#line 70 "/home/fborges/checkout/gnome-boxes/src/icon-view-child.vala"
	_tmp20_ = boxes_icon_view_child_get_machine (self);
#line 70 "/home/fborges/checkout/gnome-boxes/src/icon-view-child.vala"
	_tmp21_ = _tmp20_;
#line 70 "/home/fborges/checkout/gnome-boxes/src/icon-view-child.vala"
	_tmp22_ = self->priv->machine_name;
#line 70 "/home/fborges/checkout/gnome-boxes/src/icon-view-child.vala"
	g_object_bind_property_with_closures ((GObject*) _tmp21_, "name", (GObject*) _tmp22_, "label", G_BINDING_SYNC_CREATE, (GClosure*) ((NULL == NULL) ? NULL : g_cclosure_new ((GCallback) NULL, NULL, (GClosureNotify) NULL)), (GClosure*) ((NULL == NULL) ? NULL : g_cclosure_new ((GCallback) NULL, NULL, (GClosureNotify) NULL)));
#line 51 "/home/fborges/checkout/gnome-boxes/src/icon-view-child.vala"
	return self;
#line 391 "icon-view-child.c"
}


BoxesIconViewChild* boxes_icon_view_child_new (BoxesCollectionItem* item) {
#line 51 "/home/fborges/checkout/gnome-boxes/src/icon-view-child.vala"
	return boxes_icon_view_child_construct (BOXES_TYPE_ICON_VIEW_CHILD, item);
#line 398 "icon-view-child.c"
}


static void boxes_icon_view_child_update_thumbnail (BoxesIconViewChild* self) {
	BoxesMachine* _tmp0_;
	BoxesMachine* _tmp1_;
	gboolean _tmp2_;
	gboolean _tmp3_;
#line 73 "/home/fborges/checkout/gnome-boxes/src/icon-view-child.vala"
	g_return_if_fail (self != NULL);
#line 74 "/home/fborges/checkout/gnome-boxes/src/icon-view-child.vala"
	_tmp0_ = boxes_icon_view_child_get_machine (self);
#line 74 "/home/fborges/checkout/gnome-boxes/src/icon-view-child.vala"
	_tmp1_ = _tmp0_;
#line 74 "/home/fborges/checkout/gnome-boxes/src/icon-view-child.vala"
	_tmp2_ = boxes_machine_get_under_construction (_tmp1_);
#line 74 "/home/fborges/checkout/gnome-boxes/src/icon-view-child.vala"
	_tmp3_ = _tmp2_;
#line 74 "/home/fborges/checkout/gnome-boxes/src/icon-view-child.vala"
	if (_tmp3_) {
#line 419 "icon-view-child.c"
		GtkStack* _tmp4_;
		GtkSpinner* _tmp5_;
		GtkSpinner* _tmp6_;
		GtkSpinner* _tmp7_;
#line 75 "/home/fborges/checkout/gnome-boxes/src/icon-view-child.vala"
		_tmp4_ = self->priv->stack;
#line 75 "/home/fborges/checkout/gnome-boxes/src/icon-view-child.vala"
		_tmp5_ = self->priv->spinner;
#line 75 "/home/fborges/checkout/gnome-boxes/src/icon-view-child.vala"
		gtk_stack_set_visible_child (_tmp4_, (GtkWidget*) _tmp5_);
#line 76 "/home/fborges/checkout/gnome-boxes/src/icon-view-child.vala"
		_tmp6_ = self->priv->spinner;
#line 76 "/home/fborges/checkout/gnome-boxes/src/icon-view-child.vala"
		gtk_spinner_start (_tmp6_);
#line 77 "/home/fborges/checkout/gnome-boxes/src/icon-view-child.vala"
		_tmp7_ = self->priv->spinner;
#line 77 "/home/fborges/checkout/gnome-boxes/src/icon-view-child.vala"
		gtk_widget_set_visible ((GtkWidget*) _tmp7_, TRUE);
#line 438 "icon-view-child.c"
	} else {
		GtkStack* _tmp8_;
		GtkImage* _tmp9_;
		GtkSpinner* _tmp10_;
#line 80 "/home/fborges/checkout/gnome-boxes/src/icon-view-child.vala"
		_tmp8_ = self->priv->stack;
#line 80 "/home/fborges/checkout/gnome-boxes/src/icon-view-child.vala"
		_tmp9_ = self->thumbnail;
#line 80 "/home/fborges/checkout/gnome-boxes/src/icon-view-child.vala"
		gtk_stack_set_visible_child (_tmp8_, (GtkWidget*) _tmp9_);
#line 81 "/home/fborges/checkout/gnome-boxes/src/icon-view-child.vala"
		_tmp10_ = self->priv->spinner;
#line 81 "/home/fborges/checkout/gnome-boxes/src/icon-view-child.vala"
		gtk_spinner_stop (_tmp10_);
#line 453 "icon-view-child.c"
	}
}


static gboolean _vala_string_array_contains (gchar* * stack, int stack_length, gchar* needle) {
	int i;
#line 86 "/home/fborges/checkout/gnome-boxes/src/icon-view-child.vala"
	for (i = 0; i < stack_length; i++) {
#line 86 "/home/fborges/checkout/gnome-boxes/src/icon-view-child.vala"
		if (g_strcmp0 (stack[i], needle) == 0) {
#line 86 "/home/fborges/checkout/gnome-boxes/src/icon-view-child.vala"
			return TRUE;
#line 466 "icon-view-child.c"
		}
	}
#line 86 "/home/fborges/checkout/gnome-boxes/src/icon-view-child.vala"
	return FALSE;
#line 471 "icon-view-child.c"
}


static void boxes_icon_view_child_update_favorite (BoxesIconViewChild* self) {
	BoxesMachine* _tmp0_;
	BoxesMachine* _tmp1_;
	BoxesBoxConfig* _tmp2_;
	gchar** _tmp3_;
	gint _tmp3__length1;
	gchar** _tmp4_;
	gint _tmp4__length1;
	gchar** _tmp5_;
	gint _tmp5__length1;
	gboolean _tmp6_;
#line 85 "/home/fborges/checkout/gnome-boxes/src/icon-view-child.vala"
	g_return_if_fail (self != NULL);
#line 86 "/home/fborges/checkout/gnome-boxes/src/icon-view-child.vala"
	_tmp0_ = boxes_icon_view_child_get_machine (self);
#line 86 "/home/fborges/checkout/gnome-boxes/src/icon-view-child.vala"
	_tmp1_ = _tmp0_;
#line 86 "/home/fborges/checkout/gnome-boxes/src/icon-view-child.vala"
	_tmp2_ = _tmp1_->config;
#line 86 "/home/fborges/checkout/gnome-boxes/src/icon-view-child.vala"
	_tmp3_ = boxes_box_config_get_categories (_tmp2_, &_tmp3__length1);
#line 86 "/home/fborges/checkout/gnome-boxes/src/icon-view-child.vala"
	_tmp4_ = _tmp3_;
#line 86 "/home/fborges/checkout/gnome-boxes/src/icon-view-child.vala"
	_tmp4__length1 = _tmp3__length1;
#line 86 "/home/fborges/checkout/gnome-boxes/src/icon-view-child.vala"
	_tmp5_ = _tmp4_;
#line 86 "/home/fborges/checkout/gnome-boxes/src/icon-view-child.vala"
	_tmp5__length1 = _tmp4__length1;
#line 86 "/home/fborges/checkout/gnome-boxes/src/icon-view-child.vala"
	_tmp6_ = _vala_string_array_contains (_tmp5_, _tmp4__length1, "favorite");
#line 86 "/home/fborges/checkout/gnome-boxes/src/icon-view-child.vala"
	_tmp5_ = (_vala_array_free (_tmp5_, _tmp5__length1, (GDestroyNotify) g_free), NULL);
#line 86 "/home/fborges/checkout/gnome-boxes/src/icon-view-child.vala"
	if (_tmp6_) {
#line 510 "icon-view-child.c"
		GtkImage* _tmp7_;
#line 87 "/home/fborges/checkout/gnome-boxes/src/icon-view-child.vala"
		_tmp7_ = self->priv->favorite;
#line 87 "/home/fborges/checkout/gnome-boxes/src/icon-view-child.vala"
		gtk_image_set_from_icon_name (_tmp7_, "starred-symbolic", GTK_ICON_SIZE_MENU);
#line 516 "icon-view-child.c"
	} else {
		GtkImage* _tmp8_;
#line 89 "/home/fborges/checkout/gnome-boxes/src/icon-view-child.vala"
		_tmp8_ = self->priv->favorite;
#line 89 "/home/fborges/checkout/gnome-boxes/src/icon-view-child.vala"
		gtk_image_clear (_tmp8_);
#line 523 "icon-view-child.c"
	}
}


gboolean boxes_icon_view_child_get_selection_mode (BoxesIconViewChild* self) {
	gboolean result;
	gboolean _tmp0_;
#line 9 "/home/fborges/checkout/gnome-boxes/src/icon-view-child.vala"
	g_return_val_if_fail (self != NULL, FALSE);
#line 9 "/home/fborges/checkout/gnome-boxes/src/icon-view-child.vala"
	_tmp0_ = self->_selection_mode;
#line 9 "/home/fborges/checkout/gnome-boxes/src/icon-view-child.vala"
	result = _tmp0_;
#line 9 "/home/fborges/checkout/gnome-boxes/src/icon-view-child.vala"
	return result;
#line 539 "icon-view-child.c"
}


void boxes_icon_view_child_set_selection_mode (BoxesIconViewChild* self, gboolean value) {
	gboolean _tmp0_;
	GtkCheckButton* _tmp1_;
	gboolean _tmp2_;
	gboolean _tmp3_;
#line 10 "/home/fborges/checkout/gnome-boxes/src/icon-view-child.vala"
	g_return_if_fail (self != NULL);
#line 11 "/home/fborges/checkout/gnome-boxes/src/icon-view-child.vala"
	_tmp0_ = value;
#line 11 "/home/fborges/checkout/gnome-boxes/src/icon-view-child.vala"
	self->_selection_mode = _tmp0_;
#line 13 "/home/fborges/checkout/gnome-boxes/src/icon-view-child.vala"
	_tmp1_ = self->priv->selection_button;
#line 13 "/home/fborges/checkout/gnome-boxes/src/icon-view-child.vala"
	_tmp2_ = self->_selection_mode;
#line 13 "/home/fborges/checkout/gnome-boxes/src/icon-view-child.vala"
	gtk_widget_set_visible ((GtkWidget*) _tmp1_, _tmp2_);
#line 15 "/home/fborges/checkout/gnome-boxes/src/icon-view-child.vala"
	_tmp3_ = self->_selection_mode;
#line 15 "/home/fborges/checkout/gnome-boxes/src/icon-view-child.vala"
	if (!_tmp3_) {
#line 16 "/home/fborges/checkout/gnome-boxes/src/icon-view-child.vala"
		boxes_icon_view_child_set_selected (self, FALSE);
#line 566 "icon-view-child.c"
	}
#line 10 "/home/fborges/checkout/gnome-boxes/src/icon-view-child.vala"
	g_object_notify_by_pspec ((GObject *) self, boxes_icon_view_child_properties[BOXES_ICON_VIEW_CHILD_SELECTION_MODE_PROPERTY]);
#line 570 "icon-view-child.c"
}


gboolean boxes_icon_view_child_get_selected (BoxesIconViewChild* self) {
	gboolean result;
	gboolean _tmp0_;
#line 23 "/home/fborges/checkout/gnome-boxes/src/icon-view-child.vala"
	g_return_val_if_fail (self != NULL, FALSE);
#line 23 "/home/fborges/checkout/gnome-boxes/src/icon-view-child.vala"
	_tmp0_ = self->_selected;
#line 23 "/home/fborges/checkout/gnome-boxes/src/icon-view-child.vala"
	result = _tmp0_;
#line 23 "/home/fborges/checkout/gnome-boxes/src/icon-view-child.vala"
	return result;
#line 585 "icon-view-child.c"
}


void boxes_icon_view_child_set_selected (BoxesIconViewChild* self, gboolean value) {
	gboolean _tmp0_ = FALSE;
	gboolean _tmp1_;
	gboolean _tmp2_;
#line 24 "/home/fborges/checkout/gnome-boxes/src/icon-view-child.vala"
	g_return_if_fail (self != NULL);
#line 24 "/home/fborges/checkout/gnome-boxes/src/icon-view-child.vala"
	_tmp1_ = boxes_icon_view_child_get_selection_mode (self);
#line 24 "/home/fborges/checkout/gnome-boxes/src/icon-view-child.vala"
	_tmp2_ = _tmp1_;
#line 24 "/home/fborges/checkout/gnome-boxes/src/icon-view-child.vala"
	if (_tmp2_) {
#line 601 "icon-view-child.c"
		gboolean _tmp3_;
#line 24 "/home/fborges/checkout/gnome-boxes/src/icon-view-child.vala"
		_tmp3_ = value;
#line 24 "/home/fborges/checkout/gnome-boxes/src/icon-view-child.vala"
		_tmp0_ = _tmp3_;
#line 607 "icon-view-child.c"
	} else {
#line 24 "/home/fborges/checkout/gnome-boxes/src/icon-view-child.vala"
		_tmp0_ = FALSE;
#line 611 "icon-view-child.c"
	}
#line 24 "/home/fborges/checkout/gnome-boxes/src/icon-view-child.vala"
	self->_selected = _tmp0_;
#line 24 "/home/fborges/checkout/gnome-boxes/src/icon-view-child.vala"
	g_object_notify_by_pspec ((GObject *) self, boxes_icon_view_child_properties[BOXES_ICON_VIEW_CHILD_SELECTED_PROPERTY]);
#line 617 "icon-view-child.c"
}


BoxesCollectionItem* boxes_icon_view_child_get_item (BoxesIconViewChild* self) {
	BoxesCollectionItem* result;
	BoxesCollectionItem* _tmp0_;
#line 28 "/home/fborges/checkout/gnome-boxes/src/icon-view-child.vala"
	g_return_val_if_fail (self != NULL, NULL);
#line 28 "/home/fborges/checkout/gnome-boxes/src/icon-view-child.vala"
	_tmp0_ = self->priv->_item;
#line 28 "/home/fborges/checkout/gnome-boxes/src/icon-view-child.vala"
	result = _tmp0_;
#line 28 "/home/fborges/checkout/gnome-boxes/src/icon-view-child.vala"
	return result;
#line 632 "icon-view-child.c"
}


static void boxes_icon_view_child_set_item (BoxesIconViewChild* self, BoxesCollectionItem* value) {
#line 28 "/home/fborges/checkout/gnome-boxes/src/icon-view-child.vala"
	g_return_if_fail (self != NULL);
#line 28 "/home/fborges/checkout/gnome-boxes/src/icon-view-child.vala"
	if (boxes_icon_view_child_get_item (self) != value) {
#line 641 "icon-view-child.c"
		BoxesCollectionItem* _tmp0_;
		BoxesCollectionItem* _tmp1_;
#line 28 "/home/fborges/checkout/gnome-boxes/src/icon-view-child.vala"
		_tmp0_ = value;
#line 28 "/home/fborges/checkout/gnome-boxes/src/icon-view-child.vala"
		_tmp1_ = _g_object_ref0 (_tmp0_);
#line 28 "/home/fborges/checkout/gnome-boxes/src/icon-view-child.vala"
		_g_object_unref0 (self->priv->_item);
#line 28 "/home/fborges/checkout/gnome-boxes/src/icon-view-child.vala"
		self->priv->_item = _tmp1_;
#line 28 "/home/fborges/checkout/gnome-boxes/src/icon-view-child.vala"
		g_object_notify_by_pspec ((GObject *) self, boxes_icon_view_child_properties[BOXES_ICON_VIEW_CHILD_ITEM_PROPERTY]);
#line 654 "icon-view-child.c"
	}
}


static BoxesMachine* boxes_icon_view_child_get_machine (BoxesIconViewChild* self) {
	BoxesMachine* result;
	BoxesCollectionItem* _tmp0_;
#line 30 "/home/fborges/checkout/gnome-boxes/src/icon-view-child.vala"
	g_return_val_if_fail (self != NULL, NULL);
#line 30 "/home/fborges/checkout/gnome-boxes/src/icon-view-child.vala"
	_tmp0_ = self->priv->_item;
#line 30 "/home/fborges/checkout/gnome-boxes/src/icon-view-child.vala"
	result = G_TYPE_CHECK_INSTANCE_TYPE (_tmp0_, BOXES_TYPE_MACHINE) ? ((BoxesMachine*) _tmp0_) : NULL;
#line 30 "/home/fborges/checkout/gnome-boxes/src/icon-view-child.vala"
	return result;
#line 670 "icon-view-child.c"
}


static void boxes_icon_view_child_class_init (BoxesIconViewChildClass * klass) {
	gint BoxesIconViewChild_private_offset;
#line 6 "/home/fborges/checkout/gnome-boxes/src/icon-view-child.vala"
	boxes_icon_view_child_parent_class = g_type_class_peek_parent (klass);
#line 6 "/home/fborges/checkout/gnome-boxes/src/icon-view-child.vala"
	g_type_class_add_private (klass, sizeof (BoxesIconViewChildPrivate));
#line 6 "/home/fborges/checkout/gnome-boxes/src/icon-view-child.vala"
	G_OBJECT_CLASS (klass)->get_property = _vala_boxes_icon_view_child_get_property;
#line 6 "/home/fborges/checkout/gnome-boxes/src/icon-view-child.vala"
	G_OBJECT_CLASS (klass)->set_property = _vala_boxes_icon_view_child_set_property;
#line 6 "/home/fborges/checkout/gnome-boxes/src/icon-view-child.vala"
	G_OBJECT_CLASS (klass)->finalize = boxes_icon_view_child_finalize;
#line 6 "/home/fborges/checkout/gnome-boxes/src/icon-view-child.vala"
	g_object_class_install_property (G_OBJECT_CLASS (klass), BOXES_ICON_VIEW_CHILD_SELECTION_MODE_PROPERTY, boxes_icon_view_child_properties[BOXES_ICON_VIEW_CHILD_SELECTION_MODE_PROPERTY] = g_param_spec_boolean ("selection-mode", "selection-mode", "selection-mode", FALSE, G_PARAM_STATIC_NAME | G_PARAM_STATIC_NICK | G_PARAM_STATIC_BLURB | G_PARAM_READABLE | G_PARAM_WRITABLE));
#line 6 "/home/fborges/checkout/gnome-boxes/src/icon-view-child.vala"
	g_object_class_install_property (G_OBJECT_CLASS (klass), BOXES_ICON_VIEW_CHILD_SELECTED_PROPERTY, boxes_icon_view_child_properties[BOXES_ICON_VIEW_CHILD_SELECTED_PROPERTY] = g_param_spec_boolean ("selected", "selected", "selected", FALSE, G_PARAM_STATIC_NAME | G_PARAM_STATIC_NICK | G_PARAM_STATIC_BLURB | G_PARAM_READABLE | G_PARAM_WRITABLE));
#line 6 "/home/fborges/checkout/gnome-boxes/src/icon-view-child.vala"
	g_object_class_install_property (G_OBJECT_CLASS (klass), BOXES_ICON_VIEW_CHILD_ITEM_PROPERTY, boxes_icon_view_child_properties[BOXES_ICON_VIEW_CHILD_ITEM_PROPERTY] = g_param_spec_object ("item", "item", "item", BOXES_TYPE_COLLECTION_ITEM, G_PARAM_STATIC_NAME | G_PARAM_STATIC_NICK | G_PARAM_STATIC_BLURB | G_PARAM_READABLE));
#line 6 "/home/fborges/checkout/gnome-boxes/src/icon-view-child.vala"
	BoxesIconViewChild_private_offset = g_type_class_get_instance_private_offset (klass);
#line 6 "/home/fborges/checkout/gnome-boxes/src/icon-view-child.vala"
	gtk_widget_class_set_template_from_resource (GTK_WIDGET_CLASS (klass), "/org/gnome/Boxes/ui/icon-view-child.ui");
#line 6 "/home/fborges/checkout/gnome-boxes/src/icon-view-child.vala"
	gtk_widget_class_bind_template_child_full (GTK_WIDGET_CLASS (klass), "selection_button", FALSE, BoxesIconViewChild_private_offset + G_STRUCT_OFFSET (BoxesIconViewChildPrivate, selection_button));
#line 6 "/home/fborges/checkout/gnome-boxes/src/icon-view-child.vala"
	gtk_widget_class_bind_template_child_full (GTK_WIDGET_CLASS (klass), "stack", FALSE, BoxesIconViewChild_private_offset + G_STRUCT_OFFSET (BoxesIconViewChildPrivate, stack));
#line 6 "/home/fborges/checkout/gnome-boxes/src/icon-view-child.vala"
	gtk_widget_class_bind_template_child_full (GTK_WIDGET_CLASS (klass), "thumbnail", FALSE, G_STRUCT_OFFSET (BoxesIconViewChild, thumbnail));
#line 6 "/home/fborges/checkout/gnome-boxes/src/icon-view-child.vala"
	gtk_widget_class_bind_template_child_full (GTK_WIDGET_CLASS (klass), "spinner", FALSE, BoxesIconViewChild_private_offset + G_STRUCT_OFFSET (BoxesIconViewChildPrivate, spinner));
#line 6 "/home/fborges/checkout/gnome-boxes/src/icon-view-child.vala"
	gtk_widget_class_bind_template_child_full (GTK_WIDGET_CLASS (klass), "favorite", FALSE, BoxesIconViewChild_private_offset + G_STRUCT_OFFSET (BoxesIconViewChildPrivate, favorite));
#line 6 "/home/fborges/checkout/gnome-boxes/src/icon-view-child.vala"
	gtk_widget_class_bind_template_child_full (GTK_WIDGET_CLASS (klass), "machine_name", FALSE, BoxesIconViewChild_private_offset + G_STRUCT_OFFSET (BoxesIconViewChildPrivate, machine_name));
#line 708 "icon-view-child.c"
}


static void boxes_icon_view_child_instance_init (BoxesIconViewChild * self) {
#line 6 "/home/fborges/checkout/gnome-boxes/src/icon-view-child.vala"
	self->priv = BOXES_ICON_VIEW_CHILD_GET_PRIVATE (self);
#line 6 "/home/fborges/checkout/gnome-boxes/src/icon-view-child.vala"
	gtk_widget_init_template (GTK_WIDGET (self));
#line 717 "icon-view-child.c"
}


static void boxes_icon_view_child_finalize (GObject * obj) {
	BoxesIconViewChild * self;
#line 6 "/home/fborges/checkout/gnome-boxes/src/icon-view-child.vala"
	self = G_TYPE_CHECK_INSTANCE_CAST (obj, BOXES_TYPE_ICON_VIEW_CHILD, BoxesIconViewChild);
#line 28 "/home/fborges/checkout/gnome-boxes/src/icon-view-child.vala"
	_g_object_unref0 (self->priv->_item);
#line 34 "/home/fborges/checkout/gnome-boxes/src/icon-view-child.vala"
	_g_object_unref0 (self->priv->selection_button);
#line 36 "/home/fborges/checkout/gnome-boxes/src/icon-view-child.vala"
	_g_object_unref0 (self->priv->stack);
#line 38 "/home/fborges/checkout/gnome-boxes/src/icon-view-child.vala"
	_g_object_unref0 (self->thumbnail);
#line 40 "/home/fborges/checkout/gnome-boxes/src/icon-view-child.vala"
	_g_object_unref0 (self->priv->spinner);
#line 42 "/home/fborges/checkout/gnome-boxes/src/icon-view-child.vala"
	_g_object_unref0 (self->priv->favorite);
#line 44 "/home/fborges/checkout/gnome-boxes/src/icon-view-child.vala"
	_g_object_unref0 (self->priv->machine_name);
#line 46 "/home/fborges/checkout/gnome-boxes/src/icon-view-child.vala"
	_g_object_unref0 (self->priv->thumbnailer);
#line 48 "/home/fborges/checkout/gnome-boxes/src/icon-view-child.vala"
	_g_object_unref0 (self->priv->selected_binding);
#line 6 "/home/fborges/checkout/gnome-boxes/src/icon-view-child.vala"
	G_OBJECT_CLASS (boxes_icon_view_child_parent_class)->finalize (obj);
#line 745 "icon-view-child.c"
}


GType boxes_icon_view_child_get_type (void) {
	static volatile gsize boxes_icon_view_child_type_id__volatile = 0;
	if (g_once_init_enter (&boxes_icon_view_child_type_id__volatile)) {
		static const GTypeInfo g_define_type_info = { sizeof (BoxesIconViewChildClass), (GBaseInitFunc) NULL, (GBaseFinalizeFunc) NULL, (GClassInitFunc) boxes_icon_view_child_class_init, (GClassFinalizeFunc) NULL, NULL, sizeof (BoxesIconViewChild), 0, (GInstanceInitFunc) boxes_icon_view_child_instance_init, NULL };
		GType boxes_icon_view_child_type_id;
		boxes_icon_view_child_type_id = g_type_register_static (gtk_box_get_type (), "BoxesIconViewChild", &g_define_type_info, 0);
		g_once_init_leave (&boxes_icon_view_child_type_id__volatile, boxes_icon_view_child_type_id);
	}
	return boxes_icon_view_child_type_id__volatile;
}


static void _vala_boxes_icon_view_child_get_property (GObject * object, guint property_id, GValue * value, GParamSpec * pspec) {
	BoxesIconViewChild * self;
	self = G_TYPE_CHECK_INSTANCE_CAST (object, BOXES_TYPE_ICON_VIEW_CHILD, BoxesIconViewChild);
#line 6 "/home/fborges/checkout/gnome-boxes/src/icon-view-child.vala"
	switch (property_id) {
#line 6 "/home/fborges/checkout/gnome-boxes/src/icon-view-child.vala"
		case BOXES_ICON_VIEW_CHILD_SELECTION_MODE_PROPERTY:
#line 6 "/home/fborges/checkout/gnome-boxes/src/icon-view-child.vala"
		g_value_set_boolean (value, boxes_icon_view_child_get_selection_mode (self));
#line 6 "/home/fborges/checkout/gnome-boxes/src/icon-view-child.vala"
		break;
#line 6 "/home/fborges/checkout/gnome-boxes/src/icon-view-child.vala"
		case BOXES_ICON_VIEW_CHILD_SELECTED_PROPERTY:
#line 6 "/home/fborges/checkout/gnome-boxes/src/icon-view-child.vala"
		g_value_set_boolean (value, boxes_icon_view_child_get_selected (self));
#line 6 "/home/fborges/checkout/gnome-boxes/src/icon-view-child.vala"
		break;
#line 6 "/home/fborges/checkout/gnome-boxes/src/icon-view-child.vala"
		case BOXES_ICON_VIEW_CHILD_ITEM_PROPERTY:
#line 6 "/home/fborges/checkout/gnome-boxes/src/icon-view-child.vala"
		g_value_set_object (value, boxes_icon_view_child_get_item (self));
#line 6 "/home/fborges/checkout/gnome-boxes/src/icon-view-child.vala"
		break;
#line 784 "icon-view-child.c"
		default:
#line 6 "/home/fborges/checkout/gnome-boxes/src/icon-view-child.vala"
		G_OBJECT_WARN_INVALID_PROPERTY_ID (object, property_id, pspec);
#line 6 "/home/fborges/checkout/gnome-boxes/src/icon-view-child.vala"
		break;
#line 790 "icon-view-child.c"
	}
}


static void _vala_boxes_icon_view_child_set_property (GObject * object, guint property_id, const GValue * value, GParamSpec * pspec) {
	BoxesIconViewChild * self;
	self = G_TYPE_CHECK_INSTANCE_CAST (object, BOXES_TYPE_ICON_VIEW_CHILD, BoxesIconViewChild);
#line 6 "/home/fborges/checkout/gnome-boxes/src/icon-view-child.vala"
	switch (property_id) {
#line 6 "/home/fborges/checkout/gnome-boxes/src/icon-view-child.vala"
		case BOXES_ICON_VIEW_CHILD_SELECTION_MODE_PROPERTY:
#line 6 "/home/fborges/checkout/gnome-boxes/src/icon-view-child.vala"
		boxes_icon_view_child_set_selection_mode (self, g_value_get_boolean (value));
#line 6 "/home/fborges/checkout/gnome-boxes/src/icon-view-child.vala"
		break;
#line 6 "/home/fborges/checkout/gnome-boxes/src/icon-view-child.vala"
		case BOXES_ICON_VIEW_CHILD_SELECTED_PROPERTY:
#line 6 "/home/fborges/checkout/gnome-boxes/src/icon-view-child.vala"
		boxes_icon_view_child_set_selected (self, g_value_get_boolean (value));
#line 6 "/home/fborges/checkout/gnome-boxes/src/icon-view-child.vala"
		break;
#line 6 "/home/fborges/checkout/gnome-boxes/src/icon-view-child.vala"
		case BOXES_ICON_VIEW_CHILD_ITEM_PROPERTY:
#line 6 "/home/fborges/checkout/gnome-boxes/src/icon-view-child.vala"
		boxes_icon_view_child_set_item (self, g_value_get_object (value));
#line 6 "/home/fborges/checkout/gnome-boxes/src/icon-view-child.vala"
		break;
#line 818 "icon-view-child.c"
		default:
#line 6 "/home/fborges/checkout/gnome-boxes/src/icon-view-child.vala"
		G_OBJECT_WARN_INVALID_PROPERTY_ID (object, property_id, pspec);
#line 6 "/home/fborges/checkout/gnome-boxes/src/icon-view-child.vala"
		break;
#line 824 "icon-view-child.c"
	}
}


static void _vala_array_destroy (gpointer array, gint array_length, GDestroyNotify destroy_func) {
	if ((array != NULL) && (destroy_func != NULL)) {
		int i;
		for (i = 0; i < array_length; i = i + 1) {
			if (((gpointer*) array)[i] != NULL) {
				destroy_func (((gpointer*) array)[i]);
			}
		}
	}
}


static void _vala_array_free (gpointer array, gint array_length, GDestroyNotify destroy_func) {
	_vala_array_destroy (array, array_length, destroy_func);
	g_free (array);
}



