/* properties-page-widget.c generated by valac 0.38.4, the Vala compiler
 * generated from properties-page-widget.vala, do not modify */

/* This file is part of GNOME Boxes. License: LGPLv2+*/

#include <glib.h>
#include <glib-object.h>
#include <gtk/gtk.h>
#include <glib/gi18n-lib.h>
#include <stdlib.h>
#include <string.h>


#define BOXES_TYPE_PROPERTIES_PAGE_WIDGET (boxes_properties_page_widget_get_type ())
#define BOXES_PROPERTIES_PAGE_WIDGET(obj) (G_TYPE_CHECK_INSTANCE_CAST ((obj), BOXES_TYPE_PROPERTIES_PAGE_WIDGET, BoxesPropertiesPageWidget))
#define BOXES_PROPERTIES_PAGE_WIDGET_CLASS(klass) (G_TYPE_CHECK_CLASS_CAST ((klass), BOXES_TYPE_PROPERTIES_PAGE_WIDGET, BoxesPropertiesPageWidgetClass))
#define BOXES_IS_PROPERTIES_PAGE_WIDGET(obj) (G_TYPE_CHECK_INSTANCE_TYPE ((obj), BOXES_TYPE_PROPERTIES_PAGE_WIDGET))
#define BOXES_IS_PROPERTIES_PAGE_WIDGET_CLASS(klass) (G_TYPE_CHECK_CLASS_TYPE ((klass), BOXES_TYPE_PROPERTIES_PAGE_WIDGET))
#define BOXES_PROPERTIES_PAGE_WIDGET_GET_CLASS(obj) (G_TYPE_INSTANCE_GET_CLASS ((obj), BOXES_TYPE_PROPERTIES_PAGE_WIDGET, BoxesPropertiesPageWidgetClass))

typedef struct _BoxesPropertiesPageWidget BoxesPropertiesPageWidget;
typedef struct _BoxesPropertiesPageWidgetClass BoxesPropertiesPageWidgetClass;
typedef struct _BoxesPropertiesPageWidgetPrivate BoxesPropertiesPageWidgetPrivate;

#define BOXES_TYPE_PROPERTY (boxes_property_get_type ())
#define BOXES_PROPERTY(obj) (G_TYPE_CHECK_INSTANCE_CAST ((obj), BOXES_TYPE_PROPERTY, BoxesProperty))
#define BOXES_PROPERTY_CLASS(klass) (G_TYPE_CHECK_CLASS_CAST ((klass), BOXES_TYPE_PROPERTY, BoxesPropertyClass))
#define BOXES_IS_PROPERTY(obj) (G_TYPE_CHECK_INSTANCE_TYPE ((obj), BOXES_TYPE_PROPERTY))
#define BOXES_IS_PROPERTY_CLASS(klass) (G_TYPE_CHECK_CLASS_TYPE ((klass), BOXES_TYPE_PROPERTY))
#define BOXES_PROPERTY_GET_CLASS(obj) (G_TYPE_INSTANCE_GET_CLASS ((obj), BOXES_TYPE_PROPERTY, BoxesPropertyClass))

typedef struct _BoxesProperty BoxesProperty;
typedef struct _BoxesPropertyClass BoxesPropertyClass;
enum  {
	BOXES_PROPERTIES_PAGE_WIDGET_0_PROPERTY,
	BOXES_PROPERTIES_PAGE_WIDGET_NUM_PROPERTIES
};
static GParamSpec* boxes_properties_page_widget_properties[BOXES_PROPERTIES_PAGE_WIDGET_NUM_PROPERTIES];
#define _g_object_unref0(var) ((var == NULL) ? NULL : (var = (g_object_unref (var), NULL)))
#define __g_list_free__g_object_unref0_0(var) ((var == NULL) ? NULL : (var = (_g_list_free__g_object_unref0_ (var), NULL)))

#define BOXES_TYPE_PROPERTIES_PAGE (boxes_properties_page_get_type ())

#define BOXES_TYPE_COLLECTION_ITEM (boxes_collection_item_get_type ())
#define BOXES_COLLECTION_ITEM(obj) (G_TYPE_CHECK_INSTANCE_CAST ((obj), BOXES_TYPE_COLLECTION_ITEM, BoxesCollectionItem))
#define BOXES_COLLECTION_ITEM_CLASS(klass) (G_TYPE_CHECK_CLASS_CAST ((klass), BOXES_TYPE_COLLECTION_ITEM, BoxesCollectionItemClass))
#define BOXES_IS_COLLECTION_ITEM(obj) (G_TYPE_CHECK_INSTANCE_TYPE ((obj), BOXES_TYPE_COLLECTION_ITEM))
#define BOXES_IS_COLLECTION_ITEM_CLASS(klass) (G_TYPE_CHECK_CLASS_TYPE ((klass), BOXES_TYPE_COLLECTION_ITEM))
#define BOXES_COLLECTION_ITEM_GET_CLASS(obj) (G_TYPE_INSTANCE_GET_CLASS ((obj), BOXES_TYPE_COLLECTION_ITEM, BoxesCollectionItemClass))

typedef struct _BoxesCollectionItem BoxesCollectionItem;
typedef struct _BoxesCollectionItemClass BoxesCollectionItemClass;

#define BOXES_TYPE_MACHINE (boxes_machine_get_type ())
#define BOXES_MACHINE(obj) (G_TYPE_CHECK_INSTANCE_CAST ((obj), BOXES_TYPE_MACHINE, BoxesMachine))
#define BOXES_MACHINE_CLASS(klass) (G_TYPE_CHECK_CLASS_CAST ((klass), BOXES_TYPE_MACHINE, BoxesMachineClass))
#define BOXES_IS_MACHINE(obj) (G_TYPE_CHECK_INSTANCE_TYPE ((obj), BOXES_TYPE_MACHINE))
#define BOXES_IS_MACHINE_CLASS(klass) (G_TYPE_CHECK_CLASS_TYPE ((klass), BOXES_TYPE_MACHINE))
#define BOXES_MACHINE_GET_CLASS(obj) (G_TYPE_INSTANCE_GET_CLASS ((obj), BOXES_TYPE_MACHINE, BoxesMachineClass))

typedef struct _BoxesMachine BoxesMachine;
typedef struct _BoxesMachineClass BoxesMachineClass;
enum  {
	BOXES_PROPERTIES_PAGE_WIDGET_REFRESH_PROPERTIES_SIGNAL,
	BOXES_PROPERTIES_PAGE_WIDGET_NUM_SIGNALS
};
static guint boxes_properties_page_widget_signals[BOXES_PROPERTIES_PAGE_WIDGET_NUM_SIGNALS] = {0};

struct _BoxesPropertiesPageWidget {
	GtkBox parent_instance;
	BoxesPropertiesPageWidgetPrivate * priv;
	gboolean empty;
};

struct _BoxesPropertiesPageWidgetClass {
	GtkBoxClass parent_class;
};

struct _BoxesPropertiesPageWidgetPrivate {
	GtkGrid* grid;
	GList* properties;
};

typedef enum  {
	BOXES_PROPERTIES_PAGE_GENERAL,
	BOXES_PROPERTIES_PAGE_SYSTEM,
	BOXES_PROPERTIES_PAGE_DEVICES,
	BOXES_PROPERTIES_PAGE_SNAPSHOTS,
	BOXES_PROPERTIES_PAGE_LAST
} BoxesPropertiesPage;


static gpointer boxes_properties_page_widget_parent_class = NULL;

GType boxes_properties_page_widget_get_type (void) G_GNUC_CONST;
GType boxes_property_get_type (void) G_GNUC_CONST;
#define BOXES_PROPERTIES_PAGE_WIDGET_GET_PRIVATE(o) (G_TYPE_INSTANCE_GET_PRIVATE ((o), BOXES_TYPE_PROPERTIES_PAGE_WIDGET, BoxesPropertiesPageWidgetPrivate))
static void _g_object_unref0_ (gpointer var);
static inline void _g_list_free__g_object_unref0_ (GList* self);
GType boxes_properties_page_get_type (void) G_GNUC_CONST;
GType boxes_collection_item_get_type (void) G_GNUC_CONST;
GType boxes_machine_get_type (void) G_GNUC_CONST;
BoxesPropertiesPageWidget* boxes_properties_page_widget_new (BoxesPropertiesPage page, BoxesMachine* machine);
BoxesPropertiesPageWidget* boxes_properties_page_widget_construct (GType object_type, BoxesPropertiesPage page, BoxesMachine* machine);
GList* boxes_machine_get_properties (BoxesMachine* self, BoxesPropertiesPage page);
const gchar* boxes_property_get_description (BoxesProperty* self);
GtkAlign boxes_property_get_description_alignment (BoxesProperty* self);
GtkWidget* boxes_property_get_widget (BoxesProperty* self);
GtkWidget* boxes_property_get_extra_widget (BoxesProperty* self);
static void _____lambda124_ (BoxesPropertiesPageWidget* self);
static void ______lambda124__boxes_property_refresh_properties (BoxesProperty* _sender, gpointer self);
gboolean boxes_properties_page_widget_flush_changes (BoxesPropertiesPageWidget* self);
void boxes_property_flush (BoxesProperty* self);
gboolean boxes_property_get_reboot_required (BoxesProperty* self);
static void boxes_properties_page_widget_finalize (GObject * obj);


static void _g_object_unref0_ (gpointer var) {
#line 8 "/home/fborges/checkout/gnome-boxes/src/properties-page-widget.vala"
	(var == NULL) ? NULL : (var = (g_object_unref (var), NULL));
#line 122 "properties-page-widget.c"
}


static inline void _g_list_free__g_object_unref0_ (GList* self) {
#line 8 "/home/fborges/checkout/gnome-boxes/src/properties-page-widget.vala"
	g_list_free_full (self, (GDestroyNotify) _g_object_unref0_);
#line 129 "properties-page-widget.c"
}


static gpointer _g_object_ref0 (gpointer self) {
#line 48 "/home/fborges/checkout/gnome-boxes/src/properties-page-widget.vala"
	return self ? g_object_ref (self) : NULL;
#line 136 "properties-page-widget.c"
}


static void _____lambda124_ (BoxesPropertiesPageWidget* self) {
#line 73 "/home/fborges/checkout/gnome-boxes/src/properties-page-widget.vala"
	g_signal_emit (self, boxes_properties_page_widget_signals[BOXES_PROPERTIES_PAGE_WIDGET_REFRESH_PROPERTIES_SIGNAL], 0);
#line 143 "properties-page-widget.c"
}


static void ______lambda124__boxes_property_refresh_properties (BoxesProperty* _sender, gpointer self) {
#line 72 "/home/fborges/checkout/gnome-boxes/src/properties-page-widget.vala"
	_____lambda124_ ((BoxesPropertiesPageWidget*) self);
#line 150 "properties-page-widget.c"
}


BoxesPropertiesPageWidget* boxes_properties_page_widget_construct (GType object_type, BoxesPropertiesPage page, BoxesMachine* machine) {
	BoxesPropertiesPageWidget * self = NULL;
	BoxesPropertiesPage _tmp0_;
	GtkStyleContext* _tmp1_;
	GtkGrid* _tmp2_;
	GtkGrid* _tmp3_;
	GtkGrid* _tmp4_;
	GtkGrid* _tmp5_;
	GtkScrolledWindow* scrolled_win = NULL;
	GtkScrolledWindow* _tmp6_;
	GtkScrolledWindow* _tmp7_;
	GtkScrolledWindow* _tmp8_;
	GtkScrolledWindow* _tmp9_;
	GtkScrolledWindow* _tmp10_;
	GtkGrid* _tmp11_;
	GtkScrolledWindow* _tmp12_;
	BoxesMachine* _tmp13_;
	BoxesPropertiesPage _tmp14_;
	GList* _tmp15_;
	GList* _tmp16_;
	guint _tmp17_;
	gboolean _tmp18_;
#line 12 "/home/fborges/checkout/gnome-boxes/src/properties-page-widget.vala"
	g_return_val_if_fail (machine != NULL, NULL);
#line 12 "/home/fborges/checkout/gnome-boxes/src/properties-page-widget.vala"
	self = (BoxesPropertiesPageWidget*) g_object_new (object_type, NULL);
#line 13 "/home/fborges/checkout/gnome-boxes/src/properties-page-widget.vala"
	_tmp0_ = page;
#line 13 "/home/fborges/checkout/gnome-boxes/src/properties-page-widget.vala"
	switch (_tmp0_) {
#line 13 "/home/fborges/checkout/gnome-boxes/src/properties-page-widget.vala"
		case BOXES_PROPERTIES_PAGE_GENERAL:
#line 186 "properties-page-widget.c"
		{
#line 15 "/home/fborges/checkout/gnome-boxes/src/properties-page-widget.vala"
			gtk_widget_set_name ((GtkWidget*) self, _ ("General"));
#line 16 "/home/fborges/checkout/gnome-boxes/src/properties-page-widget.vala"
			break;
#line 192 "properties-page-widget.c"
		}
#line 13 "/home/fborges/checkout/gnome-boxes/src/properties-page-widget.vala"
		case BOXES_PROPERTIES_PAGE_SYSTEM:
#line 196 "properties-page-widget.c"
		{
#line 19 "/home/fborges/checkout/gnome-boxes/src/properties-page-widget.vala"
			gtk_widget_set_name ((GtkWidget*) self, _ ("System"));
#line 20 "/home/fborges/checkout/gnome-boxes/src/properties-page-widget.vala"
			break;
#line 202 "properties-page-widget.c"
		}
#line 13 "/home/fborges/checkout/gnome-boxes/src/properties-page-widget.vala"
		case BOXES_PROPERTIES_PAGE_DEVICES:
#line 206 "properties-page-widget.c"
		{
#line 23 "/home/fborges/checkout/gnome-boxes/src/properties-page-widget.vala"
			gtk_widget_set_name ((GtkWidget*) self, _ ("Devices & Shares"));
#line 24 "/home/fborges/checkout/gnome-boxes/src/properties-page-widget.vala"
			break;
#line 212 "properties-page-widget.c"
		}
#line 13 "/home/fborges/checkout/gnome-boxes/src/properties-page-widget.vala"
		case BOXES_PROPERTIES_PAGE_SNAPSHOTS:
#line 216 "properties-page-widget.c"
		{
#line 27 "/home/fborges/checkout/gnome-boxes/src/properties-page-widget.vala"
			gtk_widget_set_name ((GtkWidget*) self, _ ("Snapshots"));
#line 28 "/home/fborges/checkout/gnome-boxes/src/properties-page-widget.vala"
			break;
#line 222 "properties-page-widget.c"
		}
		default:
#line 13 "/home/fborges/checkout/gnome-boxes/src/properties-page-widget.vala"
		break;
#line 227 "properties-page-widget.c"
	}
#line 31 "/home/fborges/checkout/gnome-boxes/src/properties-page-widget.vala"
	_tmp1_ = gtk_widget_get_style_context ((GtkWidget*) self);
#line 31 "/home/fborges/checkout/gnome-boxes/src/properties-page-widget.vala"
	gtk_style_context_add_class (_tmp1_, "transparent-bg");
#line 33 "/home/fborges/checkout/gnome-boxes/src/properties-page-widget.vala"
	_tmp2_ = (GtkGrid*) gtk_grid_new ();
#line 33 "/home/fborges/checkout/gnome-boxes/src/properties-page-widget.vala"
	g_object_ref_sink (_tmp2_);
#line 33 "/home/fborges/checkout/gnome-boxes/src/properties-page-widget.vala"
	_g_object_unref0 (self->priv->grid);
#line 33 "/home/fborges/checkout/gnome-boxes/src/properties-page-widget.vala"
	self->priv->grid = _tmp2_;
#line 34 "/home/fborges/checkout/gnome-boxes/src/properties-page-widget.vala"
	_tmp3_ = self->priv->grid;
#line 34 "/home/fborges/checkout/gnome-boxes/src/properties-page-widget.vala"
	g_object_set ((GtkWidget*) _tmp3_, "margin", 20, NULL);
#line 35 "/home/fborges/checkout/gnome-boxes/src/properties-page-widget.vala"
	_tmp4_ = self->priv->grid;
#line 35 "/home/fborges/checkout/gnome-boxes/src/properties-page-widget.vala"
	gtk_grid_set_row_spacing (_tmp4_, 10);
#line 36 "/home/fborges/checkout/gnome-boxes/src/properties-page-widget.vala"
	_tmp5_ = self->priv->grid;
#line 36 "/home/fborges/checkout/gnome-boxes/src/properties-page-widget.vala"
	gtk_grid_set_column_spacing (_tmp5_, 20);
#line 37 "/home/fborges/checkout/gnome-boxes/src/properties-page-widget.vala"
	_tmp6_ = (GtkScrolledWindow*) gtk_scrolled_window_new (NULL, NULL);
#line 37 "/home/fborges/checkout/gnome-boxes/src/properties-page-widget.vala"
	g_object_ref_sink (_tmp6_);
#line 37 "/home/fborges/checkout/gnome-boxes/src/properties-page-widget.vala"
	scrolled_win = _tmp6_;
#line 38 "/home/fborges/checkout/gnome-boxes/src/properties-page-widget.vala"
	_tmp7_ = scrolled_win;
#line 38 "/home/fborges/checkout/gnome-boxes/src/properties-page-widget.vala"
	gtk_widget_set_margin_start ((GtkWidget*) _tmp7_, 20);
#line 39 "/home/fborges/checkout/gnome-boxes/src/properties-page-widget.vala"
	_tmp8_ = scrolled_win;
#line 39 "/home/fborges/checkout/gnome-boxes/src/properties-page-widget.vala"
	gtk_widget_set_margin_end ((GtkWidget*) _tmp8_, 20);
#line 40 "/home/fborges/checkout/gnome-boxes/src/properties-page-widget.vala"
	_tmp9_ = scrolled_win;
#line 40 "/home/fborges/checkout/gnome-boxes/src/properties-page-widget.vala"
	gtk_scrolled_window_set_policy (_tmp9_, GTK_POLICY_NEVER, GTK_POLICY_AUTOMATIC);
#line 41 "/home/fborges/checkout/gnome-boxes/src/properties-page-widget.vala"
	_tmp10_ = scrolled_win;
#line 41 "/home/fborges/checkout/gnome-boxes/src/properties-page-widget.vala"
	_tmp11_ = self->priv->grid;
#line 41 "/home/fborges/checkout/gnome-boxes/src/properties-page-widget.vala"
	gtk_container_add ((GtkContainer*) _tmp10_, (GtkWidget*) _tmp11_);
#line 42 "/home/fborges/checkout/gnome-boxes/src/properties-page-widget.vala"
	_tmp12_ = scrolled_win;
#line 42 "/home/fborges/checkout/gnome-boxes/src/properties-page-widget.vala"
	gtk_box_pack_end ((GtkBox*) self, (GtkWidget*) _tmp12_, TRUE, TRUE, (guint) 0);
#line 44 "/home/fborges/checkout/gnome-boxes/src/properties-page-widget.vala"
	_tmp13_ = machine;
#line 44 "/home/fborges/checkout/gnome-boxes/src/properties-page-widget.vala"
	_tmp14_ = page;
#line 44 "/home/fborges/checkout/gnome-boxes/src/properties-page-widget.vala"
	_tmp15_ = boxes_machine_get_properties (_tmp13_, _tmp14_);
#line 44 "/home/fborges/checkout/gnome-boxes/src/properties-page-widget.vala"
	__g_list_free__g_object_unref0_0 (self->priv->properties);
#line 44 "/home/fborges/checkout/gnome-boxes/src/properties-page-widget.vala"
	self->priv->properties = _tmp15_;
#line 45 "/home/fborges/checkout/gnome-boxes/src/properties-page-widget.vala"
	_tmp16_ = self->priv->properties;
#line 45 "/home/fborges/checkout/gnome-boxes/src/properties-page-widget.vala"
	_tmp17_ = g_list_length (_tmp16_);
#line 45 "/home/fborges/checkout/gnome-boxes/src/properties-page-widget.vala"
	self->empty = _tmp17_ == ((guint) 0);
#line 46 "/home/fborges/checkout/gnome-boxes/src/properties-page-widget.vala"
	_tmp18_ = self->empty;
#line 46 "/home/fborges/checkout/gnome-boxes/src/properties-page-widget.vala"
	if (!_tmp18_) {
#line 301 "properties-page-widget.c"
		gint current_row = 0;
		GList* _tmp19_;
#line 47 "/home/fborges/checkout/gnome-boxes/src/properties-page-widget.vala"
		current_row = 1;
#line 48 "/home/fborges/checkout/gnome-boxes/src/properties-page-widget.vala"
		_tmp19_ = self->priv->properties;
#line 308 "properties-page-widget.c"
		{
			GList* property_collection = NULL;
			GList* property_it = NULL;
#line 48 "/home/fborges/checkout/gnome-boxes/src/properties-page-widget.vala"
			property_collection = _tmp19_;
#line 48 "/home/fborges/checkout/gnome-boxes/src/properties-page-widget.vala"
			for (property_it = property_collection; property_it != NULL; property_it = property_it->next) {
#line 316 "properties-page-widget.c"
				BoxesProperty* _tmp20_;
				BoxesProperty* property = NULL;
#line 48 "/home/fborges/checkout/gnome-boxes/src/properties-page-widget.vala"
				_tmp20_ = _g_object_ref0 ((BoxesProperty*) property_it->data);
#line 48 "/home/fborges/checkout/gnome-boxes/src/properties-page-widget.vala"
				property = _tmp20_;
#line 323 "properties-page-widget.c"
				{
					BoxesProperty* _tmp21_;
					const gchar* _tmp22_;
					const gchar* _tmp23_;
					GtkWidget* widget = NULL;
					BoxesProperty* _tmp56_;
					GtkWidget* _tmp57_;
					GtkWidget* _tmp58_;
					GtkWidget* _tmp59_;
					GtkWidget* _tmp60_;
					BoxesProperty* _tmp66_;
					gint _tmp67_;
#line 49 "/home/fborges/checkout/gnome-boxes/src/properties-page-widget.vala"
					_tmp21_ = property;
#line 49 "/home/fborges/checkout/gnome-boxes/src/properties-page-widget.vala"
					_tmp22_ = boxes_property_get_description (_tmp21_);
#line 49 "/home/fborges/checkout/gnome-boxes/src/properties-page-widget.vala"
					_tmp23_ = _tmp22_;
#line 49 "/home/fborges/checkout/gnome-boxes/src/properties-page-widget.vala"
					if (_tmp23_ != NULL) {
#line 344 "properties-page-widget.c"
						GtkLabel* label_name = NULL;
						BoxesProperty* _tmp24_;
						const gchar* _tmp25_;
						const gchar* _tmp26_;
						GtkLabel* _tmp27_;
						GtkLabel* _tmp28_;
						GtkStyleContext* _tmp29_;
						GtkLabel* _tmp30_;
						BoxesProperty* _tmp31_;
						GtkAlign _tmp32_;
						GtkAlign _tmp33_;
						GtkLabel* _tmp34_;
						GtkGrid* _tmp35_;
						GtkLabel* _tmp36_;
						gint _tmp37_;
						GtkWidget* widget = NULL;
						BoxesProperty* _tmp38_;
						GtkWidget* _tmp39_;
						GtkWidget* _tmp40_;
						GtkWidget* _tmp41_;
						GtkWidget* _tmp42_;
						GtkGrid* _tmp43_;
						GtkWidget* _tmp44_;
						gint _tmp45_;
						GtkLabel* _tmp46_;
						GtkWidget* _tmp47_;
#line 50 "/home/fborges/checkout/gnome-boxes/src/properties-page-widget.vala"
						_tmp24_ = property;
#line 50 "/home/fborges/checkout/gnome-boxes/src/properties-page-widget.vala"
						_tmp25_ = boxes_property_get_description (_tmp24_);
#line 50 "/home/fborges/checkout/gnome-boxes/src/properties-page-widget.vala"
						_tmp26_ = _tmp25_;
#line 50 "/home/fborges/checkout/gnome-boxes/src/properties-page-widget.vala"
						_tmp27_ = (GtkLabel*) gtk_label_new_with_mnemonic (_tmp26_);
#line 50 "/home/fborges/checkout/gnome-boxes/src/properties-page-widget.vala"
						g_object_ref_sink (_tmp27_);
#line 50 "/home/fborges/checkout/gnome-boxes/src/properties-page-widget.vala"
						label_name = _tmp27_;
#line 51 "/home/fborges/checkout/gnome-boxes/src/properties-page-widget.vala"
						_tmp28_ = label_name;
#line 51 "/home/fborges/checkout/gnome-boxes/src/properties-page-widget.vala"
						_tmp29_ = gtk_widget_get_style_context ((GtkWidget*) _tmp28_);
#line 51 "/home/fborges/checkout/gnome-boxes/src/properties-page-widget.vala"
						gtk_style_context_add_class (_tmp29_, "dim-label");
#line 52 "/home/fborges/checkout/gnome-boxes/src/properties-page-widget.vala"
						_tmp30_ = label_name;
#line 52 "/home/fborges/checkout/gnome-boxes/src/properties-page-widget.vala"
						_tmp31_ = property;
#line 52 "/home/fborges/checkout/gnome-boxes/src/properties-page-widget.vala"
						_tmp32_ = boxes_property_get_description_alignment (_tmp31_);
#line 52 "/home/fborges/checkout/gnome-boxes/src/properties-page-widget.vala"
						_tmp33_ = _tmp32_;
#line 52 "/home/fborges/checkout/gnome-boxes/src/properties-page-widget.vala"
						gtk_widget_set_halign ((GtkWidget*) _tmp30_, _tmp33_);
#line 53 "/home/fborges/checkout/gnome-boxes/src/properties-page-widget.vala"
						_tmp34_ = label_name;
#line 53 "/home/fborges/checkout/gnome-boxes/src/properties-page-widget.vala"
						gtk_widget_set_hexpand ((GtkWidget*) _tmp34_, FALSE);
#line 54 "/home/fborges/checkout/gnome-boxes/src/properties-page-widget.vala"
						_tmp35_ = self->priv->grid;
#line 54 "/home/fborges/checkout/gnome-boxes/src/properties-page-widget.vala"
						_tmp36_ = label_name;
#line 54 "/home/fborges/checkout/gnome-boxes/src/properties-page-widget.vala"
						_tmp37_ = current_row;
#line 54 "/home/fborges/checkout/gnome-boxes/src/properties-page-widget.vala"
						gtk_grid_attach (_tmp35_, (GtkWidget*) _tmp36_, 0, _tmp37_, 1, 1);
#line 55 "/home/fborges/checkout/gnome-boxes/src/properties-page-widget.vala"
						_tmp38_ = property;
#line 55 "/home/fborges/checkout/gnome-boxes/src/properties-page-widget.vala"
						_tmp39_ = boxes_property_get_widget (_tmp38_);
#line 55 "/home/fborges/checkout/gnome-boxes/src/properties-page-widget.vala"
						_tmp40_ = _tmp39_;
#line 55 "/home/fborges/checkout/gnome-boxes/src/properties-page-widget.vala"
						_tmp41_ = _g_object_ref0 (_tmp40_);
#line 55 "/home/fborges/checkout/gnome-boxes/src/properties-page-widget.vala"
						widget = _tmp41_;
#line 56 "/home/fborges/checkout/gnome-boxes/src/properties-page-widget.vala"
						_tmp42_ = widget;
#line 56 "/home/fborges/checkout/gnome-boxes/src/properties-page-widget.vala"
						gtk_widget_set_hexpand (_tmp42_, TRUE);
#line 57 "/home/fborges/checkout/gnome-boxes/src/properties-page-widget.vala"
						_tmp43_ = self->priv->grid;
#line 57 "/home/fborges/checkout/gnome-boxes/src/properties-page-widget.vala"
						_tmp44_ = widget;
#line 57 "/home/fborges/checkout/gnome-boxes/src/properties-page-widget.vala"
						_tmp45_ = current_row;
#line 57 "/home/fborges/checkout/gnome-boxes/src/properties-page-widget.vala"
						gtk_grid_attach (_tmp43_, _tmp44_, 1, _tmp45_, 1, 1);
#line 58 "/home/fborges/checkout/gnome-boxes/src/properties-page-widget.vala"
						_tmp46_ = label_name;
#line 58 "/home/fborges/checkout/gnome-boxes/src/properties-page-widget.vala"
						_tmp47_ = widget;
#line 58 "/home/fborges/checkout/gnome-boxes/src/properties-page-widget.vala"
						gtk_label_set_mnemonic_widget (_tmp46_, _tmp47_);
#line 49 "/home/fborges/checkout/gnome-boxes/src/properties-page-widget.vala"
						_g_object_unref0 (widget);
#line 49 "/home/fborges/checkout/gnome-boxes/src/properties-page-widget.vala"
						_g_object_unref0 (label_name);
#line 443 "properties-page-widget.c"
					} else {
						GtkWidget* widget = NULL;
						BoxesProperty* _tmp48_;
						GtkWidget* _tmp49_;
						GtkWidget* _tmp50_;
						GtkWidget* _tmp51_;
						GtkWidget* _tmp52_;
						GtkGrid* _tmp53_;
						GtkWidget* _tmp54_;
						gint _tmp55_;
#line 60 "/home/fborges/checkout/gnome-boxes/src/properties-page-widget.vala"
						_tmp48_ = property;
#line 60 "/home/fborges/checkout/gnome-boxes/src/properties-page-widget.vala"
						_tmp49_ = boxes_property_get_widget (_tmp48_);
#line 60 "/home/fborges/checkout/gnome-boxes/src/properties-page-widget.vala"
						_tmp50_ = _tmp49_;
#line 60 "/home/fborges/checkout/gnome-boxes/src/properties-page-widget.vala"
						_tmp51_ = _g_object_ref0 (_tmp50_);
#line 60 "/home/fborges/checkout/gnome-boxes/src/properties-page-widget.vala"
						widget = _tmp51_;
#line 61 "/home/fborges/checkout/gnome-boxes/src/properties-page-widget.vala"
						_tmp52_ = widget;
#line 61 "/home/fborges/checkout/gnome-boxes/src/properties-page-widget.vala"
						gtk_widget_set_hexpand (_tmp52_, TRUE);
#line 62 "/home/fborges/checkout/gnome-boxes/src/properties-page-widget.vala"
						_tmp53_ = self->priv->grid;
#line 62 "/home/fborges/checkout/gnome-boxes/src/properties-page-widget.vala"
						_tmp54_ = widget;
#line 62 "/home/fborges/checkout/gnome-boxes/src/properties-page-widget.vala"
						_tmp55_ = current_row;
#line 62 "/home/fborges/checkout/gnome-boxes/src/properties-page-widget.vala"
						gtk_grid_attach (_tmp53_, _tmp54_, 0, _tmp55_, 2, 1);
#line 49 "/home/fborges/checkout/gnome-boxes/src/properties-page-widget.vala"
						_g_object_unref0 (widget);
#line 478 "properties-page-widget.c"
					}
#line 65 "/home/fborges/checkout/gnome-boxes/src/properties-page-widget.vala"
					_tmp56_ = property;
#line 65 "/home/fborges/checkout/gnome-boxes/src/properties-page-widget.vala"
					_tmp57_ = boxes_property_get_extra_widget (_tmp56_);
#line 65 "/home/fborges/checkout/gnome-boxes/src/properties-page-widget.vala"
					_tmp58_ = _tmp57_;
#line 65 "/home/fborges/checkout/gnome-boxes/src/properties-page-widget.vala"
					_tmp59_ = _g_object_ref0 (_tmp58_);
#line 65 "/home/fborges/checkout/gnome-boxes/src/properties-page-widget.vala"
					widget = _tmp59_;
#line 66 "/home/fborges/checkout/gnome-boxes/src/properties-page-widget.vala"
					_tmp60_ = widget;
#line 66 "/home/fborges/checkout/gnome-boxes/src/properties-page-widget.vala"
					if (_tmp60_ != NULL) {
#line 494 "properties-page-widget.c"
						gint _tmp61_;
						GtkWidget* _tmp62_;
						GtkGrid* _tmp63_;
						GtkWidget* _tmp64_;
						gint _tmp65_;
#line 67 "/home/fborges/checkout/gnome-boxes/src/properties-page-widget.vala"
						_tmp61_ = current_row;
#line 67 "/home/fborges/checkout/gnome-boxes/src/properties-page-widget.vala"
						current_row = _tmp61_ + 1;
#line 68 "/home/fborges/checkout/gnome-boxes/src/properties-page-widget.vala"
						_tmp62_ = widget;
#line 68 "/home/fborges/checkout/gnome-boxes/src/properties-page-widget.vala"
						gtk_widget_set_hexpand (_tmp62_, TRUE);
#line 69 "/home/fborges/checkout/gnome-boxes/src/properties-page-widget.vala"
						_tmp63_ = self->priv->grid;
#line 69 "/home/fborges/checkout/gnome-boxes/src/properties-page-widget.vala"
						_tmp64_ = widget;
#line 69 "/home/fborges/checkout/gnome-boxes/src/properties-page-widget.vala"
						_tmp65_ = current_row;
#line 69 "/home/fborges/checkout/gnome-boxes/src/properties-page-widget.vala"
						gtk_grid_attach (_tmp63_, _tmp64_, 0, _tmp65_, 2, 1);
#line 516 "properties-page-widget.c"
					}
#line 72 "/home/fborges/checkout/gnome-boxes/src/properties-page-widget.vala"
					_tmp66_ = property;
#line 72 "/home/fborges/checkout/gnome-boxes/src/properties-page-widget.vala"
					g_signal_connect_object (_tmp66_, "refresh-properties", (GCallback) ______lambda124__boxes_property_refresh_properties, self, 0);
#line 75 "/home/fborges/checkout/gnome-boxes/src/properties-page-widget.vala"
					_tmp67_ = current_row;
#line 75 "/home/fborges/checkout/gnome-boxes/src/properties-page-widget.vala"
					current_row = _tmp67_ + 1;
#line 48 "/home/fborges/checkout/gnome-boxes/src/properties-page-widget.vala"
					_g_object_unref0 (widget);
#line 48 "/home/fborges/checkout/gnome-boxes/src/properties-page-widget.vala"
					_g_object_unref0 (property);
#line 530 "properties-page-widget.c"
				}
			}
		}
	}
#line 79 "/home/fborges/checkout/gnome-boxes/src/properties-page-widget.vala"
	gtk_widget_show_all ((GtkWidget*) self);
#line 12 "/home/fborges/checkout/gnome-boxes/src/properties-page-widget.vala"
	_g_object_unref0 (scrolled_win);
#line 12 "/home/fborges/checkout/gnome-boxes/src/properties-page-widget.vala"
	return self;
#line 541 "properties-page-widget.c"
}


BoxesPropertiesPageWidget* boxes_properties_page_widget_new (BoxesPropertiesPage page, BoxesMachine* machine) {
#line 12 "/home/fborges/checkout/gnome-boxes/src/properties-page-widget.vala"
	return boxes_properties_page_widget_construct (BOXES_TYPE_PROPERTIES_PAGE_WIDGET, page, machine);
#line 548 "properties-page-widget.c"
}


gboolean boxes_properties_page_widget_flush_changes (BoxesPropertiesPageWidget* self) {
	gboolean result = FALSE;
	gboolean reboot_required = FALSE;
	GList* _tmp0_;
#line 82 "/home/fborges/checkout/gnome-boxes/src/properties-page-widget.vala"
	g_return_val_if_fail (self != NULL, FALSE);
#line 83 "/home/fborges/checkout/gnome-boxes/src/properties-page-widget.vala"
	reboot_required = FALSE;
#line 85 "/home/fborges/checkout/gnome-boxes/src/properties-page-widget.vala"
	_tmp0_ = self->priv->properties;
#line 562 "properties-page-widget.c"
	{
		GList* property_collection = NULL;
		GList* property_it = NULL;
#line 85 "/home/fborges/checkout/gnome-boxes/src/properties-page-widget.vala"
		property_collection = _tmp0_;
#line 85 "/home/fborges/checkout/gnome-boxes/src/properties-page-widget.vala"
		for (property_it = property_collection; property_it != NULL; property_it = property_it->next) {
#line 570 "properties-page-widget.c"
			BoxesProperty* _tmp1_;
			BoxesProperty* property = NULL;
#line 85 "/home/fborges/checkout/gnome-boxes/src/properties-page-widget.vala"
			_tmp1_ = _g_object_ref0 ((BoxesProperty*) property_it->data);
#line 85 "/home/fborges/checkout/gnome-boxes/src/properties-page-widget.vala"
			property = _tmp1_;
#line 577 "properties-page-widget.c"
			{
				BoxesProperty* _tmp2_;
				gboolean _tmp3_;
				BoxesProperty* _tmp4_;
				gboolean _tmp5_;
				gboolean _tmp6_;
#line 86 "/home/fborges/checkout/gnome-boxes/src/properties-page-widget.vala"
				_tmp2_ = property;
#line 86 "/home/fborges/checkout/gnome-boxes/src/properties-page-widget.vala"
				boxes_property_flush (_tmp2_);
#line 87 "/home/fborges/checkout/gnome-boxes/src/properties-page-widget.vala"
				_tmp3_ = reboot_required;
#line 87 "/home/fborges/checkout/gnome-boxes/src/properties-page-widget.vala"
				_tmp4_ = property;
#line 87 "/home/fborges/checkout/gnome-boxes/src/properties-page-widget.vala"
				_tmp5_ = boxes_property_get_reboot_required (_tmp4_);
#line 87 "/home/fborges/checkout/gnome-boxes/src/properties-page-widget.vala"
				_tmp6_ = _tmp5_;
#line 87 "/home/fborges/checkout/gnome-boxes/src/properties-page-widget.vala"
				reboot_required = _tmp3_ | _tmp6_;
#line 85 "/home/fborges/checkout/gnome-boxes/src/properties-page-widget.vala"
				_g_object_unref0 (property);
#line 600 "properties-page-widget.c"
			}
		}
	}
#line 90 "/home/fborges/checkout/gnome-boxes/src/properties-page-widget.vala"
	result = reboot_required;
#line 90 "/home/fborges/checkout/gnome-boxes/src/properties-page-widget.vala"
	return result;
#line 608 "properties-page-widget.c"
}


static void boxes_properties_page_widget_class_init (BoxesPropertiesPageWidgetClass * klass) {
#line 4 "/home/fborges/checkout/gnome-boxes/src/properties-page-widget.vala"
	boxes_properties_page_widget_parent_class = g_type_class_peek_parent (klass);
#line 4 "/home/fborges/checkout/gnome-boxes/src/properties-page-widget.vala"
	g_type_class_add_private (klass, sizeof (BoxesPropertiesPageWidgetPrivate));
#line 4 "/home/fborges/checkout/gnome-boxes/src/properties-page-widget.vala"
	G_OBJECT_CLASS (klass)->finalize = boxes_properties_page_widget_finalize;
#line 4 "/home/fborges/checkout/gnome-boxes/src/properties-page-widget.vala"
	boxes_properties_page_widget_signals[BOXES_PROPERTIES_PAGE_WIDGET_REFRESH_PROPERTIES_SIGNAL] = g_signal_new ("refresh-properties", BOXES_TYPE_PROPERTIES_PAGE_WIDGET, G_SIGNAL_RUN_LAST, 0, NULL, NULL, g_cclosure_marshal_VOID__VOID, G_TYPE_NONE, 0);
#line 621 "properties-page-widget.c"
}


static void boxes_properties_page_widget_instance_init (BoxesPropertiesPageWidget * self) {
#line 4 "/home/fborges/checkout/gnome-boxes/src/properties-page-widget.vala"
	self->priv = BOXES_PROPERTIES_PAGE_WIDGET_GET_PRIVATE (self);
#line 628 "properties-page-widget.c"
}


static void boxes_properties_page_widget_finalize (GObject * obj) {
	BoxesPropertiesPageWidget * self;
#line 4 "/home/fborges/checkout/gnome-boxes/src/properties-page-widget.vala"
	self = G_TYPE_CHECK_INSTANCE_CAST (obj, BOXES_TYPE_PROPERTIES_PAGE_WIDGET, BoxesPropertiesPageWidget);
#line 7 "/home/fborges/checkout/gnome-boxes/src/properties-page-widget.vala"
	_g_object_unref0 (self->priv->grid);
#line 8 "/home/fborges/checkout/gnome-boxes/src/properties-page-widget.vala"
	__g_list_free__g_object_unref0_0 (self->priv->properties);
#line 4 "/home/fborges/checkout/gnome-boxes/src/properties-page-widget.vala"
	G_OBJECT_CLASS (boxes_properties_page_widget_parent_class)->finalize (obj);
#line 642 "properties-page-widget.c"
}


GType boxes_properties_page_widget_get_type (void) {
	static volatile gsize boxes_properties_page_widget_type_id__volatile = 0;
	if (g_once_init_enter (&boxes_properties_page_widget_type_id__volatile)) {
		static const GTypeInfo g_define_type_info = { sizeof (BoxesPropertiesPageWidgetClass), (GBaseInitFunc) NULL, (GBaseFinalizeFunc) NULL, (GClassInitFunc) boxes_properties_page_widget_class_init, (GClassFinalizeFunc) NULL, NULL, sizeof (BoxesPropertiesPageWidget), 0, (GInstanceInitFunc) boxes_properties_page_widget_instance_init, NULL };
		GType boxes_properties_page_widget_type_id;
		boxes_properties_page_widget_type_id = g_type_register_static (gtk_box_get_type (), "BoxesPropertiesPageWidget", &g_define_type_info, 0);
		g_once_init_leave (&boxes_properties_page_widget_type_id__volatile, boxes_properties_page_widget_type_id);
	}
	return boxes_properties_page_widget_type_id__volatile;
}



