/* libvirt-machine-properties.c generated by valac 0.38.4, the Vala compiler
 * generated from libvirt-machine-properties.vala, do not modify */

/* This file is part of GNOME Boxes. License: LGPLv2+*/

#include <glib.h>
#include <glib-object.h>
#include <libvirt-gconfig/libvirt-gconfig.h>
#include <libvirt-gobject/libvirt-gobject.h>
#include <stdlib.h>
#include <string.h>
#include <gio/gio.h>
#include <gdk-pixbuf/gdk-pixbuf.h>
#include <libcommon.h>
#include <glib/gstdio.h>
#include <glib/gi18n-lib.h>
#include <gtk/gtk.h>
#include <pango/pango.h>
#include <osinfo/osinfo.h>
#include <float.h>
#include <math.h>


#define BOXES_TYPE_IPROPERTIES_PROVIDER (boxes_iproperties_provider_get_type ())
#define BOXES_IPROPERTIES_PROVIDER(obj) (G_TYPE_CHECK_INSTANCE_CAST ((obj), BOXES_TYPE_IPROPERTIES_PROVIDER, BoxesIPropertiesProvider))
#define BOXES_IS_IPROPERTIES_PROVIDER(obj) (G_TYPE_CHECK_INSTANCE_TYPE ((obj), BOXES_TYPE_IPROPERTIES_PROVIDER))
#define BOXES_IPROPERTIES_PROVIDER_GET_INTERFACE(obj) (G_TYPE_INSTANCE_GET_INTERFACE ((obj), BOXES_TYPE_IPROPERTIES_PROVIDER, BoxesIPropertiesProviderIface))

typedef struct _BoxesIPropertiesProvider BoxesIPropertiesProvider;
typedef struct _BoxesIPropertiesProviderIface BoxesIPropertiesProviderIface;

#define BOXES_TYPE_PROPERTIES_PAGE (boxes_properties_page_get_type ())

#define BOXES_TYPE_PROPERTY (boxes_property_get_type ())
#define BOXES_PROPERTY(obj) (G_TYPE_CHECK_INSTANCE_CAST ((obj), BOXES_TYPE_PROPERTY, BoxesProperty))
#define BOXES_PROPERTY_CLASS(klass) (G_TYPE_CHECK_CLASS_CAST ((klass), BOXES_TYPE_PROPERTY, BoxesPropertyClass))
#define BOXES_IS_PROPERTY(obj) (G_TYPE_CHECK_INSTANCE_TYPE ((obj), BOXES_TYPE_PROPERTY))
#define BOXES_IS_PROPERTY_CLASS(klass) (G_TYPE_CHECK_CLASS_TYPE ((klass), BOXES_TYPE_PROPERTY))
#define BOXES_PROPERTY_GET_CLASS(obj) (G_TYPE_INSTANCE_GET_CLASS ((obj), BOXES_TYPE_PROPERTY, BoxesPropertyClass))

typedef struct _BoxesProperty BoxesProperty;
typedef struct _BoxesPropertyClass BoxesPropertyClass;

#define BOXES_TYPE_LIBVIRT_MACHINE_PROPERTIES (boxes_libvirt_machine_properties_get_type ())
#define BOXES_LIBVIRT_MACHINE_PROPERTIES(obj) (G_TYPE_CHECK_INSTANCE_CAST ((obj), BOXES_TYPE_LIBVIRT_MACHINE_PROPERTIES, BoxesLibvirtMachineProperties))
#define BOXES_LIBVIRT_MACHINE_PROPERTIES_CLASS(klass) (G_TYPE_CHECK_CLASS_CAST ((klass), BOXES_TYPE_LIBVIRT_MACHINE_PROPERTIES, BoxesLibvirtMachinePropertiesClass))
#define BOXES_IS_LIBVIRT_MACHINE_PROPERTIES(obj) (G_TYPE_CHECK_INSTANCE_TYPE ((obj), BOXES_TYPE_LIBVIRT_MACHINE_PROPERTIES))
#define BOXES_IS_LIBVIRT_MACHINE_PROPERTIES_CLASS(klass) (G_TYPE_CHECK_CLASS_TYPE ((klass), BOXES_TYPE_LIBVIRT_MACHINE_PROPERTIES))
#define BOXES_LIBVIRT_MACHINE_PROPERTIES_GET_CLASS(obj) (G_TYPE_INSTANCE_GET_CLASS ((obj), BOXES_TYPE_LIBVIRT_MACHINE_PROPERTIES, BoxesLibvirtMachinePropertiesClass))

typedef struct _BoxesLibvirtMachineProperties BoxesLibvirtMachineProperties;
typedef struct _BoxesLibvirtMachinePropertiesClass BoxesLibvirtMachinePropertiesClass;
typedef struct _BoxesLibvirtMachinePropertiesPrivate BoxesLibvirtMachinePropertiesPrivate;

#define BOXES_TYPE_COLLECTION_ITEM (boxes_collection_item_get_type ())
#define BOXES_COLLECTION_ITEM(obj) (G_TYPE_CHECK_INSTANCE_CAST ((obj), BOXES_TYPE_COLLECTION_ITEM, BoxesCollectionItem))
#define BOXES_COLLECTION_ITEM_CLASS(klass) (G_TYPE_CHECK_CLASS_CAST ((klass), BOXES_TYPE_COLLECTION_ITEM, BoxesCollectionItemClass))
#define BOXES_IS_COLLECTION_ITEM(obj) (G_TYPE_CHECK_INSTANCE_TYPE ((obj), BOXES_TYPE_COLLECTION_ITEM))
#define BOXES_IS_COLLECTION_ITEM_CLASS(klass) (G_TYPE_CHECK_CLASS_TYPE ((klass), BOXES_TYPE_COLLECTION_ITEM))
#define BOXES_COLLECTION_ITEM_GET_CLASS(obj) (G_TYPE_INSTANCE_GET_CLASS ((obj), BOXES_TYPE_COLLECTION_ITEM, BoxesCollectionItemClass))

typedef struct _BoxesCollectionItem BoxesCollectionItem;
typedef struct _BoxesCollectionItemClass BoxesCollectionItemClass;

#define BOXES_TYPE_MACHINE (boxes_machine_get_type ())
#define BOXES_MACHINE(obj) (G_TYPE_CHECK_INSTANCE_CAST ((obj), BOXES_TYPE_MACHINE, BoxesMachine))
#define BOXES_MACHINE_CLASS(klass) (G_TYPE_CHECK_CLASS_CAST ((klass), BOXES_TYPE_MACHINE, BoxesMachineClass))
#define BOXES_IS_MACHINE(obj) (G_TYPE_CHECK_INSTANCE_TYPE ((obj), BOXES_TYPE_MACHINE))
#define BOXES_IS_MACHINE_CLASS(klass) (G_TYPE_CHECK_CLASS_TYPE ((klass), BOXES_TYPE_MACHINE))
#define BOXES_MACHINE_GET_CLASS(obj) (G_TYPE_INSTANCE_GET_CLASS ((obj), BOXES_TYPE_MACHINE, BoxesMachineClass))

typedef struct _BoxesMachine BoxesMachine;
typedef struct _BoxesMachineClass BoxesMachineClass;

#define BOXES_TYPE_LIBVIRT_MACHINE (boxes_libvirt_machine_get_type ())
#define BOXES_LIBVIRT_MACHINE(obj) (G_TYPE_CHECK_INSTANCE_CAST ((obj), BOXES_TYPE_LIBVIRT_MACHINE, BoxesLibvirtMachine))
#define BOXES_LIBVIRT_MACHINE_CLASS(klass) (G_TYPE_CHECK_CLASS_CAST ((klass), BOXES_TYPE_LIBVIRT_MACHINE, BoxesLibvirtMachineClass))
#define BOXES_IS_LIBVIRT_MACHINE(obj) (G_TYPE_CHECK_INSTANCE_TYPE ((obj), BOXES_TYPE_LIBVIRT_MACHINE))
#define BOXES_IS_LIBVIRT_MACHINE_CLASS(klass) (G_TYPE_CHECK_CLASS_TYPE ((klass), BOXES_TYPE_LIBVIRT_MACHINE))
#define BOXES_LIBVIRT_MACHINE_GET_CLASS(obj) (G_TYPE_INSTANCE_GET_CLASS ((obj), BOXES_TYPE_LIBVIRT_MACHINE, BoxesLibvirtMachineClass))

typedef struct _BoxesLibvirtMachine BoxesLibvirtMachine;
typedef struct _BoxesLibvirtMachineClass BoxesLibvirtMachineClass;
enum  {
	BOXES_LIBVIRT_MACHINE_PROPERTIES_0_PROPERTY,
	BOXES_LIBVIRT_MACHINE_PROPERTIES_NUM_PROPERTIES
};
static GParamSpec* boxes_libvirt_machine_properties_properties[BOXES_LIBVIRT_MACHINE_PROPERTIES_NUM_PROPERTIES];
#define _g_object_unref0(var) ((var == NULL) ? NULL : (var = (g_object_unref (var), NULL)))
#define _g_error_free0(var) ((var == NULL) ? NULL : (var = (g_error_free (var), NULL)))

#define BOXES_TYPE_UI (boxes_ui_get_type ())
#define BOXES_UI(obj) (G_TYPE_CHECK_INSTANCE_CAST ((obj), BOXES_TYPE_UI, BoxesUI))
#define BOXES_IS_UI(obj) (G_TYPE_CHECK_INSTANCE_TYPE ((obj), BOXES_TYPE_UI))
#define BOXES_UI_GET_INTERFACE(obj) (G_TYPE_INSTANCE_GET_INTERFACE ((obj), BOXES_TYPE_UI, BoxesUIIface))

typedef struct _BoxesUI BoxesUI;
typedef struct _BoxesUIIface BoxesUIIface;

#define BOXES_TYPE_UI_STATE (boxes_ui_state_get_type ())
typedef struct _BoxesCollectionItemPrivate BoxesCollectionItemPrivate;
typedef struct _BoxesMachinePrivate BoxesMachinePrivate;

#define BOXES_MACHINE_TYPE_CONNECT_FLAGS (boxes_machine_connect_flags_get_type ())
#define _g_free0(var) (var = (g_free (var), NULL))
#define __vala_GVirDomainInfo_free0(var) ((var == NULL) ? NULL : (var = (_vala_GVirDomainInfo_free (var), NULL)))
#define __vala_GVirNodeInfo_free0(var) ((var == NULL) ? NULL : (var = (_vala_GVirNodeInfo_free (var), NULL)))
#define _g_string_free0(var) ((var == NULL) ? NULL : (var = (g_string_free (var, TRUE), NULL)))

#define BOXES_TYPE_DISPLAY (boxes_display_get_type ())
#define BOXES_DISPLAY(obj) (G_TYPE_CHECK_INSTANCE_CAST ((obj), BOXES_TYPE_DISPLAY, BoxesDisplay))
#define BOXES_DISPLAY_CLASS(klass) (G_TYPE_CHECK_CLASS_CAST ((klass), BOXES_TYPE_DISPLAY, BoxesDisplayClass))
#define BOXES_IS_DISPLAY(obj) (G_TYPE_CHECK_INSTANCE_TYPE ((obj), BOXES_TYPE_DISPLAY))
#define BOXES_IS_DISPLAY_CLASS(klass) (G_TYPE_CHECK_CLASS_TYPE ((klass), BOXES_TYPE_DISPLAY))
#define BOXES_DISPLAY_GET_CLASS(obj) (G_TYPE_INSTANCE_GET_CLASS ((obj), BOXES_TYPE_DISPLAY, BoxesDisplayClass))

typedef struct _BoxesDisplay BoxesDisplay;
typedef struct _BoxesDisplayClass BoxesDisplayClass;
#define __g_list_free__g_object_unref0_0(var) ((var == NULL) ? NULL : (var = (_g_list_free__g_object_unref0_ (var), NULL)))

#define BOXES_TYPE_EDITABLE_STRING_PROPERTY (boxes_editable_string_property_get_type ())
#define BOXES_EDITABLE_STRING_PROPERTY(obj) (G_TYPE_CHECK_INSTANCE_CAST ((obj), BOXES_TYPE_EDITABLE_STRING_PROPERTY, BoxesEditableStringProperty))
#define BOXES_EDITABLE_STRING_PROPERTY_CLASS(klass) (G_TYPE_CHECK_CLASS_CAST ((klass), BOXES_TYPE_EDITABLE_STRING_PROPERTY, BoxesEditableStringPropertyClass))
#define BOXES_IS_EDITABLE_STRING_PROPERTY(obj) (G_TYPE_CHECK_INSTANCE_TYPE ((obj), BOXES_TYPE_EDITABLE_STRING_PROPERTY))
#define BOXES_IS_EDITABLE_STRING_PROPERTY_CLASS(klass) (G_TYPE_CHECK_CLASS_TYPE ((klass), BOXES_TYPE_EDITABLE_STRING_PROPERTY))
#define BOXES_EDITABLE_STRING_PROPERTY_GET_CLASS(obj) (G_TYPE_INSTANCE_GET_CLASS ((obj), BOXES_TYPE_EDITABLE_STRING_PROPERTY, BoxesEditableStringPropertyClass))

typedef struct _BoxesEditableStringProperty BoxesEditableStringProperty;
typedef struct _BoxesEditableStringPropertyClass BoxesEditableStringPropertyClass;
typedef struct _Block46Data Block46Data;

#define BOXES_TYPE_STRING_PROPERTY (boxes_string_property_get_type ())
#define BOXES_STRING_PROPERTY(obj) (G_TYPE_CHECK_INSTANCE_CAST ((obj), BOXES_TYPE_STRING_PROPERTY, BoxesStringProperty))
#define BOXES_STRING_PROPERTY_CLASS(klass) (G_TYPE_CHECK_CLASS_CAST ((klass), BOXES_TYPE_STRING_PROPERTY, BoxesStringPropertyClass))
#define BOXES_IS_STRING_PROPERTY(obj) (G_TYPE_CHECK_INSTANCE_TYPE ((obj), BOXES_TYPE_STRING_PROPERTY))
#define BOXES_IS_STRING_PROPERTY_CLASS(klass) (G_TYPE_CHECK_CLASS_TYPE ((klass), BOXES_TYPE_STRING_PROPERTY))
#define BOXES_STRING_PROPERTY_GET_CLASS(obj) (G_TYPE_INSTANCE_GET_CLASS ((obj), BOXES_TYPE_STRING_PROPERTY, BoxesStringPropertyClass))

typedef struct _BoxesStringProperty BoxesStringProperty;
typedef struct _BoxesStringPropertyClass BoxesStringPropertyClass;

#define BOXES_TYPE_SNAPSHOTS_PROPERTY (boxes_snapshots_property_get_type ())
#define BOXES_SNAPSHOTS_PROPERTY(obj) (G_TYPE_CHECK_INSTANCE_CAST ((obj), BOXES_TYPE_SNAPSHOTS_PROPERTY, BoxesSnapshotsProperty))
#define BOXES_SNAPSHOTS_PROPERTY_CLASS(klass) (G_TYPE_CHECK_CLASS_CAST ((klass), BOXES_TYPE_SNAPSHOTS_PROPERTY, BoxesSnapshotsPropertyClass))
#define BOXES_IS_SNAPSHOTS_PROPERTY(obj) (G_TYPE_CHECK_INSTANCE_TYPE ((obj), BOXES_TYPE_SNAPSHOTS_PROPERTY))
#define BOXES_IS_SNAPSHOTS_PROPERTY_CLASS(klass) (G_TYPE_CHECK_CLASS_TYPE ((klass), BOXES_TYPE_SNAPSHOTS_PROPERTY))
#define BOXES_SNAPSHOTS_PROPERTY_GET_CLASS(obj) (G_TYPE_INSTANCE_GET_CLASS ((obj), BOXES_TYPE_SNAPSHOTS_PROPERTY, BoxesSnapshotsPropertyClass))

typedef struct _BoxesSnapshotsProperty BoxesSnapshotsProperty;
typedef struct _BoxesSnapshotsPropertyClass BoxesSnapshotsPropertyClass;

#define BOXES_TYPE_SIZE_PROPERTY (boxes_size_property_get_type ())
#define BOXES_SIZE_PROPERTY(obj) (G_TYPE_CHECK_INSTANCE_CAST ((obj), BOXES_TYPE_SIZE_PROPERTY, BoxesSizeProperty))
#define BOXES_SIZE_PROPERTY_CLASS(klass) (G_TYPE_CHECK_CLASS_CAST ((klass), BOXES_TYPE_SIZE_PROPERTY, BoxesSizePropertyClass))
#define BOXES_IS_SIZE_PROPERTY(obj) (G_TYPE_CHECK_INSTANCE_TYPE ((obj), BOXES_TYPE_SIZE_PROPERTY))
#define BOXES_IS_SIZE_PROPERTY_CLASS(klass) (G_TYPE_CHECK_CLASS_TYPE ((klass), BOXES_TYPE_SIZE_PROPERTY))
#define BOXES_SIZE_PROPERTY_GET_CLASS(obj) (G_TYPE_INSTANCE_GET_CLASS ((obj), BOXES_TYPE_SIZE_PROPERTY, BoxesSizePropertyClass))

typedef struct _BoxesSizeProperty BoxesSizeProperty;
typedef struct _BoxesSizePropertyClass BoxesSizePropertyClass;
typedef struct _Block47Data Block47Data;

#define BOXES_TYPE_VM_CREATOR (boxes_vm_creator_get_type ())
#define BOXES_VM_CREATOR(obj) (G_TYPE_CHECK_INSTANCE_CAST ((obj), BOXES_TYPE_VM_CREATOR, BoxesVMCreator))
#define BOXES_VM_CREATOR_CLASS(klass) (G_TYPE_CHECK_CLASS_CAST ((klass), BOXES_TYPE_VM_CREATOR, BoxesVMCreatorClass))
#define BOXES_IS_VM_CREATOR(obj) (G_TYPE_CHECK_INSTANCE_TYPE ((obj), BOXES_TYPE_VM_CREATOR))
#define BOXES_IS_VM_CREATOR_CLASS(klass) (G_TYPE_CHECK_CLASS_TYPE ((klass), BOXES_TYPE_VM_CREATOR))
#define BOXES_VM_CREATOR_GET_CLASS(obj) (G_TYPE_INSTANCE_GET_CLASS ((obj), BOXES_TYPE_VM_CREATOR, BoxesVMCreatorClass))

typedef struct _BoxesVMCreator BoxesVMCreator;
typedef struct _BoxesVMCreatorClass BoxesVMCreatorClass;

#define BOXES_TYPE_INSTALLER_MEDIA (boxes_installer_media_get_type ())
#define BOXES_INSTALLER_MEDIA(obj) (G_TYPE_CHECK_INSTANCE_CAST ((obj), BOXES_TYPE_INSTALLER_MEDIA, BoxesInstallerMedia))
#define BOXES_INSTALLER_MEDIA_CLASS(klass) (G_TYPE_CHECK_CLASS_CAST ((klass), BOXES_TYPE_INSTALLER_MEDIA, BoxesInstallerMediaClass))
#define BOXES_IS_INSTALLER_MEDIA(obj) (G_TYPE_CHECK_INSTANCE_TYPE ((obj), BOXES_TYPE_INSTALLER_MEDIA))
#define BOXES_IS_INSTALLER_MEDIA_CLASS(klass) (G_TYPE_CHECK_CLASS_TYPE ((klass), BOXES_TYPE_INSTALLER_MEDIA))
#define BOXES_INSTALLER_MEDIA_GET_CLASS(obj) (G_TYPE_INSTANCE_GET_CLASS ((obj), BOXES_TYPE_INSTALLER_MEDIA, BoxesInstallerMediaClass))

typedef struct _BoxesInstallerMedia BoxesInstallerMedia;
typedef struct _BoxesInstallerMediaClass BoxesInstallerMediaClass;
typedef struct _BoxesInstallerMediaPrivate BoxesInstallerMediaPrivate;

#define BOXES_TYPE_APP_WINDOW (boxes_app_window_get_type ())
#define BOXES_APP_WINDOW(obj) (G_TYPE_CHECK_INSTANCE_CAST ((obj), BOXES_TYPE_APP_WINDOW, BoxesAppWindow))
#define BOXES_APP_WINDOW_CLASS(klass) (G_TYPE_CHECK_CLASS_CAST ((klass), BOXES_TYPE_APP_WINDOW, BoxesAppWindowClass))
#define BOXES_IS_APP_WINDOW(obj) (G_TYPE_CHECK_INSTANCE_TYPE ((obj), BOXES_TYPE_APP_WINDOW))
#define BOXES_IS_APP_WINDOW_CLASS(klass) (G_TYPE_CHECK_CLASS_TYPE ((klass), BOXES_TYPE_APP_WINDOW))
#define BOXES_APP_WINDOW_GET_CLASS(obj) (G_TYPE_INSTANCE_GET_CLASS ((obj), BOXES_TYPE_APP_WINDOW, BoxesAppWindowClass))

typedef struct _BoxesAppWindow BoxesAppWindow;
typedef struct _BoxesAppWindowClass BoxesAppWindowClass;
typedef struct _BoxesAppWindowPrivate BoxesAppWindowPrivate;

#define BOXES_TYPE_WIZARD_WINDOW (boxes_wizard_window_get_type ())
#define BOXES_WIZARD_WINDOW(obj) (G_TYPE_CHECK_INSTANCE_CAST ((obj), BOXES_TYPE_WIZARD_WINDOW, BoxesWizardWindow))
#define BOXES_WIZARD_WINDOW_CLASS(klass) (G_TYPE_CHECK_CLASS_CAST ((klass), BOXES_TYPE_WIZARD_WINDOW, BoxesWizardWindowClass))
#define BOXES_IS_WIZARD_WINDOW(obj) (G_TYPE_CHECK_INSTANCE_TYPE ((obj), BOXES_TYPE_WIZARD_WINDOW))
#define BOXES_IS_WIZARD_WINDOW_CLASS(klass) (G_TYPE_CHECK_CLASS_TYPE ((klass), BOXES_TYPE_WIZARD_WINDOW))
#define BOXES_WIZARD_WINDOW_GET_CLASS(obj) (G_TYPE_INSTANCE_GET_CLASS ((obj), BOXES_TYPE_WIZARD_WINDOW, BoxesWizardWindowClass))

typedef struct _BoxesWizardWindow BoxesWizardWindow;
typedef struct _BoxesWizardWindowClass BoxesWizardWindowClass;

#define BOXES_TYPE_PROPERTIES_WINDOW (boxes_properties_window_get_type ())
#define BOXES_PROPERTIES_WINDOW(obj) (G_TYPE_CHECK_INSTANCE_CAST ((obj), BOXES_TYPE_PROPERTIES_WINDOW, BoxesPropertiesWindow))
#define BOXES_PROPERTIES_WINDOW_CLASS(klass) (G_TYPE_CHECK_CLASS_CAST ((klass), BOXES_TYPE_PROPERTIES_WINDOW, BoxesPropertiesWindowClass))
#define BOXES_IS_PROPERTIES_WINDOW(obj) (G_TYPE_CHECK_INSTANCE_TYPE ((obj), BOXES_TYPE_PROPERTIES_WINDOW))
#define BOXES_IS_PROPERTIES_WINDOW_CLASS(klass) (G_TYPE_CHECK_CLASS_TYPE ((klass), BOXES_TYPE_PROPERTIES_WINDOW))
#define BOXES_PROPERTIES_WINDOW_GET_CLASS(obj) (G_TYPE_INSTANCE_GET_CLASS ((obj), BOXES_TYPE_PROPERTIES_WINDOW, BoxesPropertiesWindowClass))

typedef struct _BoxesPropertiesWindow BoxesPropertiesWindow;
typedef struct _BoxesPropertiesWindowClass BoxesPropertiesWindowClass;

#define BOXES_TYPE_SEARCHBAR (boxes_searchbar_get_type ())
#define BOXES_SEARCHBAR(obj) (G_TYPE_CHECK_INSTANCE_CAST ((obj), BOXES_TYPE_SEARCHBAR, BoxesSearchbar))
#define BOXES_SEARCHBAR_CLASS(klass) (G_TYPE_CHECK_CLASS_CAST ((klass), BOXES_TYPE_SEARCHBAR, BoxesSearchbarClass))
#define BOXES_IS_SEARCHBAR(obj) (G_TYPE_CHECK_INSTANCE_TYPE ((obj), BOXES_TYPE_SEARCHBAR))
#define BOXES_IS_SEARCHBAR_CLASS(klass) (G_TYPE_CHECK_CLASS_TYPE ((klass), BOXES_TYPE_SEARCHBAR))
#define BOXES_SEARCHBAR_GET_CLASS(obj) (G_TYPE_INSTANCE_GET_CLASS ((obj), BOXES_TYPE_SEARCHBAR, BoxesSearchbarClass))

typedef struct _BoxesSearchbar BoxesSearchbar;
typedef struct _BoxesSearchbarClass BoxesSearchbarClass;

#define BOXES_TYPE_TOPBAR (boxes_topbar_get_type ())
#define BOXES_TOPBAR(obj) (G_TYPE_CHECK_INSTANCE_CAST ((obj), BOXES_TYPE_TOPBAR, BoxesTopbar))
#define BOXES_TOPBAR_CLASS(klass) (G_TYPE_CHECK_CLASS_CAST ((klass), BOXES_TYPE_TOPBAR, BoxesTopbarClass))
#define BOXES_IS_TOPBAR(obj) (G_TYPE_CHECK_INSTANCE_TYPE ((obj), BOXES_TYPE_TOPBAR))
#define BOXES_IS_TOPBAR_CLASS(klass) (G_TYPE_CHECK_CLASS_TYPE ((klass), BOXES_TYPE_TOPBAR))
#define BOXES_TOPBAR_GET_CLASS(obj) (G_TYPE_INSTANCE_GET_CLASS ((obj), BOXES_TYPE_TOPBAR, BoxesTopbarClass))

typedef struct _BoxesTopbar BoxesTopbar;
typedef struct _BoxesTopbarClass BoxesTopbarClass;

#define BOXES_TYPE_SELECTIONBAR (boxes_selectionbar_get_type ())
#define BOXES_SELECTIONBAR(obj) (G_TYPE_CHECK_INSTANCE_CAST ((obj), BOXES_TYPE_SELECTIONBAR, BoxesSelectionbar))
#define BOXES_SELECTIONBAR_CLASS(klass) (G_TYPE_CHECK_CLASS_CAST ((klass), BOXES_TYPE_SELECTIONBAR, BoxesSelectionbarClass))
#define BOXES_IS_SELECTIONBAR(obj) (G_TYPE_CHECK_INSTANCE_TYPE ((obj), BOXES_TYPE_SELECTIONBAR))
#define BOXES_IS_SELECTIONBAR_CLASS(klass) (G_TYPE_CHECK_CLASS_TYPE ((klass), BOXES_TYPE_SELECTIONBAR))
#define BOXES_SELECTIONBAR_GET_CLASS(obj) (G_TYPE_INSTANCE_GET_CLASS ((obj), BOXES_TYPE_SELECTIONBAR, BoxesSelectionbarClass))

typedef struct _BoxesSelectionbar BoxesSelectionbar;
typedef struct _BoxesSelectionbarClass BoxesSelectionbarClass;

#define BOXES_TYPE_DISPLAY_PAGE (boxes_display_page_get_type ())
#define BOXES_DISPLAY_PAGE(obj) (G_TYPE_CHECK_INSTANCE_CAST ((obj), BOXES_TYPE_DISPLAY_PAGE, BoxesDisplayPage))
#define BOXES_DISPLAY_PAGE_CLASS(klass) (G_TYPE_CHECK_CLASS_CAST ((klass), BOXES_TYPE_DISPLAY_PAGE, BoxesDisplayPageClass))
#define BOXES_IS_DISPLAY_PAGE(obj) (G_TYPE_CHECK_INSTANCE_TYPE ((obj), BOXES_TYPE_DISPLAY_PAGE))
#define BOXES_IS_DISPLAY_PAGE_CLASS(klass) (G_TYPE_CHECK_CLASS_TYPE ((klass), BOXES_TYPE_DISPLAY_PAGE))
#define BOXES_DISPLAY_PAGE_GET_CLASS(obj) (G_TYPE_INSTANCE_GET_CLASS ((obj), BOXES_TYPE_DISPLAY_PAGE, BoxesDisplayPageClass))

typedef struct _BoxesDisplayPage BoxesDisplayPage;
typedef struct _BoxesDisplayPageClass BoxesDisplayPageClass;

#define BOXES_TYPE_EMPTY_BOXES (boxes_empty_boxes_get_type ())
#define BOXES_EMPTY_BOXES(obj) (G_TYPE_CHECK_INSTANCE_CAST ((obj), BOXES_TYPE_EMPTY_BOXES, BoxesEmptyBoxes))
#define BOXES_EMPTY_BOXES_CLASS(klass) (G_TYPE_CHECK_CLASS_CAST ((klass), BOXES_TYPE_EMPTY_BOXES, BoxesEmptyBoxesClass))
#define BOXES_IS_EMPTY_BOXES(obj) (G_TYPE_CHECK_INSTANCE_TYPE ((obj), BOXES_TYPE_EMPTY_BOXES))
#define BOXES_IS_EMPTY_BOXES_CLASS(klass) (G_TYPE_CHECK_CLASS_TYPE ((klass), BOXES_TYPE_EMPTY_BOXES))
#define BOXES_EMPTY_BOXES_GET_CLASS(obj) (G_TYPE_INSTANCE_GET_CLASS ((obj), BOXES_TYPE_EMPTY_BOXES, BoxesEmptyBoxesClass))

typedef struct _BoxesEmptyBoxes BoxesEmptyBoxes;
typedef struct _BoxesEmptyBoxesClass BoxesEmptyBoxesClass;
typedef struct _BoxesLibvirtMachinePropertiesMarkRecommendedResourcesData BoxesLibvirtMachinePropertiesMarkRecommendedResourcesData;

#define BOXES_TYPE_OS_DATABASE (boxes_os_database_get_type ())
#define BOXES_OS_DATABASE(obj) (G_TYPE_CHECK_INSTANCE_CAST ((obj), BOXES_TYPE_OS_DATABASE, BoxesOSDatabase))
#define BOXES_OS_DATABASE_CLASS(klass) (G_TYPE_CHECK_CLASS_CAST ((klass), BOXES_TYPE_OS_DATABASE, BoxesOSDatabaseClass))
#define BOXES_IS_OS_DATABASE(obj) (G_TYPE_CHECK_INSTANCE_TYPE ((obj), BOXES_TYPE_OS_DATABASE))
#define BOXES_IS_OS_DATABASE_CLASS(klass) (G_TYPE_CHECK_CLASS_TYPE ((klass), BOXES_TYPE_OS_DATABASE))
#define BOXES_OS_DATABASE_GET_CLASS(obj) (G_TYPE_INSTANCE_GET_CLASS ((obj), BOXES_TYPE_OS_DATABASE, BoxesOSDatabaseClass))

typedef struct _BoxesOSDatabase BoxesOSDatabase;
typedef struct _BoxesOSDatabaseClass BoxesOSDatabaseClass;

#define BOXES_TYPE_MEDIA_MANAGER (boxes_media_manager_get_type ())
#define BOXES_MEDIA_MANAGER(obj) (G_TYPE_CHECK_INSTANCE_CAST ((obj), BOXES_TYPE_MEDIA_MANAGER, BoxesMediaManager))
#define BOXES_MEDIA_MANAGER_CLASS(klass) (G_TYPE_CHECK_CLASS_CAST ((klass), BOXES_TYPE_MEDIA_MANAGER, BoxesMediaManagerClass))
#define BOXES_IS_MEDIA_MANAGER(obj) (G_TYPE_CHECK_INSTANCE_TYPE ((obj), BOXES_TYPE_MEDIA_MANAGER))
#define BOXES_IS_MEDIA_MANAGER_CLASS(klass) (G_TYPE_CHECK_CLASS_TYPE ((klass), BOXES_TYPE_MEDIA_MANAGER))
#define BOXES_MEDIA_MANAGER_GET_CLASS(obj) (G_TYPE_INSTANCE_GET_CLASS ((obj), BOXES_TYPE_MEDIA_MANAGER, BoxesMediaManagerClass))

typedef struct _BoxesMediaManager BoxesMediaManager;
typedef struct _BoxesMediaManagerClass BoxesMediaManagerClass;
typedef struct _BoxesLibvirtMachinePropertiesGetOsForMachineData BoxesLibvirtMachinePropertiesGetOsForMachineData;

#define BOXES_TYPE_RESOURCE_GRAPH (boxes_resource_graph_get_type ())
#define BOXES_RESOURCE_GRAPH(obj) (G_TYPE_CHECK_INSTANCE_CAST ((obj), BOXES_TYPE_RESOURCE_GRAPH, BoxesResourceGraph))
#define BOXES_RESOURCE_GRAPH_CLASS(klass) (G_TYPE_CHECK_CLASS_CAST ((klass), BOXES_TYPE_RESOURCE_GRAPH, BoxesResourceGraphClass))
#define BOXES_IS_RESOURCE_GRAPH(obj) (G_TYPE_CHECK_INSTANCE_TYPE ((obj), BOXES_TYPE_RESOURCE_GRAPH))
#define BOXES_IS_RESOURCE_GRAPH_CLASS(klass) (G_TYPE_CHECK_CLASS_TYPE ((klass), BOXES_TYPE_RESOURCE_GRAPH))
#define BOXES_RESOURCE_GRAPH_GET_CLASS(obj) (G_TYPE_INSTANCE_GET_CLASS ((obj), BOXES_TYPE_RESOURCE_GRAPH, BoxesResourceGraphClass))

typedef struct _BoxesResourceGraph BoxesResourceGraph;
typedef struct _BoxesResourceGraphClass BoxesResourceGraphClass;
typedef struct _Block48Data Block48Data;
typedef struct _BoxesLibvirtMachinePrivate BoxesLibvirtMachinePrivate;
typedef struct _Block49Data Block49Data;
typedef struct _Block50Data Block50Data;

#define BOXES_MACHINE_TYPE_MACHINE_STATE (boxes_machine_machine_state_get_type ())
typedef struct _Block51Data Block51Data;
#define __vala_GVirStorageVolInfo_free0(var) ((var == NULL) ? NULL : (var = (_vala_GVirStorageVolInfo_free (var), NULL)))
#define __vala_GVirStoragePoolInfo_free0(var) ((var == NULL) ? NULL : (var = (_vala_GVirStoragePoolInfo_free (var), NULL)))
typedef struct _Block52Data Block52Data;
typedef struct _Block53Data Block53Data;

#define BOXES_TYPE_NOTIFICATIONBAR (boxes_notificationbar_get_type ())
#define BOXES_NOTIFICATIONBAR(obj) (G_TYPE_CHECK_INSTANCE_CAST ((obj), BOXES_TYPE_NOTIFICATIONBAR, BoxesNotificationbar))
#define BOXES_NOTIFICATIONBAR_CLASS(klass) (G_TYPE_CHECK_CLASS_CAST ((klass), BOXES_TYPE_NOTIFICATIONBAR, BoxesNotificationbarClass))
#define BOXES_IS_NOTIFICATIONBAR(obj) (G_TYPE_CHECK_INSTANCE_TYPE ((obj), BOXES_TYPE_NOTIFICATIONBAR))
#define BOXES_IS_NOTIFICATIONBAR_CLASS(klass) (G_TYPE_CHECK_CLASS_TYPE ((klass), BOXES_TYPE_NOTIFICATIONBAR))
#define BOXES_NOTIFICATIONBAR_GET_CLASS(obj) (G_TYPE_INSTANCE_GET_CLASS ((obj), BOXES_TYPE_NOTIFICATIONBAR, BoxesNotificationbarClass))

typedef struct _BoxesNotificationbar BoxesNotificationbar;
typedef struct _BoxesNotificationbarClass BoxesNotificationbarClass;

#define BOXES_TYPE_NOTIFICATION (boxes_notification_get_type ())
#define BOXES_NOTIFICATION(obj) (G_TYPE_CHECK_INSTANCE_CAST ((obj), BOXES_TYPE_NOTIFICATION, BoxesNotification))
#define BOXES_NOTIFICATION_CLASS(klass) (G_TYPE_CHECK_CLASS_CAST ((klass), BOXES_TYPE_NOTIFICATION, BoxesNotificationClass))
#define BOXES_IS_NOTIFICATION(obj) (G_TYPE_CHECK_INSTANCE_TYPE ((obj), BOXES_TYPE_NOTIFICATION))
#define BOXES_IS_NOTIFICATION_CLASS(klass) (G_TYPE_CHECK_CLASS_TYPE ((klass), BOXES_TYPE_NOTIFICATION))
#define BOXES_NOTIFICATION_GET_CLASS(obj) (G_TYPE_INSTANCE_GET_CLASS ((obj), BOXES_TYPE_NOTIFICATION, BoxesNotificationClass))

typedef struct _BoxesNotification BoxesNotification;
typedef struct _BoxesNotificationClass BoxesNotificationClass;
typedef struct _BoxesLibvirtMachinePropertiesChangeStorageSizeData BoxesLibvirtMachinePropertiesChangeStorageSizeData;
typedef struct _BoxesLibvirtMachinePropertiesForceChangeStorageSizeData BoxesLibvirtMachinePropertiesForceChangeStorageSizeData;
typedef struct _BoxesLibvirtMachinePropertiesGetSnapshotsData BoxesLibvirtMachinePropertiesGetSnapshotsData;
typedef struct _Block54Data Block54Data;

#define BOXES_TYPE_APP (boxes_app_get_type ())
#define BOXES_APP(obj) (G_TYPE_CHECK_INSTANCE_CAST ((obj), BOXES_TYPE_APP, BoxesApp))
#define BOXES_APP_CLASS(klass) (G_TYPE_CHECK_CLASS_CAST ((klass), BOXES_TYPE_APP, BoxesAppClass))
#define BOXES_IS_APP(obj) (G_TYPE_CHECK_INSTANCE_TYPE ((obj), BOXES_TYPE_APP))
#define BOXES_IS_APP_CLASS(klass) (G_TYPE_CHECK_CLASS_TYPE ((klass), BOXES_TYPE_APP))
#define BOXES_APP_GET_CLASS(obj) (G_TYPE_INSTANCE_GET_CLASS ((obj), BOXES_TYPE_APP, BoxesAppClass))

typedef struct _BoxesApp BoxesApp;
typedef struct _BoxesAppClass BoxesAppClass;

typedef enum  {
	BOXES_PROPERTIES_PAGE_GENERAL,
	BOXES_PROPERTIES_PAGE_SYSTEM,
	BOXES_PROPERTIES_PAGE_DEVICES,
	BOXES_PROPERTIES_PAGE_SNAPSHOTS,
	BOXES_PROPERTIES_PAGE_LAST
} BoxesPropertiesPage;

struct _BoxesIPropertiesProviderIface {
	GTypeInterface parent_iface;
	GList* (*get_properties) (BoxesIPropertiesProvider* self, BoxesPropertiesPage page);
};

struct _BoxesLibvirtMachineProperties {
	GObject parent_instance;
	BoxesLibvirtMachinePropertiesPrivate * priv;
};

struct _BoxesLibvirtMachinePropertiesClass {
	GObjectClass parent_class;
};

struct _BoxesLibvirtMachinePropertiesPrivate {
	BoxesLibvirtMachine* machine;
};

typedef enum  {
	BOXES_UI_STATE_NONE,
	BOXES_UI_STATE_COLLECTION,
	BOXES_UI_STATE_CREDS,
	BOXES_UI_STATE_DISPLAY,
	BOXES_UI_STATE_WIZARD,
	BOXES_UI_STATE_PROPERTIES
} BoxesUIState;

struct _BoxesUIIface {
	GTypeInterface parent_iface;
	BoxesUIState (*get_previous_ui_state) (BoxesUI* self);
	void (*set_previous_ui_state) (BoxesUI* self, BoxesUIState value);
	BoxesUIState (*get_ui_state) (BoxesUI* self);
	void (*set_ui_state) (BoxesUI* self, BoxesUIState value);
};

struct _BoxesCollectionItem {
	GObject parent_instance;
	BoxesCollectionItemPrivate * priv;
};

struct _BoxesCollectionItemClass {
	GObjectClass parent_class;
	gint (*compare) (BoxesCollectionItem* self, BoxesCollectionItem* other);
};

typedef enum  {
	BOXES_MACHINE_CONNECT_FLAGS_NONE = 0,
	BOXES_MACHINE_CONNECT_FLAGS_IGNORE_SAVED_STATE = 1 << 0
} BoxesMachineConnectFlags;

struct _BoxesMachine {
	BoxesCollectionItem parent_instance;
	BoxesMachinePrivate * priv;
	BoxesCollectionSource* source;
	BoxesBoxConfig* config;
	gboolean stay_on_display;
};

struct _BoxesMachineClass {
	BoxesCollectionItemClass parent_class;
	void (*save_real) (BoxesMachine* self, GAsyncReadyCallback _callback_, gpointer _user_data_);
	void (*save_real_finish) (BoxesMachine* self, GAsyncResult* _res_, GError** error);
	void (*take_screenshot) (BoxesMachine* self, GAsyncReadyCallback _callback_, gpointer _user_data_);
	GdkPixbuf* (*take_screenshot_finish) (BoxesMachine* self, GAsyncResult* _res_, GError** error);
	GList* (*get_properties) (BoxesMachine* self, BoxesPropertiesPage page);
	void (*connect_display) (BoxesMachine* self, BoxesMachineConnectFlags flags, GAsyncReadyCallback _callback_, gpointer _user_data_);
	void (*connect_display_finish) (BoxesMachine* self, GAsyncResult* _res_, GError** error);
	void (*restart) (BoxesMachine* self);
	void (*clone) (BoxesMachine* self, GAsyncReadyCallback _callback_, gpointer _user_data_);
	void (*clone_finish) (BoxesMachine* self, GAsyncResult* _res_);
	void (*disconnect_display) (BoxesMachine* self);
	void (*update_status) (BoxesMachine* self);
	void (*delete) (BoxesMachine* self, gboolean by_user);
	gboolean (*get_suspend_at_exit) (BoxesMachine* self);
	gboolean (*get_can_save) (BoxesMachine* self);
	gboolean (*get_can_restart) (BoxesMachine* self);
	gboolean (*get_can_clone) (BoxesMachine* self);
	gboolean (*get_should_autosave) (BoxesMachine* self);
	gboolean (*get_is_local) (BoxesMachine* self);
};

struct _Block46Data {
	int _ref_count_;
	BoxesLibvirtMachineProperties* self;
	BoxesEditableStringProperty* name_property;
};

struct _Block47Data {
	int _ref_count_;
	BoxesLibvirtMachineProperties* self;
	GtkLabel* label;
	gboolean empty;
	GtkLabel* button_label;
	GVirConfigDomainDisk* disk_config;
};

struct _BoxesInstallerMedia {
	GObject parent_instance;
	BoxesInstallerMediaPrivate * priv;
	OsinfoOs* os;
	OsinfoResources* resources;
	OsinfoMedia* os_media;
	gchar* label;
	gchar* device_file;
	gchar* mount_point;
	gboolean from_image;
};

struct _BoxesInstallerMediaClass {
	GObjectClass parent_class;
	void (*set_direct_boot_params) (BoxesInstallerMedia* self, GVirConfigDomainOs* os);
	void (*prepare) (BoxesInstallerMedia* self, BoxesActivityProgress* progress, GCancellable* cancellable, GAsyncReadyCallback _callback_, gpointer _user_data_);
	gboolean (*prepare_finish) (BoxesInstallerMedia* self, GAsyncResult* _res_);
	void (*prepare_for_installation) (BoxesInstallerMedia* self, const gchar* vm_name, GCancellable* cancellable, GAsyncReadyCallback _callback_, gpointer _user_data_);
	void (*prepare_for_installation_finish) (BoxesInstallerMedia* self, GAsyncResult* _res_);
	void (*prepare_to_continue_installation) (BoxesInstallerMedia* self, const gchar* vm_name);
	void (*clean_up) (BoxesInstallerMedia* self);
	void (*clean_up_preparation_cache) (BoxesInstallerMedia* self);
	void (*setup_domain_config) (BoxesInstallerMedia* self, GVirConfigDomain* domain);
	void (*setup_post_install_domain_config) (BoxesInstallerMedia* self, GVirConfigDomain* domain);
	void (*populate_setup_box) (BoxesInstallerMedia* self, GtkBox* setup_box);
	GList* (*get_vm_properties) (BoxesInstallerMedia* self);
	BoxesVMCreator* (*get_vm_creator) (BoxesInstallerMedia* self);
	OsinfoDeviceList* (*get_supported_devices) (BoxesInstallerMedia* self);
	guint64 (*get_installed_size) (BoxesInstallerMedia* self);
	gboolean (*get_need_user_input_for_vm_creation) (BoxesInstallerMedia* self);
	gboolean (*get_ready_to_create) (BoxesInstallerMedia* self);
	gboolean (*get_live) (BoxesInstallerMedia* self);
	gboolean (*get_eject_after_install) (BoxesInstallerMedia* self);
	gchar* (*get_architecture) (BoxesInstallerMedia* self);
};

struct _BoxesAppWindow {
	GtkApplicationWindow parent_instance;
	BoxesAppWindowPrivate * priv;
	BoxesWizardWindow* wizard_window;
	BoxesPropertiesWindow* props_window;
	BoxesSearchbar* searchbar;
	BoxesTopbar* topbar;
	BoxesSelectionbar* selectionbar;
	BoxesDisplayPage* display_page;
	BoxesEmptyBoxes* empty_boxes;
	GtkStack* below_bin;
	GSettings* settings;
};

struct _BoxesAppWindowClass {
	GtkApplicationWindowClass parent_class;
};

typedef void (*BoxesPropertiesWindowFileChosenFunc) (const gchar* path, void* user_data);
struct _BoxesLibvirtMachinePropertiesMarkRecommendedResourcesData {
	int _state_;
	GObject* _source_object_;
	GAsyncResult* _res_;
	GTask* _async_result;
	BoxesLibvirtMachineProperties* self;
	BoxesSizeProperty* ram_property;
	BoxesSizeProperty* storage_property;
	gboolean _tmp0_;
	BoxesSizeProperty* _tmp1_;
	BoxesSizeProperty* _tmp2_;
	OsinfoOs* os;
	BoxesLibvirtMachine* _tmp3_;
	OsinfoOs* _tmp4_;
	OsinfoOs* _tmp5_;
	gchar* architecture;
	BoxesLibvirtMachine* _tmp6_;
	GVirConfigDomain* _tmp7_;
	GVirConfigDomain* _tmp8_;
	GVirConfigDomainOs* _tmp9_;
	GVirConfigDomainOs* _tmp10_;
	const gchar* _tmp11_;
	gchar* _tmp12_;
	gchar* _tmp13_;
	OsinfoResources* resources;
	OsinfoOs* _tmp14_;
	const gchar* _tmp15_;
	OsinfoResources* _tmp16_;
	OsinfoResources* _tmp17_;
	BoxesSizeProperty* _tmp18_;
	BoxesSizeProperty* _tmp19_;
	OsinfoResources* _tmp20_;
	gint64 _tmp21_;
	gint64 _tmp22_;
	BoxesSizeProperty* _tmp23_;
	BoxesSizeProperty* _tmp24_;
	OsinfoResources* _tmp25_;
	gint64 _tmp26_;
	gint64 _tmp27_;
};

typedef enum  {
	BOXES_OS_DATABASE_ERROR_NON_BOOTABLE,
	BOXES_OS_DATABASE_ERROR_DB_LOADING_FAILED,
	BOXES_OS_DATABASE_ERROR_UNKNOWN_OS_ID,
	BOXES_OS_DATABASE_ERROR_UNKNOWN_MEDIA_ID
} BoxesOSDatabaseError;
#define BOXES_OS_DATABASE_ERROR boxes_os_database_error_quark ()
struct _BoxesLibvirtMachinePropertiesGetOsForMachineData {
	int _state_;
	GObject* _source_object_;
	GAsyncResult* _res_;
	GTask* _async_result;
	BoxesLibvirtMachineProperties* self;
	BoxesLibvirtMachine* machine;
	OsinfoOs* result;
	gchar* os_id;
	BoxesLibvirtMachine* _tmp0_;
	GVirConfigDomain* _tmp1_;
	GVirConfigDomain* _tmp2_;
	gchar* _tmp3_;
	const gchar* _tmp4_;
	BoxesOSDatabase* os_db;
	BoxesMediaManager* _tmp5_;
	BoxesMediaManager* _tmp6_;
	BoxesOSDatabase* _tmp7_;
	BoxesOSDatabase* _tmp8_;
	BoxesOSDatabase* _tmp9_;
	BoxesOSDatabase* _tmp10_;
	OsinfoOs* _tmp11_;
	BoxesOSDatabase* _tmp12_;
	const gchar* _tmp13_;
	OsinfoOs* _tmp14_;
	OsinfoOs* _tmp15_;
	GError* _error_;
	const gchar* _tmp16_;
	GError* _tmp17_;
	const gchar* _tmp18_;
	GError * _inner_error_;
};

struct _Block48Data {
	int _ref_count_;
	BoxesLibvirtMachineProperties* self;
	BoxesResourceGraph* cpu_graph;
	BoxesResourceGraph* io_graph;
	BoxesResourceGraph* net_graph;
	gulong stats_id;
	BoxesProperty* prop;
	gulong flushed_id;
};

struct _BoxesLibvirtMachine {
	BoxesMachine parent_instance;
	BoxesLibvirtMachinePrivate * priv;
	BoxesLibvirtMachineProperties* properties;
	gdouble* cpu_stats;
	gint cpu_stats_length1;
	gint _cpu_stats_size_;
	gdouble* io_stats;
	gint io_stats_length1;
	gint _io_stats_size_;
	gdouble* net_stats;
	gint net_stats_length1;
	gint _net_stats_size_;
};

struct _BoxesLibvirtMachineClass {
	BoxesMachineClass parent_class;
};

struct _Block49Data {
	int _ref_count_;
	BoxesLibvirtMachineProperties* self;
	GtkButton* restart_button;
	GtkButton* shutdown_button;
	gulong state_notify_id;
	BoxesProperty* prop;
	gulong flushed_id;
};

struct _Block50Data {
	int _ref_count_;
	BoxesLibvirtMachineProperties* self;
	BoxesSizeProperty* property;
};

typedef enum  {
	BOXES_MACHINE_MACHINE_STATE_UNKNOWN,
	BOXES_MACHINE_MACHINE_STATE_STOPPED,
	BOXES_MACHINE_MACHINE_STATE_FORCE_STOPPED,
	BOXES_MACHINE_MACHINE_STATE_RUNNING,
	BOXES_MACHINE_MACHINE_STATE_PAUSED,
	BOXES_MACHINE_MACHINE_STATE_SAVED,
	BOXES_MACHINE_MACHINE_STATE_SLEEPING
} BoxesMachineMachineState;

struct _Block51Data {
	int _ref_count_;
	BoxesLibvirtMachineProperties* self;
	BoxesProperty* property;
	guint64 value;
};

struct _Block52Data {
	int _ref_count_;
	BoxesLibvirtMachineProperties* self;
	BoxesProperty* property;
	guint64 value;
};

struct _Block53Data {
	int _ref_count_;
	BoxesLibvirtMachineProperties* self;
	BoxesProperty* property;
	guint64 value;
	gpointer _async_data_;
};

typedef void (*BoxesNotificationOKFunc) (void* user_data);
typedef void (*BoxesNotificationDismissFunc) (void* user_data);
struct _BoxesLibvirtMachinePropertiesChangeStorageSizeData {
	int _state_;
	GObject* _source_object_;
	GAsyncResult* _res_;
	GTask* _async_result;
	BoxesLibvirtMachineProperties* self;
	BoxesProperty* property;
	guint64 value;
	Block53Data* _data53_;
	BoxesProperty* _tmp0_;
	guint64 _tmp1_;
	BoxesLibvirtMachine* _tmp2_;
	GVirStorageVol* _tmp3_;
	GVirStorageVol* _tmp4_;
	GList* snapshots;
	GList* _tmp5_;
	GList* _tmp6_;
	GList* _tmp7_;
	GError* e;
	BoxesLibvirtMachine* _tmp8_;
	const gchar* _tmp9_;
	const gchar* _tmp10_;
	GError* _tmp11_;
	const gchar* _tmp12_;
	guint num_snapshots;
	GList* _tmp13_;
	guint _tmp14_;
	guint _tmp15_;
	gchar* msg;
	guint _tmp16_;
	guint _tmp17_;
	gchar* _tmp18_;
	BoxesNotificationOKFunc undo;
	void* undo_target;
	GDestroyNotify undo_target_destroy_notify;
	BoxesNotificationDismissFunc really_resize;
	void* really_resize_target;
	GDestroyNotify really_resize_target_destroy_notify;
	BoxesLibvirtMachine* _tmp19_;
	BoxesAppWindow* _tmp20_;
	BoxesAppWindow* _tmp21_;
	BoxesNotificationbar* _tmp22_;
	BoxesNotificationbar* _tmp23_;
	const gchar* _tmp24_;
	BoxesNotificationOKFunc _tmp25_;
	void* _tmp25__target;
	GDestroyNotify _tmp25__target_destroy_notify;
	BoxesNotificationDismissFunc _tmp26_;
	void* _tmp26__target;
	GDestroyNotify _tmp26__target_destroy_notify;
	BoxesNotification* _tmp27_;
	BoxesNotification* _tmp28_;
	BoxesLibvirtMachine* _tmp29_;
	gboolean _tmp30_;
	gboolean _tmp31_;
	GVirDomainDisk* disk;
	BoxesLibvirtMachine* _tmp32_;
	GVirDomainDisk* _tmp33_;
	GVirDomainDisk* _tmp34_;
	guint64 size;
	guint64 _tmp35_;
	GVirDomainDisk* _tmp36_;
	guint64 _tmp37_;
	GVirStoragePool* pool;
	BoxesLibvirtMachine* _tmp38_;
	GVirConnection* _tmp39_;
	GVirConnection* _tmp40_;
	GVirStoragePool* _tmp41_;
	GVirStoragePool* _tmp42_;
	BoxesLibvirtMachine* _tmp43_;
	guint64 _tmp44_;
	GError* _error_;
	BoxesLibvirtMachine* _tmp45_;
	GVirStorageVol* _tmp46_;
	GVirStorageVol* _tmp47_;
	const gchar* _tmp48_;
	guint64 _tmp49_;
	GError* _tmp50_;
	const gchar* _tmp51_;
	guint64 _tmp52_;
	guint64 _tmp53_;
	GError* _vala1__error_;
	BoxesLibvirtMachine* _tmp54_;
	GVirStorageVol* _tmp55_;
	GVirStorageVol* _tmp56_;
	const gchar* _tmp57_;
	guint64 _tmp58_;
	GError* _tmp59_;
	const gchar* _tmp60_;
	GError * _inner_error_;
};

struct _BoxesLibvirtMachinePropertiesForceChangeStorageSizeData {
	int _state_;
	GObject* _source_object_;
	GAsyncResult* _res_;
	GTask* _async_result;
	BoxesLibvirtMachineProperties* self;
	BoxesProperty* property;
	guint64 value;
	GList* snapshots;
	GList* _tmp0_;
	GList* _tmp1_;
	GList* snapshot_collection;
	GList* snapshot_it;
	GVirDomainSnapshot* _tmp2_;
	GVirDomainSnapshot* snapshot;
	GVirDomainSnapshot* _tmp3_;
	BoxesProperty* _tmp4_;
	guint64 _tmp5_;
	GError* e;
	GError* _tmp6_;
	const gchar* _tmp7_;
	GError * _inner_error_;
};

struct _BoxesLibvirtMachinePropertiesGetSnapshotsData {
	int _state_;
	GObject* _source_object_;
	GAsyncResult* _res_;
	GTask* _async_result;
	BoxesLibvirtMachineProperties* self;
	GCancellable* cancellable;
	GList* result;
	BoxesLibvirtMachine* _tmp0_;
	GVirDomain* _tmp1_;
	GVirDomain* _tmp2_;
	GCancellable* _tmp3_;
	BoxesLibvirtMachine* _tmp4_;
	GVirDomain* _tmp5_;
	GVirDomain* _tmp6_;
	GList* _tmp7_;
	GError * _inner_error_;
};

struct _Block54Data {
	int _ref_count_;
	BoxesLibvirtMachineProperties* self;
	GtkBox* box;
	GtkSwitch* toggle;
	gchar* name;
};


static gpointer boxes_libvirt_machine_properties_parent_class = NULL;
extern BoxesApp* boxes_app_app;
static BoxesIPropertiesProviderIface * boxes_libvirt_machine_properties_boxes_iproperties_provider_parent_iface = NULL;

GType boxes_properties_page_get_type (void) G_GNUC_CONST;
GType boxes_property_get_type (void) G_GNUC_CONST;
GType boxes_iproperties_provider_get_type (void) G_GNUC_CONST;
GType boxes_libvirt_machine_properties_get_type (void) G_GNUC_CONST;
GType boxes_collection_item_get_type (void) G_GNUC_CONST;
GType boxes_machine_get_type (void) G_GNUC_CONST;
GType boxes_libvirt_machine_get_type (void) G_GNUC_CONST;
#define BOXES_LIBVIRT_MACHINE_PROPERTIES_GET_PRIVATE(o) (G_TYPE_INSTANCE_GET_PRIVATE ((o), BOXES_TYPE_LIBVIRT_MACHINE_PROPERTIES, BoxesLibvirtMachinePropertiesPrivate))
#define BOXES_LIBVIRT_MACHINE_PROPERTIES_MEGABYTES ((guint64) (1000 * 1000))
BoxesLibvirtMachineProperties* boxes_libvirt_machine_properties_new (BoxesLibvirtMachine* machine);
BoxesLibvirtMachineProperties* boxes_libvirt_machine_properties_construct (GType object_type, BoxesLibvirtMachine* machine);
static void __lambda113_ (BoxesLibvirtMachineProperties* self);
static gboolean boxes_libvirt_machine_properties_save_machine_name_change (BoxesLibvirtMachineProperties* self);
static void ___lambda113__g_object_notify (GObject* _sender, GParamSpec* pspec, gpointer self);
GVirDomain* boxes_libvirt_machine_get_domain (BoxesLibvirtMachine* self);
const gchar* boxes_collection_item_get_name (BoxesCollectionItem* self);
static gchar* boxes_libvirt_machine_properties_collect_logs (BoxesLibvirtMachineProperties* self);
GType boxes_ui_state_get_type (void) G_GNUC_CONST;
GType boxes_ui_get_type (void) G_GNUC_CONST;
GType boxes_machine_connect_flags_get_type (void) G_GNUC_CONST;
GVirConnection* boxes_libvirt_machine_get_connection (BoxesLibvirtMachine* self);
static void _vala_GVirDomainInfo_free (GVirDomainInfo* self);
const gchar* gvir_domain_state_to_string (GVirDomainState self);
static void _vala_GVirNodeInfo_free (GVirNodeInfo* self);
GType boxes_display_get_type (void) G_GNUC_CONST;
BoxesDisplay* boxes_machine_get_display (BoxesMachine* self);
void boxes_display_collect_logs (BoxesDisplay* self, GString* builder);
static GList* boxes_libvirt_machine_properties_real_get_properties (BoxesIPropertiesProvider* base, BoxesPropertiesPage page);
gboolean boxes_machine_get_is_on (BoxesMachine* self);
gboolean boxes_libvirt_machine_update_display (BoxesLibvirtMachine* self, GError** error);
static void _g_object_unref0_ (gpointer var);
static inline void _g_list_free__g_object_unref0_ (GList* self);
GType boxes_editable_string_property_get_type (void) G_GNUC_CONST;
static Block46Data* block46_data_ref (Block46Data* _data46_);
static void block46_data_unref (void * _userdata_);
BoxesEditableStringProperty* boxes_iproperties_provider_add_editable_string_property (BoxesIPropertiesProvider* self, GList* * list, const gchar* name, const gchar* value);
static void ___lambda114_ (BoxesLibvirtMachineProperties* self, BoxesEditableStringProperty* property, const gchar* name);
void boxes_collection_item_set_name (BoxesCollectionItem* self, const gchar* value);
static void ____lambda114__boxes_editable_string_property_changed (BoxesEditableStringProperty* _sender, const gchar* value, gpointer self);
static void ___lambda115_ (Block46Data* _data46_);
void boxes_editable_string_property_set_text (BoxesEditableStringProperty* self, const gchar* value);
static void ____lambda115__g_object_notify (GObject* _sender, GParamSpec* pspec, gpointer self);
gchar* boxes_libvirt_machine_get_ip_address (BoxesLibvirtMachine* self);
GType boxes_string_property_get_type (void) G_GNUC_CONST;
BoxesStringProperty* boxes_iproperties_provider_add_string_property (BoxesIPropertiesProvider* self, GList* * list, const gchar* name, const gchar* value);
const gchar* boxes_display_get_protocol (BoxesDisplay* self);
gchar* boxes_display_get_uri (BoxesDisplay* self);
static void boxes_libvirt_machine_properties_add_resource_usage_graphs (BoxesLibvirtMachineProperties* self, GList* * list);
static void boxes_libvirt_machine_properties_add_system_props_buttons (BoxesLibvirtMachineProperties* self, GList* * list);
void boxes_libvirt_machine_properties_get_resources_properties (BoxesLibvirtMachineProperties* self, GList* * list);
static void boxes_libvirt_machine_properties_add_run_in_bg_property (BoxesLibvirtMachineProperties* self, GList* * list);
GVirConfigDomain* boxes_libvirt_machine_get_domain_config (BoxesLibvirtMachine* self);
static void boxes_libvirt_machine_properties_add_cdrom_property (BoxesLibvirtMachineProperties* self, GVirConfigDomainDisk* disk_config, GList* * list);
gboolean boxes_vm_configurator_is_install_config (GVirConfigDomain* domain);
GType boxes_snapshots_property_get_type (void) G_GNUC_CONST;
static BoxesSnapshotsProperty* boxes_libvirt_machine_properties_add_snapshots_property (BoxesLibvirtMachineProperties* self, GList* * list);
GType boxes_size_property_get_type (void) G_GNUC_CONST;
static BoxesSizeProperty* boxes_libvirt_machine_properties_add_ram_property (BoxesLibvirtMachineProperties* self, GList* * list);
static BoxesSizeProperty* boxes_libvirt_machine_properties_add_storage_property (BoxesLibvirtMachineProperties* self, GList* * list);
static void boxes_libvirt_machine_properties_mark_recommended_resources (BoxesLibvirtMachineProperties* self, BoxesSizeProperty* ram_property, BoxesSizeProperty* storage_property, GAsyncReadyCallback _callback_, gpointer _user_data_);
static void boxes_libvirt_machine_properties_mark_recommended_resources_finish (BoxesLibvirtMachineProperties* self, GAsyncResult* _res_);
static Block47Data* block47_data_ref (Block47Data* _data47_);
static void block47_data_unref (void * _userdata_);
gpointer boxes_vm_creator_ref (gpointer instance);
void boxes_vm_creator_unref (gpointer instance);
GParamSpec* boxes_param_spec_vm_creator (const gchar* name, const gchar* nick, const gchar* blurb, GType object_type, GParamFlags flags);
void boxes_value_set_vm_creator (GValue* value, gpointer v_object);
void boxes_value_take_vm_creator (GValue* value, gpointer v_object);
gpointer boxes_value_get_vm_creator (const GValue* value);
GType boxes_vm_creator_get_type (void) G_GNUC_CONST;
BoxesVMCreator* boxes_libvirt_machine_get_vm_creator (BoxesLibvirtMachine* self);
GType boxes_installer_media_get_type (void) G_GNUC_CONST;
BoxesInstallerMedia* boxes_vm_creator_get_install_media (BoxesVMCreator* self);
gboolean boxes_vm_creator_get_express_install (BoxesVMCreator* self);
BoxesProperty* boxes_iproperties_provider_add_property (BoxesIPropertiesProvider* self, GList* * list, const gchar* name, GtkWidget* widget, GtkWidget* extra_widget);
static void __lambda140_ (Block47Data* _data47_);
GType boxes_app_window_get_type (void) G_GNUC_CONST;
BoxesAppWindow* boxes_machine_get_window (BoxesMachine* self);
GType boxes_wizard_window_get_type (void) G_GNUC_CONST;
GType boxes_properties_window_get_type (void) G_GNUC_CONST;
GType boxes_searchbar_get_type (void) G_GNUC_CONST;
GType boxes_topbar_get_type (void) G_GNUC_CONST;
GType boxes_selectionbar_get_type (void) G_GNUC_CONST;
GType boxes_display_page_get_type (void) G_GNUC_CONST;
GType boxes_empty_boxes_get_type (void) G_GNUC_CONST;
void boxes_properties_window_show_file_chooser (BoxesPropertiesWindow* self, BoxesPropertiesWindowFileChosenFunc file_chosen_func, void* file_chosen_func_target, GDestroyNotify file_chosen_func_target_destroy_notify);
static void ___lambda141_ (Block47Data* _data47_, const gchar* path);
static void ____lambda141__boxes_properties_window_file_chosen_func (const gchar* path, gpointer self);
static void ___lambda140__gtk_button_clicked (GtkButton* _sender, gpointer self);
void boxes_property_set_description_alignment (BoxesProperty* self, GtkAlign value);
static void boxes_libvirt_machine_properties_update_ram_property (BoxesLibvirtMachineProperties* self, BoxesProperty* property);
void boxes_property_set_reboot_required (BoxesProperty* self, gboolean value);
static void boxes_libvirt_machine_properties_mark_recommended_resources_data_free (gpointer _data);
static gboolean boxes_libvirt_machine_properties_mark_recommended_resources_co (BoxesLibvirtMachinePropertiesMarkRecommendedResourcesData* _data_);
static void boxes_libvirt_machine_properties_get_os_for_machine (BoxesLibvirtMachineProperties* self, BoxesLibvirtMachine* machine, GAsyncReadyCallback _callback_, gpointer _user_data_);
static OsinfoOs* boxes_libvirt_machine_properties_get_os_for_machine_finish (BoxesLibvirtMachineProperties* self, GAsyncResult* _res_);
static void boxes_libvirt_machine_properties_mark_recommended_resources_ready (GObject* source_object, GAsyncResult* _res_, gpointer _user_data_);
OsinfoResources* boxes_os_database_get_recommended_resources_for_os (OsinfoOs* os, const gchar* architecture);
void boxes_size_property_set_recommended (BoxesSizeProperty* self, guint64 value);
static void boxes_libvirt_machine_properties_get_os_for_machine_data_free (gpointer _data);
static gboolean boxes_libvirt_machine_properties_get_os_for_machine_co (BoxesLibvirtMachinePropertiesGetOsForMachineData* _data_);
gchar* boxes_vm_configurator_get_os_id (GVirConfigDomain* domain);
GType boxes_os_database_get_type (void) G_GNUC_CONST;
GType boxes_media_manager_get_type (void) G_GNUC_CONST;
BoxesMediaManager* boxes_media_manager_get_instance (void);
BoxesOSDatabase* boxes_media_manager_get_os_db (BoxesMediaManager* self);
void boxes_os_database_get_os_by_id (BoxesOSDatabase* self, const gchar* id, GAsyncReadyCallback _callback_, gpointer _user_data_);
GQuark boxes_os_database_error_quark (void);
OsinfoOs* boxes_os_database_get_os_by_id_finish (BoxesOSDatabase* self, GAsyncResult* _res_, GError** error);
static void boxes_libvirt_machine_properties_get_os_for_machine_ready (GObject* source_object, GAsyncResult* _res_, gpointer _user_data_);
GType boxes_resource_graph_get_type (void) G_GNUC_CONST;
static Block48Data* block48_data_ref (Block48Data* _data48_);
static void block48_data_unref (void * _userdata_);
BoxesResourceGraph* boxes_resource_graph_new (gdouble ymax);
BoxesResourceGraph* boxes_resource_graph_construct (GType object_type, gdouble ymax);
void boxes_resource_graph_set_npoints (BoxesResourceGraph* self, gint value);
static void __lambda116_ (Block48Data* _data48_);
void boxes_resource_graph_set_points (BoxesResourceGraph* self, gdouble* value, int value_length1);
static void ___lambda116__boxes_libvirt_machine_stats_updated (BoxesLibvirtMachine* _sender, gpointer self);
static void __lambda117_ (Block48Data* _data48_);
static void ___lambda117__boxes_property_flushed (BoxesProperty* _sender, gpointer self);
static Block49Data* block49_data_ref (Block49Data* _data49_);
static void block49_data_unref (void * _userdata_);
static void __lambda118_ (BoxesLibvirtMachineProperties* self);
void boxes_machine_restart (BoxesMachine* self);
void boxes_properties_window_revert_state (BoxesPropertiesWindow* self);
static void ___lambda118__gtk_button_clicked (GtkButton* _sender, gpointer self);
gboolean boxes_machine_get_is_running (BoxesMachine* self);
static void __lambda130_ (BoxesLibvirtMachineProperties* self);
void boxes_libvirt_machine_force_shutdown (BoxesLibvirtMachine* self);
static void ___lambda130__gtk_button_clicked (GtkButton* _sender, gpointer self);
static void __lambda131_ (Block49Data* _data49_);
static void ___lambda131__g_object_notify (GObject* _sender, GParamSpec* pspec, gpointer self);
static void __lambda132_ (BoxesLibvirtMachineProperties* self);
void boxes_properties_window_show_troubleshoot_log (BoxesPropertiesWindow* self, const gchar* log);
static void ___lambda132__gtk_button_clicked (GtkButton* _sender, gpointer self);
static void __lambda133_ (Block49Data* _data49_);
static void ___lambda133__boxes_property_flushed (BoxesProperty* _sender, gpointer self);
static Block50Data* block50_data_ref (Block50Data* _data50_);
static void block50_data_unref (void * _userdata_);
BoxesSizeProperty* boxes_iproperties_provider_add_size_property (BoxesIPropertiesProvider* self, GList* * list, const gchar* name, guint64 size, guint64 min, guint64 max, guint64 allocation, guint64 step, GFormatSizeFlags format_flags);
GtkWidget* boxes_property_get_widget (BoxesProperty* self);
gboolean boxes_vm_configurator_is_live_config (GVirConfigDomain* domain);
BoxesUIState boxes_ui_get_ui_state (BoxesUI* self);
GType boxes_machine_machine_state_get_type (void) G_GNUC_CONST;
BoxesMachineMachineState boxes_machine_get_state (BoxesMachine* self);
void boxes_property_set_sensitive (BoxesProperty* self, gboolean value);
static void boxes_libvirt_machine_properties_on_ram_changed (BoxesLibvirtMachineProperties* self, BoxesProperty* property, guint64 value);
static void _boxes_libvirt_machine_properties_on_ram_changed_boxes_size_property_changed (BoxesSizeProperty* _sender, guint64 value, gpointer self);
static void ___lambda135_ (Block50Data* _data50_);
static void ____lambda135__g_object_notify (GObject* _sender, GParamSpec* pspec, gpointer self);
static Block51Data* block51_data_ref (Block51Data* _data51_);
static void block51_data_unref (void * _userdata_);
static gboolean __lambda134_ (Block51Data* _data51_);
static gboolean ___lambda134__gsource_func (gpointer self);
void boxes_property_set_deferred_change (BoxesProperty* self, GSourceFunc value, gpointer value_target, GDestroyNotify value_target_destroy_notify);
gboolean boxes_libvirt_machine_get_importing (BoxesLibvirtMachine* self);
GVirStorageVol* boxes_libvirt_machine_get_storage_volume (BoxesLibvirtMachine* self);
GVirStoragePool* boxes_get_storage_pool (GVirConnection* connection);
static void _vala_GVirStorageVolInfo_free (GVirStorageVolInfo* self);
static guint64 boxes_libvirt_machine_properties_get_minimum_disk_size (BoxesLibvirtMachineProperties* self, GError** error);
static void _vala_GVirStoragePoolInfo_free (GVirStoragePoolInfo* self);
void boxes_property_set_defer_interval (BoxesProperty* self, guint value);
static void boxes_libvirt_machine_properties_on_storage_changed (BoxesLibvirtMachineProperties* self, BoxesProperty* property, guint64 value);
static void _boxes_libvirt_machine_properties_on_storage_changed_boxes_size_property_changed (BoxesSizeProperty* _sender, guint64 value, gpointer self);
static Block52Data* block52_data_ref (Block52Data* _data52_);
static void block52_data_unref (void * _userdata_);
static gboolean __lambda136_ (Block52Data* _data52_);
static void boxes_libvirt_machine_properties_change_storage_size (BoxesLibvirtMachineProperties* self, BoxesProperty* property, guint64 value, GAsyncReadyCallback _callback_, gpointer _user_data_);
static void boxes_libvirt_machine_properties_change_storage_size_finish (BoxesLibvirtMachineProperties* self, GAsyncResult* _res_);
static gboolean ___lambda136__gsource_func (gpointer self);
static void boxes_libvirt_machine_properties_change_storage_size_data_free (gpointer _data);
static gboolean boxes_libvirt_machine_properties_change_storage_size_co (BoxesLibvirtMachinePropertiesChangeStorageSizeData* _data_);
static Block53Data* block53_data_ref (Block53Data* _data53_);
static void block53_data_unref (void * _userdata_);
void boxes_libvirt_machine_properties_get_snapshots (BoxesLibvirtMachineProperties* self, GCancellable* cancellable, GAsyncReadyCallback _callback_, gpointer _user_data_);
GList* boxes_libvirt_machine_properties_get_snapshots_finish (BoxesLibvirtMachineProperties* self, GAsyncResult* _res_, GError** error);
static void boxes_libvirt_machine_properties_change_storage_size_ready (GObject* source_object, GAsyncResult* _res_, gpointer _user_data_);
static void ___lambda137_ (BoxesLibvirtMachineProperties* self);
static void ____lambda137__boxes_notification_ok_func (gpointer self);
static void ___lambda138_ (Block53Data* _data53_);
static void boxes_libvirt_machine_properties_force_change_storage_size (BoxesLibvirtMachineProperties* self, BoxesProperty* property, guint64 value, GAsyncReadyCallback _callback_, gpointer _user_data_);
static void boxes_libvirt_machine_properties_force_change_storage_size_finish (BoxesLibvirtMachineProperties* self, GAsyncResult* _res_);
static void ____lambda138__boxes_notification_dismiss_func (gpointer self);
GType boxes_notificationbar_get_type (void) G_GNUC_CONST;
BoxesNotificationbar* boxes_app_window_get_notificationbar (BoxesAppWindow* self);
GType boxes_notification_get_type (void) G_GNUC_CONST;
BoxesNotification* boxes_notificationbar_display_for_action (BoxesNotificationbar* self, const gchar* message, const gchar* action_label, BoxesNotificationOKFunc action_func, void* action_func_target, GDestroyNotify action_func_target_destroy_notify, BoxesNotificationDismissFunc ignore_func, void* ignore_func_target, GDestroyNotify ignore_func_target_destroy_notify, gint timeout);
#define BOXES_NOTIFICATIONBAR_DEFAULT_TIMEOUT 6
GVirDomainDisk* boxes_libvirt_machine_get_domain_disk (BoxesLibvirtMachine* self, GError** error);
void boxes_libvirt_machine_update_domain_config (BoxesLibvirtMachine* self);
static void boxes_libvirt_machine_properties_resize_storage_volume (BoxesLibvirtMachineProperties* self, guint64 size, GError** error);
static void boxes_libvirt_machine_properties_force_change_storage_size_data_free (gpointer _data);
static gboolean boxes_libvirt_machine_properties_force_change_storage_size_co (BoxesLibvirtMachinePropertiesForceChangeStorageSizeData* _data_);
static void boxes_libvirt_machine_properties_force_change_storage_size_ready (GObject* source_object, GAsyncResult* _res_, gpointer _user_data_);
OsinfoResources* boxes_os_database_get_minimum_resources_for_os (OsinfoOs* os, const gchar* architecture);
OsinfoResources* boxes_os_database_get_minimum_resources (void);
void boxes_libvirt_machine_set_storage_volume (BoxesLibvirtMachine* self, GVirStorageVol* value);
static void boxes_libvirt_machine_properties_get_snapshots_data_free (gpointer _data);
static gboolean boxes_libvirt_machine_properties_get_snapshots_co (BoxesLibvirtMachinePropertiesGetSnapshotsData* _data_);
static void boxes_libvirt_machine_properties_get_snapshots_ready (GObject* source_object, GAsyncResult* _res_, gpointer _user_data_);
static Block54Data* block54_data_ref (Block54Data* _data54_);
static void block54_data_unref (void * _userdata_);
GType boxes_app_get_type (void) G_GNUC_CONST;
GVirConnection* boxes_app_get_default_connection (BoxesApp* self);
static void __lambda139_ (Block54Data* _data54_, GParamSpec* tooltip);
static void ___lambda139__g_object_notify (GObject* _sender, GParamSpec* pspec, gpointer self);
BoxesSnapshotsProperty* boxes_snapshots_property_new (BoxesLibvirtMachine* machine);
BoxesSnapshotsProperty* boxes_snapshots_property_construct (GType object_type, BoxesLibvirtMachine* machine);
static void boxes_libvirt_machine_properties_finalize (GObject * obj);


static void __lambda113_ (BoxesLibvirtMachineProperties* self) {
#line 14 "/home/fborges/checkout/gnome-boxes/src/libvirt-machine-properties.vala"
	boxes_libvirt_machine_properties_save_machine_name_change (self);
#line 1026 "libvirt-machine-properties.c"
}


static void ___lambda113__g_object_notify (GObject* _sender, GParamSpec* pspec, gpointer self) {
#line 13 "/home/fborges/checkout/gnome-boxes/src/libvirt-machine-properties.vala"
	__lambda113_ ((BoxesLibvirtMachineProperties*) self);
#line 1033 "libvirt-machine-properties.c"
}


BoxesLibvirtMachineProperties* boxes_libvirt_machine_properties_construct (GType object_type, BoxesLibvirtMachine* machine) {
	BoxesLibvirtMachineProperties * self = NULL;
	BoxesLibvirtMachine* _tmp0_;
	BoxesLibvirtMachine* _tmp1_;
#line 10 "/home/fborges/checkout/gnome-boxes/src/libvirt-machine-properties.vala"
	g_return_val_if_fail (machine != NULL, NULL);
#line 10 "/home/fborges/checkout/gnome-boxes/src/libvirt-machine-properties.vala"
	self = (BoxesLibvirtMachineProperties*) g_object_new (object_type, NULL);
#line 11 "/home/fborges/checkout/gnome-boxes/src/libvirt-machine-properties.vala"
	_tmp0_ = machine;
#line 11 "/home/fborges/checkout/gnome-boxes/src/libvirt-machine-properties.vala"
	self->priv->machine = _tmp0_;
#line 13 "/home/fborges/checkout/gnome-boxes/src/libvirt-machine-properties.vala"
	_tmp1_ = machine;
#line 13 "/home/fborges/checkout/gnome-boxes/src/libvirt-machine-properties.vala"
	g_signal_connect_object ((GObject*) _tmp1_, "notify::name", (GCallback) ___lambda113__g_object_notify, self, 0);
#line 10 "/home/fborges/checkout/gnome-boxes/src/libvirt-machine-properties.vala"
	return self;
#line 1055 "libvirt-machine-properties.c"
}


BoxesLibvirtMachineProperties* boxes_libvirt_machine_properties_new (BoxesLibvirtMachine* machine) {
#line 10 "/home/fborges/checkout/gnome-boxes/src/libvirt-machine-properties.vala"
	return boxes_libvirt_machine_properties_construct (BOXES_TYPE_LIBVIRT_MACHINE_PROPERTIES, machine);
#line 1062 "libvirt-machine-properties.c"
}


static gboolean boxes_libvirt_machine_properties_save_machine_name_change (BoxesLibvirtMachineProperties* self) {
	gboolean result = FALSE;
	gboolean _tmp21_ = FALSE;
	GError * _inner_error_ = NULL;
#line 18 "/home/fborges/checkout/gnome-boxes/src/libvirt-machine-properties.vala"
	g_return_val_if_fail (self != NULL, FALSE);
#line 1072 "libvirt-machine-properties.c"
	{
		GVirConfigDomain* config = NULL;
		BoxesLibvirtMachine* _tmp0_;
		GVirDomain* _tmp1_;
		GVirDomain* _tmp2_;
		GVirConfigDomain* _tmp3_;
		GVirConfigDomain* _tmp4_;
		BoxesLibvirtMachine* _tmp5_;
		const gchar* _tmp6_;
		const gchar* _tmp7_;
		BoxesLibvirtMachine* _tmp8_;
		GVirDomain* _tmp9_;
		GVirDomain* _tmp10_;
		GVirConfigDomain* _tmp11_;
#line 20 "/home/fborges/checkout/gnome-boxes/src/libvirt-machine-properties.vala"
		_tmp0_ = self->priv->machine;
#line 20 "/home/fborges/checkout/gnome-boxes/src/libvirt-machine-properties.vala"
		_tmp1_ = boxes_libvirt_machine_get_domain (_tmp0_);
#line 20 "/home/fborges/checkout/gnome-boxes/src/libvirt-machine-properties.vala"
		_tmp2_ = _tmp1_;
#line 20 "/home/fborges/checkout/gnome-boxes/src/libvirt-machine-properties.vala"
		_tmp3_ = gvir_domain_get_config (_tmp2_, (guint) GVIR_DOMAIN_XML_INACTIVE, &_inner_error_);
#line 20 "/home/fborges/checkout/gnome-boxes/src/libvirt-machine-properties.vala"
		config = _tmp3_;
#line 20 "/home/fborges/checkout/gnome-boxes/src/libvirt-machine-properties.vala"
		if (G_UNLIKELY (_inner_error_ != NULL)) {
#line 1099 "libvirt-machine-properties.c"
			goto __catch35_g_error;
		}
#line 22 "/home/fborges/checkout/gnome-boxes/src/libvirt-machine-properties.vala"
		_tmp4_ = config;
#line 22 "/home/fborges/checkout/gnome-boxes/src/libvirt-machine-properties.vala"
		_tmp5_ = self->priv->machine;
#line 22 "/home/fborges/checkout/gnome-boxes/src/libvirt-machine-properties.vala"
		_tmp6_ = boxes_collection_item_get_name ((BoxesCollectionItem*) _tmp5_);
#line 22 "/home/fborges/checkout/gnome-boxes/src/libvirt-machine-properties.vala"
		_tmp7_ = _tmp6_;
#line 22 "/home/fborges/checkout/gnome-boxes/src/libvirt-machine-properties.vala"
		gvir_config_domain_set_title (_tmp4_, _tmp7_);
#line 24 "/home/fborges/checkout/gnome-boxes/src/libvirt-machine-properties.vala"
		_tmp8_ = self->priv->machine;
#line 24 "/home/fborges/checkout/gnome-boxes/src/libvirt-machine-properties.vala"
		_tmp9_ = boxes_libvirt_machine_get_domain (_tmp8_);
#line 24 "/home/fborges/checkout/gnome-boxes/src/libvirt-machine-properties.vala"
		_tmp10_ = _tmp9_;
#line 24 "/home/fborges/checkout/gnome-boxes/src/libvirt-machine-properties.vala"
		_tmp11_ = config;
#line 24 "/home/fborges/checkout/gnome-boxes/src/libvirt-machine-properties.vala"
		gvir_domain_set_config (_tmp10_, _tmp11_, &_inner_error_);
#line 24 "/home/fborges/checkout/gnome-boxes/src/libvirt-machine-properties.vala"
		if (G_UNLIKELY (_inner_error_ != NULL)) {
#line 24 "/home/fborges/checkout/gnome-boxes/src/libvirt-machine-properties.vala"
			_g_object_unref0 (config);
#line 1126 "libvirt-machine-properties.c"
			goto __catch35_g_error;
		}
#line 26 "/home/fborges/checkout/gnome-boxes/src/libvirt-machine-properties.vala"
		result = TRUE;
#line 26 "/home/fborges/checkout/gnome-boxes/src/libvirt-machine-properties.vala"
		_g_object_unref0 (config);
#line 26 "/home/fborges/checkout/gnome-boxes/src/libvirt-machine-properties.vala"
		return result;
#line 1135 "libvirt-machine-properties.c"
	}
	goto __finally35;
	__catch35_g_error:
	{
		GError* _error_ = NULL;
		BoxesLibvirtMachine* _tmp12_;
		GVirDomain* _tmp13_;
		GVirDomain* _tmp14_;
		const gchar* _tmp15_;
		BoxesLibvirtMachine* _tmp16_;
		const gchar* _tmp17_;
		const gchar* _tmp18_;
		GError* _tmp19_;
		const gchar* _tmp20_;
#line 19 "/home/fborges/checkout/gnome-boxes/src/libvirt-machine-properties.vala"
		_error_ = _inner_error_;
#line 19 "/home/fborges/checkout/gnome-boxes/src/libvirt-machine-properties.vala"
		_inner_error_ = NULL;
#line 28 "/home/fborges/checkout/gnome-boxes/src/libvirt-machine-properties.vala"
		_tmp12_ = self->priv->machine;
#line 28 "/home/fborges/checkout/gnome-boxes/src/libvirt-machine-properties.vala"
		_tmp13_ = boxes_libvirt_machine_get_domain (_tmp12_);
#line 28 "/home/fborges/checkout/gnome-boxes/src/libvirt-machine-properties.vala"
		_tmp14_ = _tmp13_;
#line 28 "/home/fborges/checkout/gnome-boxes/src/libvirt-machine-properties.vala"
		_tmp15_ = gvir_domain_get_name (_tmp14_);
#line 28 "/home/fborges/checkout/gnome-boxes/src/libvirt-machine-properties.vala"
		_tmp16_ = self->priv->machine;
#line 28 "/home/fborges/checkout/gnome-boxes/src/libvirt-machine-properties.vala"
		_tmp17_ = boxes_collection_item_get_name ((BoxesCollectionItem*) _tmp16_);
#line 28 "/home/fborges/checkout/gnome-boxes/src/libvirt-machine-properties.vala"
		_tmp18_ = _tmp17_;
#line 28 "/home/fborges/checkout/gnome-boxes/src/libvirt-machine-properties.vala"
		_tmp19_ = _error_;
#line 28 "/home/fborges/checkout/gnome-boxes/src/libvirt-machine-properties.vala"
		_tmp20_ = _tmp19_->message;
#line 28 "/home/fborges/checkout/gnome-boxes/src/libvirt-machine-properties.vala"
		g_warning ("libvirt-machine-properties.vala:28: Failed to save change of title of " \
"box from '%s' to '%s': %s", _tmp15_, _tmp18_, _tmp20_);
#line 30 "/home/fborges/checkout/gnome-boxes/src/libvirt-machine-properties.vala"
		result = FALSE;
#line 30 "/home/fborges/checkout/gnome-boxes/src/libvirt-machine-properties.vala"
		_g_error_free0 (_error_);
#line 30 "/home/fborges/checkout/gnome-boxes/src/libvirt-machine-properties.vala"
		return result;
#line 1180 "libvirt-machine-properties.c"
	}
	__finally35:
#line 19 "/home/fborges/checkout/gnome-boxes/src/libvirt-machine-properties.vala"
	g_critical ("file %s: line %d: uncaught error: %s (%s, %d)", __FILE__, __LINE__, _inner_error_->message, g_quark_to_string (_inner_error_->domain), _inner_error_->code);
#line 19 "/home/fborges/checkout/gnome-boxes/src/libvirt-machine-properties.vala"
	g_clear_error (&_inner_error_);
#line 19 "/home/fborges/checkout/gnome-boxes/src/libvirt-machine-properties.vala"
	return _tmp21_;
#line 1189 "libvirt-machine-properties.c"
}


static void _vala_GVirDomainInfo_free (GVirDomainInfo* self) {
#line 46 "/home/fborges/checkout/gnome-boxes/src/libvirt-machine-properties.vala"
	g_boxed_free (gvir_domain_info_get_type (), self);
#line 1196 "libvirt-machine-properties.c"
}


static void _vala_GVirNodeInfo_free (GVirNodeInfo* self) {
#line 41 "/home/fborges/checkout/gnome-boxes/src/libvirt-machine-properties.vala"
	g_boxed_free (gvir_node_info_get_type (), self);
#line 1203 "libvirt-machine-properties.c"
}


static gchar* boxes_libvirt_machine_properties_collect_logs (BoxesLibvirtMachineProperties* self) {
	gchar* result = NULL;
	GString* builder = NULL;
	GString* _tmp0_;
	GString* _tmp1_;
	BoxesLibvirtMachine* _tmp2_;
	BoxesCollectionSource* _tmp3_;
	gchar* _tmp4_;
	gchar* _tmp5_;
	gchar* _tmp6_;
	GString* _tmp7_;
	BoxesLibvirtMachine* _tmp8_;
	GVirDomain* _tmp9_;
	GVirDomain* _tmp10_;
	const gchar* _tmp11_;
	GString* _tmp12_;
	BoxesLibvirtMachine* _tmp13_;
	GVirDomain* _tmp14_;
	GVirDomain* _tmp15_;
	const gchar* _tmp16_;
	const gchar* _tmp17_ = NULL;
	BoxesLibvirtMachine* _tmp18_;
	GVirDomain* _tmp19_;
	GVirDomain* _tmp20_;
	gboolean _tmp21_;
	GString* _tmp22_;
	BoxesLibvirtMachine* _tmp47_;
	BoxesDisplay* _tmp48_;
	BoxesDisplay* _tmp49_;
	GString* _tmp78_;
	const gchar* _tmp79_;
	gchar* _tmp80_;
	GError * _inner_error_ = NULL;
#line 34 "/home/fborges/checkout/gnome-boxes/src/libvirt-machine-properties.vala"
	g_return_val_if_fail (self != NULL, NULL);
#line 35 "/home/fborges/checkout/gnome-boxes/src/libvirt-machine-properties.vala"
	_tmp0_ = g_string_new ("");
#line 35 "/home/fborges/checkout/gnome-boxes/src/libvirt-machine-properties.vala"
	builder = _tmp0_;
#line 37 "/home/fborges/checkout/gnome-boxes/src/libvirt-machine-properties.vala"
	_tmp1_ = builder;
#line 37 "/home/fborges/checkout/gnome-boxes/src/libvirt-machine-properties.vala"
	_tmp2_ = self->priv->machine;
#line 37 "/home/fborges/checkout/gnome-boxes/src/libvirt-machine-properties.vala"
	_tmp3_ = ((BoxesMachine*) _tmp2_)->source;
#line 37 "/home/fborges/checkout/gnome-boxes/src/libvirt-machine-properties.vala"
	_tmp4_ = boxes_collection_source_get_uri (_tmp3_);
#line 37 "/home/fborges/checkout/gnome-boxes/src/libvirt-machine-properties.vala"
	_tmp5_ = _tmp4_;
#line 37 "/home/fborges/checkout/gnome-boxes/src/libvirt-machine-properties.vala"
	_tmp6_ = _tmp5_;
#line 37 "/home/fborges/checkout/gnome-boxes/src/libvirt-machine-properties.vala"
	g_string_append_printf (_tmp1_, "Broker URL: %s\n", _tmp6_);
#line 37 "/home/fborges/checkout/gnome-boxes/src/libvirt-machine-properties.vala"
	_g_free0 (_tmp6_);
#line 38 "/home/fborges/checkout/gnome-boxes/src/libvirt-machine-properties.vala"
	_tmp7_ = builder;
#line 38 "/home/fborges/checkout/gnome-boxes/src/libvirt-machine-properties.vala"
	_tmp8_ = self->priv->machine;
#line 38 "/home/fborges/checkout/gnome-boxes/src/libvirt-machine-properties.vala"
	_tmp9_ = boxes_libvirt_machine_get_domain (_tmp8_);
#line 38 "/home/fborges/checkout/gnome-boxes/src/libvirt-machine-properties.vala"
	_tmp10_ = _tmp9_;
#line 38 "/home/fborges/checkout/gnome-boxes/src/libvirt-machine-properties.vala"
	_tmp11_ = gvir_domain_get_name (_tmp10_);
#line 38 "/home/fborges/checkout/gnome-boxes/src/libvirt-machine-properties.vala"
	g_string_append_printf (_tmp7_, "Domain: %s\n", _tmp11_);
#line 39 "/home/fborges/checkout/gnome-boxes/src/libvirt-machine-properties.vala"
	_tmp12_ = builder;
#line 39 "/home/fborges/checkout/gnome-boxes/src/libvirt-machine-properties.vala"
	_tmp13_ = self->priv->machine;
#line 39 "/home/fborges/checkout/gnome-boxes/src/libvirt-machine-properties.vala"
	_tmp14_ = boxes_libvirt_machine_get_domain (_tmp13_);
#line 39 "/home/fborges/checkout/gnome-boxes/src/libvirt-machine-properties.vala"
	_tmp15_ = _tmp14_;
#line 39 "/home/fborges/checkout/gnome-boxes/src/libvirt-machine-properties.vala"
	_tmp16_ = gvir_domain_get_uuid (_tmp15_);
#line 39 "/home/fborges/checkout/gnome-boxes/src/libvirt-machine-properties.vala"
	g_string_append_printf (_tmp12_, "UUID: %s\n", _tmp16_);
#line 40 "/home/fborges/checkout/gnome-boxes/src/libvirt-machine-properties.vala"
	_tmp18_ = self->priv->machine;
#line 40 "/home/fborges/checkout/gnome-boxes/src/libvirt-machine-properties.vala"
	_tmp19_ = boxes_libvirt_machine_get_domain (_tmp18_);
#line 40 "/home/fborges/checkout/gnome-boxes/src/libvirt-machine-properties.vala"
	_tmp20_ = _tmp19_;
#line 40 "/home/fborges/checkout/gnome-boxes/src/libvirt-machine-properties.vala"
	_tmp21_ = gvir_domain_get_persistent (_tmp20_);
#line 40 "/home/fborges/checkout/gnome-boxes/src/libvirt-machine-properties.vala"
	if (_tmp21_) {
#line 40 "/home/fborges/checkout/gnome-boxes/src/libvirt-machine-properties.vala"
		_tmp17_ = "yes";
#line 1298 "libvirt-machine-properties.c"
	} else {
#line 40 "/home/fborges/checkout/gnome-boxes/src/libvirt-machine-properties.vala"
		_tmp17_ = "no";
#line 1302 "libvirt-machine-properties.c"
	}
#line 40 "/home/fborges/checkout/gnome-boxes/src/libvirt-machine-properties.vala"
	_tmp22_ = builder;
#line 40 "/home/fborges/checkout/gnome-boxes/src/libvirt-machine-properties.vala"
	g_string_append_printf (_tmp22_, "Persistent: %s\n", _tmp17_);
#line 1308 "libvirt-machine-properties.c"
	{
		GVirDomainInfo* info = NULL;
		BoxesLibvirtMachine* _tmp23_;
		GVirDomain* _tmp24_;
		GVirDomain* _tmp25_;
		GVirDomainInfo* _tmp26_;
		GString* _tmp27_;
		GVirDomainInfo* _tmp28_;
		guint64 _tmp29_;
		GString* _tmp30_;
		GVirDomainInfo* _tmp31_;
		guint64 _tmp32_;
		GVirNodeInfo* _tmp33_ = NULL;
		BoxesLibvirtMachine* _tmp34_;
		GVirConnection* _tmp35_;
		GVirConnection* _tmp36_;
		GVirNodeInfo* _tmp37_;
		GString* _tmp38_;
		gulong _tmp39_;
		GString* _tmp40_;
		GVirDomainInfo* _tmp41_;
		guint16 _tmp42_;
		GString* _tmp43_;
		GVirDomainInfo* _tmp44_;
		GVirDomainState _tmp45_;
		GEnumValue* _tmp46_;
#line 42 "/home/fborges/checkout/gnome-boxes/src/libvirt-machine-properties.vala"
		_tmp23_ = self->priv->machine;
#line 42 "/home/fborges/checkout/gnome-boxes/src/libvirt-machine-properties.vala"
		_tmp24_ = boxes_libvirt_machine_get_domain (_tmp23_);
#line 42 "/home/fborges/checkout/gnome-boxes/src/libvirt-machine-properties.vala"
		_tmp25_ = _tmp24_;
#line 42 "/home/fborges/checkout/gnome-boxes/src/libvirt-machine-properties.vala"
		_tmp26_ = gvir_domain_get_info (_tmp25_, &_inner_error_);
#line 42 "/home/fborges/checkout/gnome-boxes/src/libvirt-machine-properties.vala"
		info = _tmp26_;
#line 42 "/home/fborges/checkout/gnome-boxes/src/libvirt-machine-properties.vala"
		if (G_UNLIKELY (_inner_error_ != NULL)) {
#line 1347 "libvirt-machine-properties.c"
			goto __catch36_g_error;
		}
#line 43 "/home/fborges/checkout/gnome-boxes/src/libvirt-machine-properties.vala"
		_tmp27_ = builder;
#line 43 "/home/fborges/checkout/gnome-boxes/src/libvirt-machine-properties.vala"
		_tmp28_ = info;
#line 43 "/home/fborges/checkout/gnome-boxes/src/libvirt-machine-properties.vala"
		_tmp29_ = _tmp28_->cpuTime;
#line 43 "/home/fborges/checkout/gnome-boxes/src/libvirt-machine-properties.vala"
		g_string_append_printf (_tmp27_, "Cpu time: %" G_GINT64_MODIFIER "d\n", _tmp29_);
#line 44 "/home/fborges/checkout/gnome-boxes/src/libvirt-machine-properties.vala"
		_tmp30_ = builder;
#line 44 "/home/fborges/checkout/gnome-boxes/src/libvirt-machine-properties.vala"
		_tmp31_ = info;
#line 44 "/home/fborges/checkout/gnome-boxes/src/libvirt-machine-properties.vala"
		_tmp32_ = _tmp31_->memory;
#line 44 "/home/fborges/checkout/gnome-boxes/src/libvirt-machine-properties.vala"
		g_string_append_printf (_tmp30_, "Memory: %" G_GINT64_MODIFIER "d KiB\n", _tmp32_);
#line 46 "/home/fborges/checkout/gnome-boxes/src/libvirt-machine-properties.vala"
		_tmp34_ = self->priv->machine;
#line 46 "/home/fborges/checkout/gnome-boxes/src/libvirt-machine-properties.vala"
		_tmp35_ = boxes_libvirt_machine_get_connection (_tmp34_);
#line 46 "/home/fborges/checkout/gnome-boxes/src/libvirt-machine-properties.vala"
		_tmp36_ = _tmp35_;
#line 46 "/home/fborges/checkout/gnome-boxes/src/libvirt-machine-properties.vala"
		_tmp37_ = gvir_connection_get_node_info (_tmp36_, &_inner_error_);
#line 46 "/home/fborges/checkout/gnome-boxes/src/libvirt-machine-properties.vala"
		_tmp33_ = _tmp37_;
#line 46 "/home/fborges/checkout/gnome-boxes/src/libvirt-machine-properties.vala"
		if (G_UNLIKELY (_inner_error_ != NULL)) {
#line 46 "/home/fborges/checkout/gnome-boxes/src/libvirt-machine-properties.vala"
			__vala_GVirDomainInfo_free0 (info);
#line 1380 "libvirt-machine-properties.c"
			goto __catch36_g_error;
		}
#line 45 "/home/fborges/checkout/gnome-boxes/src/libvirt-machine-properties.vala"
		_tmp38_ = builder;
#line 45 "/home/fborges/checkout/gnome-boxes/src/libvirt-machine-properties.vala"
		_tmp39_ = _tmp33_->memory;
#line 45 "/home/fborges/checkout/gnome-boxes/src/libvirt-machine-properties.vala"
		g_string_append_printf (_tmp38_, "Max memory: %" G_GINT64_MODIFIER "d KiB\n", _tmp39_);
#line 47 "/home/fborges/checkout/gnome-boxes/src/libvirt-machine-properties.vala"
		_tmp40_ = builder;
#line 47 "/home/fborges/checkout/gnome-boxes/src/libvirt-machine-properties.vala"
		_tmp41_ = info;
#line 47 "/home/fborges/checkout/gnome-boxes/src/libvirt-machine-properties.vala"
		_tmp42_ = _tmp41_->nrVirtCpu;
#line 47 "/home/fborges/checkout/gnome-boxes/src/libvirt-machine-properties.vala"
		g_string_append_printf (_tmp40_, "CPUs: %d\n", (gint) _tmp42_);
#line 48 "/home/fborges/checkout/gnome-boxes/src/libvirt-machine-properties.vala"
		_tmp43_ = builder;
#line 48 "/home/fborges/checkout/gnome-boxes/src/libvirt-machine-properties.vala"
		_tmp44_ = info;
#line 48 "/home/fborges/checkout/gnome-boxes/src/libvirt-machine-properties.vala"
		_tmp45_ = _tmp44_->state;
#line 48 "/home/fborges/checkout/gnome-boxes/src/libvirt-machine-properties.vala"
		_tmp46_ = g_enum_get_value (g_type_class_ref (gvir_domain_state_get_type ()), _tmp45_);
#line 48 "/home/fborges/checkout/gnome-boxes/src/libvirt-machine-properties.vala"
		g_string_append_printf (_tmp43_, "State: %s\n", (_tmp46_ != NULL) ? _tmp46_->value_name : NULL);
#line 41 "/home/fborges/checkout/gnome-boxes/src/libvirt-machine-properties.vala"
		__vala_GVirNodeInfo_free0 (_tmp33_);
#line 41 "/home/fborges/checkout/gnome-boxes/src/libvirt-machine-properties.vala"
		__vala_GVirDomainInfo_free0 (info);
#line 1411 "libvirt-machine-properties.c"
	}
	goto __finally36;
	__catch36_g_error:
	{
		GError* e = NULL;
#line 41 "/home/fborges/checkout/gnome-boxes/src/libvirt-machine-properties.vala"
		e = _inner_error_;
#line 41 "/home/fborges/checkout/gnome-boxes/src/libvirt-machine-properties.vala"
		_inner_error_ = NULL;
#line 41 "/home/fborges/checkout/gnome-boxes/src/libvirt-machine-properties.vala"
		_g_error_free0 (e);
#line 1423 "libvirt-machine-properties.c"
	}
	__finally36:
#line 41 "/home/fborges/checkout/gnome-boxes/src/libvirt-machine-properties.vala"
	if (G_UNLIKELY (_inner_error_ != NULL)) {
#line 41 "/home/fborges/checkout/gnome-boxes/src/libvirt-machine-properties.vala"
		_g_string_free0 (builder);
#line 41 "/home/fborges/checkout/gnome-boxes/src/libvirt-machine-properties.vala"
		g_critical ("file %s: line %d: uncaught error: %s (%s, %d)", __FILE__, __LINE__, _inner_error_->message, g_quark_to_string (_inner_error_->domain), _inner_error_->code);
#line 41 "/home/fborges/checkout/gnome-boxes/src/libvirt-machine-properties.vala"
		g_clear_error (&_inner_error_);
#line 41 "/home/fborges/checkout/gnome-boxes/src/libvirt-machine-properties.vala"
		return NULL;
#line 1436 "libvirt-machine-properties.c"
	}
#line 52 "/home/fborges/checkout/gnome-boxes/src/libvirt-machine-properties.vala"
	_tmp47_ = self->priv->machine;
#line 52 "/home/fborges/checkout/gnome-boxes/src/libvirt-machine-properties.vala"
	_tmp48_ = boxes_machine_get_display ((BoxesMachine*) _tmp47_);
#line 52 "/home/fborges/checkout/gnome-boxes/src/libvirt-machine-properties.vala"
	_tmp49_ = _tmp48_;
#line 52 "/home/fborges/checkout/gnome-boxes/src/libvirt-machine-properties.vala"
	if (_tmp49_ != NULL) {
#line 1446 "libvirt-machine-properties.c"
		BoxesLibvirtMachine* _tmp50_;
		BoxesDisplay* _tmp51_;
		BoxesDisplay* _tmp52_;
		GString* _tmp53_;
#line 53 "/home/fborges/checkout/gnome-boxes/src/libvirt-machine-properties.vala"
		_tmp50_ = self->priv->machine;
#line 53 "/home/fborges/checkout/gnome-boxes/src/libvirt-machine-properties.vala"
		_tmp51_ = boxes_machine_get_display ((BoxesMachine*) _tmp50_);
#line 53 "/home/fborges/checkout/gnome-boxes/src/libvirt-machine-properties.vala"
		_tmp52_ = _tmp51_;
#line 53 "/home/fborges/checkout/gnome-boxes/src/libvirt-machine-properties.vala"
		_tmp53_ = builder;
#line 53 "/home/fborges/checkout/gnome-boxes/src/libvirt-machine-properties.vala"
		boxes_display_collect_logs (_tmp52_, _tmp53_);
#line 1461 "libvirt-machine-properties.c"
	}
	{
		GVirConfigDomain* conf = NULL;
		BoxesLibvirtMachine* _tmp54_;
		GVirDomain* _tmp55_;
		GVirDomain* _tmp56_;
		GVirConfigDomain* _tmp57_;
		GString* _tmp58_;
		GString* _tmp59_;
		GString* _tmp60_;
		gchar* _tmp61_;
		gchar* _tmp62_;
		GString* _tmp63_;
#line 57 "/home/fborges/checkout/gnome-boxes/src/libvirt-machine-properties.vala"
		_tmp54_ = self->priv->machine;
#line 57 "/home/fborges/checkout/gnome-boxes/src/libvirt-machine-properties.vala"
		_tmp55_ = boxes_libvirt_machine_get_domain (_tmp54_);
#line 57 "/home/fborges/checkout/gnome-boxes/src/libvirt-machine-properties.vala"
		_tmp56_ = _tmp55_;
#line 57 "/home/fborges/checkout/gnome-boxes/src/libvirt-machine-properties.vala"
		_tmp57_ = gvir_domain_get_config (_tmp56_, (guint) GVIR_DOMAIN_XML_NONE, &_inner_error_);
#line 57 "/home/fborges/checkout/gnome-boxes/src/libvirt-machine-properties.vala"
		conf = _tmp57_;
#line 57 "/home/fborges/checkout/gnome-boxes/src/libvirt-machine-properties.vala"
		if (G_UNLIKELY (_inner_error_ != NULL)) {
#line 1487 "libvirt-machine-properties.c"
			goto __catch37_g_error;
		}
#line 58 "/home/fborges/checkout/gnome-boxes/src/libvirt-machine-properties.vala"
		_tmp58_ = builder;
#line 58 "/home/fborges/checkout/gnome-boxes/src/libvirt-machine-properties.vala"
		g_string_append_printf (_tmp58_, "\nDomain config:\n");
#line 59 "/home/fborges/checkout/gnome-boxes/src/libvirt-machine-properties.vala"
		_tmp59_ = builder;
#line 59 "/home/fborges/checkout/gnome-boxes/src/libvirt-machine-properties.vala"
		g_string_append_printf (_tmp59_, "------------------------------------------------------------\n");
#line 61 "/home/fborges/checkout/gnome-boxes/src/libvirt-machine-properties.vala"
		_tmp60_ = builder;
#line 61 "/home/fborges/checkout/gnome-boxes/src/libvirt-machine-properties.vala"
		_tmp61_ = gvir_config_object_to_xml ((GVirConfigObject*) conf);
#line 61 "/home/fborges/checkout/gnome-boxes/src/libvirt-machine-properties.vala"
		_tmp62_ = _tmp61_;
#line 61 "/home/fborges/checkout/gnome-boxes/src/libvirt-machine-properties.vala"
		g_string_append (_tmp60_, _tmp62_);
#line 61 "/home/fborges/checkout/gnome-boxes/src/libvirt-machine-properties.vala"
		_g_free0 (_tmp62_);
#line 62 "/home/fborges/checkout/gnome-boxes/src/libvirt-machine-properties.vala"
		_tmp63_ = builder;
#line 62 "/home/fborges/checkout/gnome-boxes/src/libvirt-machine-properties.vala"
		g_string_append_printf (_tmp63_, "%s", "\n" "------------------------------------------------------------\n");
#line 56 "/home/fborges/checkout/gnome-boxes/src/libvirt-machine-properties.vala"
		_g_object_unref0 (conf);
#line 1514 "libvirt-machine-properties.c"
	}
	goto __finally37;
	__catch37_g_error:
	{
		GError* _error_ = NULL;
#line 56 "/home/fborges/checkout/gnome-boxes/src/libvirt-machine-properties.vala"
		_error_ = _inner_error_;
#line 56 "/home/fborges/checkout/gnome-boxes/src/libvirt-machine-properties.vala"
		_inner_error_ = NULL;
#line 56 "/home/fborges/checkout/gnome-boxes/src/libvirt-machine-properties.vala"
		_g_error_free0 (_error_);
#line 1526 "libvirt-machine-properties.c"
	}
	__finally37:
#line 56 "/home/fborges/checkout/gnome-boxes/src/libvirt-machine-properties.vala"
	if (G_UNLIKELY (_inner_error_ != NULL)) {
#line 56 "/home/fborges/checkout/gnome-boxes/src/libvirt-machine-properties.vala"
		_g_string_free0 (builder);
#line 56 "/home/fborges/checkout/gnome-boxes/src/libvirt-machine-properties.vala"
		g_critical ("file %s: line %d: uncaught error: %s (%s, %d)", __FILE__, __LINE__, _inner_error_->message, g_quark_to_string (_inner_error_->domain), _inner_error_->code);
#line 56 "/home/fborges/checkout/gnome-boxes/src/libvirt-machine-properties.vala"
		g_clear_error (&_inner_error_);
#line 56 "/home/fborges/checkout/gnome-boxes/src/libvirt-machine-properties.vala"
		return NULL;
#line 1539 "libvirt-machine-properties.c"
	}
	{
		gchar* logfile = NULL;
		const gchar* _tmp64_;
		BoxesLibvirtMachine* _tmp65_;
		GVirDomain* _tmp66_;
		GVirDomain* _tmp67_;
		const gchar* _tmp68_;
		gchar* _tmp69_;
		gchar* _tmp70_;
		gchar* _tmp71_;
		gchar* _tmp72_;
		gchar* data = NULL;
		gchar* _tmp73_ = NULL;
		GString* _tmp74_;
		GString* _tmp75_;
		GString* _tmp76_;
		GString* _tmp77_;
#line 68 "/home/fborges/checkout/gnome-boxes/src/libvirt-machine-properties.vala"
		_tmp64_ = g_get_user_cache_dir ();
#line 68 "/home/fborges/checkout/gnome-boxes/src/libvirt-machine-properties.vala"
		_tmp65_ = self->priv->machine;
#line 68 "/home/fborges/checkout/gnome-boxes/src/libvirt-machine-properties.vala"
		_tmp66_ = boxes_libvirt_machine_get_domain (_tmp65_);
#line 68 "/home/fborges/checkout/gnome-boxes/src/libvirt-machine-properties.vala"
		_tmp67_ = _tmp66_;
#line 68 "/home/fborges/checkout/gnome-boxes/src/libvirt-machine-properties.vala"
		_tmp68_ = gvir_domain_get_name (_tmp67_);
#line 68 "/home/fborges/checkout/gnome-boxes/src/libvirt-machine-properties.vala"
		_tmp69_ = g_strconcat (_tmp68_, ".log", NULL);
#line 68 "/home/fborges/checkout/gnome-boxes/src/libvirt-machine-properties.vala"
		_tmp70_ = _tmp69_;
#line 68 "/home/fborges/checkout/gnome-boxes/src/libvirt-machine-properties.vala"
		_tmp71_ = g_build_filename (_tmp64_, "libvirt/qemu/log", _tmp70_, NULL);
#line 68 "/home/fborges/checkout/gnome-boxes/src/libvirt-machine-properties.vala"
		_tmp72_ = _tmp71_;
#line 68 "/home/fborges/checkout/gnome-boxes/src/libvirt-machine-properties.vala"
		_g_free0 (_tmp70_);
#line 68 "/home/fborges/checkout/gnome-boxes/src/libvirt-machine-properties.vala"
		logfile = _tmp72_;
#line 72 "/home/fborges/checkout/gnome-boxes/src/libvirt-machine-properties.vala"
		g_file_get_contents (logfile, &_tmp73_, NULL, &_inner_error_);
#line 72 "/home/fborges/checkout/gnome-boxes/src/libvirt-machine-properties.vala"
		_g_free0 (data);
#line 72 "/home/fborges/checkout/gnome-boxes/src/libvirt-machine-properties.vala"
		data = _tmp73_;
#line 72 "/home/fborges/checkout/gnome-boxes/src/libvirt-machine-properties.vala"
		if (G_UNLIKELY (_inner_error_ != NULL)) {
#line 72 "/home/fborges/checkout/gnome-boxes/src/libvirt-machine-properties.vala"
			_g_free0 (data);
#line 72 "/home/fborges/checkout/gnome-boxes/src/libvirt-machine-properties.vala"
			_g_free0 (logfile);
#line 1592 "libvirt-machine-properties.c"
			goto __catch38_g_error;
		}
#line 73 "/home/fborges/checkout/gnome-boxes/src/libvirt-machine-properties.vala"
		_tmp74_ = builder;
#line 73 "/home/fborges/checkout/gnome-boxes/src/libvirt-machine-properties.vala"
		g_string_append_printf (_tmp74_, "\nQEMU log:\n");
#line 74 "/home/fborges/checkout/gnome-boxes/src/libvirt-machine-properties.vala"
		_tmp75_ = builder;
#line 74 "/home/fborges/checkout/gnome-boxes/src/libvirt-machine-properties.vala"
		g_string_append_printf (_tmp75_, "------------------------------------------------------------\n");
#line 76 "/home/fborges/checkout/gnome-boxes/src/libvirt-machine-properties.vala"
		_tmp76_ = builder;
#line 76 "/home/fborges/checkout/gnome-boxes/src/libvirt-machine-properties.vala"
		g_string_append (_tmp76_, data);
#line 77 "/home/fborges/checkout/gnome-boxes/src/libvirt-machine-properties.vala"
		_tmp77_ = builder;
#line 77 "/home/fborges/checkout/gnome-boxes/src/libvirt-machine-properties.vala"
		g_string_append_printf (_tmp77_, "------------------------------------------------------------\n");
#line 67 "/home/fborges/checkout/gnome-boxes/src/libvirt-machine-properties.vala"
		_g_free0 (data);
#line 67 "/home/fborges/checkout/gnome-boxes/src/libvirt-machine-properties.vala"
		_g_free0 (logfile);
#line 1615 "libvirt-machine-properties.c"
	}
	goto __finally38;
	__catch38_g_error:
	{
		GError* e = NULL;
#line 67 "/home/fborges/checkout/gnome-boxes/src/libvirt-machine-properties.vala"
		e = _inner_error_;
#line 67 "/home/fborges/checkout/gnome-boxes/src/libvirt-machine-properties.vala"
		_inner_error_ = NULL;
#line 67 "/home/fborges/checkout/gnome-boxes/src/libvirt-machine-properties.vala"
		_g_error_free0 (e);
#line 1627 "libvirt-machine-properties.c"
	}
	__finally38:
#line 67 "/home/fborges/checkout/gnome-boxes/src/libvirt-machine-properties.vala"
	if (G_UNLIKELY (_inner_error_ != NULL)) {
#line 67 "/home/fborges/checkout/gnome-boxes/src/libvirt-machine-properties.vala"
		_g_string_free0 (builder);
#line 67 "/home/fborges/checkout/gnome-boxes/src/libvirt-machine-properties.vala"
		g_critical ("file %s: line %d: uncaught error: %s (%s, %d)", __FILE__, __LINE__, _inner_error_->message, g_quark_to_string (_inner_error_->domain), _inner_error_->code);
#line 67 "/home/fborges/checkout/gnome-boxes/src/libvirt-machine-properties.vala"
		g_clear_error (&_inner_error_);
#line 67 "/home/fborges/checkout/gnome-boxes/src/libvirt-machine-properties.vala"
		return NULL;
#line 1640 "libvirt-machine-properties.c"
	}
#line 80 "/home/fborges/checkout/gnome-boxes/src/libvirt-machine-properties.vala"
	_tmp78_ = builder;
#line 80 "/home/fborges/checkout/gnome-boxes/src/libvirt-machine-properties.vala"
	_tmp79_ = _tmp78_->str;
#line 80 "/home/fborges/checkout/gnome-boxes/src/libvirt-machine-properties.vala"
	_tmp80_ = g_strdup (_tmp79_);
#line 80 "/home/fborges/checkout/gnome-boxes/src/libvirt-machine-properties.vala"
	result = _tmp80_;
#line 80 "/home/fborges/checkout/gnome-boxes/src/libvirt-machine-properties.vala"
	_g_string_free0 (builder);
#line 80 "/home/fborges/checkout/gnome-boxes/src/libvirt-machine-properties.vala"
	return result;
#line 1654 "libvirt-machine-properties.c"
}


static void _g_object_unref0_ (gpointer var) {
#line 88 "/home/fborges/checkout/gnome-boxes/src/libvirt-machine-properties.vala"
	(var == NULL) ? NULL : (var = (g_object_unref (var), NULL));
#line 1661 "libvirt-machine-properties.c"
}


static inline void _g_list_free__g_object_unref0_ (GList* self) {
#line 88 "/home/fborges/checkout/gnome-boxes/src/libvirt-machine-properties.vala"
	g_list_free_full (self, (GDestroyNotify) _g_object_unref0_);
#line 1668 "libvirt-machine-properties.c"
}


static Block46Data* block46_data_ref (Block46Data* _data46_) {
#line 94 "/home/fborges/checkout/gnome-boxes/src/libvirt-machine-properties.vala"
	g_atomic_int_inc (&_data46_->_ref_count_);
#line 94 "/home/fborges/checkout/gnome-boxes/src/libvirt-machine-properties.vala"
	return _data46_;
#line 1677 "libvirt-machine-properties.c"
}


static void block46_data_unref (void * _userdata_) {
	Block46Data* _data46_;
	_data46_ = (Block46Data*) _userdata_;
#line 94 "/home/fborges/checkout/gnome-boxes/src/libvirt-machine-properties.vala"
	if (g_atomic_int_dec_and_test (&_data46_->_ref_count_)) {
#line 1686 "libvirt-machine-properties.c"
		BoxesLibvirtMachineProperties* self;
#line 94 "/home/fborges/checkout/gnome-boxes/src/libvirt-machine-properties.vala"
		self = _data46_->self;
#line 94 "/home/fborges/checkout/gnome-boxes/src/libvirt-machine-properties.vala"
		_g_object_unref0 (_data46_->name_property);
#line 94 "/home/fborges/checkout/gnome-boxes/src/libvirt-machine-properties.vala"
		_g_object_unref0 (self);
#line 94 "/home/fborges/checkout/gnome-boxes/src/libvirt-machine-properties.vala"
		g_slice_free (Block46Data, _data46_);
#line 1696 "libvirt-machine-properties.c"
	}
}


static void ___lambda114_ (BoxesLibvirtMachineProperties* self, BoxesEditableStringProperty* property, const gchar* name) {
	BoxesLibvirtMachine* _tmp0_;
	const gchar* _tmp1_;
#line 97 "/home/fborges/checkout/gnome-boxes/src/libvirt-machine-properties.vala"
	g_return_if_fail (property != NULL);
#line 97 "/home/fborges/checkout/gnome-boxes/src/libvirt-machine-properties.vala"
	g_return_if_fail (name != NULL);
#line 98 "/home/fborges/checkout/gnome-boxes/src/libvirt-machine-properties.vala"
	_tmp0_ = self->priv->machine;
#line 98 "/home/fborges/checkout/gnome-boxes/src/libvirt-machine-properties.vala"
	_tmp1_ = name;
#line 98 "/home/fborges/checkout/gnome-boxes/src/libvirt-machine-properties.vala"
	boxes_collection_item_set_name ((BoxesCollectionItem*) _tmp0_, _tmp1_);
#line 1714 "libvirt-machine-properties.c"
}


static void ____lambda114__boxes_editable_string_property_changed (BoxesEditableStringProperty* _sender, const gchar* value, gpointer self) {
#line 97 "/home/fborges/checkout/gnome-boxes/src/libvirt-machine-properties.vala"
	___lambda114_ ((BoxesLibvirtMachineProperties*) self, _sender, value);
#line 1721 "libvirt-machine-properties.c"
}


static gpointer _g_object_ref0 (gpointer self) {
#line 101 "/home/fborges/checkout/gnome-boxes/src/libvirt-machine-properties.vala"
	return self ? g_object_ref (self) : NULL;
#line 1728 "libvirt-machine-properties.c"
}


static void ___lambda115_ (Block46Data* _data46_) {
	BoxesLibvirtMachineProperties* self;
	BoxesEditableStringProperty* _tmp0_;
	BoxesLibvirtMachine* _tmp1_;
	const gchar* _tmp2_;
	const gchar* _tmp3_;
#line 102 "/home/fborges/checkout/gnome-boxes/src/libvirt-machine-properties.vala"
	self = _data46_->self;
#line 103 "/home/fborges/checkout/gnome-boxes/src/libvirt-machine-properties.vala"
	_tmp0_ = _data46_->name_property;
#line 103 "/home/fborges/checkout/gnome-boxes/src/libvirt-machine-properties.vala"
	_tmp1_ = self->priv->machine;
#line 103 "/home/fborges/checkout/gnome-boxes/src/libvirt-machine-properties.vala"
	_tmp2_ = boxes_collection_item_get_name ((BoxesCollectionItem*) _tmp1_);
#line 103 "/home/fborges/checkout/gnome-boxes/src/libvirt-machine-properties.vala"
	_tmp3_ = _tmp2_;
#line 103 "/home/fborges/checkout/gnome-boxes/src/libvirt-machine-properties.vala"
	boxes_editable_string_property_set_text (_tmp0_, _tmp3_);
#line 1750 "libvirt-machine-properties.c"
}


static void ____lambda115__g_object_notify (GObject* _sender, GParamSpec* pspec, gpointer self) {
#line 102 "/home/fborges/checkout/gnome-boxes/src/libvirt-machine-properties.vala"
	___lambda115_ (self);
#line 1757 "libvirt-machine-properties.c"
}


static GList* boxes_libvirt_machine_properties_real_get_properties (BoxesIPropertiesProvider* base, BoxesPropertiesPage page) {
	BoxesLibvirtMachineProperties * self;
	GList* result = NULL;
	GList* list = NULL;
	gboolean _tmp0_ = FALSE;
	BoxesLibvirtMachine* _tmp1_;
	gboolean _tmp2_;
	gboolean _tmp3_;
	BoxesPropertiesPage _tmp10_;
	GError * _inner_error_ = NULL;
#line 83 "/home/fborges/checkout/gnome-boxes/src/libvirt-machine-properties.vala"
	self = (BoxesLibvirtMachineProperties*) base;
#line 84 "/home/fborges/checkout/gnome-boxes/src/libvirt-machine-properties.vala"
	list = NULL;
#line 87 "/home/fborges/checkout/gnome-boxes/src/libvirt-machine-properties.vala"
	_tmp1_ = self->priv->machine;
#line 87 "/home/fborges/checkout/gnome-boxes/src/libvirt-machine-properties.vala"
	_tmp2_ = boxes_machine_get_is_on ((BoxesMachine*) _tmp1_);
#line 87 "/home/fborges/checkout/gnome-boxes/src/libvirt-machine-properties.vala"
	_tmp3_ = _tmp2_;
#line 87 "/home/fborges/checkout/gnome-boxes/src/libvirt-machine-properties.vala"
	if (_tmp3_) {
#line 1783 "libvirt-machine-properties.c"
		BoxesLibvirtMachine* _tmp4_;
		BoxesDisplay* _tmp5_;
		BoxesDisplay* _tmp6_;
#line 87 "/home/fborges/checkout/gnome-boxes/src/libvirt-machine-properties.vala"
		_tmp4_ = self->priv->machine;
#line 87 "/home/fborges/checkout/gnome-boxes/src/libvirt-machine-properties.vala"
		_tmp5_ = boxes_machine_get_display ((BoxesMachine*) _tmp4_);
#line 87 "/home/fborges/checkout/gnome-boxes/src/libvirt-machine-properties.vala"
		_tmp6_ = _tmp5_;
#line 87 "/home/fborges/checkout/gnome-boxes/src/libvirt-machine-properties.vala"
		_tmp0_ = _tmp6_ == NULL;
#line 1795 "libvirt-machine-properties.c"
	} else {
#line 87 "/home/fborges/checkout/gnome-boxes/src/libvirt-machine-properties.vala"
		_tmp0_ = FALSE;
#line 1799 "libvirt-machine-properties.c"
	}
#line 87 "/home/fborges/checkout/gnome-boxes/src/libvirt-machine-properties.vala"
	if (_tmp0_) {
#line 1803 "libvirt-machine-properties.c"
		{
			BoxesLibvirtMachine* _tmp7_;
#line 89 "/home/fborges/checkout/gnome-boxes/src/libvirt-machine-properties.vala"
			_tmp7_ = self->priv->machine;
#line 89 "/home/fborges/checkout/gnome-boxes/src/libvirt-machine-properties.vala"
			boxes_libvirt_machine_update_display (_tmp7_, &_inner_error_);
#line 89 "/home/fborges/checkout/gnome-boxes/src/libvirt-machine-properties.vala"
			if (G_UNLIKELY (_inner_error_ != NULL)) {
#line 1812 "libvirt-machine-properties.c"
				goto __catch39_g_error;
			}
		}
		goto __finally39;
		__catch39_g_error:
		{
			GError* e = NULL;
			GError* _tmp8_;
			const gchar* _tmp9_;
#line 88 "/home/fborges/checkout/gnome-boxes/src/libvirt-machine-properties.vala"
			e = _inner_error_;
#line 88 "/home/fborges/checkout/gnome-boxes/src/libvirt-machine-properties.vala"
			_inner_error_ = NULL;
#line 91 "/home/fborges/checkout/gnome-boxes/src/libvirt-machine-properties.vala"
			_tmp8_ = e;
#line 91 "/home/fborges/checkout/gnome-boxes/src/libvirt-machine-properties.vala"
			_tmp9_ = _tmp8_->message;
#line 91 "/home/fborges/checkout/gnome-boxes/src/libvirt-machine-properties.vala"
			g_warning ("libvirt-machine-properties.vala:91: %s", _tmp9_);
#line 88 "/home/fborges/checkout/gnome-boxes/src/libvirt-machine-properties.vala"
			_g_error_free0 (e);
#line 1834 "libvirt-machine-properties.c"
		}
		__finally39:
#line 88 "/home/fborges/checkout/gnome-boxes/src/libvirt-machine-properties.vala"
		if (G_UNLIKELY (_inner_error_ != NULL)) {
#line 88 "/home/fborges/checkout/gnome-boxes/src/libvirt-machine-properties.vala"
			__g_list_free__g_object_unref0_0 (list);
#line 88 "/home/fborges/checkout/gnome-boxes/src/libvirt-machine-properties.vala"
			g_critical ("file %s: line %d: uncaught error: %s (%s, %d)", __FILE__, __LINE__, _inner_error_->message, g_quark_to_string (_inner_error_->domain), _inner_error_->code);
#line 88 "/home/fborges/checkout/gnome-boxes/src/libvirt-machine-properties.vala"
			g_clear_error (&_inner_error_);
#line 88 "/home/fborges/checkout/gnome-boxes/src/libvirt-machine-properties.vala"
			return NULL;
#line 1847 "libvirt-machine-properties.c"
		}
	}
#line 94 "/home/fborges/checkout/gnome-boxes/src/libvirt-machine-properties.vala"
	_tmp10_ = page;
#line 94 "/home/fborges/checkout/gnome-boxes/src/libvirt-machine-properties.vala"
	switch (_tmp10_) {
#line 94 "/home/fborges/checkout/gnome-boxes/src/libvirt-machine-properties.vala"
		case BOXES_PROPERTIES_PAGE_GENERAL:
#line 1856 "libvirt-machine-properties.c"
		{
			Block46Data* _data46_;
			BoxesEditableStringProperty* property = NULL;
			BoxesLibvirtMachine* _tmp11_;
			const gchar* _tmp12_;
			const gchar* _tmp13_;
			BoxesEditableStringProperty* _tmp14_;
			BoxesEditableStringProperty* _tmp15_;
			BoxesEditableStringProperty* _tmp16_;
			BoxesEditableStringProperty* _tmp17_;
			BoxesLibvirtMachine* _tmp18_;
			gchar* ip = NULL;
			BoxesLibvirtMachine* _tmp19_;
			gchar* _tmp20_;
			const gchar* _tmp21_;
			BoxesLibvirtMachine* _tmp25_;
			BoxesCollectionSource* _tmp26_;
			gchar* _tmp27_;
			gchar* _tmp28_;
			gchar* _tmp29_;
			BoxesStringProperty* _tmp30_;
			BoxesStringProperty* _tmp31_;
			BoxesLibvirtMachine* _tmp32_;
			BoxesDisplay* _tmp33_;
			BoxesDisplay* _tmp34_;
#line 94 "/home/fborges/checkout/gnome-boxes/src/libvirt-machine-properties.vala"
			_data46_ = g_slice_new0 (Block46Data);
#line 94 "/home/fborges/checkout/gnome-boxes/src/libvirt-machine-properties.vala"
			_data46_->_ref_count_ = 1;
#line 94 "/home/fborges/checkout/gnome-boxes/src/libvirt-machine-properties.vala"
			_data46_->self = g_object_ref (self);
#line 96 "/home/fborges/checkout/gnome-boxes/src/libvirt-machine-properties.vala"
			_tmp11_ = self->priv->machine;
#line 96 "/home/fborges/checkout/gnome-boxes/src/libvirt-machine-properties.vala"
			_tmp12_ = boxes_collection_item_get_name ((BoxesCollectionItem*) _tmp11_);
#line 96 "/home/fborges/checkout/gnome-boxes/src/libvirt-machine-properties.vala"
			_tmp13_ = _tmp12_;
#line 96 "/home/fborges/checkout/gnome-boxes/src/libvirt-machine-properties.vala"
			_tmp14_ = boxes_iproperties_provider_add_editable_string_property ((BoxesIPropertiesProvider*) self, &list, _ ("_Name"), _tmp13_);
#line 96 "/home/fborges/checkout/gnome-boxes/src/libvirt-machine-properties.vala"
			property = _tmp14_;
#line 97 "/home/fborges/checkout/gnome-boxes/src/libvirt-machine-properties.vala"
			_tmp15_ = property;
#line 97 "/home/fborges/checkout/gnome-boxes/src/libvirt-machine-properties.vala"
			g_signal_connect_object (_tmp15_, "changed", (GCallback) ____lambda114__boxes_editable_string_property_changed, self, 0);
#line 101 "/home/fborges/checkout/gnome-boxes/src/libvirt-machine-properties.vala"
			_tmp16_ = property;
#line 101 "/home/fborges/checkout/gnome-boxes/src/libvirt-machine-properties.vala"
			_tmp17_ = _g_object_ref0 (_tmp16_);
#line 101 "/home/fborges/checkout/gnome-boxes/src/libvirt-machine-properties.vala"
			_data46_->name_property = _tmp17_;
#line 102 "/home/fborges/checkout/gnome-boxes/src/libvirt-machine-properties.vala"
			_tmp18_ = self->priv->machine;
#line 102 "/home/fborges/checkout/gnome-boxes/src/libvirt-machine-properties.vala"
			g_signal_connect_data ((GObject*) _tmp18_, "notify::name", (GCallback) ____lambda115__g_object_notify, block46_data_ref (_data46_), (GClosureNotify) block46_data_unref, 0);
#line 106 "/home/fborges/checkout/gnome-boxes/src/libvirt-machine-properties.vala"
			_tmp19_ = self->priv->machine;
#line 106 "/home/fborges/checkout/gnome-boxes/src/libvirt-machine-properties.vala"
			_tmp20_ = boxes_libvirt_machine_get_ip_address (_tmp19_);
#line 106 "/home/fborges/checkout/gnome-boxes/src/libvirt-machine-properties.vala"
			ip = _tmp20_;
#line 107 "/home/fborges/checkout/gnome-boxes/src/libvirt-machine-properties.vala"
			_tmp21_ = ip;
#line 107 "/home/fborges/checkout/gnome-boxes/src/libvirt-machine-properties.vala"
			if (_tmp21_ != NULL) {
#line 1922 "libvirt-machine-properties.c"
				const gchar* _tmp22_;
				BoxesStringProperty* _tmp23_;
				BoxesStringProperty* _tmp24_;
#line 108 "/home/fborges/checkout/gnome-boxes/src/libvirt-machine-properties.vala"
				_tmp22_ = ip;
#line 108 "/home/fborges/checkout/gnome-boxes/src/libvirt-machine-properties.vala"
				_tmp23_ = boxes_iproperties_provider_add_string_property ((BoxesIPropertiesProvider*) self, &list, _ ("IP Address"), _tmp22_);
#line 108 "/home/fborges/checkout/gnome-boxes/src/libvirt-machine-properties.vala"
				_tmp24_ = _tmp23_;
#line 108 "/home/fborges/checkout/gnome-boxes/src/libvirt-machine-properties.vala"
				_g_object_unref0 (_tmp24_);
#line 1934 "libvirt-machine-properties.c"
			}
#line 110 "/home/fborges/checkout/gnome-boxes/src/libvirt-machine-properties.vala"
			_tmp25_ = self->priv->machine;
#line 110 "/home/fborges/checkout/gnome-boxes/src/libvirt-machine-properties.vala"
			_tmp26_ = ((BoxesMachine*) _tmp25_)->source;
#line 110 "/home/fborges/checkout/gnome-boxes/src/libvirt-machine-properties.vala"
			_tmp27_ = boxes_collection_source_get_name (_tmp26_);
#line 110 "/home/fborges/checkout/gnome-boxes/src/libvirt-machine-properties.vala"
			_tmp28_ = _tmp27_;
#line 110 "/home/fborges/checkout/gnome-boxes/src/libvirt-machine-properties.vala"
			_tmp29_ = _tmp28_;
#line 110 "/home/fborges/checkout/gnome-boxes/src/libvirt-machine-properties.vala"
			_tmp30_ = boxes_iproperties_provider_add_string_property ((BoxesIPropertiesProvider*) self, &list, _ ("Broker"), _tmp29_);
#line 110 "/home/fborges/checkout/gnome-boxes/src/libvirt-machine-properties.vala"
			_tmp31_ = _tmp30_;
#line 110 "/home/fborges/checkout/gnome-boxes/src/libvirt-machine-properties.vala"
			_g_object_unref0 (_tmp31_);
#line 110 "/home/fborges/checkout/gnome-boxes/src/libvirt-machine-properties.vala"
			_g_free0 (_tmp29_);
#line 111 "/home/fborges/checkout/gnome-boxes/src/libvirt-machine-properties.vala"
			_tmp32_ = self->priv->machine;
#line 111 "/home/fborges/checkout/gnome-boxes/src/libvirt-machine-properties.vala"
			_tmp33_ = boxes_machine_get_display ((BoxesMachine*) _tmp32_);
#line 111 "/home/fborges/checkout/gnome-boxes/src/libvirt-machine-properties.vala"
			_tmp34_ = _tmp33_;
#line 111 "/home/fborges/checkout/gnome-boxes/src/libvirt-machine-properties.vala"
			if (_tmp34_ != NULL) {
#line 1962 "libvirt-machine-properties.c"
				BoxesLibvirtMachine* _tmp35_;
				BoxesDisplay* _tmp36_;
				BoxesDisplay* _tmp37_;
				const gchar* _tmp38_;
				const gchar* _tmp39_;
				BoxesStringProperty* _tmp40_;
				BoxesStringProperty* _tmp41_;
				BoxesLibvirtMachine* _tmp42_;
				BoxesDisplay* _tmp43_;
				BoxesDisplay* _tmp44_;
				gchar* _tmp45_;
				gchar* _tmp46_;
				gchar* _tmp47_;
				gboolean _tmp48_;
#line 113 "/home/fborges/checkout/gnome-boxes/src/libvirt-machine-properties.vala"
				_tmp35_ = self->priv->machine;
#line 113 "/home/fborges/checkout/gnome-boxes/src/libvirt-machine-properties.vala"
				_tmp36_ = boxes_machine_get_display ((BoxesMachine*) _tmp35_);
#line 113 "/home/fborges/checkout/gnome-boxes/src/libvirt-machine-properties.vala"
				_tmp37_ = _tmp36_;
#line 113 "/home/fborges/checkout/gnome-boxes/src/libvirt-machine-properties.vala"
				_tmp38_ = boxes_display_get_protocol (_tmp37_);
#line 113 "/home/fborges/checkout/gnome-boxes/src/libvirt-machine-properties.vala"
				_tmp39_ = _tmp38_;
#line 113 "/home/fborges/checkout/gnome-boxes/src/libvirt-machine-properties.vala"
				_tmp40_ = boxes_iproperties_provider_add_string_property ((BoxesIPropertiesProvider*) self, &list, _ ("Display Protocol"), _tmp39_);
#line 113 "/home/fborges/checkout/gnome-boxes/src/libvirt-machine-properties.vala"
				_tmp41_ = _tmp40_;
#line 113 "/home/fborges/checkout/gnome-boxes/src/libvirt-machine-properties.vala"
				_g_object_unref0 (_tmp41_);
#line 114 "/home/fborges/checkout/gnome-boxes/src/libvirt-machine-properties.vala"
				_tmp42_ = self->priv->machine;
#line 114 "/home/fborges/checkout/gnome-boxes/src/libvirt-machine-properties.vala"
				_tmp43_ = boxes_machine_get_display ((BoxesMachine*) _tmp42_);
#line 114 "/home/fborges/checkout/gnome-boxes/src/libvirt-machine-properties.vala"
				_tmp44_ = _tmp43_;
#line 114 "/home/fborges/checkout/gnome-boxes/src/libvirt-machine-properties.vala"
				_tmp45_ = boxes_display_get_uri (_tmp44_);
#line 114 "/home/fborges/checkout/gnome-boxes/src/libvirt-machine-properties.vala"
				_tmp46_ = _tmp45_;
#line 114 "/home/fborges/checkout/gnome-boxes/src/libvirt-machine-properties.vala"
				_tmp47_ = _tmp46_;
#line 114 "/home/fborges/checkout/gnome-boxes/src/libvirt-machine-properties.vala"
				_tmp48_ = _tmp47_ != NULL;
#line 114 "/home/fborges/checkout/gnome-boxes/src/libvirt-machine-properties.vala"
				_g_free0 (_tmp47_);
#line 114 "/home/fborges/checkout/gnome-boxes/src/libvirt-machine-properties.vala"
				if (_tmp48_) {
#line 2011 "libvirt-machine-properties.c"
					BoxesLibvirtMachine* _tmp49_;
					BoxesDisplay* _tmp50_;
					BoxesDisplay* _tmp51_;
					gchar* _tmp52_;
					gchar* _tmp53_;
					gchar* _tmp54_;
					BoxesStringProperty* _tmp55_;
					BoxesStringProperty* _tmp56_;
#line 116 "/home/fborges/checkout/gnome-boxes/src/libvirt-machine-properties.vala"
					_tmp49_ = self->priv->machine;
#line 116 "/home/fborges/checkout/gnome-boxes/src/libvirt-machine-properties.vala"
					_tmp50_ = boxes_machine_get_display ((BoxesMachine*) _tmp49_);
#line 116 "/home/fborges/checkout/gnome-boxes/src/libvirt-machine-properties.vala"
					_tmp51_ = _tmp50_;
#line 116 "/home/fborges/checkout/gnome-boxes/src/libvirt-machine-properties.vala"
					_tmp52_ = boxes_display_get_uri (_tmp51_);
#line 116 "/home/fborges/checkout/gnome-boxes/src/libvirt-machine-properties.vala"
					_tmp53_ = _tmp52_;
#line 116 "/home/fborges/checkout/gnome-boxes/src/libvirt-machine-properties.vala"
					_tmp54_ = _tmp53_;
#line 116 "/home/fborges/checkout/gnome-boxes/src/libvirt-machine-properties.vala"
					_tmp55_ = boxes_iproperties_provider_add_string_property ((BoxesIPropertiesProvider*) self, &list, _ ("Display URL"), _tmp54_);
#line 116 "/home/fborges/checkout/gnome-boxes/src/libvirt-machine-properties.vala"
					_tmp56_ = _tmp55_;
#line 116 "/home/fborges/checkout/gnome-boxes/src/libvirt-machine-properties.vala"
					_g_object_unref0 (_tmp56_);
#line 116 "/home/fborges/checkout/gnome-boxes/src/libvirt-machine-properties.vala"
					_g_free0 (_tmp54_);
#line 2040 "libvirt-machine-properties.c"
				}
			}
#line 119 "/home/fborges/checkout/gnome-boxes/src/libvirt-machine-properties.vala"
			_g_free0 (ip);
#line 119 "/home/fborges/checkout/gnome-boxes/src/libvirt-machine-properties.vala"
			_g_object_unref0 (property);
#line 119 "/home/fborges/checkout/gnome-boxes/src/libvirt-machine-properties.vala"
			block46_data_unref (_data46_);
#line 119 "/home/fborges/checkout/gnome-boxes/src/libvirt-machine-properties.vala"
			_data46_ = NULL;
#line 119 "/home/fborges/checkout/gnome-boxes/src/libvirt-machine-properties.vala"
			break;
#line 2053 "libvirt-machine-properties.c"
		}
#line 94 "/home/fborges/checkout/gnome-boxes/src/libvirt-machine-properties.vala"
		case BOXES_PROPERTIES_PAGE_SYSTEM:
#line 2057 "libvirt-machine-properties.c"
		{
#line 122 "/home/fborges/checkout/gnome-boxes/src/libvirt-machine-properties.vala"
			boxes_libvirt_machine_properties_add_resource_usage_graphs (self, &list);
#line 124 "/home/fborges/checkout/gnome-boxes/src/libvirt-machine-properties.vala"
			boxes_libvirt_machine_properties_add_system_props_buttons (self, &list);
#line 126 "/home/fborges/checkout/gnome-boxes/src/libvirt-machine-properties.vala"
			boxes_libvirt_machine_properties_get_resources_properties (self, &list);
#line 128 "/home/fborges/checkout/gnome-boxes/src/libvirt-machine-properties.vala"
			boxes_libvirt_machine_properties_add_run_in_bg_property (self, &list);
#line 130 "/home/fborges/checkout/gnome-boxes/src/libvirt-machine-properties.vala"
			break;
#line 2069 "libvirt-machine-properties.c"
		}
#line 94 "/home/fborges/checkout/gnome-boxes/src/libvirt-machine-properties.vala"
		case BOXES_PROPERTIES_PAGE_DEVICES:
#line 2073 "libvirt-machine-properties.c"
		{
			BoxesLibvirtMachine* _tmp57_;
			GVirConfigDomain* _tmp58_;
			GVirConfigDomain* _tmp59_;
			GList* _tmp60_;
#line 133 "/home/fborges/checkout/gnome-boxes/src/libvirt-machine-properties.vala"
			_tmp57_ = self->priv->machine;
#line 133 "/home/fborges/checkout/gnome-boxes/src/libvirt-machine-properties.vala"
			_tmp58_ = boxes_libvirt_machine_get_domain_config (_tmp57_);
#line 133 "/home/fborges/checkout/gnome-boxes/src/libvirt-machine-properties.vala"
			_tmp59_ = _tmp58_;
#line 133 "/home/fborges/checkout/gnome-boxes/src/libvirt-machine-properties.vala"
			_tmp60_ = gvir_config_domain_get_devices (_tmp59_);
#line 2087 "libvirt-machine-properties.c"
			{
				GList* device_config_collection = NULL;
				GList* device_config_it = NULL;
#line 133 "/home/fborges/checkout/gnome-boxes/src/libvirt-machine-properties.vala"
				device_config_collection = _tmp60_;
#line 133 "/home/fborges/checkout/gnome-boxes/src/libvirt-machine-properties.vala"
				for (device_config_it = device_config_collection; device_config_it != NULL; device_config_it = device_config_it->next) {
#line 2095 "libvirt-machine-properties.c"
					GVirConfigDomainDevice* _tmp61_;
					GVirConfigDomainDevice* device_config = NULL;
#line 133 "/home/fborges/checkout/gnome-boxes/src/libvirt-machine-properties.vala"
					_tmp61_ = _g_object_ref0 ((GVirConfigDomainDevice*) device_config_it->data);
#line 133 "/home/fborges/checkout/gnome-boxes/src/libvirt-machine-properties.vala"
					device_config = _tmp61_;
#line 2102 "libvirt-machine-properties.c"
					{
						GVirConfigDomainDevice* _tmp62_;
						GVirConfigDomainDisk* disk_config = NULL;
						GVirConfigDomainDevice* _tmp63_;
						GVirConfigDomainDisk* _tmp64_;
						GVirConfigDomainDiskGuestDeviceType disk_type = 0;
						GVirConfigDomainDisk* _tmp65_;
						GVirConfigDomainDiskGuestDeviceType _tmp66_;
						GVirConfigDomainDiskGuestDeviceType _tmp67_;
#line 134 "/home/fborges/checkout/gnome-boxes/src/libvirt-machine-properties.vala"
						_tmp62_ = device_config;
#line 134 "/home/fborges/checkout/gnome-boxes/src/libvirt-machine-properties.vala"
						if (!G_TYPE_CHECK_INSTANCE_TYPE (_tmp62_, gvir_config_domain_disk_get_type ())) {
#line 135 "/home/fborges/checkout/gnome-boxes/src/libvirt-machine-properties.vala"
							_g_object_unref0 (device_config);
#line 135 "/home/fborges/checkout/gnome-boxes/src/libvirt-machine-properties.vala"
							continue;
#line 2120 "libvirt-machine-properties.c"
						}
#line 136 "/home/fborges/checkout/gnome-boxes/src/libvirt-machine-properties.vala"
						_tmp63_ = device_config;
#line 136 "/home/fborges/checkout/gnome-boxes/src/libvirt-machine-properties.vala"
						_tmp64_ = _g_object_ref0 (G_TYPE_CHECK_INSTANCE_TYPE (_tmp63_, gvir_config_domain_disk_get_type ()) ? ((GVirConfigDomainDisk*) _tmp63_) : NULL);
#line 136 "/home/fborges/checkout/gnome-boxes/src/libvirt-machine-properties.vala"
						disk_config = _tmp64_;
#line 137 "/home/fborges/checkout/gnome-boxes/src/libvirt-machine-properties.vala"
						_tmp65_ = disk_config;
#line 137 "/home/fborges/checkout/gnome-boxes/src/libvirt-machine-properties.vala"
						_tmp66_ = gvir_config_domain_disk_get_guest_device_type (_tmp65_);
#line 137 "/home/fborges/checkout/gnome-boxes/src/libvirt-machine-properties.vala"
						disk_type = _tmp66_;
#line 138 "/home/fborges/checkout/gnome-boxes/src/libvirt-machine-properties.vala"
						_tmp67_ = disk_type;
#line 138 "/home/fborges/checkout/gnome-boxes/src/libvirt-machine-properties.vala"
						if (_tmp67_ == GVIR_CONFIG_DOMAIN_DISK_GUEST_DEVICE_CDROM) {
#line 2138 "libvirt-machine-properties.c"
							GVirConfigDomainDisk* _tmp68_;
#line 139 "/home/fborges/checkout/gnome-boxes/src/libvirt-machine-properties.vala"
							_tmp68_ = disk_config;
#line 139 "/home/fborges/checkout/gnome-boxes/src/libvirt-machine-properties.vala"
							boxes_libvirt_machine_properties_add_cdrom_property (self, _tmp68_, &list);
#line 2144 "libvirt-machine-properties.c"
						}
#line 133 "/home/fborges/checkout/gnome-boxes/src/libvirt-machine-properties.vala"
						_g_object_unref0 (disk_config);
#line 133 "/home/fborges/checkout/gnome-boxes/src/libvirt-machine-properties.vala"
						_g_object_unref0 (device_config);
#line 2150 "libvirt-machine-properties.c"
					}
				}
#line 133 "/home/fborges/checkout/gnome-boxes/src/libvirt-machine-properties.vala"
				__g_list_free__g_object_unref0_0 (device_config_collection);
#line 2155 "libvirt-machine-properties.c"
			}
#line 142 "/home/fborges/checkout/gnome-boxes/src/libvirt-machine-properties.vala"
			break;
#line 2159 "libvirt-machine-properties.c"
		}
#line 94 "/home/fborges/checkout/gnome-boxes/src/libvirt-machine-properties.vala"
		case BOXES_PROPERTIES_PAGE_SNAPSHOTS:
#line 2163 "libvirt-machine-properties.c"
		{
			{
				GVirConfigDomain* config = NULL;
				BoxesLibvirtMachine* _tmp69_;
				GVirDomain* _tmp70_;
				GVirDomain* _tmp71_;
				GVirConfigDomain* _tmp72_;
				gboolean _tmp73_ = FALSE;
				GVirConfigDomain* _tmp74_;
				GVirConfigDomainCpu* _tmp75_;
				GVirConfigDomainCpu* _tmp76_;
				GVirConfigDomainCpuMode _tmp77_;
				gboolean _tmp78_;
#line 146 "/home/fborges/checkout/gnome-boxes/src/libvirt-machine-properties.vala"
				_tmp69_ = self->priv->machine;
#line 146 "/home/fborges/checkout/gnome-boxes/src/libvirt-machine-properties.vala"
				_tmp70_ = boxes_libvirt_machine_get_domain (_tmp69_);
#line 146 "/home/fborges/checkout/gnome-boxes/src/libvirt-machine-properties.vala"
				_tmp71_ = _tmp70_;
#line 146 "/home/fborges/checkout/gnome-boxes/src/libvirt-machine-properties.vala"
				_tmp72_ = gvir_domain_get_config (_tmp71_, (guint) 0, &_inner_error_);
#line 146 "/home/fborges/checkout/gnome-boxes/src/libvirt-machine-properties.vala"
				config = _tmp72_;
#line 146 "/home/fborges/checkout/gnome-boxes/src/libvirt-machine-properties.vala"
				if (G_UNLIKELY (_inner_error_ != NULL)) {
#line 2189 "libvirt-machine-properties.c"
					goto __catch40_g_error;
				}
#line 148 "/home/fborges/checkout/gnome-boxes/src/libvirt-machine-properties.vala"
				_tmp74_ = config;
#line 148 "/home/fborges/checkout/gnome-boxes/src/libvirt-machine-properties.vala"
				_tmp75_ = gvir_config_domain_get_cpu (_tmp74_);
#line 148 "/home/fborges/checkout/gnome-boxes/src/libvirt-machine-properties.vala"
				_tmp76_ = _tmp75_;
#line 148 "/home/fborges/checkout/gnome-boxes/src/libvirt-machine-properties.vala"
				_tmp77_ = gvir_config_domain_cpu_get_mode (_tmp76_);
#line 148 "/home/fborges/checkout/gnome-boxes/src/libvirt-machine-properties.vala"
				_tmp78_ = _tmp77_ != GVIR_CONFIG_DOMAIN_CPU_MODE_HOST_PASSTHROUGH;
#line 148 "/home/fborges/checkout/gnome-boxes/src/libvirt-machine-properties.vala"
				_g_object_unref0 (_tmp76_);
#line 148 "/home/fborges/checkout/gnome-boxes/src/libvirt-machine-properties.vala"
				if (_tmp78_) {
#line 2206 "libvirt-machine-properties.c"
					GVirConfigDomain* _tmp79_;
					gboolean _tmp80_;
#line 149 "/home/fborges/checkout/gnome-boxes/src/libvirt-machine-properties.vala"
					_tmp79_ = config;
#line 149 "/home/fborges/checkout/gnome-boxes/src/libvirt-machine-properties.vala"
					_tmp80_ = boxes_vm_configurator_is_install_config (_tmp79_);
#line 149 "/home/fborges/checkout/gnome-boxes/src/libvirt-machine-properties.vala"
					_tmp73_ = !_tmp80_;
#line 2215 "libvirt-machine-properties.c"
				} else {
#line 148 "/home/fborges/checkout/gnome-boxes/src/libvirt-machine-properties.vala"
					_tmp73_ = FALSE;
#line 2219 "libvirt-machine-properties.c"
				}
#line 148 "/home/fborges/checkout/gnome-boxes/src/libvirt-machine-properties.vala"
				if (_tmp73_) {
#line 2223 "libvirt-machine-properties.c"
					BoxesSnapshotsProperty* _tmp81_;
					BoxesSnapshotsProperty* _tmp82_;
#line 150 "/home/fborges/checkout/gnome-boxes/src/libvirt-machine-properties.vala"
					_tmp81_ = boxes_libvirt_machine_properties_add_snapshots_property (self, &list);
#line 150 "/home/fborges/checkout/gnome-boxes/src/libvirt-machine-properties.vala"
					_tmp82_ = _tmp81_;
#line 150 "/home/fborges/checkout/gnome-boxes/src/libvirt-machine-properties.vala"
					_g_object_unref0 (_tmp82_);
#line 2232 "libvirt-machine-properties.c"
				}
#line 145 "/home/fborges/checkout/gnome-boxes/src/libvirt-machine-properties.vala"
				_g_object_unref0 (config);
#line 2236 "libvirt-machine-properties.c"
			}
			goto __finally40;
			__catch40_g_error:
			{
				GError* e = NULL;
				GError* _tmp83_;
				const gchar* _tmp84_;
#line 145 "/home/fborges/checkout/gnome-boxes/src/libvirt-machine-properties.vala"
				e = _inner_error_;
#line 145 "/home/fborges/checkout/gnome-boxes/src/libvirt-machine-properties.vala"
				_inner_error_ = NULL;
#line 152 "/home/fborges/checkout/gnome-boxes/src/libvirt-machine-properties.vala"
				_tmp83_ = e;
#line 152 "/home/fborges/checkout/gnome-boxes/src/libvirt-machine-properties.vala"
				_tmp84_ = _tmp83_->message;
#line 152 "/home/fborges/checkout/gnome-boxes/src/libvirt-machine-properties.vala"
				g_warning ("libvirt-machine-properties.vala:152: %s", _tmp84_);
#line 145 "/home/fborges/checkout/gnome-boxes/src/libvirt-machine-properties.vala"
				_g_error_free0 (e);
#line 2256 "libvirt-machine-properties.c"
			}
			__finally40:
#line 145 "/home/fborges/checkout/gnome-boxes/src/libvirt-machine-properties.vala"
			if (G_UNLIKELY (_inner_error_ != NULL)) {
#line 145 "/home/fborges/checkout/gnome-boxes/src/libvirt-machine-properties.vala"
				__g_list_free__g_object_unref0_0 (list);
#line 145 "/home/fborges/checkout/gnome-boxes/src/libvirt-machine-properties.vala"
				g_critical ("file %s: line %d: uncaught error: %s (%s, %d)", __FILE__, __LINE__, _inner_error_->message, g_quark_to_string (_inner_error_->domain), _inner_error_->code);
#line 145 "/home/fborges/checkout/gnome-boxes/src/libvirt-machine-properties.vala"
				g_clear_error (&_inner_error_);
#line 145 "/home/fborges/checkout/gnome-boxes/src/libvirt-machine-properties.vala"
				return NULL;
#line 2269 "libvirt-machine-properties.c"
			}
#line 155 "/home/fborges/checkout/gnome-boxes/src/libvirt-machine-properties.vala"
			break;
#line 2273 "libvirt-machine-properties.c"
		}
		default:
#line 94 "/home/fborges/checkout/gnome-boxes/src/libvirt-machine-properties.vala"
		break;
#line 2278 "libvirt-machine-properties.c"
	}
#line 158 "/home/fborges/checkout/gnome-boxes/src/libvirt-machine-properties.vala"
	result = list;
#line 158 "/home/fborges/checkout/gnome-boxes/src/libvirt-machine-properties.vala"
	return result;
#line 2284 "libvirt-machine-properties.c"
}


void boxes_libvirt_machine_properties_get_resources_properties (BoxesLibvirtMachineProperties* self, GList* * list) {
	BoxesSizeProperty* ram_property = NULL;
	BoxesSizeProperty* _tmp0_;
	BoxesSizeProperty* storage_property = NULL;
	BoxesSizeProperty* _tmp1_;
#line 161 "/home/fborges/checkout/gnome-boxes/src/libvirt-machine-properties.vala"
	g_return_if_fail (self != NULL);
#line 162 "/home/fborges/checkout/gnome-boxes/src/libvirt-machine-properties.vala"
	_tmp0_ = boxes_libvirt_machine_properties_add_ram_property (self, list);
#line 162 "/home/fborges/checkout/gnome-boxes/src/libvirt-machine-properties.vala"
	ram_property = _tmp0_;
#line 163 "/home/fborges/checkout/gnome-boxes/src/libvirt-machine-properties.vala"
	_tmp1_ = boxes_libvirt_machine_properties_add_storage_property (self, list);
#line 163 "/home/fborges/checkout/gnome-boxes/src/libvirt-machine-properties.vala"
	storage_property = _tmp1_;
#line 164 "/home/fborges/checkout/gnome-boxes/src/libvirt-machine-properties.vala"
	boxes_libvirt_machine_properties_mark_recommended_resources (self, ram_property, storage_property, NULL, NULL);
#line 161 "/home/fborges/checkout/gnome-boxes/src/libvirt-machine-properties.vala"
	_g_object_unref0 (storage_property);
#line 161 "/home/fborges/checkout/gnome-boxes/src/libvirt-machine-properties.vala"
	_g_object_unref0 (ram_property);
#line 2309 "libvirt-machine-properties.c"
}


static Block47Data* block47_data_ref (Block47Data* _data47_) {
#line 167 "/home/fborges/checkout/gnome-boxes/src/libvirt-machine-properties.vala"
	g_atomic_int_inc (&_data47_->_ref_count_);
#line 167 "/home/fborges/checkout/gnome-boxes/src/libvirt-machine-properties.vala"
	return _data47_;
#line 2318 "libvirt-machine-properties.c"
}


static void block47_data_unref (void * _userdata_) {
	Block47Data* _data47_;
	_data47_ = (Block47Data*) _userdata_;
#line 167 "/home/fborges/checkout/gnome-boxes/src/libvirt-machine-properties.vala"
	if (g_atomic_int_dec_and_test (&_data47_->_ref_count_)) {
#line 2327 "libvirt-machine-properties.c"
		BoxesLibvirtMachineProperties* self;
#line 167 "/home/fborges/checkout/gnome-boxes/src/libvirt-machine-properties.vala"
		self = _data47_->self;
#line 167 "/home/fborges/checkout/gnome-boxes/src/libvirt-machine-properties.vala"
		_g_object_unref0 (_data47_->button_label);
#line 167 "/home/fborges/checkout/gnome-boxes/src/libvirt-machine-properties.vala"
		_g_object_unref0 (_data47_->label);
#line 167 "/home/fborges/checkout/gnome-boxes/src/libvirt-machine-properties.vala"
		_g_object_unref0 (_data47_->disk_config);
#line 167 "/home/fborges/checkout/gnome-boxes/src/libvirt-machine-properties.vala"
		_g_object_unref0 (self);
#line 167 "/home/fborges/checkout/gnome-boxes/src/libvirt-machine-properties.vala"
		g_slice_free (Block47Data, _data47_);
#line 2341 "libvirt-machine-properties.c"
	}
}


static void ___lambda141_ (Block47Data* _data47_, const gchar* path) {
	BoxesLibvirtMachineProperties* self;
	GVirConfigDomainDisk* _tmp0_;
	const gchar* _tmp1_;
	GError * _inner_error_ = NULL;
#line 211 "/home/fborges/checkout/gnome-boxes/src/libvirt-machine-properties.vala"
	self = _data47_->self;
#line 211 "/home/fborges/checkout/gnome-boxes/src/libvirt-machine-properties.vala"
	g_return_if_fail (path != NULL);
#line 212 "/home/fborges/checkout/gnome-boxes/src/libvirt-machine-properties.vala"
	_tmp0_ = _data47_->disk_config;
#line 212 "/home/fborges/checkout/gnome-boxes/src/libvirt-machine-properties.vala"
	_tmp1_ = path;
#line 212 "/home/fborges/checkout/gnome-boxes/src/libvirt-machine-properties.vala"
	gvir_config_domain_disk_set_source (_tmp0_, _tmp1_);
#line 2361 "libvirt-machine-properties.c"
	{
		BoxesLibvirtMachine* _tmp2_;
		GVirDomain* _tmp3_;
		GVirDomain* _tmp4_;
		GVirConfigDomainDisk* _tmp5_;
		GtkLabel* _tmp6_;
		GtkLabel* _tmp7_;
		const gchar* _tmp8_;
		gchar* _tmp9_;
		gchar* _tmp10_;
#line 214 "/home/fborges/checkout/gnome-boxes/src/libvirt-machine-properties.vala"
		_tmp2_ = self->priv->machine;
#line 214 "/home/fborges/checkout/gnome-boxes/src/libvirt-machine-properties.vala"
		_tmp3_ = boxes_libvirt_machine_get_domain (_tmp2_);
#line 214 "/home/fborges/checkout/gnome-boxes/src/libvirt-machine-properties.vala"
		_tmp4_ = _tmp3_;
#line 214 "/home/fborges/checkout/gnome-boxes/src/libvirt-machine-properties.vala"
		_tmp5_ = _data47_->disk_config;
#line 214 "/home/fborges/checkout/gnome-boxes/src/libvirt-machine-properties.vala"
		gvir_domain_update_device (_tmp4_, (GVirConfigDomainDevice*) _tmp5_, (guint) GVIR_DOMAIN_UPDATE_DEVICE_CURRENT, &_inner_error_);
#line 214 "/home/fborges/checkout/gnome-boxes/src/libvirt-machine-properties.vala"
		if (G_UNLIKELY (_inner_error_ != NULL)) {
#line 2384 "libvirt-machine-properties.c"
			goto __catch41_g_error;
		}
#line 215 "/home/fborges/checkout/gnome-boxes/src/libvirt-machine-properties.vala"
		_tmp6_ = _data47_->button_label;
#line 215 "/home/fborges/checkout/gnome-boxes/src/libvirt-machine-properties.vala"
		gtk_label_set_text_with_mnemonic (_tmp6_, _ ("_Remove"));
#line 216 "/home/fborges/checkout/gnome-boxes/src/libvirt-machine-properties.vala"
		_tmp7_ = _data47_->label;
#line 216 "/home/fborges/checkout/gnome-boxes/src/libvirt-machine-properties.vala"
		_tmp8_ = path;
#line 216 "/home/fborges/checkout/gnome-boxes/src/libvirt-machine-properties.vala"
		_tmp9_ = boxes_get_utf8_basename (_tmp8_);
#line 216 "/home/fborges/checkout/gnome-boxes/src/libvirt-machine-properties.vala"
		_tmp10_ = _tmp9_;
#line 216 "/home/fborges/checkout/gnome-boxes/src/libvirt-machine-properties.vala"
		gtk_label_set_text (_tmp7_, _tmp10_);
#line 216 "/home/fborges/checkout/gnome-boxes/src/libvirt-machine-properties.vala"
		_g_free0 (_tmp10_);
#line 217 "/home/fborges/checkout/gnome-boxes/src/libvirt-machine-properties.vala"
		_data47_->empty = FALSE;
#line 2405 "libvirt-machine-properties.c"
	}
	goto __finally41;
	__catch41_g_error:
	{
		GError* e = NULL;
		gchar* path_basename = NULL;
		const gchar* _tmp11_;
		gchar* _tmp12_;
		gchar* msg = NULL;
		gchar* _tmp13_;
		BoxesLibvirtMachine* _tmp14_;
		const gchar* _tmp15_;
		const gchar* _tmp16_;
		BoxesLibvirtMachine* _tmp17_;
		const gchar* _tmp18_;
		const gchar* _tmp19_;
		gchar* _tmp20_;
		gchar* _tmp21_;
		const gchar* _tmp22_;
		BoxesLibvirtMachine* _tmp23_;
		const gchar* _tmp24_;
		const gchar* _tmp25_;
		GError* _tmp26_;
		const gchar* _tmp27_;
#line 213 "/home/fborges/checkout/gnome-boxes/src/libvirt-machine-properties.vala"
		e = _inner_error_;
#line 213 "/home/fborges/checkout/gnome-boxes/src/libvirt-machine-properties.vala"
		_inner_error_ = NULL;
#line 219 "/home/fborges/checkout/gnome-boxes/src/libvirt-machine-properties.vala"
		_tmp11_ = path;
#line 219 "/home/fborges/checkout/gnome-boxes/src/libvirt-machine-properties.vala"
		_tmp12_ = boxes_get_utf8_basename (_tmp11_);
#line 219 "/home/fborges/checkout/gnome-boxes/src/libvirt-machine-properties.vala"
		path_basename = _tmp12_;
#line 222 "/home/fborges/checkout/gnome-boxes/src/libvirt-machine-properties.vala"
		_tmp13_ = g_strdup (_ ("Insertion of “%s” as a CD/DVD into “%s” failed"));
#line 222 "/home/fborges/checkout/gnome-boxes/src/libvirt-machine-properties.vala"
		msg = _tmp13_;
#line 223 "/home/fborges/checkout/gnome-boxes/src/libvirt-machine-properties.vala"
		_tmp14_ = self->priv->machine;
#line 223 "/home/fborges/checkout/gnome-boxes/src/libvirt-machine-properties.vala"
		_tmp15_ = msg;
#line 223 "/home/fborges/checkout/gnome-boxes/src/libvirt-machine-properties.vala"
		_tmp16_ = path_basename;
#line 223 "/home/fborges/checkout/gnome-boxes/src/libvirt-machine-properties.vala"
		_tmp17_ = self->priv->machine;
#line 223 "/home/fborges/checkout/gnome-boxes/src/libvirt-machine-properties.vala"
		_tmp18_ = boxes_collection_item_get_name ((BoxesCollectionItem*) _tmp17_);
#line 223 "/home/fborges/checkout/gnome-boxes/src/libvirt-machine-properties.vala"
		_tmp19_ = _tmp18_;
#line 223 "/home/fborges/checkout/gnome-boxes/src/libvirt-machine-properties.vala"
		_tmp20_ = g_strdup_printf (_tmp15_, _tmp16_, _tmp19_);
#line 223 "/home/fborges/checkout/gnome-boxes/src/libvirt-machine-properties.vala"
		_tmp21_ = _tmp20_;
#line 223 "/home/fborges/checkout/gnome-boxes/src/libvirt-machine-properties.vala"
		g_signal_emit_by_name ((BoxesMachine*) _tmp14_, "got-error", _tmp21_);
#line 223 "/home/fborges/checkout/gnome-boxes/src/libvirt-machine-properties.vala"
		_g_free0 (_tmp21_);
#line 224 "/home/fborges/checkout/gnome-boxes/src/libvirt-machine-properties.vala"
		_tmp22_ = path_basename;
#line 224 "/home/fborges/checkout/gnome-boxes/src/libvirt-machine-properties.vala"
		_tmp23_ = self->priv->machine;
#line 224 "/home/fborges/checkout/gnome-boxes/src/libvirt-machine-properties.vala"
		_tmp24_ = boxes_collection_item_get_name ((BoxesCollectionItem*) _tmp23_);
#line 224 "/home/fborges/checkout/gnome-boxes/src/libvirt-machine-properties.vala"
		_tmp25_ = _tmp24_;
#line 224 "/home/fborges/checkout/gnome-boxes/src/libvirt-machine-properties.vala"
		_tmp26_ = e;
#line 224 "/home/fborges/checkout/gnome-boxes/src/libvirt-machine-properties.vala"
		_tmp27_ = _tmp26_->message;
#line 224 "/home/fborges/checkout/gnome-boxes/src/libvirt-machine-properties.vala"
		g_debug ("libvirt-machine-properties.vala:224: Error inserting '%s' as CD into '" \
"%s': %s", _tmp22_, _tmp25_, _tmp27_);
#line 213 "/home/fborges/checkout/gnome-boxes/src/libvirt-machine-properties.vala"
		_g_free0 (msg);
#line 213 "/home/fborges/checkout/gnome-boxes/src/libvirt-machine-properties.vala"
		_g_free0 (path_basename);
#line 213 "/home/fborges/checkout/gnome-boxes/src/libvirt-machine-properties.vala"
		_g_error_free0 (e);
#line 2484 "libvirt-machine-properties.c"
	}
	__finally41:
#line 213 "/home/fborges/checkout/gnome-boxes/src/libvirt-machine-properties.vala"
	if (G_UNLIKELY (_inner_error_ != NULL)) {
#line 213 "/home/fborges/checkout/gnome-boxes/src/libvirt-machine-properties.vala"
		g_critical ("file %s: line %d: uncaught error: %s (%s, %d)", __FILE__, __LINE__, _inner_error_->message, g_quark_to_string (_inner_error_->domain), _inner_error_->code);
#line 213 "/home/fborges/checkout/gnome-boxes/src/libvirt-machine-properties.vala"
		g_clear_error (&_inner_error_);
#line 213 "/home/fborges/checkout/gnome-boxes/src/libvirt-machine-properties.vala"
		return;
#line 2495 "libvirt-machine-properties.c"
	}
}


static void ____lambda141__boxes_properties_window_file_chosen_func (const gchar* path, gpointer self) {
#line 211 "/home/fborges/checkout/gnome-boxes/src/libvirt-machine-properties.vala"
	___lambda141_ (self, path);
#line 2503 "libvirt-machine-properties.c"
}


static void __lambda140_ (Block47Data* _data47_) {
	BoxesLibvirtMachineProperties* self;
	gboolean _tmp0_;
	GError * _inner_error_ = NULL;
#line 209 "/home/fborges/checkout/gnome-boxes/src/libvirt-machine-properties.vala"
	self = _data47_->self;
#line 210 "/home/fborges/checkout/gnome-boxes/src/libvirt-machine-properties.vala"
	_tmp0_ = _data47_->empty;
#line 210 "/home/fborges/checkout/gnome-boxes/src/libvirt-machine-properties.vala"
	if (_tmp0_) {
#line 2517 "libvirt-machine-properties.c"
		BoxesLibvirtMachine* _tmp1_;
		BoxesAppWindow* _tmp2_;
		BoxesAppWindow* _tmp3_;
		BoxesPropertiesWindow* _tmp4_;
#line 211 "/home/fborges/checkout/gnome-boxes/src/libvirt-machine-properties.vala"
		_tmp1_ = self->priv->machine;
#line 211 "/home/fborges/checkout/gnome-boxes/src/libvirt-machine-properties.vala"
		_tmp2_ = boxes_machine_get_window ((BoxesMachine*) _tmp1_);
#line 211 "/home/fborges/checkout/gnome-boxes/src/libvirt-machine-properties.vala"
		_tmp3_ = _tmp2_;
#line 211 "/home/fborges/checkout/gnome-boxes/src/libvirt-machine-properties.vala"
		_tmp4_ = _tmp3_->props_window;
#line 211 "/home/fborges/checkout/gnome-boxes/src/libvirt-machine-properties.vala"
		boxes_properties_window_show_file_chooser (_tmp4_, ____lambda141__boxes_properties_window_file_chosen_func, block47_data_ref (_data47_), block47_data_unref);
#line 2532 "libvirt-machine-properties.c"
	} else {
		GVirConfigDomainDisk* _tmp5_;
#line 228 "/home/fborges/checkout/gnome-boxes/src/libvirt-machine-properties.vala"
		_tmp5_ = _data47_->disk_config;
#line 228 "/home/fborges/checkout/gnome-boxes/src/libvirt-machine-properties.vala"
		gvir_config_domain_disk_set_source (_tmp5_, "");
#line 2539 "libvirt-machine-properties.c"
		{
			BoxesLibvirtMachine* _tmp6_;
			GVirDomain* _tmp7_;
			GVirDomain* _tmp8_;
			GVirConfigDomainDisk* _tmp9_;
			GtkLabel* _tmp10_;
			GtkLabel* _tmp11_;
			gchar* _tmp12_;
			gchar* _tmp13_;
#line 230 "/home/fborges/checkout/gnome-boxes/src/libvirt-machine-properties.vala"
			_tmp6_ = self->priv->machine;
#line 230 "/home/fborges/checkout/gnome-boxes/src/libvirt-machine-properties.vala"
			_tmp7_ = boxes_libvirt_machine_get_domain (_tmp6_);
#line 230 "/home/fborges/checkout/gnome-boxes/src/libvirt-machine-properties.vala"
			_tmp8_ = _tmp7_;
#line 230 "/home/fborges/checkout/gnome-boxes/src/libvirt-machine-properties.vala"
			_tmp9_ = _data47_->disk_config;
#line 230 "/home/fborges/checkout/gnome-boxes/src/libvirt-machine-properties.vala"
			gvir_domain_update_device (_tmp8_, (GVirConfigDomainDevice*) _tmp9_, (guint) GVIR_DOMAIN_UPDATE_DEVICE_CURRENT, &_inner_error_);
#line 230 "/home/fborges/checkout/gnome-boxes/src/libvirt-machine-properties.vala"
			if (G_UNLIKELY (_inner_error_ != NULL)) {
#line 2561 "libvirt-machine-properties.c"
				goto __catch42_g_error;
			}
#line 231 "/home/fborges/checkout/gnome-boxes/src/libvirt-machine-properties.vala"
			_data47_->empty = TRUE;
#line 232 "/home/fborges/checkout/gnome-boxes/src/libvirt-machine-properties.vala"
			_tmp10_ = _data47_->button_label;
#line 232 "/home/fborges/checkout/gnome-boxes/src/libvirt-machine-properties.vala"
			gtk_label_set_text_with_mnemonic (_tmp10_, _ ("_Select"));
#line 233 "/home/fborges/checkout/gnome-boxes/src/libvirt-machine-properties.vala"
			_tmp11_ = _data47_->label;
#line 233 "/home/fborges/checkout/gnome-boxes/src/libvirt-machine-properties.vala"
			_tmp12_ = g_markup_printf_escaped ("<i>%s</i>", _ ("empty"));
#line 233 "/home/fborges/checkout/gnome-boxes/src/libvirt-machine-properties.vala"
			_tmp13_ = _tmp12_;
#line 233 "/home/fborges/checkout/gnome-boxes/src/libvirt-machine-properties.vala"
			gtk_label_set_markup (_tmp11_, _tmp13_);
#line 233 "/home/fborges/checkout/gnome-boxes/src/libvirt-machine-properties.vala"
			_g_free0 (_tmp13_);
#line 2580 "libvirt-machine-properties.c"
		}
		goto __finally42;
		__catch42_g_error:
		{
			GError* e = NULL;
			BoxesLibvirtMachine* _tmp14_;
			BoxesLibvirtMachine* _tmp15_;
			const gchar* _tmp16_;
			const gchar* _tmp17_;
			gchar* _tmp18_;
			gchar* _tmp19_;
			BoxesLibvirtMachine* _tmp20_;
			const gchar* _tmp21_;
			const gchar* _tmp22_;
			GError* _tmp23_;
			const gchar* _tmp24_;
#line 229 "/home/fborges/checkout/gnome-boxes/src/libvirt-machine-properties.vala"
			e = _inner_error_;
#line 229 "/home/fborges/checkout/gnome-boxes/src/libvirt-machine-properties.vala"
			_inner_error_ = NULL;
#line 236 "/home/fborges/checkout/gnome-boxes/src/libvirt-machine-properties.vala"
			_tmp14_ = self->priv->machine;
#line 236 "/home/fborges/checkout/gnome-boxes/src/libvirt-machine-properties.vala"
			_tmp15_ = self->priv->machine;
#line 236 "/home/fborges/checkout/gnome-boxes/src/libvirt-machine-properties.vala"
			_tmp16_ = boxes_collection_item_get_name ((BoxesCollectionItem*) _tmp15_);
#line 236 "/home/fborges/checkout/gnome-boxes/src/libvirt-machine-properties.vala"
			_tmp17_ = _tmp16_;
#line 236 "/home/fborges/checkout/gnome-boxes/src/libvirt-machine-properties.vala"
			_tmp18_ = g_strdup_printf (_ ("Removal of CD/DVD from “%s” failed"), _tmp17_);
#line 236 "/home/fborges/checkout/gnome-boxes/src/libvirt-machine-properties.vala"
			_tmp19_ = _tmp18_;
#line 236 "/home/fborges/checkout/gnome-boxes/src/libvirt-machine-properties.vala"
			g_signal_emit_by_name ((BoxesMachine*) _tmp14_, "got-error", _tmp19_);
#line 236 "/home/fborges/checkout/gnome-boxes/src/libvirt-machine-properties.vala"
			_g_free0 (_tmp19_);
#line 237 "/home/fborges/checkout/gnome-boxes/src/libvirt-machine-properties.vala"
			_tmp20_ = self->priv->machine;
#line 237 "/home/fborges/checkout/gnome-boxes/src/libvirt-machine-properties.vala"
			_tmp21_ = boxes_collection_item_get_name ((BoxesCollectionItem*) _tmp20_);
#line 237 "/home/fborges/checkout/gnome-boxes/src/libvirt-machine-properties.vala"
			_tmp22_ = _tmp21_;
#line 237 "/home/fborges/checkout/gnome-boxes/src/libvirt-machine-properties.vala"
			_tmp23_ = e;
#line 237 "/home/fborges/checkout/gnome-boxes/src/libvirt-machine-properties.vala"
			_tmp24_ = _tmp23_->message;
#line 237 "/home/fborges/checkout/gnome-boxes/src/libvirt-machine-properties.vala"
			g_debug ("libvirt-machine-properties.vala:237: Error ejecting CD from '%s': %s", _tmp22_, _tmp24_);
#line 229 "/home/fborges/checkout/gnome-boxes/src/libvirt-machine-properties.vala"
			_g_error_free0 (e);
#line 2631 "libvirt-machine-properties.c"
		}
		__finally42:
#line 229 "/home/fborges/checkout/gnome-boxes/src/libvirt-machine-properties.vala"
		if (G_UNLIKELY (_inner_error_ != NULL)) {
#line 229 "/home/fborges/checkout/gnome-boxes/src/libvirt-machine-properties.vala"
			g_critical ("file %s: line %d: uncaught error: %s (%s, %d)", __FILE__, __LINE__, _inner_error_->message, g_quark_to_string (_inner_error_->domain), _inner_error_->code);
#line 229 "/home/fborges/checkout/gnome-boxes/src/libvirt-machine-properties.vala"
			g_clear_error (&_inner_error_);
#line 229 "/home/fborges/checkout/gnome-boxes/src/libvirt-machine-properties.vala"
			return;
#line 2642 "libvirt-machine-properties.c"
		}
	}
}


static void ___lambda140__gtk_button_clicked (GtkButton* _sender, gpointer self) {
#line 209 "/home/fborges/checkout/gnome-boxes/src/libvirt-machine-properties.vala"
	__lambda140_ (self);
#line 2651 "libvirt-machine-properties.c"
}


static void boxes_libvirt_machine_properties_add_cdrom_property (BoxesLibvirtMachineProperties* self, GVirConfigDomainDisk* disk_config, GList* * list) {
	Block47Data* _data47_;
	GVirConfigDomainDisk* _tmp0_;
	GVirConfigDomainDisk* _tmp1_;
	GtkGrid* grid = NULL;
	GtkGrid* _tmp2_;
	GtkGrid* _tmp3_;
	GtkGrid* _tmp4_;
	GtkLabel* _tmp5_;
	GtkLabel* _tmp6_;
	GtkGrid* _tmp7_;
	GtkLabel* _tmp8_;
	gchar* source = NULL;
	GVirConfigDomainDisk* _tmp9_;
	const gchar* _tmp10_;
	gchar* _tmp11_;
	gboolean _tmp12_ = FALSE;
	const gchar* _tmp13_;
	gboolean _tmp15_;
	BoxesLibvirtMachine* _tmp23_;
	BoxesVMCreator* _tmp24_;
	BoxesVMCreator* _tmp25_;
	GtkLabel* _tmp48_;
	GtkButton* button = NULL;
	GtkButton* _tmp49_;
	GtkButton* _tmp50_;
	GtkLabel* _tmp51_;
	GtkGrid* _tmp52_;
	GtkButton* _tmp53_;
	gboolean _tmp54_;
	GtkButton* _tmp57_;
	BoxesProperty* property = NULL;
	GtkGrid* _tmp58_;
	BoxesProperty* _tmp59_;
	BoxesProperty* _tmp60_;
#line 167 "/home/fborges/checkout/gnome-boxes/src/libvirt-machine-properties.vala"
	g_return_if_fail (self != NULL);
#line 167 "/home/fborges/checkout/gnome-boxes/src/libvirt-machine-properties.vala"
	g_return_if_fail (disk_config != NULL);
#line 167 "/home/fborges/checkout/gnome-boxes/src/libvirt-machine-properties.vala"
	_data47_ = g_slice_new0 (Block47Data);
#line 167 "/home/fborges/checkout/gnome-boxes/src/libvirt-machine-properties.vala"
	_data47_->_ref_count_ = 1;
#line 167 "/home/fborges/checkout/gnome-boxes/src/libvirt-machine-properties.vala"
	_data47_->self = g_object_ref (self);
#line 167 "/home/fborges/checkout/gnome-boxes/src/libvirt-machine-properties.vala"
	_tmp0_ = disk_config;
#line 167 "/home/fborges/checkout/gnome-boxes/src/libvirt-machine-properties.vala"
	_tmp1_ = _g_object_ref0 (_tmp0_);
#line 167 "/home/fborges/checkout/gnome-boxes/src/libvirt-machine-properties.vala"
	_g_object_unref0 (_data47_->disk_config);
#line 167 "/home/fborges/checkout/gnome-boxes/src/libvirt-machine-properties.vala"
	_data47_->disk_config = _tmp1_;
#line 168 "/home/fborges/checkout/gnome-boxes/src/libvirt-machine-properties.vala"
	_tmp2_ = (GtkGrid*) gtk_grid_new ();
#line 168 "/home/fborges/checkout/gnome-boxes/src/libvirt-machine-properties.vala"
	g_object_ref_sink (_tmp2_);
#line 168 "/home/fborges/checkout/gnome-boxes/src/libvirt-machine-properties.vala"
	grid = _tmp2_;
#line 169 "/home/fborges/checkout/gnome-boxes/src/libvirt-machine-properties.vala"
	_tmp3_ = grid;
#line 169 "/home/fborges/checkout/gnome-boxes/src/libvirt-machine-properties.vala"
	gtk_orientable_set_orientation ((GtkOrientable*) _tmp3_, GTK_ORIENTATION_HORIZONTAL);
#line 170 "/home/fborges/checkout/gnome-boxes/src/libvirt-machine-properties.vala"
	_tmp4_ = grid;
#line 170 "/home/fborges/checkout/gnome-boxes/src/libvirt-machine-properties.vala"
	gtk_grid_set_column_spacing (_tmp4_, (guint) 12);
#line 172 "/home/fborges/checkout/gnome-boxes/src/libvirt-machine-properties.vala"
	_tmp5_ = (GtkLabel*) gtk_label_new ("");
#line 172 "/home/fborges/checkout/gnome-boxes/src/libvirt-machine-properties.vala"
	g_object_ref_sink (_tmp5_);
#line 172 "/home/fborges/checkout/gnome-boxes/src/libvirt-machine-properties.vala"
	_data47_->label = _tmp5_;
#line 173 "/home/fborges/checkout/gnome-boxes/src/libvirt-machine-properties.vala"
	_tmp6_ = _data47_->label;
#line 173 "/home/fborges/checkout/gnome-boxes/src/libvirt-machine-properties.vala"
	gtk_label_set_ellipsize (_tmp6_, PANGO_ELLIPSIZE_END);
#line 174 "/home/fborges/checkout/gnome-boxes/src/libvirt-machine-properties.vala"
	_tmp7_ = grid;
#line 174 "/home/fborges/checkout/gnome-boxes/src/libvirt-machine-properties.vala"
	_tmp8_ = _data47_->label;
#line 174 "/home/fborges/checkout/gnome-boxes/src/libvirt-machine-properties.vala"
	gtk_container_add ((GtkContainer*) _tmp7_, (GtkWidget*) _tmp8_);
#line 176 "/home/fborges/checkout/gnome-boxes/src/libvirt-machine-properties.vala"
	_tmp9_ = _data47_->disk_config;
#line 176 "/home/fborges/checkout/gnome-boxes/src/libvirt-machine-properties.vala"
	_tmp10_ = gvir_config_domain_disk_get_source (_tmp9_);
#line 176 "/home/fborges/checkout/gnome-boxes/src/libvirt-machine-properties.vala"
	_tmp11_ = g_strdup (_tmp10_);
#line 176 "/home/fborges/checkout/gnome-boxes/src/libvirt-machine-properties.vala"
	source = _tmp11_;
#line 177 "/home/fborges/checkout/gnome-boxes/src/libvirt-machine-properties.vala"
	_tmp13_ = source;
#line 177 "/home/fborges/checkout/gnome-boxes/src/libvirt-machine-properties.vala"
	if (_tmp13_ == NULL) {
#line 177 "/home/fborges/checkout/gnome-boxes/src/libvirt-machine-properties.vala"
		_tmp12_ = TRUE;
#line 2752 "libvirt-machine-properties.c"
	} else {
		const gchar* _tmp14_;
#line 177 "/home/fborges/checkout/gnome-boxes/src/libvirt-machine-properties.vala"
		_tmp14_ = source;
#line 177 "/home/fborges/checkout/gnome-boxes/src/libvirt-machine-properties.vala"
		_tmp12_ = g_strcmp0 (_tmp14_, "") == 0;
#line 2759 "libvirt-machine-properties.c"
	}
#line 177 "/home/fborges/checkout/gnome-boxes/src/libvirt-machine-properties.vala"
	_data47_->empty = _tmp12_;
#line 179 "/home/fborges/checkout/gnome-boxes/src/libvirt-machine-properties.vala"
	_tmp15_ = _data47_->empty;
#line 179 "/home/fborges/checkout/gnome-boxes/src/libvirt-machine-properties.vala"
	if (_tmp15_) {
#line 2767 "libvirt-machine-properties.c"
		GtkLabel* _tmp16_;
		gchar* _tmp17_;
		gchar* _tmp18_;
#line 181 "/home/fborges/checkout/gnome-boxes/src/libvirt-machine-properties.vala"
		_tmp16_ = _data47_->label;
#line 181 "/home/fborges/checkout/gnome-boxes/src/libvirt-machine-properties.vala"
		_tmp17_ = g_markup_printf_escaped ("<i>%s</i>", _ ("empty"));
#line 181 "/home/fborges/checkout/gnome-boxes/src/libvirt-machine-properties.vala"
		_tmp18_ = _tmp17_;
#line 181 "/home/fborges/checkout/gnome-boxes/src/libvirt-machine-properties.vala"
		gtk_label_set_markup (_tmp16_, _tmp18_);
#line 181 "/home/fborges/checkout/gnome-boxes/src/libvirt-machine-properties.vala"
		_g_free0 (_tmp18_);
#line 2781 "libvirt-machine-properties.c"
	} else {
		GtkLabel* _tmp19_;
		const gchar* _tmp20_;
		gchar* _tmp21_;
		gchar* _tmp22_;
#line 183 "/home/fborges/checkout/gnome-boxes/src/libvirt-machine-properties.vala"
		_tmp19_ = _data47_->label;
#line 183 "/home/fborges/checkout/gnome-boxes/src/libvirt-machine-properties.vala"
		_tmp20_ = source;
#line 183 "/home/fborges/checkout/gnome-boxes/src/libvirt-machine-properties.vala"
		_tmp21_ = boxes_get_utf8_basename (_tmp20_);
#line 183 "/home/fborges/checkout/gnome-boxes/src/libvirt-machine-properties.vala"
		_tmp22_ = _tmp21_;
#line 183 "/home/fborges/checkout/gnome-boxes/src/libvirt-machine-properties.vala"
		gtk_label_set_text (_tmp19_, _tmp22_);
#line 183 "/home/fborges/checkout/gnome-boxes/src/libvirt-machine-properties.vala"
		_g_free0 (_tmp22_);
#line 2799 "libvirt-machine-properties.c"
	}
#line 185 "/home/fborges/checkout/gnome-boxes/src/libvirt-machine-properties.vala"
	_tmp23_ = self->priv->machine;
#line 185 "/home/fborges/checkout/gnome-boxes/src/libvirt-machine-properties.vala"
	_tmp24_ = boxes_libvirt_machine_get_vm_creator (_tmp23_);
#line 185 "/home/fborges/checkout/gnome-boxes/src/libvirt-machine-properties.vala"
	_tmp25_ = _tmp24_;
#line 185 "/home/fborges/checkout/gnome-boxes/src/libvirt-machine-properties.vala"
	if (_tmp25_ != NULL) {
#line 2809 "libvirt-machine-properties.c"
		BoxesInstallerMedia* media = NULL;
		BoxesLibvirtMachine* _tmp26_;
		BoxesVMCreator* _tmp27_;
		BoxesVMCreator* _tmp28_;
		BoxesInstallerMedia* _tmp29_;
		BoxesInstallerMedia* _tmp30_;
		BoxesInstallerMedia* _tmp31_;
		gboolean _tmp32_ = FALSE;
		BoxesLibvirtMachine* _tmp33_;
		BoxesVMCreator* _tmp34_;
		BoxesVMCreator* _tmp35_;
		gboolean _tmp36_;
		gboolean _tmp37_;
#line 186 "/home/fborges/checkout/gnome-boxes/src/libvirt-machine-properties.vala"
		_tmp26_ = self->priv->machine;
#line 186 "/home/fborges/checkout/gnome-boxes/src/libvirt-machine-properties.vala"
		_tmp27_ = boxes_libvirt_machine_get_vm_creator (_tmp26_);
#line 186 "/home/fborges/checkout/gnome-boxes/src/libvirt-machine-properties.vala"
		_tmp28_ = _tmp27_;
#line 186 "/home/fborges/checkout/gnome-boxes/src/libvirt-machine-properties.vala"
		_tmp29_ = boxes_vm_creator_get_install_media (_tmp28_);
#line 186 "/home/fborges/checkout/gnome-boxes/src/libvirt-machine-properties.vala"
		_tmp30_ = _tmp29_;
#line 186 "/home/fborges/checkout/gnome-boxes/src/libvirt-machine-properties.vala"
		_tmp31_ = _g_object_ref0 (_tmp30_);
#line 186 "/home/fborges/checkout/gnome-boxes/src/libvirt-machine-properties.vala"
		media = _tmp31_;
#line 188 "/home/fborges/checkout/gnome-boxes/src/libvirt-machine-properties.vala"
		_tmp33_ = self->priv->machine;
#line 188 "/home/fborges/checkout/gnome-boxes/src/libvirt-machine-properties.vala"
		_tmp34_ = boxes_libvirt_machine_get_vm_creator (_tmp33_);
#line 188 "/home/fborges/checkout/gnome-boxes/src/libvirt-machine-properties.vala"
		_tmp35_ = _tmp34_;
#line 188 "/home/fborges/checkout/gnome-boxes/src/libvirt-machine-properties.vala"
		_tmp36_ = boxes_vm_creator_get_express_install (_tmp35_);
#line 188 "/home/fborges/checkout/gnome-boxes/src/libvirt-machine-properties.vala"
		_tmp37_ = _tmp36_;
#line 188 "/home/fborges/checkout/gnome-boxes/src/libvirt-machine-properties.vala"
		if (_tmp37_) {
#line 188 "/home/fborges/checkout/gnome-boxes/src/libvirt-machine-properties.vala"
			_tmp32_ = TRUE;
#line 2851 "libvirt-machine-properties.c"
		} else {
			gboolean _tmp38_ = FALSE;
			BoxesInstallerMedia* _tmp39_;
			OsinfoMedia* _tmp40_;
#line 188 "/home/fborges/checkout/gnome-boxes/src/libvirt-machine-properties.vala"
			_tmp39_ = media;
#line 188 "/home/fborges/checkout/gnome-boxes/src/libvirt-machine-properties.vala"
			_tmp40_ = _tmp39_->os_media;
#line 188 "/home/fborges/checkout/gnome-boxes/src/libvirt-machine-properties.vala"
			if (_tmp40_ != NULL) {
#line 2862 "libvirt-machine-properties.c"
				BoxesInstallerMedia* _tmp41_;
				OsinfoMedia* _tmp42_;
				gboolean _tmp43_;
				gboolean _tmp44_;
#line 188 "/home/fborges/checkout/gnome-boxes/src/libvirt-machine-properties.vala"
				_tmp41_ = media;
#line 188 "/home/fborges/checkout/gnome-boxes/src/libvirt-machine-properties.vala"
				_tmp42_ = _tmp41_->os_media;
#line 188 "/home/fborges/checkout/gnome-boxes/src/libvirt-machine-properties.vala"
				g_object_get (_tmp42_, "live", &_tmp43_, NULL);
#line 188 "/home/fborges/checkout/gnome-boxes/src/libvirt-machine-properties.vala"
				_tmp44_ = _tmp43_;
#line 188 "/home/fborges/checkout/gnome-boxes/src/libvirt-machine-properties.vala"
				_tmp38_ = _tmp44_;
#line 2877 "libvirt-machine-properties.c"
			} else {
#line 188 "/home/fborges/checkout/gnome-boxes/src/libvirt-machine-properties.vala"
				_tmp38_ = FALSE;
#line 2881 "libvirt-machine-properties.c"
			}
#line 188 "/home/fborges/checkout/gnome-boxes/src/libvirt-machine-properties.vala"
			_tmp32_ = _tmp38_;
#line 2885 "libvirt-machine-properties.c"
		}
#line 188 "/home/fborges/checkout/gnome-boxes/src/libvirt-machine-properties.vala"
		if (_tmp32_) {
#line 2889 "libvirt-machine-properties.c"
			GtkGrid* _tmp45_;
			BoxesProperty* _tmp46_;
			BoxesProperty* _tmp47_;
#line 190 "/home/fborges/checkout/gnome-boxes/src/libvirt-machine-properties.vala"
			_tmp45_ = grid;
#line 190 "/home/fborges/checkout/gnome-boxes/src/libvirt-machine-properties.vala"
			_tmp46_ = boxes_iproperties_provider_add_property ((BoxesIPropertiesProvider*) self, list, _ ("CD/DVD"), (GtkWidget*) _tmp45_, NULL);
#line 190 "/home/fborges/checkout/gnome-boxes/src/libvirt-machine-properties.vala"
			_tmp47_ = _tmp46_;
#line 190 "/home/fborges/checkout/gnome-boxes/src/libvirt-machine-properties.vala"
			_g_object_unref0 (_tmp47_);
#line 192 "/home/fborges/checkout/gnome-boxes/src/libvirt-machine-properties.vala"
			_g_object_unref0 (media);
#line 192 "/home/fborges/checkout/gnome-boxes/src/libvirt-machine-properties.vala"
			_g_free0 (source);
#line 192 "/home/fborges/checkout/gnome-boxes/src/libvirt-machine-properties.vala"
			_g_object_unref0 (grid);
#line 192 "/home/fborges/checkout/gnome-boxes/src/libvirt-machine-properties.vala"
			block47_data_unref (_data47_);
#line 192 "/home/fborges/checkout/gnome-boxes/src/libvirt-machine-properties.vala"
			_data47_ = NULL;
#line 192 "/home/fborges/checkout/gnome-boxes/src/libvirt-machine-properties.vala"
			return;
#line 2913 "libvirt-machine-properties.c"
		}
#line 185 "/home/fborges/checkout/gnome-boxes/src/libvirt-machine-properties.vala"
		_g_object_unref0 (media);
#line 2917 "libvirt-machine-properties.c"
	}
#line 196 "/home/fborges/checkout/gnome-boxes/src/libvirt-machine-properties.vala"
	_tmp48_ = (GtkLabel*) gtk_label_new ("");
#line 196 "/home/fborges/checkout/gnome-boxes/src/libvirt-machine-properties.vala"
	g_object_ref_sink (_tmp48_);
#line 196 "/home/fborges/checkout/gnome-boxes/src/libvirt-machine-properties.vala"
	_data47_->button_label = _tmp48_;
#line 197 "/home/fborges/checkout/gnome-boxes/src/libvirt-machine-properties.vala"
	_tmp49_ = (GtkButton*) gtk_button_new ();
#line 197 "/home/fborges/checkout/gnome-boxes/src/libvirt-machine-properties.vala"
	g_object_ref_sink (_tmp49_);
#line 197 "/home/fborges/checkout/gnome-boxes/src/libvirt-machine-properties.vala"
	button = _tmp49_;
#line 198 "/home/fborges/checkout/gnome-boxes/src/libvirt-machine-properties.vala"
	_tmp50_ = button;
#line 198 "/home/fborges/checkout/gnome-boxes/src/libvirt-machine-properties.vala"
	_tmp51_ = _data47_->button_label;
#line 198 "/home/fborges/checkout/gnome-boxes/src/libvirt-machine-properties.vala"
	gtk_container_add ((GtkContainer*) _tmp50_, (GtkWidget*) _tmp51_);
#line 200 "/home/fborges/checkout/gnome-boxes/src/libvirt-machine-properties.vala"
	_tmp52_ = grid;
#line 200 "/home/fborges/checkout/gnome-boxes/src/libvirt-machine-properties.vala"
	_tmp53_ = button;
#line 200 "/home/fborges/checkout/gnome-boxes/src/libvirt-machine-properties.vala"
	gtk_container_add ((GtkContainer*) _tmp52_, (GtkWidget*) _tmp53_);
#line 202 "/home/fborges/checkout/gnome-boxes/src/libvirt-machine-properties.vala"
	_tmp54_ = _data47_->empty;
#line 202 "/home/fborges/checkout/gnome-boxes/src/libvirt-machine-properties.vala"
	if (_tmp54_) {
#line 2947 "libvirt-machine-properties.c"
		GtkLabel* _tmp55_;
#line 204 "/home/fborges/checkout/gnome-boxes/src/libvirt-machine-properties.vala"
		_tmp55_ = _data47_->button_label;
#line 204 "/home/fborges/checkout/gnome-boxes/src/libvirt-machine-properties.vala"
		gtk_label_set_text_with_mnemonic (_tmp55_, _ ("_Select"));
#line 2953 "libvirt-machine-properties.c"
	} else {
		GtkLabel* _tmp56_;
#line 207 "/home/fborges/checkout/gnome-boxes/src/libvirt-machine-properties.vala"
		_tmp56_ = _data47_->button_label;
#line 207 "/home/fborges/checkout/gnome-boxes/src/libvirt-machine-properties.vala"
		gtk_label_set_text_with_mnemonic (_tmp56_, _ ("_Remove"));
#line 2960 "libvirt-machine-properties.c"
	}
#line 209 "/home/fborges/checkout/gnome-boxes/src/libvirt-machine-properties.vala"
	_tmp57_ = button;
#line 209 "/home/fborges/checkout/gnome-boxes/src/libvirt-machine-properties.vala"
	g_signal_connect_data (_tmp57_, "clicked", (GCallback) ___lambda140__gtk_button_clicked, block47_data_ref (_data47_), (GClosureNotify) block47_data_unref, 0);
#line 242 "/home/fborges/checkout/gnome-boxes/src/libvirt-machine-properties.vala"
	_tmp58_ = grid;
#line 242 "/home/fborges/checkout/gnome-boxes/src/libvirt-machine-properties.vala"
	_tmp59_ = boxes_iproperties_provider_add_property ((BoxesIPropertiesProvider*) self, list, _ ("CD/DVD"), (GtkWidget*) _tmp58_, NULL);
#line 242 "/home/fborges/checkout/gnome-boxes/src/libvirt-machine-properties.vala"
	property = _tmp59_;
#line 243 "/home/fborges/checkout/gnome-boxes/src/libvirt-machine-properties.vala"
	_tmp60_ = property;
#line 243 "/home/fborges/checkout/gnome-boxes/src/libvirt-machine-properties.vala"
	boxes_property_set_description_alignment (_tmp60_, GTK_ALIGN_START);
#line 167 "/home/fborges/checkout/gnome-boxes/src/libvirt-machine-properties.vala"
	_g_object_unref0 (property);
#line 167 "/home/fborges/checkout/gnome-boxes/src/libvirt-machine-properties.vala"
	_g_object_unref0 (button);
#line 167 "/home/fborges/checkout/gnome-boxes/src/libvirt-machine-properties.vala"
	_g_free0 (source);
#line 167 "/home/fborges/checkout/gnome-boxes/src/libvirt-machine-properties.vala"
	_g_object_unref0 (grid);
#line 167 "/home/fborges/checkout/gnome-boxes/src/libvirt-machine-properties.vala"
	block47_data_unref (_data47_);
#line 167 "/home/fborges/checkout/gnome-boxes/src/libvirt-machine-properties.vala"
	_data47_ = NULL;
#line 2988 "libvirt-machine-properties.c"
}


static void boxes_libvirt_machine_properties_update_ram_property (BoxesLibvirtMachineProperties* self, BoxesProperty* property) {
	GError * _inner_error_ = NULL;
#line 246 "/home/fborges/checkout/gnome-boxes/src/libvirt-machine-properties.vala"
	g_return_if_fail (self != NULL);
#line 246 "/home/fborges/checkout/gnome-boxes/src/libvirt-machine-properties.vala"
	g_return_if_fail (property != NULL);
#line 2998 "libvirt-machine-properties.c"
	{
		GVirConfigDomain* config = NULL;
		BoxesLibvirtMachine* _tmp0_;
		GVirDomain* _tmp1_;
		GVirDomain* _tmp2_;
		GVirConfigDomain* _tmp3_;
		guint64 actual = 0ULL;
		BoxesLibvirtMachine* _tmp4_;
		GVirConfigDomain* _tmp5_;
		GVirConfigDomain* _tmp6_;
		guint64 _tmp7_;
		guint64 _tmp8_;
		guint64 pending = 0ULL;
		guint64 _tmp9_;
		guint64 _tmp10_;
		guint64 _tmp11_;
		guint64 _tmp12_;
		BoxesProperty* _tmp13_;
		guint64 _tmp14_;
		guint64 _tmp15_;
#line 248 "/home/fborges/checkout/gnome-boxes/src/libvirt-machine-properties.vala"
		_tmp0_ = self->priv->machine;
#line 248 "/home/fborges/checkout/gnome-boxes/src/libvirt-machine-properties.vala"
		_tmp1_ = boxes_libvirt_machine_get_domain (_tmp0_);
#line 248 "/home/fborges/checkout/gnome-boxes/src/libvirt-machine-properties.vala"
		_tmp2_ = _tmp1_;
#line 248 "/home/fborges/checkout/gnome-boxes/src/libvirt-machine-properties.vala"
		_tmp3_ = gvir_domain_get_config (_tmp2_, (guint) GVIR_DOMAIN_XML_INACTIVE, &_inner_error_);
#line 248 "/home/fborges/checkout/gnome-boxes/src/libvirt-machine-properties.vala"
		config = _tmp3_;
#line 248 "/home/fborges/checkout/gnome-boxes/src/libvirt-machine-properties.vala"
		if (G_UNLIKELY (_inner_error_ != NULL)) {
#line 3031 "libvirt-machine-properties.c"
			goto __catch43_g_error;
		}
#line 251 "/home/fborges/checkout/gnome-boxes/src/libvirt-machine-properties.vala"
		_tmp4_ = self->priv->machine;
#line 251 "/home/fborges/checkout/gnome-boxes/src/libvirt-machine-properties.vala"
		_tmp5_ = boxes_libvirt_machine_get_domain_config (_tmp4_);
#line 251 "/home/fborges/checkout/gnome-boxes/src/libvirt-machine-properties.vala"
		_tmp6_ = _tmp5_;
#line 251 "/home/fborges/checkout/gnome-boxes/src/libvirt-machine-properties.vala"
		_tmp7_ = gvir_config_domain_get_memory (_tmp6_);
#line 251 "/home/fborges/checkout/gnome-boxes/src/libvirt-machine-properties.vala"
		_tmp8_ = _tmp7_;
#line 251 "/home/fborges/checkout/gnome-boxes/src/libvirt-machine-properties.vala"
		actual = _tmp8_ / 1024;
#line 252 "/home/fborges/checkout/gnome-boxes/src/libvirt-machine-properties.vala"
		_tmp9_ = gvir_config_domain_get_memory (config);
#line 252 "/home/fborges/checkout/gnome-boxes/src/libvirt-machine-properties.vala"
		_tmp10_ = _tmp9_;
#line 252 "/home/fborges/checkout/gnome-boxes/src/libvirt-machine-properties.vala"
		pending = _tmp10_ / 1024;
#line 254 "/home/fborges/checkout/gnome-boxes/src/libvirt-machine-properties.vala"
		_tmp11_ = actual;
#line 254 "/home/fborges/checkout/gnome-boxes/src/libvirt-machine-properties.vala"
		_tmp12_ = pending;
#line 254 "/home/fborges/checkout/gnome-boxes/src/libvirt-machine-properties.vala"
		g_debug ("libvirt-machine-properties.vala:254: RAM actual: %llu, pending: %llu", _tmp11_, _tmp12_);
#line 256 "/home/fborges/checkout/gnome-boxes/src/libvirt-machine-properties.vala"
		_tmp13_ = property;
#line 256 "/home/fborges/checkout/gnome-boxes/src/libvirt-machine-properties.vala"
		_tmp14_ = actual;
#line 256 "/home/fborges/checkout/gnome-boxes/src/libvirt-machine-properties.vala"
		_tmp15_ = pending;
#line 256 "/home/fborges/checkout/gnome-boxes/src/libvirt-machine-properties.vala"
		boxes_property_set_reboot_required (_tmp13_, (_tmp14_ - _tmp15_) > ((guint64) 1));
#line 247 "/home/fborges/checkout/gnome-boxes/src/libvirt-machine-properties.vala"
		_g_object_unref0 (config);
#line 3068 "libvirt-machine-properties.c"
	}
	goto __finally43;
	__catch43_g_error:
	{
		GError* e = NULL;
#line 247 "/home/fborges/checkout/gnome-boxes/src/libvirt-machine-properties.vala"
		e = _inner_error_;
#line 247 "/home/fborges/checkout/gnome-boxes/src/libvirt-machine-properties.vala"
		_inner_error_ = NULL;
#line 247 "/home/fborges/checkout/gnome-boxes/src/libvirt-machine-properties.vala"
		_g_error_free0 (e);
#line 3080 "libvirt-machine-properties.c"
	}
	__finally43:
#line 247 "/home/fborges/checkout/gnome-boxes/src/libvirt-machine-properties.vala"
	if (G_UNLIKELY (_inner_error_ != NULL)) {
#line 247 "/home/fborges/checkout/gnome-boxes/src/libvirt-machine-properties.vala"
		g_critical ("file %s: line %d: uncaught error: %s (%s, %d)", __FILE__, __LINE__, _inner_error_->message, g_quark_to_string (_inner_error_->domain), _inner_error_->code);
#line 247 "/home/fborges/checkout/gnome-boxes/src/libvirt-machine-properties.vala"
		g_clear_error (&_inner_error_);
#line 247 "/home/fborges/checkout/gnome-boxes/src/libvirt-machine-properties.vala"
		return;
#line 3091 "libvirt-machine-properties.c"
	}
}


static void boxes_libvirt_machine_properties_mark_recommended_resources_data_free (gpointer _data) {
	BoxesLibvirtMachinePropertiesMarkRecommendedResourcesData* _data_;
	_data_ = _data;
#line 5 "/home/fborges/checkout/gnome-boxes/src/libvirt-machine-properties.vala"
	_g_object_unref0 (_data_->ram_property);
#line 5 "/home/fborges/checkout/gnome-boxes/src/libvirt-machine-properties.vala"
	_g_object_unref0 (_data_->storage_property);
#line 5 "/home/fborges/checkout/gnome-boxes/src/libvirt-machine-properties.vala"
	_g_object_unref0 (_data_->self);
#line 5 "/home/fborges/checkout/gnome-boxes/src/libvirt-machine-properties.vala"
	g_slice_free (BoxesLibvirtMachinePropertiesMarkRecommendedResourcesData, _data_);
#line 3107 "libvirt-machine-properties.c"
}


static void boxes_libvirt_machine_properties_mark_recommended_resources (BoxesLibvirtMachineProperties* self, BoxesSizeProperty* ram_property, BoxesSizeProperty* storage_property, GAsyncReadyCallback _callback_, gpointer _user_data_) {
	BoxesLibvirtMachinePropertiesMarkRecommendedResourcesData* _data_;
	BoxesLibvirtMachineProperties* _tmp0_;
	BoxesSizeProperty* _tmp1_;
	BoxesSizeProperty* _tmp2_;
	BoxesSizeProperty* _tmp3_;
	BoxesSizeProperty* _tmp4_;
#line 5 "/home/fborges/checkout/gnome-boxes/src/libvirt-machine-properties.vala"
	_data_ = g_slice_new0 (BoxesLibvirtMachinePropertiesMarkRecommendedResourcesData);
#line 5 "/home/fborges/checkout/gnome-boxes/src/libvirt-machine-properties.vala"
	_data_->_async_result = g_task_new (G_OBJECT (self), NULL, _callback_, _user_data_);
#line 5 "/home/fborges/checkout/gnome-boxes/src/libvirt-machine-properties.vala"
	g_task_set_task_data (_data_->_async_result, _data_, boxes_libvirt_machine_properties_mark_recommended_resources_data_free);
#line 5 "/home/fborges/checkout/gnome-boxes/src/libvirt-machine-properties.vala"
	_tmp0_ = _g_object_ref0 (self);
#line 5 "/home/fborges/checkout/gnome-boxes/src/libvirt-machine-properties.vala"
	_data_->self = _tmp0_;
#line 5 "/home/fborges/checkout/gnome-boxes/src/libvirt-machine-properties.vala"
	_tmp1_ = ram_property;
#line 5 "/home/fborges/checkout/gnome-boxes/src/libvirt-machine-properties.vala"
	_tmp2_ = _g_object_ref0 (_tmp1_);
#line 5 "/home/fborges/checkout/gnome-boxes/src/libvirt-machine-properties.vala"
	_g_object_unref0 (_data_->ram_property);
#line 5 "/home/fborges/checkout/gnome-boxes/src/libvirt-machine-properties.vala"
	_data_->ram_property = _tmp2_;
#line 5 "/home/fborges/checkout/gnome-boxes/src/libvirt-machine-properties.vala"
	_tmp3_ = storage_property;
#line 5 "/home/fborges/checkout/gnome-boxes/src/libvirt-machine-properties.vala"
	_tmp4_ = _g_object_ref0 (_tmp3_);
#line 5 "/home/fborges/checkout/gnome-boxes/src/libvirt-machine-properties.vala"
	_g_object_unref0 (_data_->storage_property);
#line 5 "/home/fborges/checkout/gnome-boxes/src/libvirt-machine-properties.vala"
	_data_->storage_property = _tmp4_;
#line 5 "/home/fborges/checkout/gnome-boxes/src/libvirt-machine-properties.vala"
	boxes_libvirt_machine_properties_mark_recommended_resources_co (_data_);
#line 3146 "libvirt-machine-properties.c"
}


static void boxes_libvirt_machine_properties_mark_recommended_resources_finish (BoxesLibvirtMachineProperties* self, GAsyncResult* _res_) {
	BoxesLibvirtMachinePropertiesMarkRecommendedResourcesData* _data_;
#line 5 "/home/fborges/checkout/gnome-boxes/src/libvirt-machine-properties.vala"
	_data_ = g_task_propagate_pointer (G_TASK (_res_), NULL);
#line 3154 "libvirt-machine-properties.c"
}


static void boxes_libvirt_machine_properties_mark_recommended_resources_ready (GObject* source_object, GAsyncResult* _res_, gpointer _user_data_) {
	BoxesLibvirtMachinePropertiesMarkRecommendedResourcesData* _data_;
#line 265 "/home/fborges/checkout/gnome-boxes/src/libvirt-machine-properties.vala"
	_data_ = _user_data_;
#line 265 "/home/fborges/checkout/gnome-boxes/src/libvirt-machine-properties.vala"
	_data_->_source_object_ = source_object;
#line 265 "/home/fborges/checkout/gnome-boxes/src/libvirt-machine-properties.vala"
	_data_->_res_ = _res_;
#line 265 "/home/fborges/checkout/gnome-boxes/src/libvirt-machine-properties.vala"
	boxes_libvirt_machine_properties_mark_recommended_resources_co (_data_);
#line 3168 "libvirt-machine-properties.c"
}


static gboolean boxes_libvirt_machine_properties_mark_recommended_resources_co (BoxesLibvirtMachinePropertiesMarkRecommendedResourcesData* _data_) {
#line 261 "/home/fborges/checkout/gnome-boxes/src/libvirt-machine-properties.vala"
	switch (_data_->_state_) {
#line 261 "/home/fborges/checkout/gnome-boxes/src/libvirt-machine-properties.vala"
		case 0:
#line 3177 "libvirt-machine-properties.c"
		goto _state_0;
#line 261 "/home/fborges/checkout/gnome-boxes/src/libvirt-machine-properties.vala"
		case 1:
#line 3181 "libvirt-machine-properties.c"
		goto _state_1;
		default:
#line 261 "/home/fborges/checkout/gnome-boxes/src/libvirt-machine-properties.vala"
		g_assert_not_reached ();
#line 3186 "libvirt-machine-properties.c"
	}
	_state_0:
#line 262 "/home/fborges/checkout/gnome-boxes/src/libvirt-machine-properties.vala"
	_data_->_tmp1_ = _data_->ram_property;
#line 262 "/home/fborges/checkout/gnome-boxes/src/libvirt-machine-properties.vala"
	if (_data_->_tmp1_ == NULL) {
#line 262 "/home/fborges/checkout/gnome-boxes/src/libvirt-machine-properties.vala"
		_data_->_tmp2_ = _data_->storage_property;
#line 262 "/home/fborges/checkout/gnome-boxes/src/libvirt-machine-properties.vala"
		_data_->_tmp0_ = _data_->_tmp2_ == NULL;
#line 3197 "libvirt-machine-properties.c"
	} else {
#line 262 "/home/fborges/checkout/gnome-boxes/src/libvirt-machine-properties.vala"
		_data_->_tmp0_ = FALSE;
#line 3201 "libvirt-machine-properties.c"
	}
#line 262 "/home/fborges/checkout/gnome-boxes/src/libvirt-machine-properties.vala"
	if (_data_->_tmp0_) {
#line 263 "/home/fborges/checkout/gnome-boxes/src/libvirt-machine-properties.vala"
		g_task_return_pointer (_data_->_async_result, _data_, NULL);
#line 263 "/home/fborges/checkout/gnome-boxes/src/libvirt-machine-properties.vala"
		if (_data_->_state_ != 0) {
#line 263 "/home/fborges/checkout/gnome-boxes/src/libvirt-machine-properties.vala"
			while (g_task_get_completed (_data_->_async_result) != TRUE) {
#line 263 "/home/fborges/checkout/gnome-boxes/src/libvirt-machine-properties.vala"
				g_main_context_iteration (g_task_get_context (_data_->_async_result), TRUE);
#line 3213 "libvirt-machine-properties.c"
			}
		}
#line 263 "/home/fborges/checkout/gnome-boxes/src/libvirt-machine-properties.vala"
		g_object_unref (_data_->_async_result);
#line 263 "/home/fborges/checkout/gnome-boxes/src/libvirt-machine-properties.vala"
		return FALSE;
#line 3220 "libvirt-machine-properties.c"
	}
#line 265 "/home/fborges/checkout/gnome-boxes/src/libvirt-machine-properties.vala"
	_data_->_tmp3_ = _data_->self->priv->machine;
#line 265 "/home/fborges/checkout/gnome-boxes/src/libvirt-machine-properties.vala"
	_data_->_state_ = 1;
#line 265 "/home/fborges/checkout/gnome-boxes/src/libvirt-machine-properties.vala"
	boxes_libvirt_machine_properties_get_os_for_machine (_data_->self, _data_->_tmp3_, boxes_libvirt_machine_properties_mark_recommended_resources_ready, _data_);
#line 265 "/home/fborges/checkout/gnome-boxes/src/libvirt-machine-properties.vala"
	return FALSE;
#line 3230 "libvirt-machine-properties.c"
	_state_1:
#line 265 "/home/fborges/checkout/gnome-boxes/src/libvirt-machine-properties.vala"
	_data_->_tmp4_ = boxes_libvirt_machine_properties_get_os_for_machine_finish (_data_->self, _data_->_res_);
#line 265 "/home/fborges/checkout/gnome-boxes/src/libvirt-machine-properties.vala"
	_data_->os = _data_->_tmp4_;
#line 266 "/home/fborges/checkout/gnome-boxes/src/libvirt-machine-properties.vala"
	_data_->_tmp5_ = _data_->os;
#line 266 "/home/fborges/checkout/gnome-boxes/src/libvirt-machine-properties.vala"
	if (_data_->_tmp5_ == NULL) {
#line 267 "/home/fborges/checkout/gnome-boxes/src/libvirt-machine-properties.vala"
		_g_object_unref0 (_data_->os);
#line 267 "/home/fborges/checkout/gnome-boxes/src/libvirt-machine-properties.vala"
		g_task_return_pointer (_data_->_async_result, _data_, NULL);
#line 267 "/home/fborges/checkout/gnome-boxes/src/libvirt-machine-properties.vala"
		if (_data_->_state_ != 0) {
#line 267 "/home/fborges/checkout/gnome-boxes/src/libvirt-machine-properties.vala"
			while (g_task_get_completed (_data_->_async_result) != TRUE) {
#line 267 "/home/fborges/checkout/gnome-boxes/src/libvirt-machine-properties.vala"
				g_main_context_iteration (g_task_get_context (_data_->_async_result), TRUE);
#line 3250 "libvirt-machine-properties.c"
			}
		}
#line 267 "/home/fborges/checkout/gnome-boxes/src/libvirt-machine-properties.vala"
		g_object_unref (_data_->_async_result);
#line 267 "/home/fborges/checkout/gnome-boxes/src/libvirt-machine-properties.vala"
		return FALSE;
#line 3257 "libvirt-machine-properties.c"
	}
#line 269 "/home/fborges/checkout/gnome-boxes/src/libvirt-machine-properties.vala"
	_data_->_tmp6_ = _data_->self->priv->machine;
#line 269 "/home/fborges/checkout/gnome-boxes/src/libvirt-machine-properties.vala"
	_data_->_tmp7_ = boxes_libvirt_machine_get_domain_config (_data_->_tmp6_);
#line 269 "/home/fborges/checkout/gnome-boxes/src/libvirt-machine-properties.vala"
	_data_->_tmp8_ = _data_->_tmp7_;
#line 269 "/home/fborges/checkout/gnome-boxes/src/libvirt-machine-properties.vala"
	_data_->_tmp9_ = gvir_config_domain_get_os (_data_->_tmp8_);
#line 269 "/home/fborges/checkout/gnome-boxes/src/libvirt-machine-properties.vala"
	_data_->_tmp10_ = _data_->_tmp9_;
#line 269 "/home/fborges/checkout/gnome-boxes/src/libvirt-machine-properties.vala"
	_data_->_tmp11_ = gvir_config_domain_os_get_arch (_data_->_tmp10_);
#line 269 "/home/fborges/checkout/gnome-boxes/src/libvirt-machine-properties.vala"
	_data_->_tmp12_ = g_strdup (_data_->_tmp11_);
#line 269 "/home/fborges/checkout/gnome-boxes/src/libvirt-machine-properties.vala"
	_data_->_tmp13_ = _data_->_tmp12_;
#line 269 "/home/fborges/checkout/gnome-boxes/src/libvirt-machine-properties.vala"
	_g_object_unref0 (_data_->_tmp10_);
#line 269 "/home/fborges/checkout/gnome-boxes/src/libvirt-machine-properties.vala"
	_data_->architecture = _data_->_tmp13_;
#line 270 "/home/fborges/checkout/gnome-boxes/src/libvirt-machine-properties.vala"
	_data_->_tmp14_ = _data_->os;
#line 270 "/home/fborges/checkout/gnome-boxes/src/libvirt-machine-properties.vala"
	_data_->_tmp15_ = _data_->architecture;
#line 270 "/home/fborges/checkout/gnome-boxes/src/libvirt-machine-properties.vala"
	_data_->_tmp16_ = boxes_os_database_get_recommended_resources_for_os (_data_->_tmp14_, _data_->_tmp15_);
#line 270 "/home/fborges/checkout/gnome-boxes/src/libvirt-machine-properties.vala"
	_data_->resources = _data_->_tmp16_;
#line 271 "/home/fborges/checkout/gnome-boxes/src/libvirt-machine-properties.vala"
	_data_->_tmp17_ = _data_->resources;
#line 271 "/home/fborges/checkout/gnome-boxes/src/libvirt-machine-properties.vala"
	if (_data_->_tmp17_ != NULL) {
#line 272 "/home/fborges/checkout/gnome-boxes/src/libvirt-machine-properties.vala"
		_data_->_tmp18_ = _data_->ram_property;
#line 272 "/home/fborges/checkout/gnome-boxes/src/libvirt-machine-properties.vala"
		if (_data_->_tmp18_ != NULL) {
#line 273 "/home/fborges/checkout/gnome-boxes/src/libvirt-machine-properties.vala"
			_data_->_tmp19_ = _data_->ram_property;
#line 273 "/home/fborges/checkout/gnome-boxes/src/libvirt-machine-properties.vala"
			_data_->_tmp20_ = _data_->resources;
#line 273 "/home/fborges/checkout/gnome-boxes/src/libvirt-machine-properties.vala"
			_data_->_tmp21_ = osinfo_resources_get_ram (_data_->_tmp20_);
#line 273 "/home/fborges/checkout/gnome-boxes/src/libvirt-machine-properties.vala"
			_data_->_tmp22_ = _data_->_tmp21_;
#line 273 "/home/fborges/checkout/gnome-boxes/src/libvirt-machine-properties.vala"
			boxes_size_property_set_recommended (_data_->_tmp19_, (guint64) _data_->_tmp22_);
#line 3305 "libvirt-machine-properties.c"
		}
#line 274 "/home/fborges/checkout/gnome-boxes/src/libvirt-machine-properties.vala"
		_data_->_tmp23_ = _data_->storage_property;
#line 274 "/home/fborges/checkout/gnome-boxes/src/libvirt-machine-properties.vala"
		if (_data_->_tmp23_ != NULL) {
#line 275 "/home/fborges/checkout/gnome-boxes/src/libvirt-machine-properties.vala"
			_data_->_tmp24_ = _data_->storage_property;
#line 275 "/home/fborges/checkout/gnome-boxes/src/libvirt-machine-properties.vala"
			_data_->_tmp25_ = _data_->resources;
#line 275 "/home/fborges/checkout/gnome-boxes/src/libvirt-machine-properties.vala"
			_data_->_tmp26_ = osinfo_resources_get_storage (_data_->_tmp25_);
#line 275 "/home/fborges/checkout/gnome-boxes/src/libvirt-machine-properties.vala"
			_data_->_tmp27_ = _data_->_tmp26_;
#line 275 "/home/fborges/checkout/gnome-boxes/src/libvirt-machine-properties.vala"
			boxes_size_property_set_recommended (_data_->_tmp24_, (guint64) _data_->_tmp27_);
#line 3321 "libvirt-machine-properties.c"
		}
	}
#line 261 "/home/fborges/checkout/gnome-boxes/src/libvirt-machine-properties.vala"
	_g_object_unref0 (_data_->resources);
#line 261 "/home/fborges/checkout/gnome-boxes/src/libvirt-machine-properties.vala"
	_g_free0 (_data_->architecture);
#line 261 "/home/fborges/checkout/gnome-boxes/src/libvirt-machine-properties.vala"
	_g_object_unref0 (_data_->os);
#line 261 "/home/fborges/checkout/gnome-boxes/src/libvirt-machine-properties.vala"
	g_task_return_pointer (_data_->_async_result, _data_, NULL);
#line 261 "/home/fborges/checkout/gnome-boxes/src/libvirt-machine-properties.vala"
	if (_data_->_state_ != 0) {
#line 261 "/home/fborges/checkout/gnome-boxes/src/libvirt-machine-properties.vala"
		while (g_task_get_completed (_data_->_async_result) != TRUE) {
#line 261 "/home/fborges/checkout/gnome-boxes/src/libvirt-machine-properties.vala"
			g_main_context_iteration (g_task_get_context (_data_->_async_result), TRUE);
#line 3338 "libvirt-machine-properties.c"
		}
	}
#line 261 "/home/fborges/checkout/gnome-boxes/src/libvirt-machine-properties.vala"
	g_object_unref (_data_->_async_result);
#line 261 "/home/fborges/checkout/gnome-boxes/src/libvirt-machine-properties.vala"
	return FALSE;
#line 3345 "libvirt-machine-properties.c"
}


static void boxes_libvirt_machine_properties_get_os_for_machine_data_free (gpointer _data) {
	BoxesLibvirtMachinePropertiesGetOsForMachineData* _data_;
	_data_ = _data;
#line 5 "/home/fborges/checkout/gnome-boxes/src/libvirt-machine-properties.vala"
	_g_object_unref0 (_data_->machine);
#line 5 "/home/fborges/checkout/gnome-boxes/src/libvirt-machine-properties.vala"
	_g_object_unref0 (_data_->result);
#line 5 "/home/fborges/checkout/gnome-boxes/src/libvirt-machine-properties.vala"
	_g_object_unref0 (_data_->self);
#line 5 "/home/fborges/checkout/gnome-boxes/src/libvirt-machine-properties.vala"
	g_slice_free (BoxesLibvirtMachinePropertiesGetOsForMachineData, _data_);
#line 3360 "libvirt-machine-properties.c"
}


static void boxes_libvirt_machine_properties_get_os_for_machine (BoxesLibvirtMachineProperties* self, BoxesLibvirtMachine* machine, GAsyncReadyCallback _callback_, gpointer _user_data_) {
	BoxesLibvirtMachinePropertiesGetOsForMachineData* _data_;
	BoxesLibvirtMachineProperties* _tmp0_;
	BoxesLibvirtMachine* _tmp1_;
	BoxesLibvirtMachine* _tmp2_;
#line 5 "/home/fborges/checkout/gnome-boxes/src/libvirt-machine-properties.vala"
	_data_ = g_slice_new0 (BoxesLibvirtMachinePropertiesGetOsForMachineData);
#line 5 "/home/fborges/checkout/gnome-boxes/src/libvirt-machine-properties.vala"
	_data_->_async_result = g_task_new (G_OBJECT (self), NULL, _callback_, _user_data_);
#line 5 "/home/fborges/checkout/gnome-boxes/src/libvirt-machine-properties.vala"
	g_task_set_task_data (_data_->_async_result, _data_, boxes_libvirt_machine_properties_get_os_for_machine_data_free);
#line 5 "/home/fborges/checkout/gnome-boxes/src/libvirt-machine-properties.vala"
	_tmp0_ = _g_object_ref0 (self);
#line 5 "/home/fborges/checkout/gnome-boxes/src/libvirt-machine-properties.vala"
	_data_->self = _tmp0_;
#line 5 "/home/fborges/checkout/gnome-boxes/src/libvirt-machine-properties.vala"
	_tmp1_ = machine;
#line 5 "/home/fborges/checkout/gnome-boxes/src/libvirt-machine-properties.vala"
	_tmp2_ = _g_object_ref0 (_tmp1_);
#line 5 "/home/fborges/checkout/gnome-boxes/src/libvirt-machine-properties.vala"
	_g_object_unref0 (_data_->machine);
#line 5 "/home/fborges/checkout/gnome-boxes/src/libvirt-machine-properties.vala"
	_data_->machine = _tmp2_;
#line 5 "/home/fborges/checkout/gnome-boxes/src/libvirt-machine-properties.vala"
	boxes_libvirt_machine_properties_get_os_for_machine_co (_data_);
#line 3389 "libvirt-machine-properties.c"
}


static OsinfoOs* boxes_libvirt_machine_properties_get_os_for_machine_finish (BoxesLibvirtMachineProperties* self, GAsyncResult* _res_) {
	OsinfoOs* result;
	BoxesLibvirtMachinePropertiesGetOsForMachineData* _data_;
#line 5 "/home/fborges/checkout/gnome-boxes/src/libvirt-machine-properties.vala"
	_data_ = g_task_propagate_pointer (G_TASK (_res_), NULL);
#line 5 "/home/fborges/checkout/gnome-boxes/src/libvirt-machine-properties.vala"
	result = _data_->result;
#line 5 "/home/fborges/checkout/gnome-boxes/src/libvirt-machine-properties.vala"
	_data_->result = NULL;
#line 5 "/home/fborges/checkout/gnome-boxes/src/libvirt-machine-properties.vala"
	return result;
#line 3404 "libvirt-machine-properties.c"
}


static void boxes_libvirt_machine_properties_get_os_for_machine_ready (GObject* source_object, GAsyncResult* _res_, gpointer _user_data_) {
	BoxesLibvirtMachinePropertiesGetOsForMachineData* _data_;
#line 286 "/home/fborges/checkout/gnome-boxes/src/libvirt-machine-properties.vala"
	_data_ = _user_data_;
#line 286 "/home/fborges/checkout/gnome-boxes/src/libvirt-machine-properties.vala"
	_data_->_source_object_ = source_object;
#line 286 "/home/fborges/checkout/gnome-boxes/src/libvirt-machine-properties.vala"
	_data_->_res_ = _res_;
#line 286 "/home/fborges/checkout/gnome-boxes/src/libvirt-machine-properties.vala"
	boxes_libvirt_machine_properties_get_os_for_machine_co (_data_);
#line 3418 "libvirt-machine-properties.c"
}


static gboolean boxes_libvirt_machine_properties_get_os_for_machine_co (BoxesLibvirtMachinePropertiesGetOsForMachineData* _data_) {
#line 279 "/home/fborges/checkout/gnome-boxes/src/libvirt-machine-properties.vala"
	switch (_data_->_state_) {
#line 279 "/home/fborges/checkout/gnome-boxes/src/libvirt-machine-properties.vala"
		case 0:
#line 3427 "libvirt-machine-properties.c"
		goto _state_0;
#line 279 "/home/fborges/checkout/gnome-boxes/src/libvirt-machine-properties.vala"
		case 1:
#line 3431 "libvirt-machine-properties.c"
		goto _state_1;
		default:
#line 279 "/home/fborges/checkout/gnome-boxes/src/libvirt-machine-properties.vala"
		g_assert_not_reached ();
#line 3436 "libvirt-machine-properties.c"
	}
	_state_0:
#line 280 "/home/fborges/checkout/gnome-boxes/src/libvirt-machine-properties.vala"
	_data_->_tmp0_ = _data_->machine;
#line 280 "/home/fborges/checkout/gnome-boxes/src/libvirt-machine-properties.vala"
	_data_->_tmp1_ = boxes_libvirt_machine_get_domain_config (_data_->_tmp0_);
#line 280 "/home/fborges/checkout/gnome-boxes/src/libvirt-machine-properties.vala"
	_data_->_tmp2_ = _data_->_tmp1_;
#line 280 "/home/fborges/checkout/gnome-boxes/src/libvirt-machine-properties.vala"
	_data_->_tmp3_ = boxes_vm_configurator_get_os_id (_data_->_tmp2_);
#line 280 "/home/fborges/checkout/gnome-boxes/src/libvirt-machine-properties.vala"
	_data_->os_id = _data_->_tmp3_;
#line 281 "/home/fborges/checkout/gnome-boxes/src/libvirt-machine-properties.vala"
	_data_->_tmp4_ = _data_->os_id;
#line 281 "/home/fborges/checkout/gnome-boxes/src/libvirt-machine-properties.vala"
	if (_data_->_tmp4_ == NULL) {
#line 282 "/home/fborges/checkout/gnome-boxes/src/libvirt-machine-properties.vala"
		_data_->result = NULL;
#line 282 "/home/fborges/checkout/gnome-boxes/src/libvirt-machine-properties.vala"
		_g_free0 (_data_->os_id);
#line 282 "/home/fborges/checkout/gnome-boxes/src/libvirt-machine-properties.vala"
		g_task_return_pointer (_data_->_async_result, _data_, NULL);
#line 282 "/home/fborges/checkout/gnome-boxes/src/libvirt-machine-properties.vala"
		if (_data_->_state_ != 0) {
#line 282 "/home/fborges/checkout/gnome-boxes/src/libvirt-machine-properties.vala"
			while (g_task_get_completed (_data_->_async_result) != TRUE) {
#line 282 "/home/fborges/checkout/gnome-boxes/src/libvirt-machine-properties.vala"
				g_main_context_iteration (g_task_get_context (_data_->_async_result), TRUE);
#line 3465 "libvirt-machine-properties.c"
			}
		}
#line 282 "/home/fborges/checkout/gnome-boxes/src/libvirt-machine-properties.vala"
		g_object_unref (_data_->_async_result);
#line 282 "/home/fborges/checkout/gnome-boxes/src/libvirt-machine-properties.vala"
		return FALSE;
#line 3472 "libvirt-machine-properties.c"
	}
#line 284 "/home/fborges/checkout/gnome-boxes/src/libvirt-machine-properties.vala"
	_data_->_tmp5_ = boxes_media_manager_get_instance ();
#line 284 "/home/fborges/checkout/gnome-boxes/src/libvirt-machine-properties.vala"
	_data_->_tmp6_ = _data_->_tmp5_;
#line 284 "/home/fborges/checkout/gnome-boxes/src/libvirt-machine-properties.vala"
	_data_->_tmp7_ = boxes_media_manager_get_os_db (_data_->_tmp6_);
#line 284 "/home/fborges/checkout/gnome-boxes/src/libvirt-machine-properties.vala"
	_data_->_tmp8_ = _data_->_tmp7_;
#line 284 "/home/fborges/checkout/gnome-boxes/src/libvirt-machine-properties.vala"
	_data_->_tmp9_ = _g_object_ref0 (_data_->_tmp8_);
#line 284 "/home/fborges/checkout/gnome-boxes/src/libvirt-machine-properties.vala"
	_data_->_tmp10_ = _data_->_tmp9_;
#line 284 "/home/fborges/checkout/gnome-boxes/src/libvirt-machine-properties.vala"
	_g_object_unref0 (_data_->_tmp6_);
#line 284 "/home/fborges/checkout/gnome-boxes/src/libvirt-machine-properties.vala"
	_data_->os_db = _data_->_tmp10_;
#line 3490 "libvirt-machine-properties.c"
	{
#line 286 "/home/fborges/checkout/gnome-boxes/src/libvirt-machine-properties.vala"
		_data_->_tmp12_ = _data_->os_db;
#line 286 "/home/fborges/checkout/gnome-boxes/src/libvirt-machine-properties.vala"
		_data_->_tmp13_ = _data_->os_id;
#line 286 "/home/fborges/checkout/gnome-boxes/src/libvirt-machine-properties.vala"
		_data_->_state_ = 1;
#line 286 "/home/fborges/checkout/gnome-boxes/src/libvirt-machine-properties.vala"
		boxes_os_database_get_os_by_id (_data_->_tmp12_, _data_->_tmp13_, boxes_libvirt_machine_properties_get_os_for_machine_ready, _data_);
#line 286 "/home/fborges/checkout/gnome-boxes/src/libvirt-machine-properties.vala"
		return FALSE;
#line 3502 "libvirt-machine-properties.c"
		_state_1:
#line 286 "/home/fborges/checkout/gnome-boxes/src/libvirt-machine-properties.vala"
		_data_->_tmp14_ = boxes_os_database_get_os_by_id_finish (_data_->_tmp12_, _data_->_res_, &_data_->_inner_error_);
#line 286 "/home/fborges/checkout/gnome-boxes/src/libvirt-machine-properties.vala"
		_data_->_tmp11_ = _data_->_tmp14_;
#line 286 "/home/fborges/checkout/gnome-boxes/src/libvirt-machine-properties.vala"
		if (G_UNLIKELY (_data_->_inner_error_ != NULL)) {
#line 286 "/home/fborges/checkout/gnome-boxes/src/libvirt-machine-properties.vala"
			if (_data_->_inner_error_->domain == BOXES_OS_DATABASE_ERROR) {
#line 3512 "libvirt-machine-properties.c"
				goto __catch44_boxes_os_database_error;
			}
#line 286 "/home/fborges/checkout/gnome-boxes/src/libvirt-machine-properties.vala"
			_g_object_unref0 (_data_->os_db);
#line 286 "/home/fborges/checkout/gnome-boxes/src/libvirt-machine-properties.vala"
			_g_free0 (_data_->os_id);
#line 286 "/home/fborges/checkout/gnome-boxes/src/libvirt-machine-properties.vala"
			g_critical ("file %s: line %d: unexpected error: %s (%s, %d)", __FILE__, __LINE__, _data_->_inner_error_->message, g_quark_to_string (_data_->_inner_error_->domain), _data_->_inner_error_->code);
#line 286 "/home/fborges/checkout/gnome-boxes/src/libvirt-machine-properties.vala"
			g_clear_error (&_data_->_inner_error_);
#line 286 "/home/fborges/checkout/gnome-boxes/src/libvirt-machine-properties.vala"
			g_object_unref (_data_->_async_result);
#line 286 "/home/fborges/checkout/gnome-boxes/src/libvirt-machine-properties.vala"
			return FALSE;
#line 3527 "libvirt-machine-properties.c"
		}
#line 286 "/home/fborges/checkout/gnome-boxes/src/libvirt-machine-properties.vala"
		_data_->_tmp15_ = _data_->_tmp11_;
#line 286 "/home/fborges/checkout/gnome-boxes/src/libvirt-machine-properties.vala"
		_data_->_tmp11_ = NULL;
#line 286 "/home/fborges/checkout/gnome-boxes/src/libvirt-machine-properties.vala"
		_data_->result = _data_->_tmp15_;
#line 286 "/home/fborges/checkout/gnome-boxes/src/libvirt-machine-properties.vala"
		_g_object_unref0 (_data_->_tmp11_);
#line 286 "/home/fborges/checkout/gnome-boxes/src/libvirt-machine-properties.vala"
		_g_object_unref0 (_data_->os_db);
#line 286 "/home/fborges/checkout/gnome-boxes/src/libvirt-machine-properties.vala"
		_g_free0 (_data_->os_id);
#line 286 "/home/fborges/checkout/gnome-boxes/src/libvirt-machine-properties.vala"
		g_task_return_pointer (_data_->_async_result, _data_, NULL);
#line 286 "/home/fborges/checkout/gnome-boxes/src/libvirt-machine-properties.vala"
		if (_data_->_state_ != 0) {
#line 286 "/home/fborges/checkout/gnome-boxes/src/libvirt-machine-properties.vala"
			while (g_task_get_completed (_data_->_async_result) != TRUE) {
#line 286 "/home/fborges/checkout/gnome-boxes/src/libvirt-machine-properties.vala"
				g_main_context_iteration (g_task_get_context (_data_->_async_result), TRUE);
#line 3549 "libvirt-machine-properties.c"
			}
		}
#line 286 "/home/fborges/checkout/gnome-boxes/src/libvirt-machine-properties.vala"
		g_object_unref (_data_->_async_result);
#line 286 "/home/fborges/checkout/gnome-boxes/src/libvirt-machine-properties.vala"
		return FALSE;
#line 3556 "libvirt-machine-properties.c"
	}
	goto __finally44;
	__catch44_boxes_os_database_error:
	{
#line 285 "/home/fborges/checkout/gnome-boxes/src/libvirt-machine-properties.vala"
		_data_->_error_ = _data_->_inner_error_;
#line 285 "/home/fborges/checkout/gnome-boxes/src/libvirt-machine-properties.vala"
		_data_->_inner_error_ = NULL;
#line 288 "/home/fborges/checkout/gnome-boxes/src/libvirt-machine-properties.vala"
		_data_->_tmp16_ = _data_->os_id;
#line 288 "/home/fborges/checkout/gnome-boxes/src/libvirt-machine-properties.vala"
		_data_->_tmp17_ = _data_->_error_;
#line 288 "/home/fborges/checkout/gnome-boxes/src/libvirt-machine-properties.vala"
		_data_->_tmp18_ = _data_->_tmp17_->message;
#line 288 "/home/fborges/checkout/gnome-boxes/src/libvirt-machine-properties.vala"
		g_warning ("libvirt-machine-properties.vala:288: Failed to find OS with ID '%s': %" \
"s", _data_->_tmp16_, _data_->_tmp18_);
#line 289 "/home/fborges/checkout/gnome-boxes/src/libvirt-machine-properties.vala"
		_data_->result = NULL;
#line 289 "/home/fborges/checkout/gnome-boxes/src/libvirt-machine-properties.vala"
		_g_error_free0 (_data_->_error_);
#line 289 "/home/fborges/checkout/gnome-boxes/src/libvirt-machine-properties.vala"
		_g_object_unref0 (_data_->os_db);
#line 289 "/home/fborges/checkout/gnome-boxes/src/libvirt-machine-properties.vala"
		_g_free0 (_data_->os_id);
#line 289 "/home/fborges/checkout/gnome-boxes/src/libvirt-machine-properties.vala"
		g_task_return_pointer (_data_->_async_result, _data_, NULL);
#line 289 "/home/fborges/checkout/gnome-boxes/src/libvirt-machine-properties.vala"
		if (_data_->_state_ != 0) {
#line 289 "/home/fborges/checkout/gnome-boxes/src/libvirt-machine-properties.vala"
			while (g_task_get_completed (_data_->_async_result) != TRUE) {
#line 289 "/home/fborges/checkout/gnome-boxes/src/libvirt-machine-properties.vala"
				g_main_context_iteration (g_task_get_context (_data_->_async_result), TRUE);
#line 3589 "libvirt-machine-properties.c"
			}
		}
#line 289 "/home/fborges/checkout/gnome-boxes/src/libvirt-machine-properties.vala"
		g_object_unref (_data_->_async_result);
#line 289 "/home/fborges/checkout/gnome-boxes/src/libvirt-machine-properties.vala"
		return FALSE;
#line 3596 "libvirt-machine-properties.c"
	}
	__finally44:
#line 285 "/home/fborges/checkout/gnome-boxes/src/libvirt-machine-properties.vala"
	_g_object_unref0 (_data_->os_db);
#line 285 "/home/fborges/checkout/gnome-boxes/src/libvirt-machine-properties.vala"
	_g_free0 (_data_->os_id);
#line 285 "/home/fborges/checkout/gnome-boxes/src/libvirt-machine-properties.vala"
	g_critical ("file %s: line %d: uncaught error: %s (%s, %d)", __FILE__, __LINE__, _data_->_inner_error_->message, g_quark_to_string (_data_->_inner_error_->domain), _data_->_inner_error_->code);
#line 285 "/home/fborges/checkout/gnome-boxes/src/libvirt-machine-properties.vala"
	g_clear_error (&_data_->_inner_error_);
#line 285 "/home/fborges/checkout/gnome-boxes/src/libvirt-machine-properties.vala"
	g_object_unref (_data_->_async_result);
#line 285 "/home/fborges/checkout/gnome-boxes/src/libvirt-machine-properties.vala"
	return FALSE;
#line 3611 "libvirt-machine-properties.c"
}


static Block48Data* block48_data_ref (Block48Data* _data48_) {
#line 293 "/home/fborges/checkout/gnome-boxes/src/libvirt-machine-properties.vala"
	g_atomic_int_inc (&_data48_->_ref_count_);
#line 293 "/home/fborges/checkout/gnome-boxes/src/libvirt-machine-properties.vala"
	return _data48_;
#line 3620 "libvirt-machine-properties.c"
}


static void block48_data_unref (void * _userdata_) {
	Block48Data* _data48_;
	_data48_ = (Block48Data*) _userdata_;
#line 293 "/home/fborges/checkout/gnome-boxes/src/libvirt-machine-properties.vala"
	if (g_atomic_int_dec_and_test (&_data48_->_ref_count_)) {
#line 3629 "libvirt-machine-properties.c"
		BoxesLibvirtMachineProperties* self;
#line 293 "/home/fborges/checkout/gnome-boxes/src/libvirt-machine-properties.vala"
		self = _data48_->self;
#line 293 "/home/fborges/checkout/gnome-boxes/src/libvirt-machine-properties.vala"
		_g_object_unref0 (_data48_->prop);
#line 293 "/home/fborges/checkout/gnome-boxes/src/libvirt-machine-properties.vala"
		_g_object_unref0 (_data48_->net_graph);
#line 293 "/home/fborges/checkout/gnome-boxes/src/libvirt-machine-properties.vala"
		_g_object_unref0 (_data48_->io_graph);
#line 293 "/home/fborges/checkout/gnome-boxes/src/libvirt-machine-properties.vala"
		_g_object_unref0 (_data48_->cpu_graph);
#line 293 "/home/fborges/checkout/gnome-boxes/src/libvirt-machine-properties.vala"
		_g_object_unref0 (self);
#line 293 "/home/fborges/checkout/gnome-boxes/src/libvirt-machine-properties.vala"
		g_slice_free (Block48Data, _data48_);
#line 3645 "libvirt-machine-properties.c"
	}
}


static void __lambda116_ (Block48Data* _data48_) {
	BoxesLibvirtMachineProperties* self;
	BoxesLibvirtMachine* _tmp0_;
	gdouble* _tmp1_;
	gint _tmp1__length1;
	BoxesLibvirtMachine* _tmp2_;
	gdouble* _tmp3_;
	gint _tmp3__length1;
	BoxesLibvirtMachine* _tmp4_;
	gdouble* _tmp5_;
	gint _tmp5__length1;
#line 321 "/home/fborges/checkout/gnome-boxes/src/libvirt-machine-properties.vala"
	self = _data48_->self;
#line 322 "/home/fborges/checkout/gnome-boxes/src/libvirt-machine-properties.vala"
	_tmp0_ = self->priv->machine;
#line 322 "/home/fborges/checkout/gnome-boxes/src/libvirt-machine-properties.vala"
	_tmp1_ = _tmp0_->cpu_stats;
#line 322 "/home/fborges/checkout/gnome-boxes/src/libvirt-machine-properties.vala"
	_tmp1__length1 = _tmp0_->cpu_stats_length1;
#line 322 "/home/fborges/checkout/gnome-boxes/src/libvirt-machine-properties.vala"
	boxes_resource_graph_set_points (_data48_->cpu_graph, _tmp1_, _tmp1__length1);
#line 323 "/home/fborges/checkout/gnome-boxes/src/libvirt-machine-properties.vala"
	_tmp2_ = self->priv->machine;
#line 323 "/home/fborges/checkout/gnome-boxes/src/libvirt-machine-properties.vala"
	_tmp3_ = _tmp2_->io_stats;
#line 323 "/home/fborges/checkout/gnome-boxes/src/libvirt-machine-properties.vala"
	_tmp3__length1 = _tmp2_->io_stats_length1;
#line 323 "/home/fborges/checkout/gnome-boxes/src/libvirt-machine-properties.vala"
	boxes_resource_graph_set_points (_data48_->io_graph, _tmp3_, _tmp3__length1);
#line 324 "/home/fborges/checkout/gnome-boxes/src/libvirt-machine-properties.vala"
	_tmp4_ = self->priv->machine;
#line 324 "/home/fborges/checkout/gnome-boxes/src/libvirt-machine-properties.vala"
	_tmp5_ = _tmp4_->net_stats;
#line 324 "/home/fborges/checkout/gnome-boxes/src/libvirt-machine-properties.vala"
	_tmp5__length1 = _tmp4_->net_stats_length1;
#line 324 "/home/fborges/checkout/gnome-boxes/src/libvirt-machine-properties.vala"
	boxes_resource_graph_set_points (_data48_->net_graph, _tmp5_, _tmp5__length1);
#line 3687 "libvirt-machine-properties.c"
}


static void ___lambda116__boxes_libvirt_machine_stats_updated (BoxesLibvirtMachine* _sender, gpointer self) {
#line 321 "/home/fborges/checkout/gnome-boxes/src/libvirt-machine-properties.vala"
	__lambda116_ (self);
#line 3694 "libvirt-machine-properties.c"
}


static void __lambda117_ (Block48Data* _data48_) {
	BoxesLibvirtMachineProperties* self;
	BoxesLibvirtMachine* _tmp0_;
	gulong _tmp1_;
#line 329 "/home/fborges/checkout/gnome-boxes/src/libvirt-machine-properties.vala"
	self = _data48_->self;
#line 330 "/home/fborges/checkout/gnome-boxes/src/libvirt-machine-properties.vala"
	_tmp0_ = self->priv->machine;
#line 330 "/home/fborges/checkout/gnome-boxes/src/libvirt-machine-properties.vala"
	g_signal_handler_disconnect ((GObject*) _tmp0_, _data48_->stats_id);
#line 331 "/home/fborges/checkout/gnome-boxes/src/libvirt-machine-properties.vala"
	_tmp1_ = _data48_->flushed_id;
#line 331 "/home/fborges/checkout/gnome-boxes/src/libvirt-machine-properties.vala"
	g_signal_handler_disconnect ((GObject*) _data48_->prop, _tmp1_);
#line 3712 "libvirt-machine-properties.c"
}


static void ___lambda117__boxes_property_flushed (BoxesProperty* _sender, gpointer self) {
#line 329 "/home/fborges/checkout/gnome-boxes/src/libvirt-machine-properties.vala"
	__lambda117_ (self);
#line 3719 "libvirt-machine-properties.c"
}


static void boxes_libvirt_machine_properties_add_resource_usage_graphs (BoxesLibvirtMachineProperties* self, GList* * list) {
	Block48Data* _data48_;
	GtkGrid* grid = NULL;
	GtkGrid* _tmp0_;
	BoxesResourceGraph* _tmp1_;
	GtkLabel* label = NULL;
	GtkLabel* _tmp2_;
	GtkLabel* _tmp3_;
	BoxesResourceGraph* _tmp4_;
	GtkLabel* _tmp5_;
	GtkLabel* _tmp6_;
	BoxesResourceGraph* _tmp7_;
	GtkLabel* _tmp8_;
	GtkLabel* _tmp9_;
	BoxesLibvirtMachine* _tmp10_;
	gulong _tmp11_;
	BoxesProperty* _tmp12_;
	gulong _tmp13_;
#line 293 "/home/fborges/checkout/gnome-boxes/src/libvirt-machine-properties.vala"
	g_return_if_fail (self != NULL);
#line 293 "/home/fborges/checkout/gnome-boxes/src/libvirt-machine-properties.vala"
	_data48_ = g_slice_new0 (Block48Data);
#line 293 "/home/fborges/checkout/gnome-boxes/src/libvirt-machine-properties.vala"
	_data48_->_ref_count_ = 1;
#line 293 "/home/fborges/checkout/gnome-boxes/src/libvirt-machine-properties.vala"
	_data48_->self = g_object_ref (self);
#line 294 "/home/fborges/checkout/gnome-boxes/src/libvirt-machine-properties.vala"
	_tmp0_ = (GtkGrid*) gtk_grid_new ();
#line 294 "/home/fborges/checkout/gnome-boxes/src/libvirt-machine-properties.vala"
	g_object_ref_sink (_tmp0_);
#line 294 "/home/fborges/checkout/gnome-boxes/src/libvirt-machine-properties.vala"
	grid = _tmp0_;
#line 295 "/home/fborges/checkout/gnome-boxes/src/libvirt-machine-properties.vala"
	gtk_widget_set_margin_top ((GtkWidget*) grid, 20);
#line 296 "/home/fborges/checkout/gnome-boxes/src/libvirt-machine-properties.vala"
	gtk_widget_set_margin_bottom ((GtkWidget*) grid, 20);
#line 297 "/home/fborges/checkout/gnome-boxes/src/libvirt-machine-properties.vala"
	gtk_grid_set_row_spacing (grid, 5);
#line 298 "/home/fborges/checkout/gnome-boxes/src/libvirt-machine-properties.vala"
	gtk_grid_set_column_spacing (grid, 10);
#line 299 "/home/fborges/checkout/gnome-boxes/src/libvirt-machine-properties.vala"
	gtk_grid_set_column_homogeneous (grid, TRUE);
#line 300 "/home/fborges/checkout/gnome-boxes/src/libvirt-machine-properties.vala"
	gtk_widget_set_vexpand ((GtkWidget*) grid, FALSE);
#line 303 "/home/fborges/checkout/gnome-boxes/src/libvirt-machine-properties.vala"
	_tmp1_ = boxes_resource_graph_new ((gdouble) 100);
#line 303 "/home/fborges/checkout/gnome-boxes/src/libvirt-machine-properties.vala"
	g_object_ref_sink (_tmp1_);
#line 303 "/home/fborges/checkout/gnome-boxes/src/libvirt-machine-properties.vala"
	_data48_->cpu_graph = _tmp1_;
#line 304 "/home/fborges/checkout/gnome-boxes/src/libvirt-machine-properties.vala"
	boxes_resource_graph_set_npoints (_data48_->cpu_graph, 20);
#line 305 "/home/fborges/checkout/gnome-boxes/src/libvirt-machine-properties.vala"
	gtk_grid_attach (grid, (GtkWidget*) _data48_->cpu_graph, 0, 0, 1, 1);
#line 306 "/home/fborges/checkout/gnome-boxes/src/libvirt-machine-properties.vala"
	_tmp2_ = (GtkLabel*) gtk_label_new (_ ("CPU"));
#line 306 "/home/fborges/checkout/gnome-boxes/src/libvirt-machine-properties.vala"
	g_object_ref_sink (_tmp2_);
#line 306 "/home/fborges/checkout/gnome-boxes/src/libvirt-machine-properties.vala"
	label = _tmp2_;
#line 307 "/home/fborges/checkout/gnome-boxes/src/libvirt-machine-properties.vala"
	_tmp3_ = label;
#line 307 "/home/fborges/checkout/gnome-boxes/src/libvirt-machine-properties.vala"
	gtk_grid_attach (grid, (GtkWidget*) _tmp3_, 0, 1, 1, 1);
#line 310 "/home/fborges/checkout/gnome-boxes/src/libvirt-machine-properties.vala"
	_tmp4_ = boxes_resource_graph_new ((gdouble) 104857600);
#line 310 "/home/fborges/checkout/gnome-boxes/src/libvirt-machine-properties.vala"
	g_object_ref_sink (_tmp4_);
#line 310 "/home/fborges/checkout/gnome-boxes/src/libvirt-machine-properties.vala"
	_data48_->io_graph = _tmp4_;
#line 311 "/home/fborges/checkout/gnome-boxes/src/libvirt-machine-properties.vala"
	gtk_grid_attach (grid, (GtkWidget*) _data48_->io_graph, 1, 0, 1, 1);
#line 312 "/home/fborges/checkout/gnome-boxes/src/libvirt-machine-properties.vala"
	_tmp5_ = (GtkLabel*) gtk_label_new (_ ("I/O"));
#line 312 "/home/fborges/checkout/gnome-boxes/src/libvirt-machine-properties.vala"
	g_object_ref_sink (_tmp5_);
#line 312 "/home/fborges/checkout/gnome-boxes/src/libvirt-machine-properties.vala"
	_g_object_unref0 (label);
#line 312 "/home/fborges/checkout/gnome-boxes/src/libvirt-machine-properties.vala"
	label = _tmp5_;
#line 313 "/home/fborges/checkout/gnome-boxes/src/libvirt-machine-properties.vala"
	_tmp6_ = label;
#line 313 "/home/fborges/checkout/gnome-boxes/src/libvirt-machine-properties.vala"
	gtk_grid_attach (grid, (GtkWidget*) _tmp6_, 1, 1, 1, 1);
#line 316 "/home/fborges/checkout/gnome-boxes/src/libvirt-machine-properties.vala"
	_tmp7_ = boxes_resource_graph_new ((gdouble) 1048576);
#line 316 "/home/fborges/checkout/gnome-boxes/src/libvirt-machine-properties.vala"
	g_object_ref_sink (_tmp7_);
#line 316 "/home/fborges/checkout/gnome-boxes/src/libvirt-machine-properties.vala"
	_data48_->net_graph = _tmp7_;
#line 317 "/home/fborges/checkout/gnome-boxes/src/libvirt-machine-properties.vala"
	gtk_grid_attach (grid, (GtkWidget*) _data48_->net_graph, 2, 0, 1, 1);
#line 318 "/home/fborges/checkout/gnome-boxes/src/libvirt-machine-properties.vala"
	_tmp8_ = (GtkLabel*) gtk_label_new (_ ("Network"));
#line 318 "/home/fborges/checkout/gnome-boxes/src/libvirt-machine-properties.vala"
	g_object_ref_sink (_tmp8_);
#line 318 "/home/fborges/checkout/gnome-boxes/src/libvirt-machine-properties.vala"
	_g_object_unref0 (label);
#line 318 "/home/fborges/checkout/gnome-boxes/src/libvirt-machine-properties.vala"
	label = _tmp8_;
#line 319 "/home/fborges/checkout/gnome-boxes/src/libvirt-machine-properties.vala"
	_tmp9_ = label;
#line 319 "/home/fborges/checkout/gnome-boxes/src/libvirt-machine-properties.vala"
	gtk_grid_attach (grid, (GtkWidget*) _tmp9_, 2, 1, 1, 1);
#line 321 "/home/fborges/checkout/gnome-boxes/src/libvirt-machine-properties.vala"
	_tmp10_ = self->priv->machine;
#line 321 "/home/fborges/checkout/gnome-boxes/src/libvirt-machine-properties.vala"
	_tmp11_ = g_signal_connect_data (_tmp10_, "stats-updated", (GCallback) ___lambda116__boxes_libvirt_machine_stats_updated, block48_data_ref (_data48_), (GClosureNotify) block48_data_unref, 0);
#line 321 "/home/fborges/checkout/gnome-boxes/src/libvirt-machine-properties.vala"
	_data48_->stats_id = _tmp11_;
#line 327 "/home/fborges/checkout/gnome-boxes/src/libvirt-machine-properties.vala"
	_tmp12_ = boxes_iproperties_provider_add_property ((BoxesIPropertiesProvider*) self, list, NULL, (GtkWidget*) grid, NULL);
#line 327 "/home/fborges/checkout/gnome-boxes/src/libvirt-machine-properties.vala"
	_data48_->prop = _tmp12_;
#line 328 "/home/fborges/checkout/gnome-boxes/src/libvirt-machine-properties.vala"
	_data48_->flushed_id = (gulong) 0;
#line 329 "/home/fborges/checkout/gnome-boxes/src/libvirt-machine-properties.vala"
	_tmp13_ = g_signal_connect_data (_data48_->prop, "flushed", (GCallback) ___lambda117__boxes_property_flushed, block48_data_ref (_data48_), (GClosureNotify) block48_data_unref, 0);
#line 329 "/home/fborges/checkout/gnome-boxes/src/libvirt-machine-properties.vala"
	_data48_->flushed_id = _tmp13_;
#line 293 "/home/fborges/checkout/gnome-boxes/src/libvirt-machine-properties.vala"
	_g_object_unref0 (label);
#line 293 "/home/fborges/checkout/gnome-boxes/src/libvirt-machine-properties.vala"
	_g_object_unref0 (grid);
#line 293 "/home/fborges/checkout/gnome-boxes/src/libvirt-machine-properties.vala"
	block48_data_unref (_data48_);
#line 293 "/home/fborges/checkout/gnome-boxes/src/libvirt-machine-properties.vala"
	_data48_ = NULL;
#line 3851 "libvirt-machine-properties.c"
}


static Block49Data* block49_data_ref (Block49Data* _data49_) {
#line 335 "/home/fborges/checkout/gnome-boxes/src/libvirt-machine-properties.vala"
	g_atomic_int_inc (&_data49_->_ref_count_);
#line 335 "/home/fborges/checkout/gnome-boxes/src/libvirt-machine-properties.vala"
	return _data49_;
#line 3860 "libvirt-machine-properties.c"
}


static void block49_data_unref (void * _userdata_) {
	Block49Data* _data49_;
	_data49_ = (Block49Data*) _userdata_;
#line 335 "/home/fborges/checkout/gnome-boxes/src/libvirt-machine-properties.vala"
	if (g_atomic_int_dec_and_test (&_data49_->_ref_count_)) {
#line 3869 "libvirt-machine-properties.c"
		BoxesLibvirtMachineProperties* self;
#line 335 "/home/fborges/checkout/gnome-boxes/src/libvirt-machine-properties.vala"
		self = _data49_->self;
#line 335 "/home/fborges/checkout/gnome-boxes/src/libvirt-machine-properties.vala"
		_g_object_unref0 (_data49_->prop);
#line 335 "/home/fborges/checkout/gnome-boxes/src/libvirt-machine-properties.vala"
		_g_object_unref0 (_data49_->shutdown_button);
#line 335 "/home/fborges/checkout/gnome-boxes/src/libvirt-machine-properties.vala"
		_g_object_unref0 (_data49_->restart_button);
#line 335 "/home/fborges/checkout/gnome-boxes/src/libvirt-machine-properties.vala"
		_g_object_unref0 (self);
#line 335 "/home/fborges/checkout/gnome-boxes/src/libvirt-machine-properties.vala"
		g_slice_free (Block49Data, _data49_);
#line 3883 "libvirt-machine-properties.c"
	}
}


static void __lambda118_ (BoxesLibvirtMachineProperties* self) {
	BoxesLibvirtMachine* _tmp0_;
	BoxesLibvirtMachine* _tmp1_;
	BoxesAppWindow* _tmp2_;
	BoxesAppWindow* _tmp3_;
	BoxesPropertiesWindow* _tmp4_;
#line 349 "/home/fborges/checkout/gnome-boxes/src/libvirt-machine-properties.vala"
	_tmp0_ = self->priv->machine;
#line 349 "/home/fborges/checkout/gnome-boxes/src/libvirt-machine-properties.vala"
	boxes_machine_restart ((BoxesMachine*) _tmp0_);
#line 350 "/home/fborges/checkout/gnome-boxes/src/libvirt-machine-properties.vala"
	_tmp1_ = self->priv->machine;
#line 350 "/home/fborges/checkout/gnome-boxes/src/libvirt-machine-properties.vala"
	_tmp2_ = boxes_machine_get_window ((BoxesMachine*) _tmp1_);
#line 350 "/home/fborges/checkout/gnome-boxes/src/libvirt-machine-properties.vala"
	_tmp3_ = _tmp2_;
#line 350 "/home/fborges/checkout/gnome-boxes/src/libvirt-machine-properties.vala"
	_tmp4_ = _tmp3_->props_window;
#line 350 "/home/fborges/checkout/gnome-boxes/src/libvirt-machine-properties.vala"
	boxes_properties_window_revert_state (_tmp4_);
#line 3908 "libvirt-machine-properties.c"
}


static void ___lambda118__gtk_button_clicked (GtkButton* _sender, gpointer self) {
#line 348 "/home/fborges/checkout/gnome-boxes/src/libvirt-machine-properties.vala"
	__lambda118_ ((BoxesLibvirtMachineProperties*) self);
#line 3915 "libvirt-machine-properties.c"
}


static void __lambda130_ (BoxesLibvirtMachineProperties* self) {
	BoxesLibvirtMachine* _tmp0_;
	BoxesLibvirtMachine* _tmp1_;
	BoxesAppWindow* _tmp2_;
	BoxesAppWindow* _tmp3_;
	BoxesPropertiesWindow* _tmp4_;
#line 358 "/home/fborges/checkout/gnome-boxes/src/libvirt-machine-properties.vala"
	_tmp0_ = self->priv->machine;
#line 358 "/home/fborges/checkout/gnome-boxes/src/libvirt-machine-properties.vala"
	boxes_libvirt_machine_force_shutdown (_tmp0_);
#line 359 "/home/fborges/checkout/gnome-boxes/src/libvirt-machine-properties.vala"
	_tmp1_ = self->priv->machine;
#line 359 "/home/fborges/checkout/gnome-boxes/src/libvirt-machine-properties.vala"
	_tmp2_ = boxes_machine_get_window ((BoxesMachine*) _tmp1_);
#line 359 "/home/fborges/checkout/gnome-boxes/src/libvirt-machine-properties.vala"
	_tmp3_ = _tmp2_;
#line 359 "/home/fborges/checkout/gnome-boxes/src/libvirt-machine-properties.vala"
	_tmp4_ = _tmp3_->props_window;
#line 359 "/home/fborges/checkout/gnome-boxes/src/libvirt-machine-properties.vala"
	boxes_properties_window_revert_state (_tmp4_);
#line 3939 "libvirt-machine-properties.c"
}


static void ___lambda130__gtk_button_clicked (GtkButton* _sender, gpointer self) {
#line 357 "/home/fborges/checkout/gnome-boxes/src/libvirt-machine-properties.vala"
	__lambda130_ ((BoxesLibvirtMachineProperties*) self);
#line 3946 "libvirt-machine-properties.c"
}


static void __lambda131_ (Block49Data* _data49_) {
	BoxesLibvirtMachineProperties* self;
	BoxesLibvirtMachine* _tmp0_;
	gboolean _tmp1_;
	gboolean _tmp2_;
	BoxesLibvirtMachine* _tmp3_;
	gboolean _tmp4_;
	gboolean _tmp5_;
#line 364 "/home/fborges/checkout/gnome-boxes/src/libvirt-machine-properties.vala"
	self = _data49_->self;
#line 365 "/home/fborges/checkout/gnome-boxes/src/libvirt-machine-properties.vala"
	_tmp0_ = self->priv->machine;
#line 365 "/home/fborges/checkout/gnome-boxes/src/libvirt-machine-properties.vala"
	_tmp1_ = boxes_machine_get_is_running ((BoxesMachine*) _tmp0_);
#line 365 "/home/fborges/checkout/gnome-boxes/src/libvirt-machine-properties.vala"
	_tmp2_ = _tmp1_;
#line 365 "/home/fborges/checkout/gnome-boxes/src/libvirt-machine-properties.vala"
	gtk_widget_set_sensitive ((GtkWidget*) _data49_->restart_button, _tmp2_);
#line 366 "/home/fborges/checkout/gnome-boxes/src/libvirt-machine-properties.vala"
	_tmp3_ = self->priv->machine;
#line 366 "/home/fborges/checkout/gnome-boxes/src/libvirt-machine-properties.vala"
	_tmp4_ = boxes_machine_get_is_running ((BoxesMachine*) _tmp3_);
#line 366 "/home/fborges/checkout/gnome-boxes/src/libvirt-machine-properties.vala"
	_tmp5_ = _tmp4_;
#line 366 "/home/fborges/checkout/gnome-boxes/src/libvirt-machine-properties.vala"
	gtk_widget_set_sensitive ((GtkWidget*) _data49_->shutdown_button, _tmp5_);
#line 3976 "libvirt-machine-properties.c"
}


static void ___lambda131__g_object_notify (GObject* _sender, GParamSpec* pspec, gpointer self) {
#line 364 "/home/fborges/checkout/gnome-boxes/src/libvirt-machine-properties.vala"
	__lambda131_ (self);
#line 3983 "libvirt-machine-properties.c"
}


static void __lambda132_ (BoxesLibvirtMachineProperties* self) {
	gchar* log = NULL;
	gchar* _tmp0_;
	BoxesLibvirtMachine* _tmp1_;
	BoxesAppWindow* _tmp2_;
	BoxesAppWindow* _tmp3_;
	BoxesPropertiesWindow* _tmp4_;
#line 373 "/home/fborges/checkout/gnome-boxes/src/libvirt-machine-properties.vala"
	_tmp0_ = boxes_libvirt_machine_properties_collect_logs (self);
#line 373 "/home/fborges/checkout/gnome-boxes/src/libvirt-machine-properties.vala"
	log = _tmp0_;
#line 374 "/home/fborges/checkout/gnome-boxes/src/libvirt-machine-properties.vala"
	_tmp1_ = self->priv->machine;
#line 374 "/home/fborges/checkout/gnome-boxes/src/libvirt-machine-properties.vala"
	_tmp2_ = boxes_machine_get_window ((BoxesMachine*) _tmp1_);
#line 374 "/home/fborges/checkout/gnome-boxes/src/libvirt-machine-properties.vala"
	_tmp3_ = _tmp2_;
#line 374 "/home/fborges/checkout/gnome-boxes/src/libvirt-machine-properties.vala"
	_tmp4_ = _tmp3_->props_window;
#line 374 "/home/fborges/checkout/gnome-boxes/src/libvirt-machine-properties.vala"
	boxes_properties_window_show_troubleshoot_log (_tmp4_, log);
#line 372 "/home/fborges/checkout/gnome-boxes/src/libvirt-machine-properties.vala"
	_g_free0 (log);
#line 4010 "libvirt-machine-properties.c"
}


static void ___lambda132__gtk_button_clicked (GtkButton* _sender, gpointer self) {
#line 372 "/home/fborges/checkout/gnome-boxes/src/libvirt-machine-properties.vala"
	__lambda132_ ((BoxesLibvirtMachineProperties*) self);
#line 4017 "libvirt-machine-properties.c"
}


static void __lambda133_ (Block49Data* _data49_) {
	BoxesLibvirtMachineProperties* self;
	BoxesLibvirtMachine* _tmp0_;
	gulong _tmp1_;
#line 379 "/home/fborges/checkout/gnome-boxes/src/libvirt-machine-properties.vala"
	self = _data49_->self;
#line 380 "/home/fborges/checkout/gnome-boxes/src/libvirt-machine-properties.vala"
	_tmp0_ = self->priv->machine;
#line 380 "/home/fborges/checkout/gnome-boxes/src/libvirt-machine-properties.vala"
	g_signal_handler_disconnect ((GObject*) _tmp0_, _data49_->state_notify_id);
#line 381 "/home/fborges/checkout/gnome-boxes/src/libvirt-machine-properties.vala"
	_tmp1_ = _data49_->flushed_id;
#line 381 "/home/fborges/checkout/gnome-boxes/src/libvirt-machine-properties.vala"
	g_signal_handler_disconnect ((GObject*) _data49_->prop, _tmp1_);
#line 4035 "libvirt-machine-properties.c"
}


static void ___lambda133__boxes_property_flushed (BoxesProperty* _sender, gpointer self) {
#line 379 "/home/fborges/checkout/gnome-boxes/src/libvirt-machine-properties.vala"
	__lambda133_ (self);
#line 4042 "libvirt-machine-properties.c"
}


static void boxes_libvirt_machine_properties_add_system_props_buttons (BoxesLibvirtMachineProperties* self, GList* * list) {
	Block49Data* _data49_;
	GtkGrid* grid = NULL;
	GtkGrid* _tmp0_;
	GtkGrid* inner_grid = NULL;
	GtkGrid* _tmp1_;
	GtkButton* _tmp2_;
	BoxesLibvirtMachine* _tmp3_;
	gboolean _tmp4_;
	gboolean _tmp5_;
	GtkButton* _tmp6_;
	GtkStyleContext* _tmp7_;
	BoxesLibvirtMachine* _tmp8_;
	gboolean _tmp9_;
	gboolean _tmp10_;
	BoxesLibvirtMachine* _tmp11_;
	gulong _tmp12_;
	GtkButton* log_button = NULL;
	GtkButton* _tmp13_;
	BoxesProperty* _tmp14_;
	gulong _tmp15_;
#line 335 "/home/fborges/checkout/gnome-boxes/src/libvirt-machine-properties.vala"
	g_return_if_fail (self != NULL);
#line 335 "/home/fborges/checkout/gnome-boxes/src/libvirt-machine-properties.vala"
	_data49_ = g_slice_new0 (Block49Data);
#line 335 "/home/fborges/checkout/gnome-boxes/src/libvirt-machine-properties.vala"
	_data49_->_ref_count_ = 1;
#line 335 "/home/fborges/checkout/gnome-boxes/src/libvirt-machine-properties.vala"
	_data49_->self = g_object_ref (self);
#line 336 "/home/fborges/checkout/gnome-boxes/src/libvirt-machine-properties.vala"
	_tmp0_ = (GtkGrid*) gtk_grid_new ();
#line 336 "/home/fborges/checkout/gnome-boxes/src/libvirt-machine-properties.vala"
	g_object_ref_sink (_tmp0_);
#line 336 "/home/fborges/checkout/gnome-boxes/src/libvirt-machine-properties.vala"
	grid = _tmp0_;
#line 337 "/home/fborges/checkout/gnome-boxes/src/libvirt-machine-properties.vala"
	gtk_widget_set_margin_bottom ((GtkWidget*) grid, 20);
#line 338 "/home/fborges/checkout/gnome-boxes/src/libvirt-machine-properties.vala"
	gtk_grid_set_column_spacing (grid, 5);
#line 339 "/home/fborges/checkout/gnome-boxes/src/libvirt-machine-properties.vala"
	gtk_widget_set_hexpand ((GtkWidget*) grid, TRUE);
#line 341 "/home/fborges/checkout/gnome-boxes/src/libvirt-machine-properties.vala"
	_tmp1_ = (GtkGrid*) gtk_grid_new ();
#line 341 "/home/fborges/checkout/gnome-boxes/src/libvirt-machine-properties.vala"
	g_object_ref_sink (_tmp1_);
#line 341 "/home/fborges/checkout/gnome-boxes/src/libvirt-machine-properties.vala"
	inner_grid = _tmp1_;
#line 342 "/home/fborges/checkout/gnome-boxes/src/libvirt-machine-properties.vala"
	gtk_grid_set_column_spacing (inner_grid, 5);
#line 343 "/home/fborges/checkout/gnome-boxes/src/libvirt-machine-properties.vala"
	gtk_widget_set_halign ((GtkWidget*) inner_grid, GTK_ALIGN_START);
#line 344 "/home/fborges/checkout/gnome-boxes/src/libvirt-machine-properties.vala"
	gtk_widget_set_hexpand ((GtkWidget*) inner_grid, TRUE);
#line 345 "/home/fborges/checkout/gnome-boxes/src/libvirt-machine-properties.vala"
	gtk_grid_attach (grid, (GtkWidget*) inner_grid, 0, 0, 1, 1);
#line 347 "/home/fborges/checkout/gnome-boxes/src/libvirt-machine-properties.vala"
	_tmp2_ = (GtkButton*) gtk_button_new_with_mnemonic (_ ("_Restart"));
#line 347 "/home/fborges/checkout/gnome-boxes/src/libvirt-machine-properties.vala"
	g_object_ref_sink (_tmp2_);
#line 347 "/home/fborges/checkout/gnome-boxes/src/libvirt-machine-properties.vala"
	_data49_->restart_button = _tmp2_;
#line 348 "/home/fborges/checkout/gnome-boxes/src/libvirt-machine-properties.vala"
	g_signal_connect_object (_data49_->restart_button, "clicked", (GCallback) ___lambda118__gtk_button_clicked, self, 0);
#line 352 "/home/fborges/checkout/gnome-boxes/src/libvirt-machine-properties.vala"
	_tmp3_ = self->priv->machine;
#line 352 "/home/fborges/checkout/gnome-boxes/src/libvirt-machine-properties.vala"
	_tmp4_ = boxes_machine_get_is_running ((BoxesMachine*) _tmp3_);
#line 352 "/home/fborges/checkout/gnome-boxes/src/libvirt-machine-properties.vala"
	_tmp5_ = _tmp4_;
#line 352 "/home/fborges/checkout/gnome-boxes/src/libvirt-machine-properties.vala"
	gtk_widget_set_sensitive ((GtkWidget*) _data49_->restart_button, _tmp5_);
#line 353 "/home/fborges/checkout/gnome-boxes/src/libvirt-machine-properties.vala"
	gtk_grid_attach (inner_grid, (GtkWidget*) _data49_->restart_button, 1, 0, 1, 1);
#line 355 "/home/fborges/checkout/gnome-boxes/src/libvirt-machine-properties.vala"
	_tmp6_ = (GtkButton*) gtk_button_new_with_mnemonic (_ ("_Force Shutdown"));
#line 355 "/home/fborges/checkout/gnome-boxes/src/libvirt-machine-properties.vala"
	g_object_ref_sink (_tmp6_);
#line 355 "/home/fborges/checkout/gnome-boxes/src/libvirt-machine-properties.vala"
	_data49_->shutdown_button = _tmp6_;
#line 356 "/home/fborges/checkout/gnome-boxes/src/libvirt-machine-properties.vala"
	_tmp7_ = gtk_widget_get_style_context ((GtkWidget*) _data49_->shutdown_button);
#line 356 "/home/fborges/checkout/gnome-boxes/src/libvirt-machine-properties.vala"
	gtk_style_context_add_class (_tmp7_, GTK_STYLE_CLASS_DESTRUCTIVE_ACTION);
#line 357 "/home/fborges/checkout/gnome-boxes/src/libvirt-machine-properties.vala"
	g_signal_connect_object (_data49_->shutdown_button, "clicked", (GCallback) ___lambda130__gtk_button_clicked, self, 0);
#line 361 "/home/fborges/checkout/gnome-boxes/src/libvirt-machine-properties.vala"
	_tmp8_ = self->priv->machine;
#line 361 "/home/fborges/checkout/gnome-boxes/src/libvirt-machine-properties.vala"
	_tmp9_ = boxes_machine_get_is_running ((BoxesMachine*) _tmp8_);
#line 361 "/home/fborges/checkout/gnome-boxes/src/libvirt-machine-properties.vala"
	_tmp10_ = _tmp9_;
#line 361 "/home/fborges/checkout/gnome-boxes/src/libvirt-machine-properties.vala"
	gtk_widget_set_sensitive ((GtkWidget*) _data49_->shutdown_button, _tmp10_);
#line 362 "/home/fborges/checkout/gnome-boxes/src/libvirt-machine-properties.vala"
	gtk_grid_attach (inner_grid, (GtkWidget*) _data49_->shutdown_button, 2, 0, 1, 1);
#line 364 "/home/fborges/checkout/gnome-boxes/src/libvirt-machine-properties.vala"
	_tmp11_ = self->priv->machine;
#line 364 "/home/fborges/checkout/gnome-boxes/src/libvirt-machine-properties.vala"
	_tmp12_ = g_signal_connect_data ((GObject*) _tmp11_, "notify::state", (GCallback) ___lambda131__g_object_notify, block49_data_ref (_data49_), (GClosureNotify) block49_data_unref, 0);
#line 364 "/home/fborges/checkout/gnome-boxes/src/libvirt-machine-properties.vala"
	_data49_->state_notify_id = _tmp12_;
#line 369 "/home/fborges/checkout/gnome-boxes/src/libvirt-machine-properties.vala"
	_tmp13_ = (GtkButton*) gtk_button_new_with_mnemonic (_ ("_Troubleshooting Log"));
#line 369 "/home/fborges/checkout/gnome-boxes/src/libvirt-machine-properties.vala"
	g_object_ref_sink (_tmp13_);
#line 369 "/home/fborges/checkout/gnome-boxes/src/libvirt-machine-properties.vala"
	log_button = _tmp13_;
#line 370 "/home/fborges/checkout/gnome-boxes/src/libvirt-machine-properties.vala"
	gtk_widget_set_halign ((GtkWidget*) log_button, GTK_ALIGN_END);
#line 371 "/home/fborges/checkout/gnome-boxes/src/libvirt-machine-properties.vala"
	gtk_grid_attach (grid, (GtkWidget*) log_button, 1, 0, 1, 1);
#line 372 "/home/fborges/checkout/gnome-boxes/src/libvirt-machine-properties.vala"
	g_signal_connect_object (log_button, "clicked", (GCallback) ___lambda132__gtk_button_clicked, self, 0);
#line 377 "/home/fborges/checkout/gnome-boxes/src/libvirt-machine-properties.vala"
	_tmp14_ = boxes_iproperties_provider_add_property ((BoxesIPropertiesProvider*) self, list, NULL, (GtkWidget*) grid, NULL);
#line 377 "/home/fborges/checkout/gnome-boxes/src/libvirt-machine-properties.vala"
	_data49_->prop = _tmp14_;
#line 378 "/home/fborges/checkout/gnome-boxes/src/libvirt-machine-properties.vala"
	_data49_->flushed_id = (gulong) 0;
#line 379 "/home/fborges/checkout/gnome-boxes/src/libvirt-machine-properties.vala"
	_tmp15_ = g_signal_connect_data (_data49_->prop, "flushed", (GCallback) ___lambda133__boxes_property_flushed, block49_data_ref (_data49_), (GClosureNotify) block49_data_unref, 0);
#line 379 "/home/fborges/checkout/gnome-boxes/src/libvirt-machine-properties.vala"
	_data49_->flushed_id = _tmp15_;
#line 335 "/home/fborges/checkout/gnome-boxes/src/libvirt-machine-properties.vala"
	_g_object_unref0 (log_button);
#line 335 "/home/fborges/checkout/gnome-boxes/src/libvirt-machine-properties.vala"
	_g_object_unref0 (inner_grid);
#line 335 "/home/fborges/checkout/gnome-boxes/src/libvirt-machine-properties.vala"
	_g_object_unref0 (grid);
#line 335 "/home/fborges/checkout/gnome-boxes/src/libvirt-machine-properties.vala"
	block49_data_unref (_data49_);
#line 335 "/home/fborges/checkout/gnome-boxes/src/libvirt-machine-properties.vala"
	_data49_ = NULL;
#line 4179 "libvirt-machine-properties.c"
}


static Block50Data* block50_data_ref (Block50Data* _data50_) {
#line 386 "/home/fborges/checkout/gnome-boxes/src/libvirt-machine-properties.vala"
	g_atomic_int_inc (&_data50_->_ref_count_);
#line 386 "/home/fborges/checkout/gnome-boxes/src/libvirt-machine-properties.vala"
	return _data50_;
#line 4188 "libvirt-machine-properties.c"
}


static void block50_data_unref (void * _userdata_) {
	Block50Data* _data50_;
	_data50_ = (Block50Data*) _userdata_;
#line 386 "/home/fborges/checkout/gnome-boxes/src/libvirt-machine-properties.vala"
	if (g_atomic_int_dec_and_test (&_data50_->_ref_count_)) {
#line 4197 "libvirt-machine-properties.c"
		BoxesLibvirtMachineProperties* self;
#line 386 "/home/fborges/checkout/gnome-boxes/src/libvirt-machine-properties.vala"
		self = _data50_->self;
#line 386 "/home/fborges/checkout/gnome-boxes/src/libvirt-machine-properties.vala"
		_g_object_unref0 (_data50_->property);
#line 386 "/home/fborges/checkout/gnome-boxes/src/libvirt-machine-properties.vala"
		_g_object_unref0 (self);
#line 386 "/home/fborges/checkout/gnome-boxes/src/libvirt-machine-properties.vala"
		g_slice_free (Block50Data, _data50_);
#line 4207 "libvirt-machine-properties.c"
	}
}


static void _boxes_libvirt_machine_properties_on_ram_changed_boxes_size_property_changed (BoxesSizeProperty* _sender, guint64 value, gpointer self) {
#line 405 "/home/fborges/checkout/gnome-boxes/src/libvirt-machine-properties.vala"
	boxes_libvirt_machine_properties_on_ram_changed ((BoxesLibvirtMachineProperties*) self, _sender, value);
#line 4215 "libvirt-machine-properties.c"
}


static void ___lambda135_ (Block50Data* _data50_) {
	BoxesLibvirtMachineProperties* self;
	BoxesLibvirtMachine* _tmp0_;
	gboolean _tmp1_;
	gboolean _tmp2_;
#line 407 "/home/fborges/checkout/gnome-boxes/src/libvirt-machine-properties.vala"
	self = _data50_->self;
#line 408 "/home/fborges/checkout/gnome-boxes/src/libvirt-machine-properties.vala"
	_tmp0_ = self->priv->machine;
#line 408 "/home/fborges/checkout/gnome-boxes/src/libvirt-machine-properties.vala"
	_tmp1_ = boxes_machine_get_is_on ((BoxesMachine*) _tmp0_);
#line 408 "/home/fborges/checkout/gnome-boxes/src/libvirt-machine-properties.vala"
	_tmp2_ = _tmp1_;
#line 408 "/home/fborges/checkout/gnome-boxes/src/libvirt-machine-properties.vala"
	if (!_tmp2_) {
#line 4234 "libvirt-machine-properties.c"
		BoxesSizeProperty* _tmp3_;
#line 409 "/home/fborges/checkout/gnome-boxes/src/libvirt-machine-properties.vala"
		_tmp3_ = _data50_->property;
#line 409 "/home/fborges/checkout/gnome-boxes/src/libvirt-machine-properties.vala"
		boxes_property_set_reboot_required ((BoxesProperty*) _tmp3_, FALSE);
#line 4240 "libvirt-machine-properties.c"
	}
}


static void ____lambda135__g_object_notify (GObject* _sender, GParamSpec* pspec, gpointer self) {
#line 407 "/home/fborges/checkout/gnome-boxes/src/libvirt-machine-properties.vala"
	___lambda135_ (self);
#line 4248 "libvirt-machine-properties.c"
}


static BoxesSizeProperty* boxes_libvirt_machine_properties_add_ram_property (BoxesLibvirtMachineProperties* self, GList* * list) {
	BoxesSizeProperty* result = NULL;
	GError * _inner_error_ = NULL;
#line 385 "/home/fborges/checkout/gnome-boxes/src/libvirt-machine-properties.vala"
	g_return_val_if_fail (self != NULL, NULL);
#line 4257 "libvirt-machine-properties.c"
	{
		Block50Data* _data50_;
		GVirNodeInfo* _tmp0_ = NULL;
		BoxesLibvirtMachine* _tmp1_;
		GVirConnection* _tmp2_;
		GVirConnection* _tmp3_;
		GVirNodeInfo* _tmp4_;
		gulong max_ram = 0UL;
		gulong _tmp5_;
		BoxesLibvirtMachine* _tmp6_;
		GVirConfigDomain* _tmp7_;
		GVirConfigDomain* _tmp8_;
		guint64 _tmp9_;
		guint64 _tmp10_;
		gulong _tmp11_;
		BoxesSizeProperty* _tmp12_;
		BoxesSizeProperty* _tmp13_;
		BoxesSizeProperty* _tmp14_;
		GtkWidget* _tmp15_;
		GtkWidget* _tmp16_;
		gboolean _tmp17_ = FALSE;
		gboolean _tmp18_ = FALSE;
		gboolean _tmp19_ = FALSE;
		BoxesLibvirtMachine* _tmp20_;
		GVirConfigDomain* _tmp21_;
		GVirConfigDomain* _tmp22_;
		gboolean _tmp23_;
		BoxesLibvirtMachine* _tmp38_;
		BoxesSizeProperty* _tmp39_;
		BoxesSizeProperty* _tmp40_;
		BoxesSizeProperty* _tmp41_;
#line 386 "/home/fborges/checkout/gnome-boxes/src/libvirt-machine-properties.vala"
		_data50_ = g_slice_new0 (Block50Data);
#line 386 "/home/fborges/checkout/gnome-boxes/src/libvirt-machine-properties.vala"
		_data50_->_ref_count_ = 1;
#line 386 "/home/fborges/checkout/gnome-boxes/src/libvirt-machine-properties.vala"
		_data50_->self = g_object_ref (self);
#line 387 "/home/fborges/checkout/gnome-boxes/src/libvirt-machine-properties.vala"
		_tmp1_ = self->priv->machine;
#line 387 "/home/fborges/checkout/gnome-boxes/src/libvirt-machine-properties.vala"
		_tmp2_ = boxes_libvirt_machine_get_connection (_tmp1_);
#line 387 "/home/fborges/checkout/gnome-boxes/src/libvirt-machine-properties.vala"
		_tmp3_ = _tmp2_;
#line 387 "/home/fborges/checkout/gnome-boxes/src/libvirt-machine-properties.vala"
		_tmp4_ = gvir_connection_get_node_info (_tmp3_, &_inner_error_);
#line 387 "/home/fborges/checkout/gnome-boxes/src/libvirt-machine-properties.vala"
		_tmp0_ = _tmp4_;
#line 387 "/home/fborges/checkout/gnome-boxes/src/libvirt-machine-properties.vala"
		if (G_UNLIKELY (_inner_error_ != NULL)) {
#line 387 "/home/fborges/checkout/gnome-boxes/src/libvirt-machine-properties.vala"
			block50_data_unref (_data50_);
#line 387 "/home/fborges/checkout/gnome-boxes/src/libvirt-machine-properties.vala"
			_data50_ = NULL;
#line 4311 "libvirt-machine-properties.c"
			goto __catch45_g_error;
		}
#line 387 "/home/fborges/checkout/gnome-boxes/src/libvirt-machine-properties.vala"
		_tmp5_ = _tmp0_->memory;
#line 387 "/home/fborges/checkout/gnome-boxes/src/libvirt-machine-properties.vala"
		max_ram = _tmp5_;
#line 389 "/home/fborges/checkout/gnome-boxes/src/libvirt-machine-properties.vala"
		_tmp6_ = self->priv->machine;
#line 389 "/home/fborges/checkout/gnome-boxes/src/libvirt-machine-properties.vala"
		_tmp7_ = boxes_libvirt_machine_get_domain_config (_tmp6_);
#line 389 "/home/fborges/checkout/gnome-boxes/src/libvirt-machine-properties.vala"
		_tmp8_ = _tmp7_;
#line 389 "/home/fborges/checkout/gnome-boxes/src/libvirt-machine-properties.vala"
		_tmp9_ = gvir_config_domain_get_memory (_tmp8_);
#line 389 "/home/fborges/checkout/gnome-boxes/src/libvirt-machine-properties.vala"
		_tmp10_ = _tmp9_;
#line 389 "/home/fborges/checkout/gnome-boxes/src/libvirt-machine-properties.vala"
		_tmp11_ = max_ram;
#line 389 "/home/fborges/checkout/gnome-boxes/src/libvirt-machine-properties.vala"
		_tmp12_ = boxes_iproperties_provider_add_size_property ((BoxesIPropertiesProvider*) self, list, _ ("_Memory: "), _tmp10_ * OSINFO_KIBIBYTES, (guint64) (64 * OSINFO_MEBIBYTES), (guint64) (_tmp11_ * OSINFO_KIBIBYTES), (guint64) 0, (guint64) (64 * OSINFO_MEBIBYTES), G_FORMAT_SIZE_IEC_UNITS);
#line 389 "/home/fborges/checkout/gnome-boxes/src/libvirt-machine-properties.vala"
		_data50_->property = _tmp12_;
#line 397 "/home/fborges/checkout/gnome-boxes/src/libvirt-machine-properties.vala"
		_tmp13_ = _data50_->property;
#line 397 "/home/fborges/checkout/gnome-boxes/src/libvirt-machine-properties.vala"
		boxes_property_set_description_alignment ((BoxesProperty*) _tmp13_, GTK_ALIGN_START);
#line 398 "/home/fborges/checkout/gnome-boxes/src/libvirt-machine-properties.vala"
		_tmp14_ = _data50_->property;
#line 398 "/home/fborges/checkout/gnome-boxes/src/libvirt-machine-properties.vala"
		_tmp15_ = boxes_property_get_widget ((BoxesProperty*) _tmp14_);
#line 398 "/home/fborges/checkout/gnome-boxes/src/libvirt-machine-properties.vala"
		_tmp16_ = _tmp15_;
#line 398 "/home/fborges/checkout/gnome-boxes/src/libvirt-machine-properties.vala"
		gtk_widget_set_margin_top (_tmp16_, 5);
#line 399 "/home/fborges/checkout/gnome-boxes/src/libvirt-machine-properties.vala"
		_tmp20_ = self->priv->machine;
#line 399 "/home/fborges/checkout/gnome-boxes/src/libvirt-machine-properties.vala"
		_tmp21_ = boxes_libvirt_machine_get_domain_config (_tmp20_);
#line 399 "/home/fborges/checkout/gnome-boxes/src/libvirt-machine-properties.vala"
		_tmp22_ = _tmp21_;
#line 399 "/home/fborges/checkout/gnome-boxes/src/libvirt-machine-properties.vala"
		_tmp23_ = boxes_vm_configurator_is_install_config (_tmp22_);
#line 399 "/home/fborges/checkout/gnome-boxes/src/libvirt-machine-properties.vala"
		if (_tmp23_) {
#line 399 "/home/fborges/checkout/gnome-boxes/src/libvirt-machine-properties.vala"
			_tmp19_ = TRUE;
#line 4358 "libvirt-machine-properties.c"
		} else {
			BoxesLibvirtMachine* _tmp24_;
			GVirConfigDomain* _tmp25_;
			GVirConfigDomain* _tmp26_;
			gboolean _tmp27_;
#line 400 "/home/fborges/checkout/gnome-boxes/src/libvirt-machine-properties.vala"
			_tmp24_ = self->priv->machine;
#line 400 "/home/fborges/checkout/gnome-boxes/src/libvirt-machine-properties.vala"
			_tmp25_ = boxes_libvirt_machine_get_domain_config (_tmp24_);
#line 400 "/home/fborges/checkout/gnome-boxes/src/libvirt-machine-properties.vala"
			_tmp26_ = _tmp25_;
#line 400 "/home/fborges/checkout/gnome-boxes/src/libvirt-machine-properties.vala"
			_tmp27_ = boxes_vm_configurator_is_live_config (_tmp26_);
#line 400 "/home/fborges/checkout/gnome-boxes/src/libvirt-machine-properties.vala"
			_tmp19_ = _tmp27_;
#line 4374 "libvirt-machine-properties.c"
		}
#line 399 "/home/fborges/checkout/gnome-boxes/src/libvirt-machine-properties.vala"
		if (_tmp19_) {
#line 4378 "libvirt-machine-properties.c"
			BoxesLibvirtMachine* _tmp28_;
			BoxesAppWindow* _tmp29_;
			BoxesAppWindow* _tmp30_;
			BoxesUIState _tmp31_;
			BoxesUIState _tmp32_;
#line 401 "/home/fborges/checkout/gnome-boxes/src/libvirt-machine-properties.vala"
			_tmp28_ = self->priv->machine;
#line 401 "/home/fborges/checkout/gnome-boxes/src/libvirt-machine-properties.vala"
			_tmp29_ = boxes_machine_get_window ((BoxesMachine*) _tmp28_);
#line 401 "/home/fborges/checkout/gnome-boxes/src/libvirt-machine-properties.vala"
			_tmp30_ = _tmp29_;
#line 401 "/home/fborges/checkout/gnome-boxes/src/libvirt-machine-properties.vala"
			_tmp31_ = boxes_ui_get_ui_state ((BoxesUI*) _tmp30_);
#line 401 "/home/fborges/checkout/gnome-boxes/src/libvirt-machine-properties.vala"
			_tmp32_ = _tmp31_;
#line 401 "/home/fborges/checkout/gnome-boxes/src/libvirt-machine-properties.vala"
			_tmp18_ = _tmp32_ != BOXES_UI_STATE_WIZARD;
#line 4396 "libvirt-machine-properties.c"
		} else {
#line 399 "/home/fborges/checkout/gnome-boxes/src/libvirt-machine-properties.vala"
			_tmp18_ = FALSE;
#line 4400 "libvirt-machine-properties.c"
		}
#line 399 "/home/fborges/checkout/gnome-boxes/src/libvirt-machine-properties.vala"
		if (_tmp18_) {
#line 4404 "libvirt-machine-properties.c"
			BoxesLibvirtMachine* _tmp33_;
			BoxesMachineMachineState _tmp34_;
			BoxesMachineMachineState _tmp35_;
#line 402 "/home/fborges/checkout/gnome-boxes/src/libvirt-machine-properties.vala"
			_tmp33_ = self->priv->machine;
#line 402 "/home/fborges/checkout/gnome-boxes/src/libvirt-machine-properties.vala"
			_tmp34_ = boxes_machine_get_state ((BoxesMachine*) _tmp33_);
#line 402 "/home/fborges/checkout/gnome-boxes/src/libvirt-machine-properties.vala"
			_tmp35_ = _tmp34_;
#line 402 "/home/fborges/checkout/gnome-boxes/src/libvirt-machine-properties.vala"
			_tmp17_ = _tmp35_ != BOXES_MACHINE_MACHINE_STATE_FORCE_STOPPED;
#line 4416 "libvirt-machine-properties.c"
		} else {
#line 399 "/home/fborges/checkout/gnome-boxes/src/libvirt-machine-properties.vala"
			_tmp17_ = FALSE;
#line 4420 "libvirt-machine-properties.c"
		}
#line 399 "/home/fborges/checkout/gnome-boxes/src/libvirt-machine-properties.vala"
		if (_tmp17_) {
#line 4424 "libvirt-machine-properties.c"
			BoxesSizeProperty* _tmp36_;
#line 403 "/home/fborges/checkout/gnome-boxes/src/libvirt-machine-properties.vala"
			_tmp36_ = _data50_->property;
#line 403 "/home/fborges/checkout/gnome-boxes/src/libvirt-machine-properties.vala"
			boxes_property_set_sensitive ((BoxesProperty*) _tmp36_, FALSE);
#line 4430 "libvirt-machine-properties.c"
		} else {
			BoxesSizeProperty* _tmp37_;
#line 405 "/home/fborges/checkout/gnome-boxes/src/libvirt-machine-properties.vala"
			_tmp37_ = _data50_->property;
#line 405 "/home/fborges/checkout/gnome-boxes/src/libvirt-machine-properties.vala"
			g_signal_connect_object (_tmp37_, "changed", (GCallback) _boxes_libvirt_machine_properties_on_ram_changed_boxes_size_property_changed, self, 0);
#line 4437 "libvirt-machine-properties.c"
		}
#line 407 "/home/fborges/checkout/gnome-boxes/src/libvirt-machine-properties.vala"
		_tmp38_ = self->priv->machine;
#line 407 "/home/fborges/checkout/gnome-boxes/src/libvirt-machine-properties.vala"
		g_signal_connect_data ((GObject*) _tmp38_, "notify::state", (GCallback) ____lambda135__g_object_notify, block50_data_ref (_data50_), (GClosureNotify) block50_data_unref, 0);
#line 412 "/home/fborges/checkout/gnome-boxes/src/libvirt-machine-properties.vala"
		_tmp39_ = _data50_->property;
#line 412 "/home/fborges/checkout/gnome-boxes/src/libvirt-machine-properties.vala"
		boxes_libvirt_machine_properties_update_ram_property (self, (BoxesProperty*) _tmp39_);
#line 414 "/home/fborges/checkout/gnome-boxes/src/libvirt-machine-properties.vala"
		_tmp40_ = _data50_->property;
#line 414 "/home/fborges/checkout/gnome-boxes/src/libvirt-machine-properties.vala"
		_tmp41_ = _g_object_ref0 (_tmp40_);
#line 414 "/home/fborges/checkout/gnome-boxes/src/libvirt-machine-properties.vala"
		result = _tmp41_;
#line 414 "/home/fborges/checkout/gnome-boxes/src/libvirt-machine-properties.vala"
		__vala_GVirNodeInfo_free0 (_tmp0_);
#line 414 "/home/fborges/checkout/gnome-boxes/src/libvirt-machine-properties.vala"
		block50_data_unref (_data50_);
#line 414 "/home/fborges/checkout/gnome-boxes/src/libvirt-machine-properties.vala"
		_data50_ = NULL;
#line 414 "/home/fborges/checkout/gnome-boxes/src/libvirt-machine-properties.vala"
		return result;
#line 4461 "libvirt-machine-properties.c"
	}
	goto __finally45;
	__catch45_g_error:
	{
		GError* _error_ = NULL;
#line 386 "/home/fborges/checkout/gnome-boxes/src/libvirt-machine-properties.vala"
		_error_ = _inner_error_;
#line 386 "/home/fborges/checkout/gnome-boxes/src/libvirt-machine-properties.vala"
		_inner_error_ = NULL;
#line 416 "/home/fborges/checkout/gnome-boxes/src/libvirt-machine-properties.vala"
		result = NULL;
#line 416 "/home/fborges/checkout/gnome-boxes/src/libvirt-machine-properties.vala"
		_g_error_free0 (_error_);
#line 416 "/home/fborges/checkout/gnome-boxes/src/libvirt-machine-properties.vala"
		return result;
#line 4477 "libvirt-machine-properties.c"
	}
	__finally45:
#line 386 "/home/fborges/checkout/gnome-boxes/src/libvirt-machine-properties.vala"
	g_critical ("file %s: line %d: uncaught error: %s (%s, %d)", __FILE__, __LINE__, _inner_error_->message, g_quark_to_string (_inner_error_->domain), _inner_error_->code);
#line 386 "/home/fborges/checkout/gnome-boxes/src/libvirt-machine-properties.vala"
	g_clear_error (&_inner_error_);
#line 386 "/home/fborges/checkout/gnome-boxes/src/libvirt-machine-properties.vala"
	return NULL;
#line 4486 "libvirt-machine-properties.c"
}


static Block51Data* block51_data_ref (Block51Data* _data51_) {
#line 420 "/home/fborges/checkout/gnome-boxes/src/libvirt-machine-properties.vala"
	g_atomic_int_inc (&_data51_->_ref_count_);
#line 420 "/home/fborges/checkout/gnome-boxes/src/libvirt-machine-properties.vala"
	return _data51_;
#line 4495 "libvirt-machine-properties.c"
}


static void block51_data_unref (void * _userdata_) {
	Block51Data* _data51_;
	_data51_ = (Block51Data*) _userdata_;
#line 420 "/home/fborges/checkout/gnome-boxes/src/libvirt-machine-properties.vala"
	if (g_atomic_int_dec_and_test (&_data51_->_ref_count_)) {
#line 4504 "libvirt-machine-properties.c"
		BoxesLibvirtMachineProperties* self;
#line 420 "/home/fborges/checkout/gnome-boxes/src/libvirt-machine-properties.vala"
		self = _data51_->self;
#line 420 "/home/fborges/checkout/gnome-boxes/src/libvirt-machine-properties.vala"
		_g_object_unref0 (_data51_->property);
#line 420 "/home/fborges/checkout/gnome-boxes/src/libvirt-machine-properties.vala"
		_g_object_unref0 (self);
#line 420 "/home/fborges/checkout/gnome-boxes/src/libvirt-machine-properties.vala"
		g_slice_free (Block51Data, _data51_);
#line 4514 "libvirt-machine-properties.c"
	}
}


static gboolean __lambda134_ (Block51Data* _data51_) {
	BoxesLibvirtMachineProperties* self;
	gboolean result = FALSE;
	guint64 ram = 0ULL;
	guint64 _tmp0_;
	BoxesProperty* _tmp25_;
	GError * _inner_error_ = NULL;
#line 422 "/home/fborges/checkout/gnome-boxes/src/libvirt-machine-properties.vala"
	self = _data51_->self;
#line 423 "/home/fborges/checkout/gnome-boxes/src/libvirt-machine-properties.vala"
	_tmp0_ = _data51_->value;
#line 423 "/home/fborges/checkout/gnome-boxes/src/libvirt-machine-properties.vala"
	ram = ((_tmp0_ + OSINFO_KIBIBYTES) - 1) / OSINFO_KIBIBYTES;
#line 4532 "libvirt-machine-properties.c"
	{
		GVirConfigDomain* config = NULL;
		BoxesLibvirtMachine* _tmp1_;
		GVirDomain* _tmp2_;
		GVirDomain* _tmp3_;
		GVirConfigDomain* _tmp4_;
		GVirConfigDomain* _tmp5_;
		guint64 _tmp6_;
		GVirConfigDomain* _tmp7_;
		GObjectClass* _tmp8_;
		GParamSpec* _tmp9_;
		BoxesLibvirtMachine* _tmp12_;
		GVirDomain* _tmp13_;
		GVirDomain* _tmp14_;
		GVirConfigDomain* _tmp15_;
		guint64 _tmp16_;
#line 425 "/home/fborges/checkout/gnome-boxes/src/libvirt-machine-properties.vala"
		_tmp1_ = self->priv->machine;
#line 425 "/home/fborges/checkout/gnome-boxes/src/libvirt-machine-properties.vala"
		_tmp2_ = boxes_libvirt_machine_get_domain (_tmp1_);
#line 425 "/home/fborges/checkout/gnome-boxes/src/libvirt-machine-properties.vala"
		_tmp3_ = _tmp2_;
#line 425 "/home/fborges/checkout/gnome-boxes/src/libvirt-machine-properties.vala"
		_tmp4_ = gvir_domain_get_config (_tmp3_, (guint) GVIR_DOMAIN_XML_INACTIVE, &_inner_error_);
#line 425 "/home/fborges/checkout/gnome-boxes/src/libvirt-machine-properties.vala"
		config = _tmp4_;
#line 425 "/home/fborges/checkout/gnome-boxes/src/libvirt-machine-properties.vala"
		if (G_UNLIKELY (_inner_error_ != NULL)) {
#line 4561 "libvirt-machine-properties.c"
			goto __catch46_g_error;
		}
#line 426 "/home/fborges/checkout/gnome-boxes/src/libvirt-machine-properties.vala"
		_tmp5_ = config;
#line 426 "/home/fborges/checkout/gnome-boxes/src/libvirt-machine-properties.vala"
		_tmp6_ = ram;
#line 426 "/home/fborges/checkout/gnome-boxes/src/libvirt-machine-properties.vala"
		gvir_config_domain_set_memory (_tmp5_, _tmp6_);
#line 427 "/home/fborges/checkout/gnome-boxes/src/libvirt-machine-properties.vala"
		_tmp7_ = config;
#line 427 "/home/fborges/checkout/gnome-boxes/src/libvirt-machine-properties.vala"
		_tmp8_ = G_OBJECT_GET_CLASS ((GObject*) _tmp7_);
#line 427 "/home/fborges/checkout/gnome-boxes/src/libvirt-machine-properties.vala"
		_tmp9_ = g_object_class_find_property (_tmp8_, "current-memory");
#line 427 "/home/fborges/checkout/gnome-boxes/src/libvirt-machine-properties.vala"
		if (_tmp9_ != NULL) {
#line 4578 "libvirt-machine-properties.c"
			GVirConfigDomain* _tmp10_;
			guint64 _tmp11_;
#line 428 "/home/fborges/checkout/gnome-boxes/src/libvirt-machine-properties.vala"
			_tmp10_ = config;
#line 428 "/home/fborges/checkout/gnome-boxes/src/libvirt-machine-properties.vala"
			_tmp11_ = ram;
#line 428 "/home/fborges/checkout/gnome-boxes/src/libvirt-machine-properties.vala"
			g_object_set ((GObject*) _tmp10_, "current-memory", _tmp11_, NULL);
#line 4587 "libvirt-machine-properties.c"
		}
#line 429 "/home/fborges/checkout/gnome-boxes/src/libvirt-machine-properties.vala"
		_tmp12_ = self->priv->machine;
#line 429 "/home/fborges/checkout/gnome-boxes/src/libvirt-machine-properties.vala"
		_tmp13_ = boxes_libvirt_machine_get_domain (_tmp12_);
#line 429 "/home/fborges/checkout/gnome-boxes/src/libvirt-machine-properties.vala"
		_tmp14_ = _tmp13_;
#line 429 "/home/fborges/checkout/gnome-boxes/src/libvirt-machine-properties.vala"
		_tmp15_ = config;
#line 429 "/home/fborges/checkout/gnome-boxes/src/libvirt-machine-properties.vala"
		gvir_domain_set_config (_tmp14_, _tmp15_, &_inner_error_);
#line 429 "/home/fborges/checkout/gnome-boxes/src/libvirt-machine-properties.vala"
		if (G_UNLIKELY (_inner_error_ != NULL)) {
#line 429 "/home/fborges/checkout/gnome-boxes/src/libvirt-machine-properties.vala"
			_g_object_unref0 (config);
#line 4603 "libvirt-machine-properties.c"
			goto __catch46_g_error;
		}
#line 430 "/home/fborges/checkout/gnome-boxes/src/libvirt-machine-properties.vala"
		_tmp16_ = ram;
#line 430 "/home/fborges/checkout/gnome-boxes/src/libvirt-machine-properties.vala"
		g_debug ("libvirt-machine-properties.vala:430: RAM changed to %llu KiB", _tmp16_);
#line 424 "/home/fborges/checkout/gnome-boxes/src/libvirt-machine-properties.vala"
		_g_object_unref0 (config);
#line 4612 "libvirt-machine-properties.c"
	}
	goto __finally46;
	__catch46_g_error:
	{
		GError* _error_ = NULL;
		BoxesLibvirtMachine* _tmp17_;
		GVirDomain* _tmp18_;
		GVirDomain* _tmp19_;
		const gchar* _tmp20_;
		guint64 _tmp21_;
		GError* _tmp22_;
		const gchar* _tmp23_;
#line 424 "/home/fborges/checkout/gnome-boxes/src/libvirt-machine-properties.vala"
		_error_ = _inner_error_;
#line 424 "/home/fborges/checkout/gnome-boxes/src/libvirt-machine-properties.vala"
		_inner_error_ = NULL;
#line 432 "/home/fborges/checkout/gnome-boxes/src/libvirt-machine-properties.vala"
		_tmp17_ = self->priv->machine;
#line 432 "/home/fborges/checkout/gnome-boxes/src/libvirt-machine-properties.vala"
		_tmp18_ = boxes_libvirt_machine_get_domain (_tmp17_);
#line 432 "/home/fborges/checkout/gnome-boxes/src/libvirt-machine-properties.vala"
		_tmp19_ = _tmp18_;
#line 432 "/home/fborges/checkout/gnome-boxes/src/libvirt-machine-properties.vala"
		_tmp20_ = gvir_domain_get_name (_tmp19_);
#line 432 "/home/fborges/checkout/gnome-boxes/src/libvirt-machine-properties.vala"
		_tmp21_ = ram;
#line 432 "/home/fborges/checkout/gnome-boxes/src/libvirt-machine-properties.vala"
		_tmp22_ = _error_;
#line 432 "/home/fborges/checkout/gnome-boxes/src/libvirt-machine-properties.vala"
		_tmp23_ = _tmp22_->message;
#line 432 "/home/fborges/checkout/gnome-boxes/src/libvirt-machine-properties.vala"
		g_warning ("libvirt-machine-properties.vala:432: Failed to change RAM of box '%s' " \
"to %llu KiB: %s", _tmp20_, _tmp21_, _tmp23_);
#line 424 "/home/fborges/checkout/gnome-boxes/src/libvirt-machine-properties.vala"
		_g_error_free0 (_error_);
#line 4647 "libvirt-machine-properties.c"
	}
	__finally46:
#line 424 "/home/fborges/checkout/gnome-boxes/src/libvirt-machine-properties.vala"
	if (G_UNLIKELY (_inner_error_ != NULL)) {
#line 4652 "libvirt-machine-properties.c"
		gboolean _tmp24_ = FALSE;
#line 424 "/home/fborges/checkout/gnome-boxes/src/libvirt-machine-properties.vala"
		g_critical ("file %s: line %d: uncaught error: %s (%s, %d)", __FILE__, __LINE__, _inner_error_->message, g_quark_to_string (_inner_error_->domain), _inner_error_->code);
#line 424 "/home/fborges/checkout/gnome-boxes/src/libvirt-machine-properties.vala"
		g_clear_error (&_inner_error_);
#line 424 "/home/fborges/checkout/gnome-boxes/src/libvirt-machine-properties.vala"
		return _tmp24_;
#line 4660 "libvirt-machine-properties.c"
	}
#line 438 "/home/fborges/checkout/gnome-boxes/src/libvirt-machine-properties.vala"
	_tmp25_ = _data51_->property;
#line 438 "/home/fborges/checkout/gnome-boxes/src/libvirt-machine-properties.vala"
	boxes_libvirt_machine_properties_update_ram_property (self, _tmp25_);
#line 440 "/home/fborges/checkout/gnome-boxes/src/libvirt-machine-properties.vala"
	result = FALSE;
#line 440 "/home/fborges/checkout/gnome-boxes/src/libvirt-machine-properties.vala"
	return result;
#line 4670 "libvirt-machine-properties.c"
}


static gboolean ___lambda134__gsource_func (gpointer self) {
	gboolean result;
	result = __lambda134_ (self);
#line 422 "/home/fborges/checkout/gnome-boxes/src/libvirt-machine-properties.vala"
	return result;
#line 4679 "libvirt-machine-properties.c"
}


static void boxes_libvirt_machine_properties_on_ram_changed (BoxesLibvirtMachineProperties* self, BoxesProperty* property, guint64 value) {
	Block51Data* _data51_;
	BoxesProperty* _tmp0_;
	BoxesProperty* _tmp1_;
	guint64 _tmp2_;
	BoxesProperty* _tmp3_;
#line 420 "/home/fborges/checkout/gnome-boxes/src/libvirt-machine-properties.vala"
	g_return_if_fail (self != NULL);
#line 420 "/home/fborges/checkout/gnome-boxes/src/libvirt-machine-properties.vala"
	g_return_if_fail (property != NULL);
#line 420 "/home/fborges/checkout/gnome-boxes/src/libvirt-machine-properties.vala"
	_data51_ = g_slice_new0 (Block51Data);
#line 420 "/home/fborges/checkout/gnome-boxes/src/libvirt-machine-properties.vala"
	_data51_->_ref_count_ = 1;
#line 420 "/home/fborges/checkout/gnome-boxes/src/libvirt-machine-properties.vala"
	_data51_->self = g_object_ref (self);
#line 420 "/home/fborges/checkout/gnome-boxes/src/libvirt-machine-properties.vala"
	_tmp0_ = property;
#line 420 "/home/fborges/checkout/gnome-boxes/src/libvirt-machine-properties.vala"
	_tmp1_ = _g_object_ref0 (_tmp0_);
#line 420 "/home/fborges/checkout/gnome-boxes/src/libvirt-machine-properties.vala"
	_g_object_unref0 (_data51_->property);
#line 420 "/home/fborges/checkout/gnome-boxes/src/libvirt-machine-properties.vala"
	_data51_->property = _tmp1_;
#line 420 "/home/fborges/checkout/gnome-boxes/src/libvirt-machine-properties.vala"
	_tmp2_ = value;
#line 420 "/home/fborges/checkout/gnome-boxes/src/libvirt-machine-properties.vala"
	_data51_->value = _tmp2_;
#line 422 "/home/fborges/checkout/gnome-boxes/src/libvirt-machine-properties.vala"
	_tmp3_ = _data51_->property;
#line 422 "/home/fborges/checkout/gnome-boxes/src/libvirt-machine-properties.vala"
	boxes_property_set_deferred_change (_tmp3_, ___lambda134__gsource_func, block51_data_ref (_data51_), block51_data_unref);
#line 420 "/home/fborges/checkout/gnome-boxes/src/libvirt-machine-properties.vala"
	block51_data_unref (_data51_);
#line 420 "/home/fborges/checkout/gnome-boxes/src/libvirt-machine-properties.vala"
	_data51_ = NULL;
#line 4719 "libvirt-machine-properties.c"
}


static void _vala_GVirStorageVolInfo_free (GVirStorageVolInfo* self) {
#line 451 "/home/fborges/checkout/gnome-boxes/src/libvirt-machine-properties.vala"
	g_boxed_free (gvir_storage_vol_info_get_type (), self);
#line 4726 "libvirt-machine-properties.c"
}


static void _vala_GVirStoragePoolInfo_free (GVirStoragePoolInfo* self) {
#line 452 "/home/fborges/checkout/gnome-boxes/src/libvirt-machine-properties.vala"
	g_boxed_free (gvir_storage_pool_info_get_type (), self);
#line 4733 "libvirt-machine-properties.c"
}


static void _boxes_libvirt_machine_properties_on_storage_changed_boxes_size_property_changed (BoxesSizeProperty* _sender, guint64 value, gpointer self) {
#line 502 "/home/fborges/checkout/gnome-boxes/src/libvirt-machine-properties.vala"
	boxes_libvirt_machine_properties_on_storage_changed ((BoxesLibvirtMachineProperties*) self, _sender, value);
#line 4740 "libvirt-machine-properties.c"
}


static BoxesSizeProperty* boxes_libvirt_machine_properties_add_storage_property (BoxesLibvirtMachineProperties* self, GList* * list) {
	BoxesSizeProperty* result = NULL;
	gboolean _tmp0_ = FALSE;
	BoxesLibvirtMachine* _tmp1_;
	gboolean _tmp2_;
	gboolean _tmp3_;
	GError * _inner_error_ = NULL;
#line 444 "/home/fborges/checkout/gnome-boxes/src/libvirt-machine-properties.vala"
	g_return_val_if_fail (self != NULL, NULL);
#line 445 "/home/fborges/checkout/gnome-boxes/src/libvirt-machine-properties.vala"
	_tmp1_ = self->priv->machine;
#line 445 "/home/fborges/checkout/gnome-boxes/src/libvirt-machine-properties.vala"
	_tmp2_ = boxes_libvirt_machine_get_importing (_tmp1_);
#line 445 "/home/fborges/checkout/gnome-boxes/src/libvirt-machine-properties.vala"
	_tmp3_ = _tmp2_;
#line 445 "/home/fborges/checkout/gnome-boxes/src/libvirt-machine-properties.vala"
	if (_tmp3_) {
#line 445 "/home/fborges/checkout/gnome-boxes/src/libvirt-machine-properties.vala"
		_tmp0_ = TRUE;
#line 4763 "libvirt-machine-properties.c"
	} else {
		BoxesLibvirtMachine* _tmp4_;
		GVirStorageVol* _tmp5_;
		GVirStorageVol* _tmp6_;
#line 445 "/home/fborges/checkout/gnome-boxes/src/libvirt-machine-properties.vala"
		_tmp4_ = self->priv->machine;
#line 445 "/home/fborges/checkout/gnome-boxes/src/libvirt-machine-properties.vala"
		_tmp5_ = boxes_libvirt_machine_get_storage_volume (_tmp4_);
#line 445 "/home/fborges/checkout/gnome-boxes/src/libvirt-machine-properties.vala"
		_tmp6_ = _tmp5_;
#line 445 "/home/fborges/checkout/gnome-boxes/src/libvirt-machine-properties.vala"
		_tmp0_ = _tmp6_ == NULL;
#line 4776 "libvirt-machine-properties.c"
	}
#line 445 "/home/fborges/checkout/gnome-boxes/src/libvirt-machine-properties.vala"
	if (_tmp0_) {
#line 446 "/home/fborges/checkout/gnome-boxes/src/libvirt-machine-properties.vala"
		result = NULL;
#line 446 "/home/fborges/checkout/gnome-boxes/src/libvirt-machine-properties.vala"
		return result;
#line 4784 "libvirt-machine-properties.c"
	}
	{
		GVirStorageVolInfo* volume_info = NULL;
		BoxesLibvirtMachine* _tmp7_;
		GVirStorageVol* _tmp8_;
		GVirStorageVol* _tmp9_;
		GVirStorageVolInfo* _tmp10_;
		GVirStoragePool* pool = NULL;
		BoxesLibvirtMachine* _tmp11_;
		GVirConnection* _tmp12_;
		GVirConnection* _tmp13_;
		GVirStoragePool* _tmp14_;
		GVirStoragePoolInfo* pool_info = NULL;
		GVirStoragePool* _tmp15_;
		GVirStoragePoolInfo* _tmp16_;
		guint64 min_storage = 0ULL;
		guint64 _tmp17_;
		guint64 max_storage = 0ULL;
		GVirStorageVolInfo* _tmp18_;
		guint64 _tmp19_;
		GVirStoragePoolInfo* _tmp20_;
		guint64 _tmp21_;
		guint64 _tmp22_;
		guint64 _tmp23_;
		BoxesSizeProperty* property = NULL;
		GVirStorageVolInfo* _tmp58_;
		guint64 _tmp59_;
		guint64 _tmp60_;
		guint64 _tmp61_;
		GVirStorageVolInfo* _tmp62_;
		guint64 _tmp63_;
		BoxesSizeProperty* _tmp64_;
		BoxesSizeProperty* _tmp65_;
		BoxesSizeProperty* _tmp66_;
		gboolean _tmp67_ = FALSE;
		gboolean _tmp68_ = FALSE;
		gboolean _tmp69_ = FALSE;
		BoxesLibvirtMachine* _tmp70_;
		GVirConfigDomain* _tmp71_;
		GVirConfigDomain* _tmp72_;
		gboolean _tmp73_;
#line 449 "/home/fborges/checkout/gnome-boxes/src/libvirt-machine-properties.vala"
		_tmp7_ = self->priv->machine;
#line 449 "/home/fborges/checkout/gnome-boxes/src/libvirt-machine-properties.vala"
		_tmp8_ = boxes_libvirt_machine_get_storage_volume (_tmp7_);
#line 449 "/home/fborges/checkout/gnome-boxes/src/libvirt-machine-properties.vala"
		_tmp9_ = _tmp8_;
#line 449 "/home/fborges/checkout/gnome-boxes/src/libvirt-machine-properties.vala"
		_tmp10_ = gvir_storage_vol_get_info (_tmp9_, &_inner_error_);
#line 449 "/home/fborges/checkout/gnome-boxes/src/libvirt-machine-properties.vala"
		volume_info = _tmp10_;
#line 449 "/home/fborges/checkout/gnome-boxes/src/libvirt-machine-properties.vala"
		if (G_UNLIKELY (_inner_error_ != NULL)) {
#line 4838 "libvirt-machine-properties.c"
			goto __catch47_g_error;
		}
#line 450 "/home/fborges/checkout/gnome-boxes/src/libvirt-machine-properties.vala"
		_tmp11_ = self->priv->machine;
#line 450 "/home/fborges/checkout/gnome-boxes/src/libvirt-machine-properties.vala"
		_tmp12_ = boxes_libvirt_machine_get_connection (_tmp11_);
#line 450 "/home/fborges/checkout/gnome-boxes/src/libvirt-machine-properties.vala"
		_tmp13_ = _tmp12_;
#line 450 "/home/fborges/checkout/gnome-boxes/src/libvirt-machine-properties.vala"
		_tmp14_ = boxes_get_storage_pool (_tmp13_);
#line 450 "/home/fborges/checkout/gnome-boxes/src/libvirt-machine-properties.vala"
		pool = _tmp14_;
#line 451 "/home/fborges/checkout/gnome-boxes/src/libvirt-machine-properties.vala"
		_tmp15_ = pool;
#line 451 "/home/fborges/checkout/gnome-boxes/src/libvirt-machine-properties.vala"
		_tmp16_ = gvir_storage_pool_get_info (_tmp15_, &_inner_error_);
#line 451 "/home/fborges/checkout/gnome-boxes/src/libvirt-machine-properties.vala"
		pool_info = _tmp16_;
#line 451 "/home/fborges/checkout/gnome-boxes/src/libvirt-machine-properties.vala"
		if (G_UNLIKELY (_inner_error_ != NULL)) {
#line 451 "/home/fborges/checkout/gnome-boxes/src/libvirt-machine-properties.vala"
			_g_object_unref0 (pool);
#line 451 "/home/fborges/checkout/gnome-boxes/src/libvirt-machine-properties.vala"
			__vala_GVirStorageVolInfo_free0 (volume_info);
#line 4863 "libvirt-machine-properties.c"
			goto __catch47_g_error;
		}
#line 452 "/home/fborges/checkout/gnome-boxes/src/libvirt-machine-properties.vala"
		_tmp17_ = boxes_libvirt_machine_properties_get_minimum_disk_size (self, &_inner_error_);
#line 452 "/home/fborges/checkout/gnome-boxes/src/libvirt-machine-properties.vala"
		min_storage = _tmp17_;
#line 452 "/home/fborges/checkout/gnome-boxes/src/libvirt-machine-properties.vala"
		if (G_UNLIKELY (_inner_error_ != NULL)) {
#line 452 "/home/fborges/checkout/gnome-boxes/src/libvirt-machine-properties.vala"
			__vala_GVirStoragePoolInfo_free0 (pool_info);
#line 452 "/home/fborges/checkout/gnome-boxes/src/libvirt-machine-properties.vala"
			_g_object_unref0 (pool);
#line 452 "/home/fborges/checkout/gnome-boxes/src/libvirt-machine-properties.vala"
			__vala_GVirStorageVolInfo_free0 (volume_info);
#line 4878 "libvirt-machine-properties.c"
			goto __catch47_g_error;
		}
#line 453 "/home/fborges/checkout/gnome-boxes/src/libvirt-machine-properties.vala"
		_tmp18_ = volume_info;
#line 453 "/home/fborges/checkout/gnome-boxes/src/libvirt-machine-properties.vala"
		_tmp19_ = _tmp18_->allocation;
#line 453 "/home/fborges/checkout/gnome-boxes/src/libvirt-machine-properties.vala"
		_tmp20_ = pool_info;
#line 453 "/home/fborges/checkout/gnome-boxes/src/libvirt-machine-properties.vala"
		_tmp21_ = _tmp20_->available;
#line 453 "/home/fborges/checkout/gnome-boxes/src/libvirt-machine-properties.vala"
		max_storage = _tmp19_ + _tmp21_;
#line 455 "/home/fborges/checkout/gnome-boxes/src/libvirt-machine-properties.vala"
		_tmp22_ = min_storage;
#line 455 "/home/fborges/checkout/gnome-boxes/src/libvirt-machine-properties.vala"
		_tmp23_ = max_storage;
#line 455 "/home/fborges/checkout/gnome-boxes/src/libvirt-machine-properties.vala"
		if (_tmp22_ >= _tmp23_) {
#line 4897 "libvirt-machine-properties.c"
			GtkLabel* label = NULL;
			GtkLabel* _tmp24_;
			gchar* capacity = NULL;
			GVirStorageVolInfo* _tmp25_;
			guint64 _tmp26_;
			gchar* _tmp27_;
			gchar* allocation = NULL;
			GVirStorageVolInfo* _tmp28_;
			guint64 _tmp29_;
			gchar* _tmp30_;
			gchar* markup = NULL;
			const gchar* _tmp31_;
			const gchar* _tmp32_;
			gchar* _tmp33_;
			GtkLabel* _tmp34_;
			const gchar* _tmp35_;
			GtkLabel* _tmp36_;
			GtkLabel* _tmp37_;
			BoxesProperty* _tmp38_;
			BoxesProperty* _tmp39_;
			GtkInfoBar* infobar = NULL;
			GtkInfoBar* _tmp40_;
			GtkInfoBar* _tmp41_;
			GtkContainer* content = NULL;
			GtkInfoBar* _tmp42_;
			GtkContainer* _tmp43_;
			GtkContainer* _tmp44_;
			GtkImage* image = NULL;
			GtkImage* _tmp45_;
			GtkImage* _tmp46_;
			GtkImage* _tmp47_;
			GtkContainer* _tmp48_;
			GtkImage* _tmp49_;
			gchar* msg = NULL;
			gchar* _tmp50_;
			const gchar* _tmp51_;
			GtkLabel* _tmp52_;
			GtkContainer* _tmp53_;
			GtkLabel* _tmp54_;
			GtkInfoBar* _tmp55_;
			BoxesProperty* _tmp56_;
			BoxesProperty* _tmp57_;
#line 456 "/home/fborges/checkout/gnome-boxes/src/libvirt-machine-properties.vala"
			_tmp24_ = (GtkLabel*) gtk_label_new ("");
#line 456 "/home/fborges/checkout/gnome-boxes/src/libvirt-machine-properties.vala"
			g_object_ref_sink (_tmp24_);
#line 456 "/home/fborges/checkout/gnome-boxes/src/libvirt-machine-properties.vala"
			label = _tmp24_;
#line 457 "/home/fborges/checkout/gnome-boxes/src/libvirt-machine-properties.vala"
			_tmp25_ = volume_info;
#line 457 "/home/fborges/checkout/gnome-boxes/src/libvirt-machine-properties.vala"
			_tmp26_ = _tmp25_->capacity;
#line 457 "/home/fborges/checkout/gnome-boxes/src/libvirt-machine-properties.vala"
			_tmp27_ = g_format_size_full (_tmp26_, G_FORMAT_SIZE_DEFAULT);
#line 457 "/home/fborges/checkout/gnome-boxes/src/libvirt-machine-properties.vala"
			capacity = _tmp27_;
#line 458 "/home/fborges/checkout/gnome-boxes/src/libvirt-machine-properties.vala"
			_tmp28_ = volume_info;
#line 458 "/home/fborges/checkout/gnome-boxes/src/libvirt-machine-properties.vala"
			_tmp29_ = _tmp28_->allocation;
#line 458 "/home/fborges/checkout/gnome-boxes/src/libvirt-machine-properties.vala"
			_tmp30_ = g_format_size_full (_tmp29_, G_FORMAT_SIZE_DEFAULT);
#line 458 "/home/fborges/checkout/gnome-boxes/src/libvirt-machine-properties.vala"
			allocation = _tmp30_;
#line 459 "/home/fborges/checkout/gnome-boxes/src/libvirt-machine-properties.vala"
			_tmp31_ = capacity;
#line 459 "/home/fborges/checkout/gnome-boxes/src/libvirt-machine-properties.vala"
			_tmp32_ = allocation;
#line 459 "/home/fborges/checkout/gnome-boxes/src/libvirt-machine-properties.vala"
			_tmp33_ = g_strdup_printf (_ ("<span color=\"grey\">Maximum Disk Size</span>\t\t %s <span color=\"gre" \
"y\">(%s used)</span>"), _tmp31_, _tmp32_);
#line 459 "/home/fborges/checkout/gnome-boxes/src/libvirt-machine-properties.vala"
			markup = _tmp33_;
#line 460 "/home/fborges/checkout/gnome-boxes/src/libvirt-machine-properties.vala"
			_tmp34_ = label;
#line 460 "/home/fborges/checkout/gnome-boxes/src/libvirt-machine-properties.vala"
			_tmp35_ = markup;
#line 460 "/home/fborges/checkout/gnome-boxes/src/libvirt-machine-properties.vala"
			gtk_label_set_markup (_tmp34_, _tmp35_);
#line 461 "/home/fborges/checkout/gnome-boxes/src/libvirt-machine-properties.vala"
			_tmp36_ = label;
#line 461 "/home/fborges/checkout/gnome-boxes/src/libvirt-machine-properties.vala"
			gtk_widget_set_halign ((GtkWidget*) _tmp36_, GTK_ALIGN_START);
#line 463 "/home/fborges/checkout/gnome-boxes/src/libvirt-machine-properties.vala"
			_tmp37_ = label;
#line 463 "/home/fborges/checkout/gnome-boxes/src/libvirt-machine-properties.vala"
			_tmp38_ = boxes_iproperties_provider_add_property ((BoxesIPropertiesProvider*) self, list, NULL, (GtkWidget*) _tmp37_, NULL);
#line 463 "/home/fborges/checkout/gnome-boxes/src/libvirt-machine-properties.vala"
			_tmp39_ = _tmp38_;
#line 463 "/home/fborges/checkout/gnome-boxes/src/libvirt-machine-properties.vala"
			_g_object_unref0 (_tmp39_);
#line 465 "/home/fborges/checkout/gnome-boxes/src/libvirt-machine-properties.vala"
			_tmp40_ = (GtkInfoBar*) gtk_info_bar_new ();
#line 465 "/home/fborges/checkout/gnome-boxes/src/libvirt-machine-properties.vala"
			g_object_ref_sink (_tmp40_);
#line 465 "/home/fborges/checkout/gnome-boxes/src/libvirt-machine-properties.vala"
			infobar = _tmp40_;
#line 466 "/home/fborges/checkout/gnome-boxes/src/libvirt-machine-properties.vala"
			_tmp41_ = infobar;
#line 466 "/home/fborges/checkout/gnome-boxes/src/libvirt-machine-properties.vala"
			gtk_info_bar_set_message_type (_tmp41_, GTK_MESSAGE_WARNING);
#line 468 "/home/fborges/checkout/gnome-boxes/src/libvirt-machine-properties.vala"
			_tmp42_ = infobar;
#line 468 "/home/fborges/checkout/gnome-boxes/src/libvirt-machine-properties.vala"
			_tmp43_ = gtk_info_bar_get_content_area (_tmp42_);
#line 468 "/home/fborges/checkout/gnome-boxes/src/libvirt-machine-properties.vala"
			_tmp44_ = _g_object_ref0 (_tmp43_);
#line 468 "/home/fborges/checkout/gnome-boxes/src/libvirt-machine-properties.vala"
			content = _tmp44_;
#line 470 "/home/fborges/checkout/gnome-boxes/src/libvirt-machine-properties.vala"
			_tmp45_ = (GtkImage*) gtk_image_new ();
#line 470 "/home/fborges/checkout/gnome-boxes/src/libvirt-machine-properties.vala"
			g_object_ref_sink (_tmp45_);
#line 470 "/home/fborges/checkout/gnome-boxes/src/libvirt-machine-properties.vala"
			image = _tmp45_;
#line 471 "/home/fborges/checkout/gnome-boxes/src/libvirt-machine-properties.vala"
			_tmp46_ = image;
#line 471 "/home/fborges/checkout/gnome-boxes/src/libvirt-machine-properties.vala"
			g_object_set (_tmp46_, "icon-name", "dialog-warning", NULL);
#line 472 "/home/fborges/checkout/gnome-boxes/src/libvirt-machine-properties.vala"
			_tmp47_ = image;
#line 472 "/home/fborges/checkout/gnome-boxes/src/libvirt-machine-properties.vala"
			g_object_set (_tmp47_, "icon-size", 3, NULL);
#line 473 "/home/fborges/checkout/gnome-boxes/src/libvirt-machine-properties.vala"
			_tmp48_ = content;
#line 473 "/home/fborges/checkout/gnome-boxes/src/libvirt-machine-properties.vala"
			_tmp49_ = image;
#line 473 "/home/fborges/checkout/gnome-boxes/src/libvirt-machine-properties.vala"
			gtk_container_add (_tmp48_, (GtkWidget*) _tmp49_);
#line 475 "/home/fborges/checkout/gnome-boxes/src/libvirt-machine-properties.vala"
			_tmp50_ = g_strdup (_ ("There is not enough space on your machine to increase the maximum disk" \
" size."));
#line 475 "/home/fborges/checkout/gnome-boxes/src/libvirt-machine-properties.vala"
			msg = _tmp50_;
#line 476 "/home/fborges/checkout/gnome-boxes/src/libvirt-machine-properties.vala"
			_tmp51_ = msg;
#line 476 "/home/fborges/checkout/gnome-boxes/src/libvirt-machine-properties.vala"
			_tmp52_ = (GtkLabel*) gtk_label_new (_tmp51_);
#line 476 "/home/fborges/checkout/gnome-boxes/src/libvirt-machine-properties.vala"
			g_object_ref_sink (_tmp52_);
#line 476 "/home/fborges/checkout/gnome-boxes/src/libvirt-machine-properties.vala"
			_g_object_unref0 (label);
#line 476 "/home/fborges/checkout/gnome-boxes/src/libvirt-machine-properties.vala"
			label = _tmp52_;
#line 477 "/home/fborges/checkout/gnome-boxes/src/libvirt-machine-properties.vala"
			_tmp53_ = content;
#line 477 "/home/fborges/checkout/gnome-boxes/src/libvirt-machine-properties.vala"
			_tmp54_ = label;
#line 477 "/home/fborges/checkout/gnome-boxes/src/libvirt-machine-properties.vala"
			gtk_container_add (_tmp53_, (GtkWidget*) _tmp54_);
#line 479 "/home/fborges/checkout/gnome-boxes/src/libvirt-machine-properties.vala"
			_tmp55_ = infobar;
#line 479 "/home/fborges/checkout/gnome-boxes/src/libvirt-machine-properties.vala"
			_tmp56_ = boxes_iproperties_provider_add_property ((BoxesIPropertiesProvider*) self, list, NULL, (GtkWidget*) _tmp55_, NULL);
#line 479 "/home/fborges/checkout/gnome-boxes/src/libvirt-machine-properties.vala"
			_tmp57_ = _tmp56_;
#line 479 "/home/fborges/checkout/gnome-boxes/src/libvirt-machine-properties.vala"
			_g_object_unref0 (_tmp57_);
#line 481 "/home/fborges/checkout/gnome-boxes/src/libvirt-machine-properties.vala"
			result = NULL;
#line 481 "/home/fborges/checkout/gnome-boxes/src/libvirt-machine-properties.vala"
			_g_free0 (msg);
#line 481 "/home/fborges/checkout/gnome-boxes/src/libvirt-machine-properties.vala"
			_g_object_unref0 (image);
#line 481 "/home/fborges/checkout/gnome-boxes/src/libvirt-machine-properties.vala"
			_g_object_unref0 (content);
#line 481 "/home/fborges/checkout/gnome-boxes/src/libvirt-machine-properties.vala"
			_g_object_unref0 (infobar);
#line 481 "/home/fborges/checkout/gnome-boxes/src/libvirt-machine-properties.vala"
			_g_free0 (markup);
#line 481 "/home/fborges/checkout/gnome-boxes/src/libvirt-machine-properties.vala"
			_g_free0 (allocation);
#line 481 "/home/fborges/checkout/gnome-boxes/src/libvirt-machine-properties.vala"
			_g_free0 (capacity);
#line 481 "/home/fborges/checkout/gnome-boxes/src/libvirt-machine-properties.vala"
			_g_object_unref0 (label);
#line 481 "/home/fborges/checkout/gnome-boxes/src/libvirt-machine-properties.vala"
			__vala_GVirStoragePoolInfo_free0 (pool_info);
#line 481 "/home/fborges/checkout/gnome-boxes/src/libvirt-machine-properties.vala"
			_g_object_unref0 (pool);
#line 481 "/home/fborges/checkout/gnome-boxes/src/libvirt-machine-properties.vala"
			__vala_GVirStorageVolInfo_free0 (volume_info);
#line 481 "/home/fborges/checkout/gnome-boxes/src/libvirt-machine-properties.vala"
			return result;
#line 5080 "libvirt-machine-properties.c"
		}
#line 484 "/home/fborges/checkout/gnome-boxes/src/libvirt-machine-properties.vala"
		_tmp58_ = volume_info;
#line 484 "/home/fborges/checkout/gnome-boxes/src/libvirt-machine-properties.vala"
		_tmp59_ = _tmp58_->capacity;
#line 484 "/home/fborges/checkout/gnome-boxes/src/libvirt-machine-properties.vala"
		_tmp60_ = min_storage;
#line 484 "/home/fborges/checkout/gnome-boxes/src/libvirt-machine-properties.vala"
		_tmp61_ = max_storage;
#line 484 "/home/fborges/checkout/gnome-boxes/src/libvirt-machine-properties.vala"
		_tmp62_ = volume_info;
#line 484 "/home/fborges/checkout/gnome-boxes/src/libvirt-machine-properties.vala"
		_tmp63_ = _tmp62_->allocation;
#line 484 "/home/fborges/checkout/gnome-boxes/src/libvirt-machine-properties.vala"
		_tmp64_ = boxes_iproperties_provider_add_size_property ((BoxesIPropertiesProvider*) self, list, _ ("Maximum _Disk Size: "), _tmp59_, _tmp60_, _tmp61_, _tmp63_, 256 * BOXES_LIBVIRT_MACHINE_PROPERTIES_MEGABYTES, G_FORMAT_SIZE_DEFAULT);
#line 484 "/home/fborges/checkout/gnome-boxes/src/libvirt-machine-properties.vala"
		property = _tmp64_;
#line 491 "/home/fborges/checkout/gnome-boxes/src/libvirt-machine-properties.vala"
		_tmp65_ = property;
#line 491 "/home/fborges/checkout/gnome-boxes/src/libvirt-machine-properties.vala"
		boxes_property_set_description_alignment ((BoxesProperty*) _tmp65_, GTK_ALIGN_START);
#line 495 "/home/fborges/checkout/gnome-boxes/src/libvirt-machine-properties.vala"
		_tmp66_ = property;
#line 495 "/home/fborges/checkout/gnome-boxes/src/libvirt-machine-properties.vala"
		boxes_property_set_defer_interval ((BoxesProperty*) _tmp66_, (guint) 0);
#line 496 "/home/fborges/checkout/gnome-boxes/src/libvirt-machine-properties.vala"
		_tmp70_ = self->priv->machine;
#line 496 "/home/fborges/checkout/gnome-boxes/src/libvirt-machine-properties.vala"
		_tmp71_ = boxes_libvirt_machine_get_domain_config (_tmp70_);
#line 496 "/home/fborges/checkout/gnome-boxes/src/libvirt-machine-properties.vala"
		_tmp72_ = _tmp71_;
#line 496 "/home/fborges/checkout/gnome-boxes/src/libvirt-machine-properties.vala"
		_tmp73_ = boxes_vm_configurator_is_install_config (_tmp72_);
#line 496 "/home/fborges/checkout/gnome-boxes/src/libvirt-machine-properties.vala"
		if (_tmp73_) {
#line 496 "/home/fborges/checkout/gnome-boxes/src/libvirt-machine-properties.vala"
			_tmp69_ = TRUE;
#line 5118 "libvirt-machine-properties.c"
		} else {
			BoxesLibvirtMachine* _tmp74_;
			GVirConfigDomain* _tmp75_;
			GVirConfigDomain* _tmp76_;
			gboolean _tmp77_;
#line 497 "/home/fborges/checkout/gnome-boxes/src/libvirt-machine-properties.vala"
			_tmp74_ = self->priv->machine;
#line 497 "/home/fborges/checkout/gnome-boxes/src/libvirt-machine-properties.vala"
			_tmp75_ = boxes_libvirt_machine_get_domain_config (_tmp74_);
#line 497 "/home/fborges/checkout/gnome-boxes/src/libvirt-machine-properties.vala"
			_tmp76_ = _tmp75_;
#line 497 "/home/fborges/checkout/gnome-boxes/src/libvirt-machine-properties.vala"
			_tmp77_ = boxes_vm_configurator_is_live_config (_tmp76_);
#line 497 "/home/fborges/checkout/gnome-boxes/src/libvirt-machine-properties.vala"
			_tmp69_ = _tmp77_;
#line 5134 "libvirt-machine-properties.c"
		}
#line 496 "/home/fborges/checkout/gnome-boxes/src/libvirt-machine-properties.vala"
		if (_tmp69_) {
#line 5138 "libvirt-machine-properties.c"
			BoxesLibvirtMachine* _tmp78_;
			BoxesAppWindow* _tmp79_;
			BoxesAppWindow* _tmp80_;
			BoxesUIState _tmp81_;
			BoxesUIState _tmp82_;
#line 498 "/home/fborges/checkout/gnome-boxes/src/libvirt-machine-properties.vala"
			_tmp78_ = self->priv->machine;
#line 498 "/home/fborges/checkout/gnome-boxes/src/libvirt-machine-properties.vala"
			_tmp79_ = boxes_machine_get_window ((BoxesMachine*) _tmp78_);
#line 498 "/home/fborges/checkout/gnome-boxes/src/libvirt-machine-properties.vala"
			_tmp80_ = _tmp79_;
#line 498 "/home/fborges/checkout/gnome-boxes/src/libvirt-machine-properties.vala"
			_tmp81_ = boxes_ui_get_ui_state ((BoxesUI*) _tmp80_);
#line 498 "/home/fborges/checkout/gnome-boxes/src/libvirt-machine-properties.vala"
			_tmp82_ = _tmp81_;
#line 498 "/home/fborges/checkout/gnome-boxes/src/libvirt-machine-properties.vala"
			_tmp68_ = _tmp82_ != BOXES_UI_STATE_WIZARD;
#line 5156 "libvirt-machine-properties.c"
		} else {
#line 496 "/home/fborges/checkout/gnome-boxes/src/libvirt-machine-properties.vala"
			_tmp68_ = FALSE;
#line 5160 "libvirt-machine-properties.c"
		}
#line 496 "/home/fborges/checkout/gnome-boxes/src/libvirt-machine-properties.vala"
		if (_tmp68_) {
#line 5164 "libvirt-machine-properties.c"
			BoxesLibvirtMachine* _tmp83_;
			BoxesMachineMachineState _tmp84_;
			BoxesMachineMachineState _tmp85_;
#line 499 "/home/fborges/checkout/gnome-boxes/src/libvirt-machine-properties.vala"
			_tmp83_ = self->priv->machine;
#line 499 "/home/fborges/checkout/gnome-boxes/src/libvirt-machine-properties.vala"
			_tmp84_ = boxes_machine_get_state ((BoxesMachine*) _tmp83_);
#line 499 "/home/fborges/checkout/gnome-boxes/src/libvirt-machine-properties.vala"
			_tmp85_ = _tmp84_;
#line 499 "/home/fborges/checkout/gnome-boxes/src/libvirt-machine-properties.vala"
			_tmp67_ = _tmp85_ != BOXES_MACHINE_MACHINE_STATE_FORCE_STOPPED;
#line 5176 "libvirt-machine-properties.c"
		} else {
#line 496 "/home/fborges/checkout/gnome-boxes/src/libvirt-machine-properties.vala"
			_tmp67_ = FALSE;
#line 5180 "libvirt-machine-properties.c"
		}
#line 496 "/home/fborges/checkout/gnome-boxes/src/libvirt-machine-properties.vala"
		if (_tmp67_) {
#line 5184 "libvirt-machine-properties.c"
			BoxesSizeProperty* _tmp86_;
#line 500 "/home/fborges/checkout/gnome-boxes/src/libvirt-machine-properties.vala"
			_tmp86_ = property;
#line 500 "/home/fborges/checkout/gnome-boxes/src/libvirt-machine-properties.vala"
			boxes_property_set_sensitive ((BoxesProperty*) _tmp86_, FALSE);
#line 5190 "libvirt-machine-properties.c"
		} else {
			BoxesSizeProperty* _tmp87_;
#line 502 "/home/fborges/checkout/gnome-boxes/src/libvirt-machine-properties.vala"
			_tmp87_ = property;
#line 502 "/home/fborges/checkout/gnome-boxes/src/libvirt-machine-properties.vala"
			g_signal_connect_object (_tmp87_, "changed", (GCallback) _boxes_libvirt_machine_properties_on_storage_changed_boxes_size_property_changed, self, 0);
#line 5197 "libvirt-machine-properties.c"
		}
#line 504 "/home/fborges/checkout/gnome-boxes/src/libvirt-machine-properties.vala"
		result = property;
#line 504 "/home/fborges/checkout/gnome-boxes/src/libvirt-machine-properties.vala"
		__vala_GVirStoragePoolInfo_free0 (pool_info);
#line 504 "/home/fborges/checkout/gnome-boxes/src/libvirt-machine-properties.vala"
		_g_object_unref0 (pool);
#line 504 "/home/fborges/checkout/gnome-boxes/src/libvirt-machine-properties.vala"
		__vala_GVirStorageVolInfo_free0 (volume_info);
#line 504 "/home/fborges/checkout/gnome-boxes/src/libvirt-machine-properties.vala"
		return result;
#line 5209 "libvirt-machine-properties.c"
	}
	goto __finally47;
	__catch47_g_error:
	{
		GError* _error_ = NULL;
		BoxesLibvirtMachine* _tmp88_;
		GVirStorageVol* _tmp89_;
		GVirStorageVol* _tmp90_;
		const gchar* _tmp91_;
		GError* _tmp92_;
		const gchar* _tmp93_;
#line 448 "/home/fborges/checkout/gnome-boxes/src/libvirt-machine-properties.vala"
		_error_ = _inner_error_;
#line 448 "/home/fborges/checkout/gnome-boxes/src/libvirt-machine-properties.vala"
		_inner_error_ = NULL;
#line 506 "/home/fborges/checkout/gnome-boxes/src/libvirt-machine-properties.vala"
		_tmp88_ = self->priv->machine;
#line 506 "/home/fborges/checkout/gnome-boxes/src/libvirt-machine-properties.vala"
		_tmp89_ = boxes_libvirt_machine_get_storage_volume (_tmp88_);
#line 506 "/home/fborges/checkout/gnome-boxes/src/libvirt-machine-properties.vala"
		_tmp90_ = _tmp89_;
#line 506 "/home/fborges/checkout/gnome-boxes/src/libvirt-machine-properties.vala"
		_tmp91_ = gvir_storage_vol_get_name (_tmp90_);
#line 506 "/home/fborges/checkout/gnome-boxes/src/libvirt-machine-properties.vala"
		_tmp92_ = _error_;
#line 506 "/home/fborges/checkout/gnome-boxes/src/libvirt-machine-properties.vala"
		_tmp93_ = _tmp92_->message;
#line 506 "/home/fborges/checkout/gnome-boxes/src/libvirt-machine-properties.vala"
		g_warning ("libvirt-machine-properties.vala:506: Failed to get information on volu" \
"me '%s' or it's parent pool: %s", _tmp91_, _tmp93_);
#line 509 "/home/fborges/checkout/gnome-boxes/src/libvirt-machine-properties.vala"
		result = NULL;
#line 509 "/home/fborges/checkout/gnome-boxes/src/libvirt-machine-properties.vala"
		_g_error_free0 (_error_);
#line 509 "/home/fborges/checkout/gnome-boxes/src/libvirt-machine-properties.vala"
		return result;
#line 5245 "libvirt-machine-properties.c"
	}
	__finally47:
#line 448 "/home/fborges/checkout/gnome-boxes/src/libvirt-machine-properties.vala"
	g_critical ("file %s: line %d: uncaught error: %s (%s, %d)", __FILE__, __LINE__, _inner_error_->message, g_quark_to_string (_inner_error_->domain), _inner_error_->code);
#line 448 "/home/fborges/checkout/gnome-boxes/src/libvirt-machine-properties.vala"
	g_clear_error (&_inner_error_);
#line 448 "/home/fborges/checkout/gnome-boxes/src/libvirt-machine-properties.vala"
	return NULL;
#line 5254 "libvirt-machine-properties.c"
}


static Block52Data* block52_data_ref (Block52Data* _data52_) {
#line 513 "/home/fborges/checkout/gnome-boxes/src/libvirt-machine-properties.vala"
	g_atomic_int_inc (&_data52_->_ref_count_);
#line 513 "/home/fborges/checkout/gnome-boxes/src/libvirt-machine-properties.vala"
	return _data52_;
#line 5263 "libvirt-machine-properties.c"
}


static void block52_data_unref (void * _userdata_) {
	Block52Data* _data52_;
	_data52_ = (Block52Data*) _userdata_;
#line 513 "/home/fborges/checkout/gnome-boxes/src/libvirt-machine-properties.vala"
	if (g_atomic_int_dec_and_test (&_data52_->_ref_count_)) {
#line 5272 "libvirt-machine-properties.c"
		BoxesLibvirtMachineProperties* self;
#line 513 "/home/fborges/checkout/gnome-boxes/src/libvirt-machine-properties.vala"
		self = _data52_->self;
#line 513 "/home/fborges/checkout/gnome-boxes/src/libvirt-machine-properties.vala"
		_g_object_unref0 (_data52_->property);
#line 513 "/home/fborges/checkout/gnome-boxes/src/libvirt-machine-properties.vala"
		_g_object_unref0 (self);
#line 513 "/home/fborges/checkout/gnome-boxes/src/libvirt-machine-properties.vala"
		g_slice_free (Block52Data, _data52_);
#line 5282 "libvirt-machine-properties.c"
	}
}


static gboolean __lambda136_ (Block52Data* _data52_) {
	BoxesLibvirtMachineProperties* self;
	gboolean result = FALSE;
	BoxesProperty* _tmp0_;
	guint64 _tmp1_;
#line 515 "/home/fborges/checkout/gnome-boxes/src/libvirt-machine-properties.vala"
	self = _data52_->self;
#line 516 "/home/fborges/checkout/gnome-boxes/src/libvirt-machine-properties.vala"
	_tmp0_ = _data52_->property;
#line 516 "/home/fborges/checkout/gnome-boxes/src/libvirt-machine-properties.vala"
	_tmp1_ = _data52_->value;
#line 516 "/home/fborges/checkout/gnome-boxes/src/libvirt-machine-properties.vala"
	boxes_libvirt_machine_properties_change_storage_size (self, _tmp0_, _tmp1_, NULL, NULL);
#line 518 "/home/fborges/checkout/gnome-boxes/src/libvirt-machine-properties.vala"
	result = FALSE;
#line 518 "/home/fborges/checkout/gnome-boxes/src/libvirt-machine-properties.vala"
	return result;
#line 5304 "libvirt-machine-properties.c"
}


static gboolean ___lambda136__gsource_func (gpointer self) {
	gboolean result;
	result = __lambda136_ (self);
#line 515 "/home/fborges/checkout/gnome-boxes/src/libvirt-machine-properties.vala"
	return result;
#line 5313 "libvirt-machine-properties.c"
}


static void boxes_libvirt_machine_properties_on_storage_changed (BoxesLibvirtMachineProperties* self, BoxesProperty* property, guint64 value) {
	Block52Data* _data52_;
	BoxesProperty* _tmp0_;
	BoxesProperty* _tmp1_;
	guint64 _tmp2_;
	BoxesProperty* _tmp3_;
#line 513 "/home/fborges/checkout/gnome-boxes/src/libvirt-machine-properties.vala"
	g_return_if_fail (self != NULL);
#line 513 "/home/fborges/checkout/gnome-boxes/src/libvirt-machine-properties.vala"
	g_return_if_fail (property != NULL);
#line 513 "/home/fborges/checkout/gnome-boxes/src/libvirt-machine-properties.vala"
	_data52_ = g_slice_new0 (Block52Data);
#line 513 "/home/fborges/checkout/gnome-boxes/src/libvirt-machine-properties.vala"
	_data52_->_ref_count_ = 1;
#line 513 "/home/fborges/checkout/gnome-boxes/src/libvirt-machine-properties.vala"
	_data52_->self = g_object_ref (self);
#line 513 "/home/fborges/checkout/gnome-boxes/src/libvirt-machine-properties.vala"
	_tmp0_ = property;
#line 513 "/home/fborges/checkout/gnome-boxes/src/libvirt-machine-properties.vala"
	_tmp1_ = _g_object_ref0 (_tmp0_);
#line 513 "/home/fborges/checkout/gnome-boxes/src/libvirt-machine-properties.vala"
	_g_object_unref0 (_data52_->property);
#line 513 "/home/fborges/checkout/gnome-boxes/src/libvirt-machine-properties.vala"
	_data52_->property = _tmp1_;
#line 513 "/home/fborges/checkout/gnome-boxes/src/libvirt-machine-properties.vala"
	_tmp2_ = value;
#line 513 "/home/fborges/checkout/gnome-boxes/src/libvirt-machine-properties.vala"
	_data52_->value = _tmp2_;
#line 515 "/home/fborges/checkout/gnome-boxes/src/libvirt-machine-properties.vala"
	_tmp3_ = _data52_->property;
#line 515 "/home/fborges/checkout/gnome-boxes/src/libvirt-machine-properties.vala"
	boxes_property_set_deferred_change (_tmp3_, ___lambda136__gsource_func, block52_data_ref (_data52_), block52_data_unref);
#line 513 "/home/fborges/checkout/gnome-boxes/src/libvirt-machine-properties.vala"
	block52_data_unref (_data52_);
#line 513 "/home/fborges/checkout/gnome-boxes/src/libvirt-machine-properties.vala"
	_data52_ = NULL;
#line 5353 "libvirt-machine-properties.c"
}


static void boxes_libvirt_machine_properties_change_storage_size_data_free (gpointer _data) {
	BoxesLibvirtMachinePropertiesChangeStorageSizeData* _data_;
	_data_ = _data;
#line 5 "/home/fborges/checkout/gnome-boxes/src/libvirt-machine-properties.vala"
	_g_object_unref0 (_data_->self);
#line 5 "/home/fborges/checkout/gnome-boxes/src/libvirt-machine-properties.vala"
	g_slice_free (BoxesLibvirtMachinePropertiesChangeStorageSizeData, _data_);
#line 5364 "libvirt-machine-properties.c"
}


static void boxes_libvirt_machine_properties_change_storage_size (BoxesLibvirtMachineProperties* self, BoxesProperty* property, guint64 value, GAsyncReadyCallback _callback_, gpointer _user_data_) {
	BoxesLibvirtMachinePropertiesChangeStorageSizeData* _data_;
	BoxesLibvirtMachineProperties* _tmp0_;
	BoxesProperty* _tmp1_;
	BoxesProperty* _tmp2_;
	guint64 _tmp3_;
#line 5 "/home/fborges/checkout/gnome-boxes/src/libvirt-machine-properties.vala"
	_data_ = g_slice_new0 (BoxesLibvirtMachinePropertiesChangeStorageSizeData);
#line 5 "/home/fborges/checkout/gnome-boxes/src/libvirt-machine-properties.vala"
	_data_->_async_result = g_task_new (G_OBJECT (self), NULL, _callback_, _user_data_);
#line 5 "/home/fborges/checkout/gnome-boxes/src/libvirt-machine-properties.vala"
	g_task_set_task_data (_data_->_async_result, _data_, boxes_libvirt_machine_properties_change_storage_size_data_free);
#line 5 "/home/fborges/checkout/gnome-boxes/src/libvirt-machine-properties.vala"
	_tmp0_ = _g_object_ref0 (self);
#line 5 "/home/fborges/checkout/gnome-boxes/src/libvirt-machine-properties.vala"
	_data_->self = _tmp0_;
#line 5 "/home/fborges/checkout/gnome-boxes/src/libvirt-machine-properties.vala"
	_tmp1_ = property;
#line 5 "/home/fborges/checkout/gnome-boxes/src/libvirt-machine-properties.vala"
	_tmp2_ = _g_object_ref0 (_tmp1_);
#line 5 "/home/fborges/checkout/gnome-boxes/src/libvirt-machine-properties.vala"
	_g_object_unref0 (_data_->property);
#line 5 "/home/fborges/checkout/gnome-boxes/src/libvirt-machine-properties.vala"
	_data_->property = _tmp2_;
#line 5 "/home/fborges/checkout/gnome-boxes/src/libvirt-machine-properties.vala"
	_tmp3_ = value;
#line 5 "/home/fborges/checkout/gnome-boxes/src/libvirt-machine-properties.vala"
	_data_->value = _tmp3_;
#line 5 "/home/fborges/checkout/gnome-boxes/src/libvirt-machine-properties.vala"
	boxes_libvirt_machine_properties_change_storage_size_co (_data_);
#line 5398 "libvirt-machine-properties.c"
}


static void boxes_libvirt_machine_properties_change_storage_size_finish (BoxesLibvirtMachineProperties* self, GAsyncResult* _res_) {
	BoxesLibvirtMachinePropertiesChangeStorageSizeData* _data_;
#line 5 "/home/fborges/checkout/gnome-boxes/src/libvirt-machine-properties.vala"
	_data_ = g_task_propagate_pointer (G_TASK (_res_), NULL);
#line 5406 "libvirt-machine-properties.c"
}


static Block53Data* block53_data_ref (Block53Data* _data53_) {
#line 522 "/home/fborges/checkout/gnome-boxes/src/libvirt-machine-properties.vala"
	g_atomic_int_inc (&_data53_->_ref_count_);
#line 522 "/home/fborges/checkout/gnome-boxes/src/libvirt-machine-properties.vala"
	return _data53_;
#line 5415 "libvirt-machine-properties.c"
}


static void block53_data_unref (void * _userdata_) {
	Block53Data* _data53_;
	_data53_ = (Block53Data*) _userdata_;
#line 522 "/home/fborges/checkout/gnome-boxes/src/libvirt-machine-properties.vala"
	if (g_atomic_int_dec_and_test (&_data53_->_ref_count_)) {
#line 5424 "libvirt-machine-properties.c"
		BoxesLibvirtMachineProperties* self;
#line 522 "/home/fborges/checkout/gnome-boxes/src/libvirt-machine-properties.vala"
		self = _data53_->self;
#line 522 "/home/fborges/checkout/gnome-boxes/src/libvirt-machine-properties.vala"
		_g_object_unref0 (_data53_->property);
#line 522 "/home/fborges/checkout/gnome-boxes/src/libvirt-machine-properties.vala"
		_g_object_unref0 (self);
#line 522 "/home/fborges/checkout/gnome-boxes/src/libvirt-machine-properties.vala"
		g_slice_free (Block53Data, _data53_);
#line 5434 "libvirt-machine-properties.c"
	}
}


static void boxes_libvirt_machine_properties_change_storage_size_ready (GObject* source_object, GAsyncResult* _res_, gpointer _user_data_) {
	BoxesLibvirtMachinePropertiesChangeStorageSizeData* _data_;
#line 528 "/home/fborges/checkout/gnome-boxes/src/libvirt-machine-properties.vala"
	_data_ = _user_data_;
#line 528 "/home/fborges/checkout/gnome-boxes/src/libvirt-machine-properties.vala"
	_data_->_source_object_ = source_object;
#line 528 "/home/fborges/checkout/gnome-boxes/src/libvirt-machine-properties.vala"
	_data_->_res_ = _res_;
#line 528 "/home/fborges/checkout/gnome-boxes/src/libvirt-machine-properties.vala"
	boxes_libvirt_machine_properties_change_storage_size_co (_data_);
#line 5449 "libvirt-machine-properties.c"
}


static void ___lambda137_ (BoxesLibvirtMachineProperties* self) {
	BoxesLibvirtMachine* _tmp0_;
	const gchar* _tmp1_;
	const gchar* _tmp2_;
#line 543 "/home/fborges/checkout/gnome-boxes/src/libvirt-machine-properties.vala"
	_tmp0_ = self->priv->machine;
#line 543 "/home/fborges/checkout/gnome-boxes/src/libvirt-machine-properties.vala"
	_tmp1_ = boxes_collection_item_get_name ((BoxesCollectionItem*) _tmp0_);
#line 543 "/home/fborges/checkout/gnome-boxes/src/libvirt-machine-properties.vala"
	_tmp2_ = _tmp1_;
#line 543 "/home/fborges/checkout/gnome-boxes/src/libvirt-machine-properties.vala"
	g_debug ("libvirt-machine-properties.vala:543: Storage resize of '%s' cancelled " \
"by user.", _tmp2_);
#line 5465 "libvirt-machine-properties.c"
}


static void ____lambda137__boxes_notification_ok_func (gpointer self) {
#line 542 "/home/fborges/checkout/gnome-boxes/src/libvirt-machine-properties.vala"
	___lambda137_ ((BoxesLibvirtMachineProperties*) self);
#line 5472 "libvirt-machine-properties.c"
}


static void ___lambda138_ (Block53Data* _data53_) {
	BoxesLibvirtMachineProperties* self;
	BoxesLibvirtMachine* _tmp0_;
	const gchar* _tmp1_;
	const gchar* _tmp2_;
	BoxesProperty* _tmp3_;
	guint64 _tmp4_;
#line 546 "/home/fborges/checkout/gnome-boxes/src/libvirt-machine-properties.vala"
	self = _data53_->self;
#line 547 "/home/fborges/checkout/gnome-boxes/src/libvirt-machine-properties.vala"
	_tmp0_ = self->priv->machine;
#line 547 "/home/fborges/checkout/gnome-boxes/src/libvirt-machine-properties.vala"
	_tmp1_ = boxes_collection_item_get_name ((BoxesCollectionItem*) _tmp0_);
#line 547 "/home/fborges/checkout/gnome-boxes/src/libvirt-machine-properties.vala"
	_tmp2_ = _tmp1_;
#line 547 "/home/fborges/checkout/gnome-boxes/src/libvirt-machine-properties.vala"
	g_debug ("libvirt-machine-properties.vala:547: User did not cancel storage resiz" \
"e of '%s'. Deleting all snapshots..", _tmp2_);
#line 548 "/home/fborges/checkout/gnome-boxes/src/libvirt-machine-properties.vala"
	_tmp3_ = _data53_->property;
#line 548 "/home/fborges/checkout/gnome-boxes/src/libvirt-machine-properties.vala"
	_tmp4_ = _data53_->value;
#line 548 "/home/fborges/checkout/gnome-boxes/src/libvirt-machine-properties.vala"
	boxes_libvirt_machine_properties_force_change_storage_size (self, _tmp3_, _tmp4_, NULL, NULL);
#line 5499 "libvirt-machine-properties.c"
}


static void ____lambda138__boxes_notification_dismiss_func (gpointer self) {
#line 546 "/home/fborges/checkout/gnome-boxes/src/libvirt-machine-properties.vala"
	___lambda138_ (self);
#line 5506 "libvirt-machine-properties.c"
}


static gboolean boxes_libvirt_machine_properties_change_storage_size_co (BoxesLibvirtMachinePropertiesChangeStorageSizeData* _data_) {
#line 522 "/home/fborges/checkout/gnome-boxes/src/libvirt-machine-properties.vala"
	switch (_data_->_state_) {
#line 522 "/home/fborges/checkout/gnome-boxes/src/libvirt-machine-properties.vala"
		case 0:
#line 5515 "libvirt-machine-properties.c"
		goto _state_0;
#line 522 "/home/fborges/checkout/gnome-boxes/src/libvirt-machine-properties.vala"
		case 1:
#line 5519 "libvirt-machine-properties.c"
		goto _state_1;
#line 522 "/home/fborges/checkout/gnome-boxes/src/libvirt-machine-properties.vala"
		case 2:
#line 5523 "libvirt-machine-properties.c"
		goto _state_2;
		default:
#line 522 "/home/fborges/checkout/gnome-boxes/src/libvirt-machine-properties.vala"
		g_assert_not_reached ();
#line 5528 "libvirt-machine-properties.c"
	}
	_state_0:
#line 522 "/home/fborges/checkout/gnome-boxes/src/libvirt-machine-properties.vala"
	_data_->_data53_ = g_slice_new0 (Block53Data);
#line 522 "/home/fborges/checkout/gnome-boxes/src/libvirt-machine-properties.vala"
	_data_->_data53_->_ref_count_ = 1;
#line 522 "/home/fborges/checkout/gnome-boxes/src/libvirt-machine-properties.vala"
	_data_->_data53_->self = g_object_ref (_data_->self);
#line 522 "/home/fborges/checkout/gnome-boxes/src/libvirt-machine-properties.vala"
	_data_->_tmp0_ = _data_->property;
#line 522 "/home/fborges/checkout/gnome-boxes/src/libvirt-machine-properties.vala"
	_g_object_unref0 (_data_->_data53_->property);
#line 522 "/home/fborges/checkout/gnome-boxes/src/libvirt-machine-properties.vala"
	_data_->_data53_->property = _data_->_tmp0_;
#line 522 "/home/fborges/checkout/gnome-boxes/src/libvirt-machine-properties.vala"
	_data_->_tmp1_ = _data_->value;
#line 522 "/home/fborges/checkout/gnome-boxes/src/libvirt-machine-properties.vala"
	_data_->_data53_->value = _data_->_tmp1_;
#line 522 "/home/fborges/checkout/gnome-boxes/src/libvirt-machine-properties.vala"
	_data_->_data53_->_async_data_ = _data_;
#line 523 "/home/fborges/checkout/gnome-boxes/src/libvirt-machine-properties.vala"
	_data_->_tmp2_ = _data_->self->priv->machine;
#line 523 "/home/fborges/checkout/gnome-boxes/src/libvirt-machine-properties.vala"
	_data_->_tmp3_ = boxes_libvirt_machine_get_storage_volume (_data_->_tmp2_);
#line 523 "/home/fborges/checkout/gnome-boxes/src/libvirt-machine-properties.vala"
	_data_->_tmp4_ = _data_->_tmp3_;
#line 523 "/home/fborges/checkout/gnome-boxes/src/libvirt-machine-properties.vala"
	if (_data_->_tmp4_ == NULL) {
#line 524 "/home/fborges/checkout/gnome-boxes/src/libvirt-machine-properties.vala"
		block53_data_unref (_data_->_data53_);
#line 524 "/home/fborges/checkout/gnome-boxes/src/libvirt-machine-properties.vala"
		_data_->_data53_ = NULL;
#line 524 "/home/fborges/checkout/gnome-boxes/src/libvirt-machine-properties.vala"
		g_task_return_pointer (_data_->_async_result, _data_, NULL);
#line 524 "/home/fborges/checkout/gnome-boxes/src/libvirt-machine-properties.vala"
		if (_data_->_state_ != 0) {
#line 524 "/home/fborges/checkout/gnome-boxes/src/libvirt-machine-properties.vala"
			while (g_task_get_completed (_data_->_async_result) != TRUE) {
#line 524 "/home/fborges/checkout/gnome-boxes/src/libvirt-machine-properties.vala"
				g_main_context_iteration (g_task_get_context (_data_->_async_result), TRUE);
#line 5569 "libvirt-machine-properties.c"
			}
		}
#line 524 "/home/fborges/checkout/gnome-boxes/src/libvirt-machine-properties.vala"
		g_object_unref (_data_->_async_result);
#line 524 "/home/fborges/checkout/gnome-boxes/src/libvirt-machine-properties.vala"
		return FALSE;
#line 5576 "libvirt-machine-properties.c"
	}
	{
#line 528 "/home/fborges/checkout/gnome-boxes/src/libvirt-machine-properties.vala"
		_data_->_state_ = 1;
#line 528 "/home/fborges/checkout/gnome-boxes/src/libvirt-machine-properties.vala"
		boxes_libvirt_machine_properties_get_snapshots (_data_->self, NULL, boxes_libvirt_machine_properties_change_storage_size_ready, _data_);
#line 528 "/home/fborges/checkout/gnome-boxes/src/libvirt-machine-properties.vala"
		return FALSE;
#line 5585 "libvirt-machine-properties.c"
		_state_1:
#line 528 "/home/fborges/checkout/gnome-boxes/src/libvirt-machine-properties.vala"
		_data_->_tmp6_ = boxes_libvirt_machine_properties_get_snapshots_finish (_data_->self, _data_->_res_, &_data_->_inner_error_);
#line 528 "/home/fborges/checkout/gnome-boxes/src/libvirt-machine-properties.vala"
		_data_->_tmp5_ = _data_->_tmp6_;
#line 528 "/home/fborges/checkout/gnome-boxes/src/libvirt-machine-properties.vala"
		if (G_UNLIKELY (_data_->_inner_error_ != NULL)) {
#line 5593 "libvirt-machine-properties.c"
			goto __catch48_g_error;
		}
#line 528 "/home/fborges/checkout/gnome-boxes/src/libvirt-machine-properties.vala"
		_data_->_tmp7_ = _data_->_tmp5_;
#line 528 "/home/fborges/checkout/gnome-boxes/src/libvirt-machine-properties.vala"
		_data_->_tmp5_ = NULL;
#line 528 "/home/fborges/checkout/gnome-boxes/src/libvirt-machine-properties.vala"
		__g_list_free__g_object_unref0_0 (_data_->snapshots);
#line 528 "/home/fborges/checkout/gnome-boxes/src/libvirt-machine-properties.vala"
		_data_->snapshots = _data_->_tmp7_;
#line 527 "/home/fborges/checkout/gnome-boxes/src/libvirt-machine-properties.vala"
		__g_list_free__g_object_unref0_0 (_data_->_tmp5_);
#line 5606 "libvirt-machine-properties.c"
	}
	goto __finally48;
	__catch48_g_error:
	{
#line 527 "/home/fborges/checkout/gnome-boxes/src/libvirt-machine-properties.vala"
		_data_->e = _data_->_inner_error_;
#line 527 "/home/fborges/checkout/gnome-boxes/src/libvirt-machine-properties.vala"
		_data_->_inner_error_ = NULL;
#line 530 "/home/fborges/checkout/gnome-boxes/src/libvirt-machine-properties.vala"
		_data_->_tmp8_ = _data_->self->priv->machine;
#line 530 "/home/fborges/checkout/gnome-boxes/src/libvirt-machine-properties.vala"
		_data_->_tmp9_ = boxes_collection_item_get_name ((BoxesCollectionItem*) _data_->_tmp8_);
#line 530 "/home/fborges/checkout/gnome-boxes/src/libvirt-machine-properties.vala"
		_data_->_tmp10_ = _data_->_tmp9_;
#line 530 "/home/fborges/checkout/gnome-boxes/src/libvirt-machine-properties.vala"
		_data_->_tmp11_ = _data_->e;
#line 530 "/home/fborges/checkout/gnome-boxes/src/libvirt-machine-properties.vala"
		_data_->_tmp12_ = _data_->_tmp11_->message;
#line 530 "/home/fborges/checkout/gnome-boxes/src/libvirt-machine-properties.vala"
		g_warning ("libvirt-machine-properties.vala:530: Error fetching snapshots for %s: " \
"%s", _data_->_tmp10_, _data_->_tmp12_);
#line 531 "/home/fborges/checkout/gnome-boxes/src/libvirt-machine-properties.vala"
		__g_list_free__g_object_unref0_0 (_data_->snapshots);
#line 531 "/home/fborges/checkout/gnome-boxes/src/libvirt-machine-properties.vala"
		_data_->snapshots = NULL;
#line 527 "/home/fborges/checkout/gnome-boxes/src/libvirt-machine-properties.vala"
		_g_error_free0 (_data_->e);
#line 5633 "libvirt-machine-properties.c"
	}
	__finally48:
#line 527 "/home/fborges/checkout/gnome-boxes/src/libvirt-machine-properties.vala"
	if (G_UNLIKELY (_data_->_inner_error_ != NULL)) {
#line 527 "/home/fborges/checkout/gnome-boxes/src/libvirt-machine-properties.vala"
		__g_list_free__g_object_unref0_0 (_data_->snapshots);
#line 527 "/home/fborges/checkout/gnome-boxes/src/libvirt-machine-properties.vala"
		block53_data_unref (_data_->_data53_);
#line 527 "/home/fborges/checkout/gnome-boxes/src/libvirt-machine-properties.vala"
		_data_->_data53_ = NULL;
#line 527 "/home/fborges/checkout/gnome-boxes/src/libvirt-machine-properties.vala"
		g_critical ("file %s: line %d: uncaught error: %s (%s, %d)", __FILE__, __LINE__, _data_->_inner_error_->message, g_quark_to_string (_data_->_inner_error_->domain), _data_->_inner_error_->code);
#line 527 "/home/fborges/checkout/gnome-boxes/src/libvirt-machine-properties.vala"
		g_clear_error (&_data_->_inner_error_);
#line 527 "/home/fborges/checkout/gnome-boxes/src/libvirt-machine-properties.vala"
		g_object_unref (_data_->_async_result);
#line 527 "/home/fborges/checkout/gnome-boxes/src/libvirt-machine-properties.vala"
		return FALSE;
#line 5652 "libvirt-machine-properties.c"
	}
#line 534 "/home/fborges/checkout/gnome-boxes/src/libvirt-machine-properties.vala"
	_data_->_tmp13_ = _data_->snapshots;
#line 534 "/home/fborges/checkout/gnome-boxes/src/libvirt-machine-properties.vala"
	_data_->_tmp14_ = g_list_length (_data_->_tmp13_);
#line 534 "/home/fborges/checkout/gnome-boxes/src/libvirt-machine-properties.vala"
	_data_->num_snapshots = _data_->_tmp14_;
#line 535 "/home/fborges/checkout/gnome-boxes/src/libvirt-machine-properties.vala"
	_data_->_tmp15_ = _data_->num_snapshots;
#line 535 "/home/fborges/checkout/gnome-boxes/src/libvirt-machine-properties.vala"
	if (_data_->_tmp15_ != ((guint) 0)) {
#line 538 "/home/fborges/checkout/gnome-boxes/src/libvirt-machine-properties.vala"
		_data_->_tmp16_ = _data_->num_snapshots;
#line 538 "/home/fborges/checkout/gnome-boxes/src/libvirt-machine-properties.vala"
		_data_->_tmp17_ = _data_->num_snapshots;
#line 538 "/home/fborges/checkout/gnome-boxes/src/libvirt-machine-properties.vala"
		_data_->_tmp18_ = g_strdup_printf (ngettext ("Storage resize requires deleting associated snapshot.", "Storage resize requires deleting %llu associated snapshots.", (gulong) _data_->_tmp16_), _data_->_tmp17_);
#line 538 "/home/fborges/checkout/gnome-boxes/src/libvirt-machine-properties.vala"
		_data_->msg = _data_->_tmp18_;
#line 542 "/home/fborges/checkout/gnome-boxes/src/libvirt-machine-properties.vala"
		_data_->undo = ____lambda137__boxes_notification_ok_func;
#line 542 "/home/fborges/checkout/gnome-boxes/src/libvirt-machine-properties.vala"
		_data_->undo_target = g_object_ref (_data_->self);
#line 542 "/home/fborges/checkout/gnome-boxes/src/libvirt-machine-properties.vala"
		_data_->undo_target_destroy_notify = g_object_unref;
#line 546 "/home/fborges/checkout/gnome-boxes/src/libvirt-machine-properties.vala"
		_data_->really_resize = ____lambda138__boxes_notification_dismiss_func;
#line 546 "/home/fborges/checkout/gnome-boxes/src/libvirt-machine-properties.vala"
		_data_->really_resize_target = block53_data_ref (_data_->_data53_);
#line 546 "/home/fborges/checkout/gnome-boxes/src/libvirt-machine-properties.vala"
		_data_->really_resize_target_destroy_notify = block53_data_unref;
#line 551 "/home/fborges/checkout/gnome-boxes/src/libvirt-machine-properties.vala"
		_data_->_tmp19_ = _data_->self->priv->machine;
#line 551 "/home/fborges/checkout/gnome-boxes/src/libvirt-machine-properties.vala"
		_data_->_tmp20_ = boxes_machine_get_window ((BoxesMachine*) _data_->_tmp19_);
#line 551 "/home/fborges/checkout/gnome-boxes/src/libvirt-machine-properties.vala"
		_data_->_tmp21_ = _data_->_tmp20_;
#line 551 "/home/fborges/checkout/gnome-boxes/src/libvirt-machine-properties.vala"
		_data_->_tmp22_ = boxes_app_window_get_notificationbar (_data_->_tmp21_);
#line 551 "/home/fborges/checkout/gnome-boxes/src/libvirt-machine-properties.vala"
		_data_->_tmp23_ = _data_->_tmp22_;
#line 551 "/home/fborges/checkout/gnome-boxes/src/libvirt-machine-properties.vala"
		_data_->_tmp24_ = _data_->msg;
#line 551 "/home/fborges/checkout/gnome-boxes/src/libvirt-machine-properties.vala"
		_data_->_tmp25_ = _data_->undo;
#line 551 "/home/fborges/checkout/gnome-boxes/src/libvirt-machine-properties.vala"
		_data_->_tmp25__target = _data_->undo_target;
#line 551 "/home/fborges/checkout/gnome-boxes/src/libvirt-machine-properties.vala"
		_data_->_tmp25__target_destroy_notify = _data_->undo_target_destroy_notify;
#line 551 "/home/fborges/checkout/gnome-boxes/src/libvirt-machine-properties.vala"
		_data_->undo = NULL;
#line 551 "/home/fborges/checkout/gnome-boxes/src/libvirt-machine-properties.vala"
		_data_->undo_target = NULL;
#line 551 "/home/fborges/checkout/gnome-boxes/src/libvirt-machine-properties.vala"
		_data_->undo_target_destroy_notify = NULL;
#line 551 "/home/fborges/checkout/gnome-boxes/src/libvirt-machine-properties.vala"
		_data_->_tmp26_ = _data_->really_resize;
#line 551 "/home/fborges/checkout/gnome-boxes/src/libvirt-machine-properties.vala"
		_data_->_tmp26__target = _data_->really_resize_target;
#line 551 "/home/fborges/checkout/gnome-boxes/src/libvirt-machine-properties.vala"
		_data_->_tmp26__target_destroy_notify = _data_->really_resize_target_destroy_notify;
#line 551 "/home/fborges/checkout/gnome-boxes/src/libvirt-machine-properties.vala"
		_data_->really_resize = NULL;
#line 551 "/home/fborges/checkout/gnome-boxes/src/libvirt-machine-properties.vala"
		_data_->really_resize_target = NULL;
#line 551 "/home/fborges/checkout/gnome-boxes/src/libvirt-machine-properties.vala"
		_data_->really_resize_target_destroy_notify = NULL;
#line 551 "/home/fborges/checkout/gnome-boxes/src/libvirt-machine-properties.vala"
		_data_->_tmp27_ = boxes_notificationbar_display_for_action (_data_->_tmp23_, _data_->_tmp24_, _ ("_Undo"), _data_->_tmp25_, _data_->_tmp25__target, _data_->_tmp25__target_destroy_notify, _data_->_tmp26_, _data_->_tmp26__target, _data_->_tmp26__target_destroy_notify, BOXES_NOTIFICATIONBAR_DEFAULT_TIMEOUT);
#line 551 "/home/fborges/checkout/gnome-boxes/src/libvirt-machine-properties.vala"
		_data_->_tmp28_ = _data_->_tmp27_;
#line 551 "/home/fborges/checkout/gnome-boxes/src/libvirt-machine-properties.vala"
		_g_object_unref0 (_data_->_tmp28_);
#line 553 "/home/fborges/checkout/gnome-boxes/src/libvirt-machine-properties.vala"
		(_data_->really_resize_target_destroy_notify == NULL) ? NULL : (_data_->really_resize_target_destroy_notify (_data_->really_resize_target), NULL);
#line 553 "/home/fborges/checkout/gnome-boxes/src/libvirt-machine-properties.vala"
		_data_->really_resize = NULL;
#line 553 "/home/fborges/checkout/gnome-boxes/src/libvirt-machine-properties.vala"
		_data_->really_resize_target = NULL;
#line 553 "/home/fborges/checkout/gnome-boxes/src/libvirt-machine-properties.vala"
		_data_->really_resize_target_destroy_notify = NULL;
#line 553 "/home/fborges/checkout/gnome-boxes/src/libvirt-machine-properties.vala"
		(_data_->undo_target_destroy_notify == NULL) ? NULL : (_data_->undo_target_destroy_notify (_data_->undo_target), NULL);
#line 553 "/home/fborges/checkout/gnome-boxes/src/libvirt-machine-properties.vala"
		_data_->undo = NULL;
#line 553 "/home/fborges/checkout/gnome-boxes/src/libvirt-machine-properties.vala"
		_data_->undo_target = NULL;
#line 553 "/home/fborges/checkout/gnome-boxes/src/libvirt-machine-properties.vala"
		_data_->undo_target_destroy_notify = NULL;
#line 553 "/home/fborges/checkout/gnome-boxes/src/libvirt-machine-properties.vala"
		_g_free0 (_data_->msg);
#line 553 "/home/fborges/checkout/gnome-boxes/src/libvirt-machine-properties.vala"
		__g_list_free__g_object_unref0_0 (_data_->snapshots);
#line 553 "/home/fborges/checkout/gnome-boxes/src/libvirt-machine-properties.vala"
		block53_data_unref (_data_->_data53_);
#line 553 "/home/fborges/checkout/gnome-boxes/src/libvirt-machine-properties.vala"
		_data_->_data53_ = NULL;
#line 553 "/home/fborges/checkout/gnome-boxes/src/libvirt-machine-properties.vala"
		g_task_return_pointer (_data_->_async_result, _data_, NULL);
#line 553 "/home/fborges/checkout/gnome-boxes/src/libvirt-machine-properties.vala"
		if (_data_->_state_ != 0) {
#line 553 "/home/fborges/checkout/gnome-boxes/src/libvirt-machine-properties.vala"
			while (g_task_get_completed (_data_->_async_result) != TRUE) {
#line 553 "/home/fborges/checkout/gnome-boxes/src/libvirt-machine-properties.vala"
				g_main_context_iteration (g_task_get_context (_data_->_async_result), TRUE);
#line 5758 "libvirt-machine-properties.c"
			}
		}
#line 553 "/home/fborges/checkout/gnome-boxes/src/libvirt-machine-properties.vala"
		g_object_unref (_data_->_async_result);
#line 553 "/home/fborges/checkout/gnome-boxes/src/libvirt-machine-properties.vala"
		return FALSE;
#line 5765 "libvirt-machine-properties.c"
	}
	{
#line 557 "/home/fborges/checkout/gnome-boxes/src/libvirt-machine-properties.vala"
		_data_->_tmp29_ = _data_->self->priv->machine;
#line 557 "/home/fborges/checkout/gnome-boxes/src/libvirt-machine-properties.vala"
		_data_->_tmp30_ = boxes_machine_get_is_running ((BoxesMachine*) _data_->_tmp29_);
#line 557 "/home/fborges/checkout/gnome-boxes/src/libvirt-machine-properties.vala"
		_data_->_tmp31_ = _data_->_tmp30_;
#line 557 "/home/fborges/checkout/gnome-boxes/src/libvirt-machine-properties.vala"
		if (_data_->_tmp31_) {
#line 558 "/home/fborges/checkout/gnome-boxes/src/libvirt-machine-properties.vala"
			_data_->_tmp32_ = _data_->self->priv->machine;
#line 558 "/home/fborges/checkout/gnome-boxes/src/libvirt-machine-properties.vala"
			_data_->_tmp33_ = boxes_libvirt_machine_get_domain_disk (_data_->_tmp32_, &_data_->_inner_error_);
#line 558 "/home/fborges/checkout/gnome-boxes/src/libvirt-machine-properties.vala"
			_data_->disk = _data_->_tmp33_;
#line 558 "/home/fborges/checkout/gnome-boxes/src/libvirt-machine-properties.vala"
			if (G_UNLIKELY (_data_->_inner_error_ != NULL)) {
#line 5784 "libvirt-machine-properties.c"
				goto __catch49_g_error;
			}
#line 559 "/home/fborges/checkout/gnome-boxes/src/libvirt-machine-properties.vala"
			_data_->_tmp34_ = _data_->disk;
#line 559 "/home/fborges/checkout/gnome-boxes/src/libvirt-machine-properties.vala"
			if (_data_->_tmp34_ == NULL) {
#line 560 "/home/fborges/checkout/gnome-boxes/src/libvirt-machine-properties.vala"
				_g_object_unref0 (_data_->disk);
#line 560 "/home/fborges/checkout/gnome-boxes/src/libvirt-machine-properties.vala"
				__g_list_free__g_object_unref0_0 (_data_->snapshots);
#line 560 "/home/fborges/checkout/gnome-boxes/src/libvirt-machine-properties.vala"
				block53_data_unref (_data_->_data53_);
#line 560 "/home/fborges/checkout/gnome-boxes/src/libvirt-machine-properties.vala"
				_data_->_data53_ = NULL;
#line 560 "/home/fborges/checkout/gnome-boxes/src/libvirt-machine-properties.vala"
				g_task_return_pointer (_data_->_async_result, _data_, NULL);
#line 560 "/home/fborges/checkout/gnome-boxes/src/libvirt-machine-properties.vala"
				if (_data_->_state_ != 0) {
#line 560 "/home/fborges/checkout/gnome-boxes/src/libvirt-machine-properties.vala"
					while (g_task_get_completed (_data_->_async_result) != TRUE) {
#line 560 "/home/fborges/checkout/gnome-boxes/src/libvirt-machine-properties.vala"
						g_main_context_iteration (g_task_get_context (_data_->_async_result), TRUE);
#line 5807 "libvirt-machine-properties.c"
					}
				}
#line 560 "/home/fborges/checkout/gnome-boxes/src/libvirt-machine-properties.vala"
				g_object_unref (_data_->_async_result);
#line 560 "/home/fborges/checkout/gnome-boxes/src/libvirt-machine-properties.vala"
				return FALSE;
#line 5814 "libvirt-machine-properties.c"
			}
#line 562 "/home/fborges/checkout/gnome-boxes/src/libvirt-machine-properties.vala"
			_data_->_tmp35_ = _data_->_data53_->value;
#line 562 "/home/fborges/checkout/gnome-boxes/src/libvirt-machine-properties.vala"
			_data_->size = ((_data_->_tmp35_ + OSINFO_KIBIBYTES) - 1) / OSINFO_KIBIBYTES;
#line 563 "/home/fborges/checkout/gnome-boxes/src/libvirt-machine-properties.vala"
			_data_->_tmp36_ = _data_->disk;
#line 563 "/home/fborges/checkout/gnome-boxes/src/libvirt-machine-properties.vala"
			_data_->_tmp37_ = _data_->size;
#line 563 "/home/fborges/checkout/gnome-boxes/src/libvirt-machine-properties.vala"
			gvir_domain_disk_resize (_data_->_tmp36_, _data_->_tmp37_, (guint) 0, &_data_->_inner_error_);
#line 563 "/home/fborges/checkout/gnome-boxes/src/libvirt-machine-properties.vala"
			if (G_UNLIKELY (_data_->_inner_error_ != NULL)) {
#line 563 "/home/fborges/checkout/gnome-boxes/src/libvirt-machine-properties.vala"
				_g_object_unref0 (_data_->disk);
#line 5830 "libvirt-machine-properties.c"
				goto __catch49_g_error;
			}
#line 565 "/home/fborges/checkout/gnome-boxes/src/libvirt-machine-properties.vala"
			_data_->_tmp38_ = _data_->self->priv->machine;
#line 565 "/home/fborges/checkout/gnome-boxes/src/libvirt-machine-properties.vala"
			_data_->_tmp39_ = boxes_libvirt_machine_get_connection (_data_->_tmp38_);
#line 565 "/home/fborges/checkout/gnome-boxes/src/libvirt-machine-properties.vala"
			_data_->_tmp40_ = _data_->_tmp39_;
#line 565 "/home/fborges/checkout/gnome-boxes/src/libvirt-machine-properties.vala"
			_data_->_tmp41_ = boxes_get_storage_pool (_data_->_tmp40_);
#line 565 "/home/fborges/checkout/gnome-boxes/src/libvirt-machine-properties.vala"
			_data_->pool = _data_->_tmp41_;
#line 5843 "libvirt-machine-properties.c"
			{
#line 567 "/home/fborges/checkout/gnome-boxes/src/libvirt-machine-properties.vala"
				_data_->_tmp42_ = _data_->pool;
#line 567 "/home/fborges/checkout/gnome-boxes/src/libvirt-machine-properties.vala"
				_data_->_state_ = 2;
#line 567 "/home/fborges/checkout/gnome-boxes/src/libvirt-machine-properties.vala"
				gvir_storage_pool_refresh_async (_data_->_tmp42_, NULL, boxes_libvirt_machine_properties_change_storage_size_ready, _data_);
#line 567 "/home/fborges/checkout/gnome-boxes/src/libvirt-machine-properties.vala"
				return FALSE;
#line 5853 "libvirt-machine-properties.c"
				_state_2:
#line 567 "/home/fborges/checkout/gnome-boxes/src/libvirt-machine-properties.vala"
				gvir_storage_pool_refresh_finish (_data_->_tmp42_, _data_->_res_, &_data_->_inner_error_);
#line 567 "/home/fborges/checkout/gnome-boxes/src/libvirt-machine-properties.vala"
				if (G_UNLIKELY (_data_->_inner_error_ != NULL)) {
#line 5859 "libvirt-machine-properties.c"
					goto __catch50_g_error;
				}
#line 568 "/home/fborges/checkout/gnome-boxes/src/libvirt-machine-properties.vala"
				_data_->_tmp43_ = _data_->self->priv->machine;
#line 568 "/home/fborges/checkout/gnome-boxes/src/libvirt-machine-properties.vala"
				boxes_libvirt_machine_update_domain_config (_data_->_tmp43_);
#line 569 "/home/fborges/checkout/gnome-boxes/src/libvirt-machine-properties.vala"
				_data_->_tmp44_ = _data_->size;
#line 569 "/home/fborges/checkout/gnome-boxes/src/libvirt-machine-properties.vala"
				g_debug ("libvirt-machine-properties.vala:569: Storage changed to %llu KiB", _data_->_tmp44_);
#line 5870 "libvirt-machine-properties.c"
			}
			goto __finally50;
			__catch50_g_error:
			{
#line 566 "/home/fborges/checkout/gnome-boxes/src/libvirt-machine-properties.vala"
				_data_->_error_ = _data_->_inner_error_;
#line 566 "/home/fborges/checkout/gnome-boxes/src/libvirt-machine-properties.vala"
				_data_->_inner_error_ = NULL;
#line 571 "/home/fborges/checkout/gnome-boxes/src/libvirt-machine-properties.vala"
				_data_->_tmp45_ = _data_->self->priv->machine;
#line 571 "/home/fborges/checkout/gnome-boxes/src/libvirt-machine-properties.vala"
				_data_->_tmp46_ = boxes_libvirt_machine_get_storage_volume (_data_->_tmp45_);
#line 571 "/home/fborges/checkout/gnome-boxes/src/libvirt-machine-properties.vala"
				_data_->_tmp47_ = _data_->_tmp46_;
#line 571 "/home/fborges/checkout/gnome-boxes/src/libvirt-machine-properties.vala"
				_data_->_tmp48_ = gvir_storage_vol_get_name (_data_->_tmp47_);
#line 571 "/home/fborges/checkout/gnome-boxes/src/libvirt-machine-properties.vala"
				_data_->_tmp49_ = _data_->size;
#line 571 "/home/fborges/checkout/gnome-boxes/src/libvirt-machine-properties.vala"
				_data_->_tmp50_ = _data_->_error_;
#line 571 "/home/fborges/checkout/gnome-boxes/src/libvirt-machine-properties.vala"
				_data_->_tmp51_ = _data_->_tmp50_->message;
#line 571 "/home/fborges/checkout/gnome-boxes/src/libvirt-machine-properties.vala"
				g_warning ("libvirt-machine-properties.vala:571: Failed to change storage capacity" \
" of volume '%s' to %llu KiB: %s", _data_->_tmp48_, _data_->_tmp49_, _data_->_tmp51_);
#line 566 "/home/fborges/checkout/gnome-boxes/src/libvirt-machine-properties.vala"
				_g_error_free0 (_data_->_error_);
#line 5897 "libvirt-machine-properties.c"
			}
			__finally50:
#line 566 "/home/fborges/checkout/gnome-boxes/src/libvirt-machine-properties.vala"
			if (G_UNLIKELY (_data_->_inner_error_ != NULL)) {
#line 566 "/home/fborges/checkout/gnome-boxes/src/libvirt-machine-properties.vala"
				_g_object_unref0 (_data_->pool);
#line 566 "/home/fborges/checkout/gnome-boxes/src/libvirt-machine-properties.vala"
				_g_object_unref0 (_data_->disk);
#line 5906 "libvirt-machine-properties.c"
				goto __catch49_g_error;
			}
#line 557 "/home/fborges/checkout/gnome-boxes/src/libvirt-machine-properties.vala"
			_g_object_unref0 (_data_->pool);
#line 557 "/home/fborges/checkout/gnome-boxes/src/libvirt-machine-properties.vala"
			_g_object_unref0 (_data_->disk);
#line 5913 "libvirt-machine-properties.c"
		} else {
#line 577 "/home/fborges/checkout/gnome-boxes/src/libvirt-machine-properties.vala"
			_data_->_tmp52_ = _data_->_data53_->value;
#line 577 "/home/fborges/checkout/gnome-boxes/src/libvirt-machine-properties.vala"
			boxes_libvirt_machine_properties_resize_storage_volume (_data_->self, _data_->_tmp52_, &_data_->_inner_error_);
#line 577 "/home/fborges/checkout/gnome-boxes/src/libvirt-machine-properties.vala"
			if (G_UNLIKELY (_data_->_inner_error_ != NULL)) {
#line 5921 "libvirt-machine-properties.c"
				goto __catch49_g_error;
			}
#line 578 "/home/fborges/checkout/gnome-boxes/src/libvirt-machine-properties.vala"
			_data_->_tmp53_ = _data_->_data53_->value;
#line 578 "/home/fborges/checkout/gnome-boxes/src/libvirt-machine-properties.vala"
			g_debug ("libvirt-machine-properties.vala:578: Storage changed to %llu", _data_->_tmp53_);
#line 5928 "libvirt-machine-properties.c"
		}
	}
	goto __finally49;
	__catch49_g_error:
	{
#line 556 "/home/fborges/checkout/gnome-boxes/src/libvirt-machine-properties.vala"
		_data_->_vala1__error_ = _data_->_inner_error_;
#line 556 "/home/fborges/checkout/gnome-boxes/src/libvirt-machine-properties.vala"
		_data_->_inner_error_ = NULL;
#line 581 "/home/fborges/checkout/gnome-boxes/src/libvirt-machine-properties.vala"
		_data_->_tmp54_ = _data_->self->priv->machine;
#line 581 "/home/fborges/checkout/gnome-boxes/src/libvirt-machine-properties.vala"
		_data_->_tmp55_ = boxes_libvirt_machine_get_storage_volume (_data_->_tmp54_);
#line 581 "/home/fborges/checkout/gnome-boxes/src/libvirt-machine-properties.vala"
		_data_->_tmp56_ = _data_->_tmp55_;
#line 581 "/home/fborges/checkout/gnome-boxes/src/libvirt-machine-properties.vala"
		_data_->_tmp57_ = gvir_storage_vol_get_name (_data_->_tmp56_);
#line 581 "/home/fborges/checkout/gnome-boxes/src/libvirt-machine-properties.vala"
		_data_->_tmp58_ = _data_->_data53_->value;
#line 581 "/home/fborges/checkout/gnome-boxes/src/libvirt-machine-properties.vala"
		_data_->_tmp59_ = _data_->_vala1__error_;
#line 581 "/home/fborges/checkout/gnome-boxes/src/libvirt-machine-properties.vala"
		_data_->_tmp60_ = _data_->_tmp59_->message;
#line 581 "/home/fborges/checkout/gnome-boxes/src/libvirt-machine-properties.vala"
		g_warning ("libvirt-machine-properties.vala:581: Failed to change storage capacity" \
" of volume '%s' to %llu: %s", _data_->_tmp57_, _data_->_tmp58_, _data_->_tmp60_);
#line 556 "/home/fborges/checkout/gnome-boxes/src/libvirt-machine-properties.vala"
		_g_error_free0 (_data_->_vala1__error_);
#line 5956 "libvirt-machine-properties.c"
	}
	__finally49:
#line 556 "/home/fborges/checkout/gnome-boxes/src/libvirt-machine-properties.vala"
	if (G_UNLIKELY (_data_->_inner_error_ != NULL)) {
#line 556 "/home/fborges/checkout/gnome-boxes/src/libvirt-machine-properties.vala"
		__g_list_free__g_object_unref0_0 (_data_->snapshots);
#line 556 "/home/fborges/checkout/gnome-boxes/src/libvirt-machine-properties.vala"
		block53_data_unref (_data_->_data53_);
#line 556 "/home/fborges/checkout/gnome-boxes/src/libvirt-machine-properties.vala"
		_data_->_data53_ = NULL;
#line 556 "/home/fborges/checkout/gnome-boxes/src/libvirt-machine-properties.vala"
		g_critical ("file %s: line %d: uncaught error: %s (%s, %d)", __FILE__, __LINE__, _data_->_inner_error_->message, g_quark_to_string (_data_->_inner_error_->domain), _data_->_inner_error_->code);
#line 556 "/home/fborges/checkout/gnome-boxes/src/libvirt-machine-properties.vala"
		g_clear_error (&_data_->_inner_error_);
#line 556 "/home/fborges/checkout/gnome-boxes/src/libvirt-machine-properties.vala"
		g_object_unref (_data_->_async_result);
#line 556 "/home/fborges/checkout/gnome-boxes/src/libvirt-machine-properties.vala"
		return FALSE;
#line 5975 "libvirt-machine-properties.c"
	}
#line 522 "/home/fborges/checkout/gnome-boxes/src/libvirt-machine-properties.vala"
	__g_list_free__g_object_unref0_0 (_data_->snapshots);
#line 522 "/home/fborges/checkout/gnome-boxes/src/libvirt-machine-properties.vala"
	block53_data_unref (_data_->_data53_);
#line 522 "/home/fborges/checkout/gnome-boxes/src/libvirt-machine-properties.vala"
	_data_->_data53_ = NULL;
#line 522 "/home/fborges/checkout/gnome-boxes/src/libvirt-machine-properties.vala"
	g_task_return_pointer (_data_->_async_result, _data_, NULL);
#line 522 "/home/fborges/checkout/gnome-boxes/src/libvirt-machine-properties.vala"
	if (_data_->_state_ != 0) {
#line 522 "/home/fborges/checkout/gnome-boxes/src/libvirt-machine-properties.vala"
		while (g_task_get_completed (_data_->_async_result) != TRUE) {
#line 522 "/home/fborges/checkout/gnome-boxes/src/libvirt-machine-properties.vala"
			g_main_context_iteration (g_task_get_context (_data_->_async_result), TRUE);
#line 5991 "libvirt-machine-properties.c"
		}
	}
#line 522 "/home/fborges/checkout/gnome-boxes/src/libvirt-machine-properties.vala"
	g_object_unref (_data_->_async_result);
#line 522 "/home/fborges/checkout/gnome-boxes/src/libvirt-machine-properties.vala"
	return FALSE;
#line 5998 "libvirt-machine-properties.c"
}


static void boxes_libvirt_machine_properties_force_change_storage_size_data_free (gpointer _data) {
	BoxesLibvirtMachinePropertiesForceChangeStorageSizeData* _data_;
	_data_ = _data;
#line 5 "/home/fborges/checkout/gnome-boxes/src/libvirt-machine-properties.vala"
	_g_object_unref0 (_data_->property);
#line 5 "/home/fborges/checkout/gnome-boxes/src/libvirt-machine-properties.vala"
	_g_object_unref0 (_data_->self);
#line 5 "/home/fborges/checkout/gnome-boxes/src/libvirt-machine-properties.vala"
	g_slice_free (BoxesLibvirtMachinePropertiesForceChangeStorageSizeData, _data_);
#line 6011 "libvirt-machine-properties.c"
}


static void boxes_libvirt_machine_properties_force_change_storage_size (BoxesLibvirtMachineProperties* self, BoxesProperty* property, guint64 value, GAsyncReadyCallback _callback_, gpointer _user_data_) {
	BoxesLibvirtMachinePropertiesForceChangeStorageSizeData* _data_;
	BoxesLibvirtMachineProperties* _tmp0_;
	BoxesProperty* _tmp1_;
	BoxesProperty* _tmp2_;
	guint64 _tmp3_;
#line 5 "/home/fborges/checkout/gnome-boxes/src/libvirt-machine-properties.vala"
	_data_ = g_slice_new0 (BoxesLibvirtMachinePropertiesForceChangeStorageSizeData);
#line 5 "/home/fborges/checkout/gnome-boxes/src/libvirt-machine-properties.vala"
	_data_->_async_result = g_task_new (G_OBJECT (self), NULL, _callback_, _user_data_);
#line 5 "/home/fborges/checkout/gnome-boxes/src/libvirt-machine-properties.vala"
	g_task_set_task_data (_data_->_async_result, _data_, boxes_libvirt_machine_properties_force_change_storage_size_data_free);
#line 5 "/home/fborges/checkout/gnome-boxes/src/libvirt-machine-properties.vala"
	_tmp0_ = _g_object_ref0 (self);
#line 5 "/home/fborges/checkout/gnome-boxes/src/libvirt-machine-properties.vala"
	_data_->self = _tmp0_;
#line 5 "/home/fborges/checkout/gnome-boxes/src/libvirt-machine-properties.vala"
	_tmp1_ = property;
#line 5 "/home/fborges/checkout/gnome-boxes/src/libvirt-machine-properties.vala"
	_tmp2_ = _g_object_ref0 (_tmp1_);
#line 5 "/home/fborges/checkout/gnome-boxes/src/libvirt-machine-properties.vala"
	_g_object_unref0 (_data_->property);
#line 5 "/home/fborges/checkout/gnome-boxes/src/libvirt-machine-properties.vala"
	_data_->property = _tmp2_;
#line 5 "/home/fborges/checkout/gnome-boxes/src/libvirt-machine-properties.vala"
	_tmp3_ = value;
#line 5 "/home/fborges/checkout/gnome-boxes/src/libvirt-machine-properties.vala"
	_data_->value = _tmp3_;
#line 5 "/home/fborges/checkout/gnome-boxes/src/libvirt-machine-properties.vala"
	boxes_libvirt_machine_properties_force_change_storage_size_co (_data_);
#line 6045 "libvirt-machine-properties.c"
}


static void boxes_libvirt_machine_properties_force_change_storage_size_finish (BoxesLibvirtMachineProperties* self, GAsyncResult* _res_) {
	BoxesLibvirtMachinePropertiesForceChangeStorageSizeData* _data_;
#line 5 "/home/fborges/checkout/gnome-boxes/src/libvirt-machine-properties.vala"
	_data_ = g_task_propagate_pointer (G_TASK (_res_), NULL);
#line 6053 "libvirt-machine-properties.c"
}


static void boxes_libvirt_machine_properties_force_change_storage_size_ready (GObject* source_object, GAsyncResult* _res_, gpointer _user_data_) {
	BoxesLibvirtMachinePropertiesForceChangeStorageSizeData* _data_;
#line 590 "/home/fborges/checkout/gnome-boxes/src/libvirt-machine-properties.vala"
	_data_ = _user_data_;
#line 590 "/home/fborges/checkout/gnome-boxes/src/libvirt-machine-properties.vala"
	_data_->_source_object_ = source_object;
#line 590 "/home/fborges/checkout/gnome-boxes/src/libvirt-machine-properties.vala"
	_data_->_res_ = _res_;
#line 590 "/home/fborges/checkout/gnome-boxes/src/libvirt-machine-properties.vala"
	boxes_libvirt_machine_properties_force_change_storage_size_co (_data_);
#line 6067 "libvirt-machine-properties.c"
}


static gboolean boxes_libvirt_machine_properties_force_change_storage_size_co (BoxesLibvirtMachinePropertiesForceChangeStorageSizeData* _data_) {
#line 588 "/home/fborges/checkout/gnome-boxes/src/libvirt-machine-properties.vala"
	switch (_data_->_state_) {
#line 588 "/home/fborges/checkout/gnome-boxes/src/libvirt-machine-properties.vala"
		case 0:
#line 6076 "libvirt-machine-properties.c"
		goto _state_0;
#line 588 "/home/fborges/checkout/gnome-boxes/src/libvirt-machine-properties.vala"
		case 1:
#line 6080 "libvirt-machine-properties.c"
		goto _state_1;
#line 588 "/home/fborges/checkout/gnome-boxes/src/libvirt-machine-properties.vala"
		case 2:
#line 6084 "libvirt-machine-properties.c"
		goto _state_2;
		default:
#line 588 "/home/fborges/checkout/gnome-boxes/src/libvirt-machine-properties.vala"
		g_assert_not_reached ();
#line 6089 "libvirt-machine-properties.c"
	}
	_state_0:
	{
#line 590 "/home/fborges/checkout/gnome-boxes/src/libvirt-machine-properties.vala"
		_data_->_state_ = 1;
#line 590 "/home/fborges/checkout/gnome-boxes/src/libvirt-machine-properties.vala"
		boxes_libvirt_machine_properties_get_snapshots (_data_->self, NULL, boxes_libvirt_machine_properties_force_change_storage_size_ready, _data_);
#line 590 "/home/fborges/checkout/gnome-boxes/src/libvirt-machine-properties.vala"
		return FALSE;
#line 6099 "libvirt-machine-properties.c"
		_state_1:
#line 590 "/home/fborges/checkout/gnome-boxes/src/libvirt-machine-properties.vala"
		_data_->_tmp0_ = boxes_libvirt_machine_properties_get_snapshots_finish (_data_->self, _data_->_res_, &_data_->_inner_error_);
#line 590 "/home/fborges/checkout/gnome-boxes/src/libvirt-machine-properties.vala"
		_data_->snapshots = _data_->_tmp0_;
#line 590 "/home/fborges/checkout/gnome-boxes/src/libvirt-machine-properties.vala"
		if (G_UNLIKELY (_data_->_inner_error_ != NULL)) {
#line 6107 "libvirt-machine-properties.c"
			goto __catch51_g_error;
		}
#line 592 "/home/fborges/checkout/gnome-boxes/src/libvirt-machine-properties.vala"
		_data_->_tmp1_ = _data_->snapshots;
#line 6112 "libvirt-machine-properties.c"
		{
#line 592 "/home/fborges/checkout/gnome-boxes/src/libvirt-machine-properties.vala"
			_data_->snapshot_collection = _data_->_tmp1_;
#line 592 "/home/fborges/checkout/gnome-boxes/src/libvirt-machine-properties.vala"
			for (_data_->snapshot_it = _data_->snapshot_collection; _data_->snapshot_it != NULL; _data_->snapshot_it = _data_->snapshot_it->next) {
#line 592 "/home/fborges/checkout/gnome-boxes/src/libvirt-machine-properties.vala"
				_data_->_tmp2_ = _g_object_ref0 ((GVirDomainSnapshot*) _data_->snapshot_it->data);
#line 592 "/home/fborges/checkout/gnome-boxes/src/libvirt-machine-properties.vala"
				_data_->snapshot = _data_->_tmp2_;
#line 6122 "libvirt-machine-properties.c"
				{
#line 593 "/home/fborges/checkout/gnome-boxes/src/libvirt-machine-properties.vala"
					_data_->_tmp3_ = _data_->snapshot;
#line 593 "/home/fborges/checkout/gnome-boxes/src/libvirt-machine-properties.vala"
					_data_->_state_ = 2;
#line 593 "/home/fborges/checkout/gnome-boxes/src/libvirt-machine-properties.vala"
					gvir_domain_snapshot_delete_async (_data_->_tmp3_, (guint) 0, NULL, boxes_libvirt_machine_properties_force_change_storage_size_ready, _data_);
#line 593 "/home/fborges/checkout/gnome-boxes/src/libvirt-machine-properties.vala"
					return FALSE;
#line 6132 "libvirt-machine-properties.c"
					_state_2:
#line 593 "/home/fborges/checkout/gnome-boxes/src/libvirt-machine-properties.vala"
					gvir_domain_snapshot_delete_finish (_data_->_tmp3_, _data_->_res_, &_data_->_inner_error_);
#line 593 "/home/fborges/checkout/gnome-boxes/src/libvirt-machine-properties.vala"
					if (G_UNLIKELY (_data_->_inner_error_ != NULL)) {
#line 593 "/home/fborges/checkout/gnome-boxes/src/libvirt-machine-properties.vala"
						_g_object_unref0 (_data_->snapshot);
#line 593 "/home/fborges/checkout/gnome-boxes/src/libvirt-machine-properties.vala"
						__g_list_free__g_object_unref0_0 (_data_->snapshots);
#line 6142 "libvirt-machine-properties.c"
						goto __catch51_g_error;
					}
#line 592 "/home/fborges/checkout/gnome-boxes/src/libvirt-machine-properties.vala"
					_g_object_unref0 (_data_->snapshot);
#line 6147 "libvirt-machine-properties.c"
				}
			}
		}
#line 596 "/home/fborges/checkout/gnome-boxes/src/libvirt-machine-properties.vala"
		_data_->_tmp4_ = _data_->property;
#line 596 "/home/fborges/checkout/gnome-boxes/src/libvirt-machine-properties.vala"
		_data_->_tmp5_ = _data_->value;
#line 596 "/home/fborges/checkout/gnome-boxes/src/libvirt-machine-properties.vala"
		boxes_libvirt_machine_properties_change_storage_size (_data_->self, _data_->_tmp4_, _data_->_tmp5_, NULL, NULL);
#line 589 "/home/fborges/checkout/gnome-boxes/src/libvirt-machine-properties.vala"
		__g_list_free__g_object_unref0_0 (_data_->snapshots);
#line 6159 "libvirt-machine-properties.c"
	}
	goto __finally51;
	__catch51_g_error:
	{
#line 589 "/home/fborges/checkout/gnome-boxes/src/libvirt-machine-properties.vala"
		_data_->e = _data_->_inner_error_;
#line 589 "/home/fborges/checkout/gnome-boxes/src/libvirt-machine-properties.vala"
		_data_->_inner_error_ = NULL;
#line 598 "/home/fborges/checkout/gnome-boxes/src/libvirt-machine-properties.vala"
		_data_->_tmp6_ = _data_->e;
#line 598 "/home/fborges/checkout/gnome-boxes/src/libvirt-machine-properties.vala"
		_data_->_tmp7_ = _data_->_tmp6_->message;
#line 598 "/home/fborges/checkout/gnome-boxes/src/libvirt-machine-properties.vala"
		g_warning ("libvirt-machine-properties.vala:598: Error while deleting snapshots: %" \
"s", _data_->_tmp7_);
#line 589 "/home/fborges/checkout/gnome-boxes/src/libvirt-machine-properties.vala"
		_g_error_free0 (_data_->e);
#line 6176 "libvirt-machine-properties.c"
	}
	__finally51:
#line 589 "/home/fborges/checkout/gnome-boxes/src/libvirt-machine-properties.vala"
	if (G_UNLIKELY (_data_->_inner_error_ != NULL)) {
#line 589 "/home/fborges/checkout/gnome-boxes/src/libvirt-machine-properties.vala"
		g_critical ("file %s: line %d: uncaught error: %s (%s, %d)", __FILE__, __LINE__, _data_->_inner_error_->message, g_quark_to_string (_data_->_inner_error_->domain), _data_->_inner_error_->code);
#line 589 "/home/fborges/checkout/gnome-boxes/src/libvirt-machine-properties.vala"
		g_clear_error (&_data_->_inner_error_);
#line 589 "/home/fborges/checkout/gnome-boxes/src/libvirt-machine-properties.vala"
		g_object_unref (_data_->_async_result);
#line 589 "/home/fborges/checkout/gnome-boxes/src/libvirt-machine-properties.vala"
		return FALSE;
#line 6189 "libvirt-machine-properties.c"
	}
#line 588 "/home/fborges/checkout/gnome-boxes/src/libvirt-machine-properties.vala"
	g_task_return_pointer (_data_->_async_result, _data_, NULL);
#line 588 "/home/fborges/checkout/gnome-boxes/src/libvirt-machine-properties.vala"
	if (_data_->_state_ != 0) {
#line 588 "/home/fborges/checkout/gnome-boxes/src/libvirt-machine-properties.vala"
		while (g_task_get_completed (_data_->_async_result) != TRUE) {
#line 588 "/home/fborges/checkout/gnome-boxes/src/libvirt-machine-properties.vala"
			g_main_context_iteration (g_task_get_context (_data_->_async_result), TRUE);
#line 6199 "libvirt-machine-properties.c"
		}
	}
#line 588 "/home/fborges/checkout/gnome-boxes/src/libvirt-machine-properties.vala"
	g_object_unref (_data_->_async_result);
#line 588 "/home/fborges/checkout/gnome-boxes/src/libvirt-machine-properties.vala"
	return FALSE;
#line 6206 "libvirt-machine-properties.c"
}


static guint64 boxes_libvirt_machine_properties_get_minimum_disk_size (BoxesLibvirtMachineProperties* self, GError** error) {
	guint64 result = 0ULL;
	GVirStorageVolInfo* volume_info = NULL;
	BoxesLibvirtMachine* _tmp0_;
	GVirStorageVol* _tmp1_;
	GVirStorageVol* _tmp2_;
	GVirStorageVolInfo* _tmp3_;
	BoxesLibvirtMachine* _tmp5_;
	BoxesVMCreator* _tmp6_;
	BoxesVMCreator* _tmp7_;
	OsinfoResources* minimum_resources = NULL;
	BoxesLibvirtMachine* _tmp10_;
	BoxesVMCreator* _tmp11_;
	BoxesVMCreator* _tmp12_;
	BoxesInstallerMedia* _tmp13_;
	BoxesInstallerMedia* _tmp14_;
	OsinfoOs* _tmp15_;
	gboolean _tmp34_ = FALSE;
	OsinfoResources* _tmp35_;
	GError * _inner_error_ = NULL;
#line 602 "/home/fborges/checkout/gnome-boxes/src/libvirt-machine-properties.vala"
	g_return_val_if_fail (self != NULL, 0ULL);
#line 603 "/home/fborges/checkout/gnome-boxes/src/libvirt-machine-properties.vala"
	_tmp0_ = self->priv->machine;
#line 603 "/home/fborges/checkout/gnome-boxes/src/libvirt-machine-properties.vala"
	_tmp1_ = boxes_libvirt_machine_get_storage_volume (_tmp0_);
#line 603 "/home/fborges/checkout/gnome-boxes/src/libvirt-machine-properties.vala"
	_tmp2_ = _tmp1_;
#line 603 "/home/fborges/checkout/gnome-boxes/src/libvirt-machine-properties.vala"
	_tmp3_ = gvir_storage_vol_get_info (_tmp2_, &_inner_error_);
#line 603 "/home/fborges/checkout/gnome-boxes/src/libvirt-machine-properties.vala"
	volume_info = _tmp3_;
#line 603 "/home/fborges/checkout/gnome-boxes/src/libvirt-machine-properties.vala"
	if (G_UNLIKELY (_inner_error_ != NULL)) {
#line 6244 "libvirt-machine-properties.c"
		guint64 _tmp4_ = 0ULL;
#line 603 "/home/fborges/checkout/gnome-boxes/src/libvirt-machine-properties.vala"
		g_propagate_error (error, _inner_error_);
#line 603 "/home/fborges/checkout/gnome-boxes/src/libvirt-machine-properties.vala"
		return _tmp4_;
#line 6250 "libvirt-machine-properties.c"
	}
#line 604 "/home/fborges/checkout/gnome-boxes/src/libvirt-machine-properties.vala"
	_tmp5_ = self->priv->machine;
#line 604 "/home/fborges/checkout/gnome-boxes/src/libvirt-machine-properties.vala"
	_tmp6_ = boxes_libvirt_machine_get_vm_creator (_tmp5_);
#line 604 "/home/fborges/checkout/gnome-boxes/src/libvirt-machine-properties.vala"
	_tmp7_ = _tmp6_;
#line 604 "/home/fborges/checkout/gnome-boxes/src/libvirt-machine-properties.vala"
	if (_tmp7_ == NULL) {
#line 6260 "libvirt-machine-properties.c"
		GVirStorageVolInfo* _tmp8_;
		guint64 _tmp9_;
#line 607 "/home/fborges/checkout/gnome-boxes/src/libvirt-machine-properties.vala"
		_tmp8_ = volume_info;
#line 607 "/home/fborges/checkout/gnome-boxes/src/libvirt-machine-properties.vala"
		_tmp9_ = _tmp8_->capacity;
#line 607 "/home/fborges/checkout/gnome-boxes/src/libvirt-machine-properties.vala"
		result = _tmp9_;
#line 607 "/home/fborges/checkout/gnome-boxes/src/libvirt-machine-properties.vala"
		__vala_GVirStorageVolInfo_free0 (volume_info);
#line 607 "/home/fborges/checkout/gnome-boxes/src/libvirt-machine-properties.vala"
		return result;
#line 6273 "libvirt-machine-properties.c"
	}
#line 610 "/home/fborges/checkout/gnome-boxes/src/libvirt-machine-properties.vala"
	minimum_resources = NULL;
#line 612 "/home/fborges/checkout/gnome-boxes/src/libvirt-machine-properties.vala"
	_tmp10_ = self->priv->machine;
#line 612 "/home/fborges/checkout/gnome-boxes/src/libvirt-machine-properties.vala"
	_tmp11_ = boxes_libvirt_machine_get_vm_creator (_tmp10_);
#line 612 "/home/fborges/checkout/gnome-boxes/src/libvirt-machine-properties.vala"
	_tmp12_ = _tmp11_;
#line 612 "/home/fborges/checkout/gnome-boxes/src/libvirt-machine-properties.vala"
	_tmp13_ = boxes_vm_creator_get_install_media (_tmp12_);
#line 612 "/home/fborges/checkout/gnome-boxes/src/libvirt-machine-properties.vala"
	_tmp14_ = _tmp13_;
#line 612 "/home/fborges/checkout/gnome-boxes/src/libvirt-machine-properties.vala"
	_tmp15_ = _tmp14_->os;
#line 612 "/home/fborges/checkout/gnome-boxes/src/libvirt-machine-properties.vala"
	if (_tmp15_ != NULL) {
#line 6291 "libvirt-machine-properties.c"
		OsinfoOs* os = NULL;
		BoxesLibvirtMachine* _tmp16_;
		BoxesVMCreator* _tmp17_;
		BoxesVMCreator* _tmp18_;
		BoxesInstallerMedia* _tmp19_;
		BoxesInstallerMedia* _tmp20_;
		OsinfoOs* _tmp21_;
		OsinfoOs* _tmp22_;
		gchar* architecture = NULL;
		BoxesLibvirtMachine* _tmp23_;
		GVirConfigDomain* _tmp24_;
		GVirConfigDomain* _tmp25_;
		GVirConfigDomainOs* _tmp26_;
		GVirConfigDomainOs* _tmp27_;
		const gchar* _tmp28_;
		gchar* _tmp29_;
		gchar* _tmp30_;
		OsinfoOs* _tmp31_;
		const gchar* _tmp32_;
		OsinfoResources* _tmp33_;
#line 613 "/home/fborges/checkout/gnome-boxes/src/libvirt-machine-properties.vala"
		_tmp16_ = self->priv->machine;
#line 613 "/home/fborges/checkout/gnome-boxes/src/libvirt-machine-properties.vala"
		_tmp17_ = boxes_libvirt_machine_get_vm_creator (_tmp16_);
#line 613 "/home/fborges/checkout/gnome-boxes/src/libvirt-machine-properties.vala"
		_tmp18_ = _tmp17_;
#line 613 "/home/fborges/checkout/gnome-boxes/src/libvirt-machine-properties.vala"
		_tmp19_ = boxes_vm_creator_get_install_media (_tmp18_);
#line 613 "/home/fborges/checkout/gnome-boxes/src/libvirt-machine-properties.vala"
		_tmp20_ = _tmp19_;
#line 613 "/home/fborges/checkout/gnome-boxes/src/libvirt-machine-properties.vala"
		_tmp21_ = _tmp20_->os;
#line 613 "/home/fborges/checkout/gnome-boxes/src/libvirt-machine-properties.vala"
		_tmp22_ = _g_object_ref0 (_tmp21_);
#line 613 "/home/fborges/checkout/gnome-boxes/src/libvirt-machine-properties.vala"
		os = _tmp22_;
#line 614 "/home/fborges/checkout/gnome-boxes/src/libvirt-machine-properties.vala"
		_tmp23_ = self->priv->machine;
#line 614 "/home/fborges/checkout/gnome-boxes/src/libvirt-machine-properties.vala"
		_tmp24_ = boxes_libvirt_machine_get_domain_config (_tmp23_);
#line 614 "/home/fborges/checkout/gnome-boxes/src/libvirt-machine-properties.vala"
		_tmp25_ = _tmp24_;
#line 614 "/home/fborges/checkout/gnome-boxes/src/libvirt-machine-properties.vala"
		_tmp26_ = gvir_config_domain_get_os (_tmp25_);
#line 614 "/home/fborges/checkout/gnome-boxes/src/libvirt-machine-properties.vala"
		_tmp27_ = _tmp26_;
#line 614 "/home/fborges/checkout/gnome-boxes/src/libvirt-machine-properties.vala"
		_tmp28_ = gvir_config_domain_os_get_arch (_tmp27_);
#line 614 "/home/fborges/checkout/gnome-boxes/src/libvirt-machine-properties.vala"
		_tmp29_ = g_strdup (_tmp28_);
#line 614 "/home/fborges/checkout/gnome-boxes/src/libvirt-machine-properties.vala"
		_tmp30_ = _tmp29_;
#line 614 "/home/fborges/checkout/gnome-boxes/src/libvirt-machine-properties.vala"
		_g_object_unref0 (_tmp27_);
#line 614 "/home/fborges/checkout/gnome-boxes/src/libvirt-machine-properties.vala"
		architecture = _tmp30_;
#line 615 "/home/fborges/checkout/gnome-boxes/src/libvirt-machine-properties.vala"
		_tmp31_ = os;
#line 615 "/home/fborges/checkout/gnome-boxes/src/libvirt-machine-properties.vala"
		_tmp32_ = architecture;
#line 615 "/home/fborges/checkout/gnome-boxes/src/libvirt-machine-properties.vala"
		_tmp33_ = boxes_os_database_get_minimum_resources_for_os (_tmp31_, _tmp32_);
#line 615 "/home/fborges/checkout/gnome-boxes/src/libvirt-machine-properties.vala"
		_g_object_unref0 (minimum_resources);
#line 615 "/home/fborges/checkout/gnome-boxes/src/libvirt-machine-properties.vala"
		minimum_resources = _tmp33_;
#line 612 "/home/fborges/checkout/gnome-boxes/src/libvirt-machine-properties.vala"
		_g_free0 (architecture);
#line 612 "/home/fborges/checkout/gnome-boxes/src/libvirt-machine-properties.vala"
		_g_object_unref0 (os);
#line 6362 "libvirt-machine-properties.c"
	}
#line 618 "/home/fborges/checkout/gnome-boxes/src/libvirt-machine-properties.vala"
	_tmp35_ = minimum_resources;
#line 618 "/home/fborges/checkout/gnome-boxes/src/libvirt-machine-properties.vala"
	if (_tmp35_ != NULL) {
#line 6368 "libvirt-machine-properties.c"
		OsinfoResources* _tmp36_;
		gint64 _tmp37_;
		gint64 _tmp38_;
#line 618 "/home/fborges/checkout/gnome-boxes/src/libvirt-machine-properties.vala"
		_tmp36_ = minimum_resources;
#line 618 "/home/fborges/checkout/gnome-boxes/src/libvirt-machine-properties.vala"
		_tmp37_ = osinfo_resources_get_storage (_tmp36_);
#line 618 "/home/fborges/checkout/gnome-boxes/src/libvirt-machine-properties.vala"
		_tmp38_ = _tmp37_;
#line 618 "/home/fborges/checkout/gnome-boxes/src/libvirt-machine-properties.vala"
		_tmp34_ = _tmp38_ != ((gint64) -1);
#line 6380 "libvirt-machine-properties.c"
	} else {
#line 618 "/home/fborges/checkout/gnome-boxes/src/libvirt-machine-properties.vala"
		_tmp34_ = FALSE;
#line 6384 "libvirt-machine-properties.c"
	}
#line 618 "/home/fborges/checkout/gnome-boxes/src/libvirt-machine-properties.vala"
	if (_tmp34_) {
#line 6388 "libvirt-machine-properties.c"
		OsinfoResources* _tmp39_;
		gint64 _tmp40_;
		gint64 _tmp41_;
#line 619 "/home/fborges/checkout/gnome-boxes/src/libvirt-machine-properties.vala"
		_tmp39_ = minimum_resources;
#line 619 "/home/fborges/checkout/gnome-boxes/src/libvirt-machine-properties.vala"
		_tmp40_ = osinfo_resources_get_storage (_tmp39_);
#line 619 "/home/fborges/checkout/gnome-boxes/src/libvirt-machine-properties.vala"
		_tmp41_ = _tmp40_;
#line 619 "/home/fborges/checkout/gnome-boxes/src/libvirt-machine-properties.vala"
		result = (guint64) _tmp41_;
#line 619 "/home/fborges/checkout/gnome-boxes/src/libvirt-machine-properties.vala"
		_g_object_unref0 (minimum_resources);
#line 619 "/home/fborges/checkout/gnome-boxes/src/libvirt-machine-properties.vala"
		__vala_GVirStorageVolInfo_free0 (volume_info);
#line 619 "/home/fborges/checkout/gnome-boxes/src/libvirt-machine-properties.vala"
		return result;
#line 6406 "libvirt-machine-properties.c"
	} else {
		OsinfoResources* _tmp42_;
		GVirStorageVolInfo* _tmp43_;
		guint64 _tmp44_;
		OsinfoResources* _tmp45_;
		gint64 _tmp46_;
		gint64 _tmp47_;
		guint64 _tmp48_;
#line 621 "/home/fborges/checkout/gnome-boxes/src/libvirt-machine-properties.vala"
		_tmp42_ = boxes_os_database_get_minimum_resources ();
#line 621 "/home/fborges/checkout/gnome-boxes/src/libvirt-machine-properties.vala"
		_g_object_unref0 (minimum_resources);
#line 621 "/home/fborges/checkout/gnome-boxes/src/libvirt-machine-properties.vala"
		minimum_resources = _tmp42_;
#line 622 "/home/fborges/checkout/gnome-boxes/src/libvirt-machine-properties.vala"
		_tmp43_ = volume_info;
#line 622 "/home/fborges/checkout/gnome-boxes/src/libvirt-machine-properties.vala"
		_tmp44_ = _tmp43_->capacity;
#line 622 "/home/fborges/checkout/gnome-boxes/src/libvirt-machine-properties.vala"
		_tmp45_ = minimum_resources;
#line 622 "/home/fborges/checkout/gnome-boxes/src/libvirt-machine-properties.vala"
		_tmp46_ = osinfo_resources_get_storage (_tmp45_);
#line 622 "/home/fborges/checkout/gnome-boxes/src/libvirt-machine-properties.vala"
		_tmp47_ = _tmp46_;
#line 622 "/home/fborges/checkout/gnome-boxes/src/libvirt-machine-properties.vala"
		_tmp48_ = MIN (_tmp44_, (guint64) _tmp47_);
#line 622 "/home/fborges/checkout/gnome-boxes/src/libvirt-machine-properties.vala"
		result = _tmp48_;
#line 622 "/home/fborges/checkout/gnome-boxes/src/libvirt-machine-properties.vala"
		_g_object_unref0 (minimum_resources);
#line 622 "/home/fborges/checkout/gnome-boxes/src/libvirt-machine-properties.vala"
		__vala_GVirStorageVolInfo_free0 (volume_info);
#line 622 "/home/fborges/checkout/gnome-boxes/src/libvirt-machine-properties.vala"
		return result;
#line 6441 "libvirt-machine-properties.c"
	}
#line 602 "/home/fborges/checkout/gnome-boxes/src/libvirt-machine-properties.vala"
	_g_object_unref0 (minimum_resources);
#line 602 "/home/fborges/checkout/gnome-boxes/src/libvirt-machine-properties.vala"
	__vala_GVirStorageVolInfo_free0 (volume_info);
#line 6447 "libvirt-machine-properties.c"
}


static void boxes_libvirt_machine_properties_resize_storage_volume (BoxesLibvirtMachineProperties* self, guint64 size, GError** error) {
	GVirStorageVolInfo* volume_info = NULL;
	BoxesLibvirtMachine* _tmp0_;
	GVirStorageVol* _tmp1_;
	GVirStorageVol* _tmp2_;
	GVirStorageVolInfo* _tmp3_;
	gboolean _tmp4_ = FALSE;
	BoxesLibvirtMachine* _tmp5_;
	BoxesVMCreator* _tmp6_;
	BoxesVMCreator* _tmp7_;
	GError * _inner_error_ = NULL;
#line 626 "/home/fborges/checkout/gnome-boxes/src/libvirt-machine-properties.vala"
	g_return_if_fail (self != NULL);
#line 627 "/home/fborges/checkout/gnome-boxes/src/libvirt-machine-properties.vala"
	_tmp0_ = self->priv->machine;
#line 627 "/home/fborges/checkout/gnome-boxes/src/libvirt-machine-properties.vala"
	_tmp1_ = boxes_libvirt_machine_get_storage_volume (_tmp0_);
#line 627 "/home/fborges/checkout/gnome-boxes/src/libvirt-machine-properties.vala"
	_tmp2_ = _tmp1_;
#line 627 "/home/fborges/checkout/gnome-boxes/src/libvirt-machine-properties.vala"
	_tmp3_ = gvir_storage_vol_get_info (_tmp2_, &_inner_error_);
#line 627 "/home/fborges/checkout/gnome-boxes/src/libvirt-machine-properties.vala"
	volume_info = _tmp3_;
#line 627 "/home/fborges/checkout/gnome-boxes/src/libvirt-machine-properties.vala"
	if (G_UNLIKELY (_inner_error_ != NULL)) {
#line 627 "/home/fborges/checkout/gnome-boxes/src/libvirt-machine-properties.vala"
		g_propagate_error (error, _inner_error_);
#line 627 "/home/fborges/checkout/gnome-boxes/src/libvirt-machine-properties.vala"
		return;
#line 6480 "libvirt-machine-properties.c"
	}
#line 628 "/home/fborges/checkout/gnome-boxes/src/libvirt-machine-properties.vala"
	_tmp5_ = self->priv->machine;
#line 628 "/home/fborges/checkout/gnome-boxes/src/libvirt-machine-properties.vala"
	_tmp6_ = boxes_libvirt_machine_get_vm_creator (_tmp5_);
#line 628 "/home/fborges/checkout/gnome-boxes/src/libvirt-machine-properties.vala"
	_tmp7_ = _tmp6_;
#line 628 "/home/fborges/checkout/gnome-boxes/src/libvirt-machine-properties.vala"
	if (_tmp7_ != NULL) {
#line 6490 "libvirt-machine-properties.c"
		guint64 _tmp8_;
		GVirStorageVolInfo* _tmp9_;
		guint64 _tmp10_;
#line 628 "/home/fborges/checkout/gnome-boxes/src/libvirt-machine-properties.vala"
		_tmp8_ = size;
#line 628 "/home/fborges/checkout/gnome-boxes/src/libvirt-machine-properties.vala"
		_tmp9_ = volume_info;
#line 628 "/home/fborges/checkout/gnome-boxes/src/libvirt-machine-properties.vala"
		_tmp10_ = _tmp9_->capacity;
#line 628 "/home/fborges/checkout/gnome-boxes/src/libvirt-machine-properties.vala"
		_tmp4_ = _tmp8_ < _tmp10_;
#line 6502 "libvirt-machine-properties.c"
	} else {
#line 628 "/home/fborges/checkout/gnome-boxes/src/libvirt-machine-properties.vala"
		_tmp4_ = FALSE;
#line 6506 "libvirt-machine-properties.c"
	}
#line 628 "/home/fborges/checkout/gnome-boxes/src/libvirt-machine-properties.vala"
	if (_tmp4_) {
#line 6510 "libvirt-machine-properties.c"
		GVirConfigStorageVol* config = NULL;
		BoxesLibvirtMachine* _tmp11_;
		GVirStorageVol* _tmp12_;
		GVirStorageVol* _tmp13_;
		GVirConfigStorageVol* _tmp14_;
		GVirConfigStorageVol* _tmp15_;
		guint64 _tmp16_;
		BoxesLibvirtMachine* _tmp17_;
		GVirStorageVol* _tmp18_;
		GVirStorageVol* _tmp19_;
		GVirStoragePool* pool = NULL;
		BoxesLibvirtMachine* _tmp20_;
		GVirConnection* _tmp21_;
		GVirConnection* _tmp22_;
		GVirStoragePool* _tmp23_;
		GVirStorageVol* _tmp24_ = NULL;
		GVirStoragePool* _tmp25_;
		GVirConfigStorageVol* _tmp26_;
		GVirStorageVol* _tmp27_;
		BoxesLibvirtMachine* _tmp28_;
#line 630 "/home/fborges/checkout/gnome-boxes/src/libvirt-machine-properties.vala"
		_tmp11_ = self->priv->machine;
#line 630 "/home/fborges/checkout/gnome-boxes/src/libvirt-machine-properties.vala"
		_tmp12_ = boxes_libvirt_machine_get_storage_volume (_tmp11_);
#line 630 "/home/fborges/checkout/gnome-boxes/src/libvirt-machine-properties.vala"
		_tmp13_ = _tmp12_;
#line 630 "/home/fborges/checkout/gnome-boxes/src/libvirt-machine-properties.vala"
		_tmp14_ = gvir_storage_vol_get_config (_tmp13_, (guint) GVIR_DOMAIN_XML_NONE, &_inner_error_);
#line 630 "/home/fborges/checkout/gnome-boxes/src/libvirt-machine-properties.vala"
		config = _tmp14_;
#line 630 "/home/fborges/checkout/gnome-boxes/src/libvirt-machine-properties.vala"
		if (G_UNLIKELY (_inner_error_ != NULL)) {
#line 630 "/home/fborges/checkout/gnome-boxes/src/libvirt-machine-properties.vala"
			g_propagate_error (error, _inner_error_);
#line 630 "/home/fborges/checkout/gnome-boxes/src/libvirt-machine-properties.vala"
			__vala_GVirStorageVolInfo_free0 (volume_info);
#line 630 "/home/fborges/checkout/gnome-boxes/src/libvirt-machine-properties.vala"
			return;
#line 6549 "libvirt-machine-properties.c"
		}
#line 631 "/home/fborges/checkout/gnome-boxes/src/libvirt-machine-properties.vala"
		_tmp15_ = config;
#line 631 "/home/fborges/checkout/gnome-boxes/src/libvirt-machine-properties.vala"
		_tmp16_ = size;
#line 631 "/home/fborges/checkout/gnome-boxes/src/libvirt-machine-properties.vala"
		gvir_config_storage_vol_set_capacity (_tmp15_, _tmp16_);
#line 632 "/home/fborges/checkout/gnome-boxes/src/libvirt-machine-properties.vala"
		_tmp17_ = self->priv->machine;
#line 632 "/home/fborges/checkout/gnome-boxes/src/libvirt-machine-properties.vala"
		_tmp18_ = boxes_libvirt_machine_get_storage_volume (_tmp17_);
#line 632 "/home/fborges/checkout/gnome-boxes/src/libvirt-machine-properties.vala"
		_tmp19_ = _tmp18_;
#line 632 "/home/fborges/checkout/gnome-boxes/src/libvirt-machine-properties.vala"
		gvir_storage_vol_delete (_tmp19_, (guint) 0, &_inner_error_);
#line 632 "/home/fborges/checkout/gnome-boxes/src/libvirt-machine-properties.vala"
		if (G_UNLIKELY (_inner_error_ != NULL)) {
#line 632 "/home/fborges/checkout/gnome-boxes/src/libvirt-machine-properties.vala"
			g_propagate_error (error, _inner_error_);
#line 632 "/home/fborges/checkout/gnome-boxes/src/libvirt-machine-properties.vala"
			_g_object_unref0 (config);
#line 632 "/home/fborges/checkout/gnome-boxes/src/libvirt-machine-properties.vala"
			__vala_GVirStorageVolInfo_free0 (volume_info);
#line 632 "/home/fborges/checkout/gnome-boxes/src/libvirt-machine-properties.vala"
			return;
#line 6575 "libvirt-machine-properties.c"
		}
#line 634 "/home/fborges/checkout/gnome-boxes/src/libvirt-machine-properties.vala"
		_tmp20_ = self->priv->machine;
#line 634 "/home/fborges/checkout/gnome-boxes/src/libvirt-machine-properties.vala"
		_tmp21_ = boxes_libvirt_machine_get_connection (_tmp20_);
#line 634 "/home/fborges/checkout/gnome-boxes/src/libvirt-machine-properties.vala"
		_tmp22_ = _tmp21_;
#line 634 "/home/fborges/checkout/gnome-boxes/src/libvirt-machine-properties.vala"
		_tmp23_ = boxes_get_storage_pool (_tmp22_);
#line 634 "/home/fborges/checkout/gnome-boxes/src/libvirt-machine-properties.vala"
		pool = _tmp23_;
#line 635 "/home/fborges/checkout/gnome-boxes/src/libvirt-machine-properties.vala"
		_tmp25_ = pool;
#line 635 "/home/fborges/checkout/gnome-boxes/src/libvirt-machine-properties.vala"
		_tmp26_ = config;
#line 635 "/home/fborges/checkout/gnome-boxes/src/libvirt-machine-properties.vala"
		_tmp27_ = gvir_storage_pool_create_volume (_tmp25_, _tmp26_, &_inner_error_);
#line 635 "/home/fborges/checkout/gnome-boxes/src/libvirt-machine-properties.vala"
		_tmp24_ = _tmp27_;
#line 635 "/home/fborges/checkout/gnome-boxes/src/libvirt-machine-properties.vala"
		if (G_UNLIKELY (_inner_error_ != NULL)) {
#line 635 "/home/fborges/checkout/gnome-boxes/src/libvirt-machine-properties.vala"
			g_propagate_error (error, _inner_error_);
#line 635 "/home/fborges/checkout/gnome-boxes/src/libvirt-machine-properties.vala"
			_g_object_unref0 (pool);
#line 635 "/home/fborges/checkout/gnome-boxes/src/libvirt-machine-properties.vala"
			_g_object_unref0 (config);
#line 635 "/home/fborges/checkout/gnome-boxes/src/libvirt-machine-properties.vala"
			__vala_GVirStorageVolInfo_free0 (volume_info);
#line 635 "/home/fborges/checkout/gnome-boxes/src/libvirt-machine-properties.vala"
			return;
#line 6607 "libvirt-machine-properties.c"
		}
#line 635 "/home/fborges/checkout/gnome-boxes/src/libvirt-machine-properties.vala"
		_tmp28_ = self->priv->machine;
#line 635 "/home/fborges/checkout/gnome-boxes/src/libvirt-machine-properties.vala"
		boxes_libvirt_machine_set_storage_volume (_tmp28_, _tmp24_);
#line 628 "/home/fborges/checkout/gnome-boxes/src/libvirt-machine-properties.vala"
		_g_object_unref0 (_tmp24_);
#line 628 "/home/fborges/checkout/gnome-boxes/src/libvirt-machine-properties.vala"
		_g_object_unref0 (pool);
#line 628 "/home/fborges/checkout/gnome-boxes/src/libvirt-machine-properties.vala"
		_g_object_unref0 (config);
#line 6619 "libvirt-machine-properties.c"
	} else {
		BoxesLibvirtMachine* _tmp29_;
		GVirStorageVol* _tmp30_;
		GVirStorageVol* _tmp31_;
		guint64 _tmp32_;
#line 637 "/home/fborges/checkout/gnome-boxes/src/libvirt-machine-properties.vala"
		_tmp29_ = self->priv->machine;
#line 637 "/home/fborges/checkout/gnome-boxes/src/libvirt-machine-properties.vala"
		_tmp30_ = boxes_libvirt_machine_get_storage_volume (_tmp29_);
#line 637 "/home/fborges/checkout/gnome-boxes/src/libvirt-machine-properties.vala"
		_tmp31_ = _tmp30_;
#line 637 "/home/fborges/checkout/gnome-boxes/src/libvirt-machine-properties.vala"
		_tmp32_ = size;
#line 637 "/home/fborges/checkout/gnome-boxes/src/libvirt-machine-properties.vala"
		gvir_storage_vol_resize (_tmp31_, _tmp32_, GVIR_STORAGE_VOL_RESIZE_NONE, &_inner_error_);
#line 637 "/home/fborges/checkout/gnome-boxes/src/libvirt-machine-properties.vala"
		if (G_UNLIKELY (_inner_error_ != NULL)) {
#line 637 "/home/fborges/checkout/gnome-boxes/src/libvirt-machine-properties.vala"
			g_propagate_error (error, _inner_error_);
#line 637 "/home/fborges/checkout/gnome-boxes/src/libvirt-machine-properties.vala"
			__vala_GVirStorageVolInfo_free0 (volume_info);
#line 637 "/home/fborges/checkout/gnome-boxes/src/libvirt-machine-properties.vala"
			return;
#line 6643 "libvirt-machine-properties.c"
		}
	}
#line 626 "/home/fborges/checkout/gnome-boxes/src/libvirt-machine-properties.vala"
	__vala_GVirStorageVolInfo_free0 (volume_info);
#line 6648 "libvirt-machine-properties.c"
}


static void boxes_libvirt_machine_properties_get_snapshots_data_free (gpointer _data) {
	BoxesLibvirtMachinePropertiesGetSnapshotsData* _data_;
	_data_ = _data;
#line 5 "/home/fborges/checkout/gnome-boxes/src/libvirt-machine-properties.vala"
	_g_object_unref0 (_data_->cancellable);
#line 5 "/home/fborges/checkout/gnome-boxes/src/libvirt-machine-properties.vala"
	__g_list_free__g_object_unref0_0 (_data_->result);
#line 5 "/home/fborges/checkout/gnome-boxes/src/libvirt-machine-properties.vala"
	_g_object_unref0 (_data_->self);
#line 5 "/home/fborges/checkout/gnome-boxes/src/libvirt-machine-properties.vala"
	g_slice_free (BoxesLibvirtMachinePropertiesGetSnapshotsData, _data_);
#line 6663 "libvirt-machine-properties.c"
}


void boxes_libvirt_machine_properties_get_snapshots (BoxesLibvirtMachineProperties* self, GCancellable* cancellable, GAsyncReadyCallback _callback_, gpointer _user_data_) {
	BoxesLibvirtMachinePropertiesGetSnapshotsData* _data_;
	BoxesLibvirtMachineProperties* _tmp0_;
	GCancellable* _tmp1_;
	GCancellable* _tmp2_;
#line 5 "/home/fborges/checkout/gnome-boxes/src/libvirt-machine-properties.vala"
	_data_ = g_slice_new0 (BoxesLibvirtMachinePropertiesGetSnapshotsData);
#line 5 "/home/fborges/checkout/gnome-boxes/src/libvirt-machine-properties.vala"
	_data_->_async_result = g_task_new (G_OBJECT (self), cancellable, _callback_, _user_data_);
#line 5 "/home/fborges/checkout/gnome-boxes/src/libvirt-machine-properties.vala"
	g_task_set_task_data (_data_->_async_result, _data_, boxes_libvirt_machine_properties_get_snapshots_data_free);
#line 5 "/home/fborges/checkout/gnome-boxes/src/libvirt-machine-properties.vala"
	_tmp0_ = _g_object_ref0 (self);
#line 5 "/home/fborges/checkout/gnome-boxes/src/libvirt-machine-properties.vala"
	_data_->self = _tmp0_;
#line 5 "/home/fborges/checkout/gnome-boxes/src/libvirt-machine-properties.vala"
	_tmp1_ = cancellable;
#line 5 "/home/fborges/checkout/gnome-boxes/src/libvirt-machine-properties.vala"
	_tmp2_ = _g_object_ref0 (_tmp1_);
#line 5 "/home/fborges/checkout/gnome-boxes/src/libvirt-machine-properties.vala"
	_g_object_unref0 (_data_->cancellable);
#line 5 "/home/fborges/checkout/gnome-boxes/src/libvirt-machine-properties.vala"
	_data_->cancellable = _tmp2_;
#line 5 "/home/fborges/checkout/gnome-boxes/src/libvirt-machine-properties.vala"
	boxes_libvirt_machine_properties_get_snapshots_co (_data_);
#line 6692 "libvirt-machine-properties.c"
}


GList* boxes_libvirt_machine_properties_get_snapshots_finish (BoxesLibvirtMachineProperties* self, GAsyncResult* _res_, GError** error) {
	GList* result;
	BoxesLibvirtMachinePropertiesGetSnapshotsData* _data_;
#line 5 "/home/fborges/checkout/gnome-boxes/src/libvirt-machine-properties.vala"
	_data_ = g_task_propagate_pointer (G_TASK (_res_), error);
#line 5 "/home/fborges/checkout/gnome-boxes/src/libvirt-machine-properties.vala"
	if (NULL == _data_) {
#line 5 "/home/fborges/checkout/gnome-boxes/src/libvirt-machine-properties.vala"
		return NULL;
#line 6705 "libvirt-machine-properties.c"
	}
#line 5 "/home/fborges/checkout/gnome-boxes/src/libvirt-machine-properties.vala"
	result = _data_->result;
#line 5 "/home/fborges/checkout/gnome-boxes/src/libvirt-machine-properties.vala"
	_data_->result = NULL;
#line 5 "/home/fborges/checkout/gnome-boxes/src/libvirt-machine-properties.vala"
	return result;
#line 6713 "libvirt-machine-properties.c"
}


static void boxes_libvirt_machine_properties_get_snapshots_ready (GObject* source_object, GAsyncResult* _res_, gpointer _user_data_) {
	BoxesLibvirtMachinePropertiesGetSnapshotsData* _data_;
#line 642 "/home/fborges/checkout/gnome-boxes/src/libvirt-machine-properties.vala"
	_data_ = _user_data_;
#line 642 "/home/fborges/checkout/gnome-boxes/src/libvirt-machine-properties.vala"
	_data_->_source_object_ = source_object;
#line 642 "/home/fborges/checkout/gnome-boxes/src/libvirt-machine-properties.vala"
	_data_->_res_ = _res_;
#line 642 "/home/fborges/checkout/gnome-boxes/src/libvirt-machine-properties.vala"
	boxes_libvirt_machine_properties_get_snapshots_co (_data_);
#line 6727 "libvirt-machine-properties.c"
}


static gboolean boxes_libvirt_machine_properties_get_snapshots_co (BoxesLibvirtMachinePropertiesGetSnapshotsData* _data_) {
#line 641 "/home/fborges/checkout/gnome-boxes/src/libvirt-machine-properties.vala"
	switch (_data_->_state_) {
#line 641 "/home/fborges/checkout/gnome-boxes/src/libvirt-machine-properties.vala"
		case 0:
#line 6736 "libvirt-machine-properties.c"
		goto _state_0;
#line 641 "/home/fborges/checkout/gnome-boxes/src/libvirt-machine-properties.vala"
		case 1:
#line 6740 "libvirt-machine-properties.c"
		goto _state_1;
		default:
#line 641 "/home/fborges/checkout/gnome-boxes/src/libvirt-machine-properties.vala"
		g_assert_not_reached ();
#line 6745 "libvirt-machine-properties.c"
	}
	_state_0:
#line 642 "/home/fborges/checkout/gnome-boxes/src/libvirt-machine-properties.vala"
	_data_->_tmp0_ = _data_->self->priv->machine;
#line 642 "/home/fborges/checkout/gnome-boxes/src/libvirt-machine-properties.vala"
	_data_->_tmp1_ = boxes_libvirt_machine_get_domain (_data_->_tmp0_);
#line 642 "/home/fborges/checkout/gnome-boxes/src/libvirt-machine-properties.vala"
	_data_->_tmp2_ = _data_->_tmp1_;
#line 642 "/home/fborges/checkout/gnome-boxes/src/libvirt-machine-properties.vala"
	_data_->_tmp3_ = _data_->cancellable;
#line 642 "/home/fborges/checkout/gnome-boxes/src/libvirt-machine-properties.vala"
	_data_->_state_ = 1;
#line 642 "/home/fborges/checkout/gnome-boxes/src/libvirt-machine-properties.vala"
	gvir_domain_fetch_snapshots_async (_data_->_tmp2_, (guint) GVIR_DOMAIN_SNAPSHOT_LIST_ALL, _data_->_tmp3_, boxes_libvirt_machine_properties_get_snapshots_ready, _data_);
#line 642 "/home/fborges/checkout/gnome-boxes/src/libvirt-machine-properties.vala"
	return FALSE;
#line 6762 "libvirt-machine-properties.c"
	_state_1:
#line 642 "/home/fborges/checkout/gnome-boxes/src/libvirt-machine-properties.vala"
	gvir_domain_fetch_snapshots_finish (_data_->_tmp2_, _data_->_res_, &_data_->_inner_error_);
#line 642 "/home/fborges/checkout/gnome-boxes/src/libvirt-machine-properties.vala"
	if (G_UNLIKELY (_data_->_inner_error_ != NULL)) {
#line 642 "/home/fborges/checkout/gnome-boxes/src/libvirt-machine-properties.vala"
		g_task_return_error (_data_->_async_result, _data_->_inner_error_);
#line 642 "/home/fborges/checkout/gnome-boxes/src/libvirt-machine-properties.vala"
		g_object_unref (_data_->_async_result);
#line 642 "/home/fborges/checkout/gnome-boxes/src/libvirt-machine-properties.vala"
		return FALSE;
#line 6774 "libvirt-machine-properties.c"
	}
#line 644 "/home/fborges/checkout/gnome-boxes/src/libvirt-machine-properties.vala"
	_data_->_tmp4_ = _data_->self->priv->machine;
#line 644 "/home/fborges/checkout/gnome-boxes/src/libvirt-machine-properties.vala"
	_data_->_tmp5_ = boxes_libvirt_machine_get_domain (_data_->_tmp4_);
#line 644 "/home/fborges/checkout/gnome-boxes/src/libvirt-machine-properties.vala"
	_data_->_tmp6_ = _data_->_tmp5_;
#line 644 "/home/fborges/checkout/gnome-boxes/src/libvirt-machine-properties.vala"
	_data_->_tmp7_ = gvir_domain_get_snapshots (_data_->_tmp6_);
#line 644 "/home/fborges/checkout/gnome-boxes/src/libvirt-machine-properties.vala"
	_data_->result = _data_->_tmp7_;
#line 644 "/home/fborges/checkout/gnome-boxes/src/libvirt-machine-properties.vala"
	g_task_return_pointer (_data_->_async_result, _data_, NULL);
#line 644 "/home/fborges/checkout/gnome-boxes/src/libvirt-machine-properties.vala"
	if (_data_->_state_ != 0) {
#line 644 "/home/fborges/checkout/gnome-boxes/src/libvirt-machine-properties.vala"
		while (g_task_get_completed (_data_->_async_result) != TRUE) {
#line 644 "/home/fborges/checkout/gnome-boxes/src/libvirt-machine-properties.vala"
			g_main_context_iteration (g_task_get_context (_data_->_async_result), TRUE);
#line 6794 "libvirt-machine-properties.c"
		}
	}
#line 644 "/home/fborges/checkout/gnome-boxes/src/libvirt-machine-properties.vala"
	g_object_unref (_data_->_async_result);
#line 644 "/home/fborges/checkout/gnome-boxes/src/libvirt-machine-properties.vala"
	return FALSE;
#line 6801 "libvirt-machine-properties.c"
}


static Block54Data* block54_data_ref (Block54Data* _data54_) {
#line 647 "/home/fborges/checkout/gnome-boxes/src/libvirt-machine-properties.vala"
	g_atomic_int_inc (&_data54_->_ref_count_);
#line 647 "/home/fborges/checkout/gnome-boxes/src/libvirt-machine-properties.vala"
	return _data54_;
#line 6810 "libvirt-machine-properties.c"
}


static void block54_data_unref (void * _userdata_) {
	Block54Data* _data54_;
	_data54_ = (Block54Data*) _userdata_;
#line 647 "/home/fborges/checkout/gnome-boxes/src/libvirt-machine-properties.vala"
	if (g_atomic_int_dec_and_test (&_data54_->_ref_count_)) {
#line 6819 "libvirt-machine-properties.c"
		BoxesLibvirtMachineProperties* self;
#line 647 "/home/fborges/checkout/gnome-boxes/src/libvirt-machine-properties.vala"
		self = _data54_->self;
#line 647 "/home/fborges/checkout/gnome-boxes/src/libvirt-machine-properties.vala"
		_g_free0 (_data54_->name);
#line 647 "/home/fborges/checkout/gnome-boxes/src/libvirt-machine-properties.vala"
		_g_object_unref0 (_data54_->toggle);
#line 647 "/home/fborges/checkout/gnome-boxes/src/libvirt-machine-properties.vala"
		_g_object_unref0 (_data54_->box);
#line 647 "/home/fborges/checkout/gnome-boxes/src/libvirt-machine-properties.vala"
		_g_object_unref0 (self);
#line 647 "/home/fborges/checkout/gnome-boxes/src/libvirt-machine-properties.vala"
		g_slice_free (Block54Data, _data54_);
#line 6833 "libvirt-machine-properties.c"
	}
}


static void __lambda139_ (Block54Data* _data54_, GParamSpec* tooltip) {
	BoxesLibvirtMachineProperties* self;
	gchar* _tmp0_ = NULL;
	GtkSwitch* _tmp1_;
	gboolean _tmp2_;
	gboolean _tmp3_;
	GtkBox* _tmp8_;
#line 668 "/home/fborges/checkout/gnome-boxes/src/libvirt-machine-properties.vala"
	self = _data54_->self;
#line 668 "/home/fborges/checkout/gnome-boxes/src/libvirt-machine-properties.vala"
	g_return_if_fail (tooltip != NULL);
#line 669 "/home/fborges/checkout/gnome-boxes/src/libvirt-machine-properties.vala"
	_tmp1_ = _data54_->toggle;
#line 669 "/home/fborges/checkout/gnome-boxes/src/libvirt-machine-properties.vala"
	_tmp2_ = gtk_switch_get_active (_tmp1_);
#line 669 "/home/fborges/checkout/gnome-boxes/src/libvirt-machine-properties.vala"
	_tmp3_ = _tmp2_;
#line 669 "/home/fborges/checkout/gnome-boxes/src/libvirt-machine-properties.vala"
	if (_tmp3_) {
#line 6857 "libvirt-machine-properties.c"
		const gchar* _tmp4_;
		gchar* _tmp5_;
#line 669 "/home/fborges/checkout/gnome-boxes/src/libvirt-machine-properties.vala"
		_tmp4_ = _data54_->name;
#line 669 "/home/fborges/checkout/gnome-boxes/src/libvirt-machine-properties.vala"
		_tmp5_ = g_strdup_printf (_ ("“%s” will not be paused automatically."), _tmp4_);
#line 669 "/home/fborges/checkout/gnome-boxes/src/libvirt-machine-properties.vala"
		_g_free0 (_tmp0_);
#line 669 "/home/fborges/checkout/gnome-boxes/src/libvirt-machine-properties.vala"
		_tmp0_ = _tmp5_;
#line 6868 "libvirt-machine-properties.c"
	} else {
		const gchar* _tmp6_;
		gchar* _tmp7_;
#line 670 "/home/fborges/checkout/gnome-boxes/src/libvirt-machine-properties.vala"
		_tmp6_ = _data54_->name;
#line 670 "/home/fborges/checkout/gnome-boxes/src/libvirt-machine-properties.vala"
		_tmp7_ = g_strdup_printf (_ ("“%s” will be paused automatically to save resources."), _tmp6_);
#line 670 "/home/fborges/checkout/gnome-boxes/src/libvirt-machine-properties.vala"
		_g_free0 (_tmp0_);
#line 670 "/home/fborges/checkout/gnome-boxes/src/libvirt-machine-properties.vala"
		_tmp0_ = _tmp7_;
#line 6880 "libvirt-machine-properties.c"
	}
#line 669 "/home/fborges/checkout/gnome-boxes/src/libvirt-machine-properties.vala"
	_tmp8_ = _data54_->box;
#line 669 "/home/fborges/checkout/gnome-boxes/src/libvirt-machine-properties.vala"
	gtk_widget_set_tooltip_text ((GtkWidget*) _tmp8_, _tmp0_);
#line 668 "/home/fborges/checkout/gnome-boxes/src/libvirt-machine-properties.vala"
	_g_free0 (_tmp0_);
#line 6888 "libvirt-machine-properties.c"
}


static void ___lambda139__g_object_notify (GObject* _sender, GParamSpec* pspec, gpointer self) {
#line 668 "/home/fborges/checkout/gnome-boxes/src/libvirt-machine-properties.vala"
	__lambda139_ (self, pspec);
#line 6895 "libvirt-machine-properties.c"
}


static void boxes_libvirt_machine_properties_add_run_in_bg_property (BoxesLibvirtMachineProperties* self, GList* * list) {
	Block54Data* _data54_;
	BoxesLibvirtMachine* _tmp0_;
	GVirConnection* _tmp1_;
	GVirConnection* _tmp2_;
	BoxesApp* _tmp3_;
	GVirConnection* _tmp4_;
	GVirConnection* _tmp5_;
	GVirConnection* _tmp6_;
	gboolean _tmp7_;
	GtkBox* _tmp8_;
	GtkBox* _tmp9_;
	GtkBox* _tmp10_;
	GtkLabel* label = NULL;
	GtkLabel* _tmp11_;
	GtkLabel* _tmp12_;
	GtkStyleContext* _tmp13_;
	GtkBox* _tmp14_;
	GtkLabel* _tmp15_;
	GtkSwitch* _tmp16_;
	BoxesLibvirtMachine* _tmp17_;
	GtkSwitch* _tmp18_;
	GtkSwitch* _tmp19_;
	GtkBox* _tmp20_;
	GtkSwitch* _tmp21_;
	GtkLabel* _tmp22_;
	GtkSwitch* _tmp23_;
	BoxesLibvirtMachine* _tmp24_;
	const gchar* _tmp25_;
	const gchar* _tmp26_;
	gchar* _tmp27_;
	gchar* _tmp28_ = NULL;
	GtkSwitch* _tmp29_;
	gboolean _tmp30_;
	gboolean _tmp31_;
	GtkBox* _tmp36_;
	GtkSwitch* _tmp37_;
	GtkBox* _tmp38_;
	BoxesProperty* _tmp39_;
	BoxesProperty* _tmp40_;
#line 647 "/home/fborges/checkout/gnome-boxes/src/libvirt-machine-properties.vala"
	g_return_if_fail (self != NULL);
#line 647 "/home/fborges/checkout/gnome-boxes/src/libvirt-machine-properties.vala"
	_data54_ = g_slice_new0 (Block54Data);
#line 647 "/home/fborges/checkout/gnome-boxes/src/libvirt-machine-properties.vala"
	_data54_->_ref_count_ = 1;
#line 647 "/home/fborges/checkout/gnome-boxes/src/libvirt-machine-properties.vala"
	_data54_->self = g_object_ref (self);
#line 648 "/home/fborges/checkout/gnome-boxes/src/libvirt-machine-properties.vala"
	_tmp0_ = self->priv->machine;
#line 648 "/home/fborges/checkout/gnome-boxes/src/libvirt-machine-properties.vala"
	_tmp1_ = boxes_libvirt_machine_get_connection (_tmp0_);
#line 648 "/home/fborges/checkout/gnome-boxes/src/libvirt-machine-properties.vala"
	_tmp2_ = _tmp1_;
#line 648 "/home/fborges/checkout/gnome-boxes/src/libvirt-machine-properties.vala"
	_tmp3_ = boxes_app_app;
#line 648 "/home/fborges/checkout/gnome-boxes/src/libvirt-machine-properties.vala"
	_tmp4_ = boxes_app_get_default_connection (_tmp3_);
#line 648 "/home/fborges/checkout/gnome-boxes/src/libvirt-machine-properties.vala"
	_tmp5_ = _tmp4_;
#line 648 "/home/fborges/checkout/gnome-boxes/src/libvirt-machine-properties.vala"
	_tmp6_ = _tmp5_;
#line 648 "/home/fborges/checkout/gnome-boxes/src/libvirt-machine-properties.vala"
	_tmp7_ = _tmp2_ != _tmp6_;
#line 648 "/home/fborges/checkout/gnome-boxes/src/libvirt-machine-properties.vala"
	_g_object_unref0 (_tmp6_);
#line 648 "/home/fborges/checkout/gnome-boxes/src/libvirt-machine-properties.vala"
	if (_tmp7_) {
#line 649 "/home/fborges/checkout/gnome-boxes/src/libvirt-machine-properties.vala"
		block54_data_unref (_data54_);
#line 649 "/home/fborges/checkout/gnome-boxes/src/libvirt-machine-properties.vala"
		_data54_ = NULL;
#line 649 "/home/fborges/checkout/gnome-boxes/src/libvirt-machine-properties.vala"
		return;
#line 6973 "libvirt-machine-properties.c"
	}
#line 651 "/home/fborges/checkout/gnome-boxes/src/libvirt-machine-properties.vala"
	_tmp8_ = (GtkBox*) gtk_box_new (GTK_ORIENTATION_HORIZONTAL, 20);
#line 651 "/home/fborges/checkout/gnome-boxes/src/libvirt-machine-properties.vala"
	g_object_ref_sink (_tmp8_);
#line 651 "/home/fborges/checkout/gnome-boxes/src/libvirt-machine-properties.vala"
	_data54_->box = _tmp8_;
#line 652 "/home/fborges/checkout/gnome-boxes/src/libvirt-machine-properties.vala"
	_tmp9_ = _data54_->box;
#line 652 "/home/fborges/checkout/gnome-boxes/src/libvirt-machine-properties.vala"
	gtk_widget_set_halign ((GtkWidget*) _tmp9_, GTK_ALIGN_END);
#line 653 "/home/fborges/checkout/gnome-boxes/src/libvirt-machine-properties.vala"
	_tmp10_ = _data54_->box;
#line 653 "/home/fborges/checkout/gnome-boxes/src/libvirt-machine-properties.vala"
	gtk_widget_set_has_tooltip ((GtkWidget*) _tmp10_, TRUE);
#line 655 "/home/fborges/checkout/gnome-boxes/src/libvirt-machine-properties.vala"
	_tmp11_ = (GtkLabel*) gtk_label_new_with_mnemonic (_ ("_Run in background"));
#line 655 "/home/fborges/checkout/gnome-boxes/src/libvirt-machine-properties.vala"
	g_object_ref_sink (_tmp11_);
#line 655 "/home/fborges/checkout/gnome-boxes/src/libvirt-machine-properties.vala"
	label = _tmp11_;
#line 656 "/home/fborges/checkout/gnome-boxes/src/libvirt-machine-properties.vala"
	_tmp12_ = label;
#line 656 "/home/fborges/checkout/gnome-boxes/src/libvirt-machine-properties.vala"
	_tmp13_ = gtk_widget_get_style_context ((GtkWidget*) _tmp12_);
#line 656 "/home/fborges/checkout/gnome-boxes/src/libvirt-machine-properties.vala"
	gtk_style_context_add_class (_tmp13_, "dim-label");
#line 657 "/home/fborges/checkout/gnome-boxes/src/libvirt-machine-properties.vala"
	_tmp14_ = _data54_->box;
#line 657 "/home/fborges/checkout/gnome-boxes/src/libvirt-machine-properties.vala"
	_tmp15_ = label;
#line 657 "/home/fborges/checkout/gnome-boxes/src/libvirt-machine-properties.vala"
	gtk_container_add ((GtkContainer*) _tmp14_, (GtkWidget*) _tmp15_);
#line 658 "/home/fborges/checkout/gnome-boxes/src/libvirt-machine-properties.vala"
	_tmp16_ = (GtkSwitch*) gtk_switch_new ();
#line 658 "/home/fborges/checkout/gnome-boxes/src/libvirt-machine-properties.vala"
	g_object_ref_sink (_tmp16_);
#line 658 "/home/fborges/checkout/gnome-boxes/src/libvirt-machine-properties.vala"
	_data54_->toggle = _tmp16_;
#line 659 "/home/fborges/checkout/gnome-boxes/src/libvirt-machine-properties.vala"
	_tmp17_ = self->priv->machine;
#line 659 "/home/fborges/checkout/gnome-boxes/src/libvirt-machine-properties.vala"
	_tmp18_ = _data54_->toggle;
#line 659 "/home/fborges/checkout/gnome-boxes/src/libvirt-machine-properties.vala"
	g_object_bind_property_with_closures ((GObject*) _tmp17_, "run-in-bg", (GObject*) _tmp18_, "active", G_BINDING_BIDIRECTIONAL | G_BINDING_SYNC_CREATE, (GClosure*) ((NULL == NULL) ? NULL : g_cclosure_new ((GCallback) NULL, NULL, (GClosureNotify) NULL)), (GClosure*) ((NULL == NULL) ? NULL : g_cclosure_new ((GCallback) NULL, NULL, (GClosureNotify) NULL)));
#line 661 "/home/fborges/checkout/gnome-boxes/src/libvirt-machine-properties.vala"
	_tmp19_ = _data54_->toggle;
#line 661 "/home/fborges/checkout/gnome-boxes/src/libvirt-machine-properties.vala"
	gtk_widget_set_halign ((GtkWidget*) _tmp19_, GTK_ALIGN_START);
#line 662 "/home/fborges/checkout/gnome-boxes/src/libvirt-machine-properties.vala"
	_tmp20_ = _data54_->box;
#line 662 "/home/fborges/checkout/gnome-boxes/src/libvirt-machine-properties.vala"
	_tmp21_ = _data54_->toggle;
#line 662 "/home/fborges/checkout/gnome-boxes/src/libvirt-machine-properties.vala"
	gtk_container_add ((GtkContainer*) _tmp20_, (GtkWidget*) _tmp21_);
#line 663 "/home/fborges/checkout/gnome-boxes/src/libvirt-machine-properties.vala"
	_tmp22_ = label;
#line 663 "/home/fborges/checkout/gnome-boxes/src/libvirt-machine-properties.vala"
	_tmp23_ = _data54_->toggle;
#line 663 "/home/fborges/checkout/gnome-boxes/src/libvirt-machine-properties.vala"
	gtk_label_set_mnemonic_widget (_tmp22_, (GtkWidget*) _tmp23_);
#line 665 "/home/fborges/checkout/gnome-boxes/src/libvirt-machine-properties.vala"
	_tmp24_ = self->priv->machine;
#line 665 "/home/fborges/checkout/gnome-boxes/src/libvirt-machine-properties.vala"
	_tmp25_ = boxes_collection_item_get_name ((BoxesCollectionItem*) _tmp24_);
#line 665 "/home/fborges/checkout/gnome-boxes/src/libvirt-machine-properties.vala"
	_tmp26_ = _tmp25_;
#line 665 "/home/fborges/checkout/gnome-boxes/src/libvirt-machine-properties.vala"
	_tmp27_ = g_strdup (_tmp26_);
#line 665 "/home/fborges/checkout/gnome-boxes/src/libvirt-machine-properties.vala"
	_data54_->name = _tmp27_;
#line 666 "/home/fborges/checkout/gnome-boxes/src/libvirt-machine-properties.vala"
	_tmp29_ = _data54_->toggle;
#line 666 "/home/fborges/checkout/gnome-boxes/src/libvirt-machine-properties.vala"
	_tmp30_ = gtk_switch_get_active (_tmp29_);
#line 666 "/home/fborges/checkout/gnome-boxes/src/libvirt-machine-properties.vala"
	_tmp31_ = _tmp30_;
#line 666 "/home/fborges/checkout/gnome-boxes/src/libvirt-machine-properties.vala"
	if (_tmp31_) {
#line 7053 "libvirt-machine-properties.c"
		const gchar* _tmp32_;
		gchar* _tmp33_;
#line 666 "/home/fborges/checkout/gnome-boxes/src/libvirt-machine-properties.vala"
		_tmp32_ = _data54_->name;
#line 666 "/home/fborges/checkout/gnome-boxes/src/libvirt-machine-properties.vala"
		_tmp33_ = g_strdup_printf (_ ("“%s” will not be paused automatically."), _tmp32_);
#line 666 "/home/fborges/checkout/gnome-boxes/src/libvirt-machine-properties.vala"
		_g_free0 (_tmp28_);
#line 666 "/home/fborges/checkout/gnome-boxes/src/libvirt-machine-properties.vala"
		_tmp28_ = _tmp33_;
#line 7064 "libvirt-machine-properties.c"
	} else {
		const gchar* _tmp34_;
		gchar* _tmp35_;
#line 667 "/home/fborges/checkout/gnome-boxes/src/libvirt-machine-properties.vala"
		_tmp34_ = _data54_->name;
#line 667 "/home/fborges/checkout/gnome-boxes/src/libvirt-machine-properties.vala"
		_tmp35_ = g_strdup_printf (_ ("“%s” will be paused automatically to save resources."), _tmp34_);
#line 667 "/home/fborges/checkout/gnome-boxes/src/libvirt-machine-properties.vala"
		_g_free0 (_tmp28_);
#line 667 "/home/fborges/checkout/gnome-boxes/src/libvirt-machine-properties.vala"
		_tmp28_ = _tmp35_;
#line 7076 "libvirt-machine-properties.c"
	}
#line 666 "/home/fborges/checkout/gnome-boxes/src/libvirt-machine-properties.vala"
	_tmp36_ = _data54_->box;
#line 666 "/home/fborges/checkout/gnome-boxes/src/libvirt-machine-properties.vala"
	gtk_widget_set_tooltip_text ((GtkWidget*) _tmp36_, _tmp28_);
#line 668 "/home/fborges/checkout/gnome-boxes/src/libvirt-machine-properties.vala"
	_tmp37_ = _data54_->toggle;
#line 668 "/home/fborges/checkout/gnome-boxes/src/libvirt-machine-properties.vala"
	g_signal_connect_data ((GObject*) _tmp37_, "notify::active", (GCallback) ___lambda139__g_object_notify, block54_data_ref (_data54_), (GClosureNotify) block54_data_unref, 0);
#line 673 "/home/fborges/checkout/gnome-boxes/src/libvirt-machine-properties.vala"
	_tmp38_ = _data54_->box;
#line 673 "/home/fborges/checkout/gnome-boxes/src/libvirt-machine-properties.vala"
	_tmp39_ = boxes_iproperties_provider_add_property ((BoxesIPropertiesProvider*) self, list, NULL, (GtkWidget*) _tmp38_, NULL);
#line 673 "/home/fborges/checkout/gnome-boxes/src/libvirt-machine-properties.vala"
	_tmp40_ = _tmp39_;
#line 673 "/home/fborges/checkout/gnome-boxes/src/libvirt-machine-properties.vala"
	_g_object_unref0 (_tmp40_);
#line 647 "/home/fborges/checkout/gnome-boxes/src/libvirt-machine-properties.vala"
	_g_free0 (_tmp28_);
#line 647 "/home/fborges/checkout/gnome-boxes/src/libvirt-machine-properties.vala"
	_g_object_unref0 (label);
#line 647 "/home/fborges/checkout/gnome-boxes/src/libvirt-machine-properties.vala"
	block54_data_unref (_data54_);
#line 647 "/home/fborges/checkout/gnome-boxes/src/libvirt-machine-properties.vala"
	_data54_ = NULL;
#line 7102 "libvirt-machine-properties.c"
}


static BoxesSnapshotsProperty* boxes_libvirt_machine_properties_add_snapshots_property (BoxesLibvirtMachineProperties* self, GList* * list) {
	BoxesSnapshotsProperty* result = NULL;
	BoxesSnapshotsProperty* property = NULL;
	BoxesLibvirtMachine* _tmp0_;
	BoxesSnapshotsProperty* _tmp1_;
	BoxesProperty* _tmp2_;
#line 676 "/home/fborges/checkout/gnome-boxes/src/libvirt-machine-properties.vala"
	g_return_val_if_fail (self != NULL, NULL);
#line 677 "/home/fborges/checkout/gnome-boxes/src/libvirt-machine-properties.vala"
	_tmp0_ = self->priv->machine;
#line 677 "/home/fborges/checkout/gnome-boxes/src/libvirt-machine-properties.vala"
	_tmp1_ = boxes_snapshots_property_new (_tmp0_);
#line 677 "/home/fborges/checkout/gnome-boxes/src/libvirt-machine-properties.vala"
	property = _tmp1_;
#line 678 "/home/fborges/checkout/gnome-boxes/src/libvirt-machine-properties.vala"
	_tmp2_ = _g_object_ref0 ((BoxesProperty*) property);
#line 678 "/home/fborges/checkout/gnome-boxes/src/libvirt-machine-properties.vala"
	*list = g_list_append (*list, _tmp2_);
#line 680 "/home/fborges/checkout/gnome-boxes/src/libvirt-machine-properties.vala"
	result = property;
#line 680 "/home/fborges/checkout/gnome-boxes/src/libvirt-machine-properties.vala"
	return result;
#line 7128 "libvirt-machine-properties.c"
}


static void boxes_libvirt_machine_properties_class_init (BoxesLibvirtMachinePropertiesClass * klass) {
#line 5 "/home/fborges/checkout/gnome-boxes/src/libvirt-machine-properties.vala"
	boxes_libvirt_machine_properties_parent_class = g_type_class_peek_parent (klass);
#line 5 "/home/fborges/checkout/gnome-boxes/src/libvirt-machine-properties.vala"
	g_type_class_add_private (klass, sizeof (BoxesLibvirtMachinePropertiesPrivate));
#line 5 "/home/fborges/checkout/gnome-boxes/src/libvirt-machine-properties.vala"
	G_OBJECT_CLASS (klass)->finalize = boxes_libvirt_machine_properties_finalize;
#line 7139 "libvirt-machine-properties.c"
}


static void boxes_libvirt_machine_properties_boxes_iproperties_provider_interface_init (BoxesIPropertiesProviderIface * iface) {
#line 5 "/home/fborges/checkout/gnome-boxes/src/libvirt-machine-properties.vala"
	boxes_libvirt_machine_properties_boxes_iproperties_provider_parent_iface = g_type_interface_peek_parent (iface);
#line 5 "/home/fborges/checkout/gnome-boxes/src/libvirt-machine-properties.vala"
	iface->get_properties = (GList* (*) (BoxesIPropertiesProvider *, BoxesPropertiesPage)) boxes_libvirt_machine_properties_real_get_properties;
#line 7148 "libvirt-machine-properties.c"
}


static void boxes_libvirt_machine_properties_instance_init (BoxesLibvirtMachineProperties * self) {
#line 5 "/home/fborges/checkout/gnome-boxes/src/libvirt-machine-properties.vala"
	self->priv = BOXES_LIBVIRT_MACHINE_PROPERTIES_GET_PRIVATE (self);
#line 7155 "libvirt-machine-properties.c"
}


static void boxes_libvirt_machine_properties_finalize (GObject * obj) {
	BoxesLibvirtMachineProperties * self;
#line 5 "/home/fborges/checkout/gnome-boxes/src/libvirt-machine-properties.vala"
	self = G_TYPE_CHECK_INSTANCE_CAST (obj, BOXES_TYPE_LIBVIRT_MACHINE_PROPERTIES, BoxesLibvirtMachineProperties);
#line 5 "/home/fborges/checkout/gnome-boxes/src/libvirt-machine-properties.vala"
	G_OBJECT_CLASS (boxes_libvirt_machine_properties_parent_class)->finalize (obj);
#line 7165 "libvirt-machine-properties.c"
}


GType boxes_libvirt_machine_properties_get_type (void) {
	static volatile gsize boxes_libvirt_machine_properties_type_id__volatile = 0;
	if (g_once_init_enter (&boxes_libvirt_machine_properties_type_id__volatile)) {
		static const GTypeInfo g_define_type_info = { sizeof (BoxesLibvirtMachinePropertiesClass), (GBaseInitFunc) NULL, (GBaseFinalizeFunc) NULL, (GClassInitFunc) boxes_libvirt_machine_properties_class_init, (GClassFinalizeFunc) NULL, NULL, sizeof (BoxesLibvirtMachineProperties), 0, (GInstanceInitFunc) boxes_libvirt_machine_properties_instance_init, NULL };
		static const GInterfaceInfo boxes_iproperties_provider_info = { (GInterfaceInitFunc) boxes_libvirt_machine_properties_boxes_iproperties_provider_interface_init, (GInterfaceFinalizeFunc) NULL, NULL};
		GType boxes_libvirt_machine_properties_type_id;
		boxes_libvirt_machine_properties_type_id = g_type_register_static (G_TYPE_OBJECT, "BoxesLibvirtMachineProperties", &g_define_type_info, 0);
		g_type_add_interface_static (boxes_libvirt_machine_properties_type_id, BOXES_TYPE_IPROPERTIES_PROVIDER, &boxes_iproperties_provider_info);
		g_once_init_leave (&boxes_libvirt_machine_properties_type_id__volatile, boxes_libvirt_machine_properties_type_id);
	}
	return boxes_libvirt_machine_properties_type_id__volatile;
}



