/* wizard-source.c generated by valac 0.38.4, the Vala compiler
 * generated from wizard-source.vala, do not modify */

/* This file is part of GNOME Boxes. License: LGPLv2+*/

#include <glib.h>
#include <glib-object.h>
#include <gtk/gtk.h>
#include <osinfo/osinfo.h>
#include <stdlib.h>
#include <string.h>
#include <gio/gio.h>
#include <glib/gi18n-lib.h>
#include <libvirt-gconfig/libvirt-gconfig.h>
#include <libcommon.h>
#include <webkit2/webkit2.h>
#include <gdk/gdk.h>
#include <float.h>
#include <math.h>
#include <pango/pango.h>
#include <gdk-pixbuf/gdk-pixbuf.h>
#include <libsoup/soup.h>


#define BOXES_TYPE_SOURCE_PAGE (boxes_source_page_get_type ())

#define BOXES_TYPE_WIZARD_SCROLLED (boxes_wizard_scrolled_get_type ())
#define BOXES_WIZARD_SCROLLED(obj) (G_TYPE_CHECK_INSTANCE_CAST ((obj), BOXES_TYPE_WIZARD_SCROLLED, BoxesWizardScrolled))
#define BOXES_WIZARD_SCROLLED_CLASS(klass) (G_TYPE_CHECK_CLASS_CAST ((klass), BOXES_TYPE_WIZARD_SCROLLED, BoxesWizardScrolledClass))
#define BOXES_IS_WIZARD_SCROLLED(obj) (G_TYPE_CHECK_INSTANCE_TYPE ((obj), BOXES_TYPE_WIZARD_SCROLLED))
#define BOXES_IS_WIZARD_SCROLLED_CLASS(klass) (G_TYPE_CHECK_CLASS_TYPE ((klass), BOXES_TYPE_WIZARD_SCROLLED))
#define BOXES_WIZARD_SCROLLED_GET_CLASS(obj) (G_TYPE_INSTANCE_GET_CLASS ((obj), BOXES_TYPE_WIZARD_SCROLLED, BoxesWizardScrolledClass))

typedef struct _BoxesWizardScrolled BoxesWizardScrolled;
typedef struct _BoxesWizardScrolledClass BoxesWizardScrolledClass;
typedef struct _BoxesWizardScrolledPrivate BoxesWizardScrolledPrivate;
enum  {
	BOXES_WIZARD_SCROLLED_0_PROPERTY,
	BOXES_WIZARD_SCROLLED_NUM_PROPERTIES
};
static GParamSpec* boxes_wizard_scrolled_properties[BOXES_WIZARD_SCROLLED_NUM_PROPERTIES];
#define _g_object_unref0(var) ((var == NULL) ? NULL : (var = (g_object_unref (var), NULL)))
#define _g_list_free0(var) ((var == NULL) ? NULL : (var = (g_list_free (var), NULL)))

#define BOXES_TYPE_WIZARD_DOWNLOADABLE_MEDIA_ENTRY (boxes_wizard_downloadable_media_entry_get_type ())
#define BOXES_WIZARD_DOWNLOADABLE_MEDIA_ENTRY(obj) (G_TYPE_CHECK_INSTANCE_CAST ((obj), BOXES_TYPE_WIZARD_DOWNLOADABLE_MEDIA_ENTRY, BoxesWizardDownloadableMediaEntry))
#define BOXES_WIZARD_DOWNLOADABLE_MEDIA_ENTRY_CLASS(klass) (G_TYPE_CHECK_CLASS_CAST ((klass), BOXES_TYPE_WIZARD_DOWNLOADABLE_MEDIA_ENTRY, BoxesWizardDownloadableMediaEntryClass))
#define BOXES_IS_WIZARD_DOWNLOADABLE_MEDIA_ENTRY(obj) (G_TYPE_CHECK_INSTANCE_TYPE ((obj), BOXES_TYPE_WIZARD_DOWNLOADABLE_MEDIA_ENTRY))
#define BOXES_IS_WIZARD_DOWNLOADABLE_MEDIA_ENTRY_CLASS(klass) (G_TYPE_CHECK_CLASS_TYPE ((klass), BOXES_TYPE_WIZARD_DOWNLOADABLE_MEDIA_ENTRY))
#define BOXES_WIZARD_DOWNLOADABLE_MEDIA_ENTRY_GET_CLASS(obj) (G_TYPE_INSTANCE_GET_CLASS ((obj), BOXES_TYPE_WIZARD_DOWNLOADABLE_MEDIA_ENTRY, BoxesWizardDownloadableMediaEntryClass))

typedef struct _BoxesWizardDownloadableMediaEntry BoxesWizardDownloadableMediaEntry;
typedef struct _BoxesWizardDownloadableMediaEntryClass BoxesWizardDownloadableMediaEntryClass;
typedef struct _BoxesWizardDownloadableMediaEntryPrivate BoxesWizardDownloadableMediaEntryPrivate;
enum  {
	BOXES_WIZARD_DOWNLOADABLE_MEDIA_ENTRY_0_PROPERTY,
	BOXES_WIZARD_DOWNLOADABLE_MEDIA_ENTRY_NUM_PROPERTIES
};
static GParamSpec* boxes_wizard_downloadable_media_entry_properties[BOXES_WIZARD_DOWNLOADABLE_MEDIA_ENTRY_NUM_PROPERTIES];
#define _g_free0(var) (var = (g_free (var), NULL))
#define _g_regex_unref0(var) ((var == NULL) ? NULL : (var = (g_regex_unref (var), NULL)))
#define _g_error_free0(var) ((var == NULL) ? NULL : (var = (g_error_free (var), NULL)))

#define BOXES_TYPE_WIZARD_DOWNLOADABLE_ENTRY (boxes_wizard_downloadable_entry_get_type ())
#define BOXES_WIZARD_DOWNLOADABLE_ENTRY(obj) (G_TYPE_CHECK_INSTANCE_CAST ((obj), BOXES_TYPE_WIZARD_DOWNLOADABLE_ENTRY, BoxesWizardDownloadableEntry))
#define BOXES_WIZARD_DOWNLOADABLE_ENTRY_CLASS(klass) (G_TYPE_CHECK_CLASS_CAST ((klass), BOXES_TYPE_WIZARD_DOWNLOADABLE_ENTRY, BoxesWizardDownloadableEntryClass))
#define BOXES_IS_WIZARD_DOWNLOADABLE_ENTRY(obj) (G_TYPE_CHECK_INSTANCE_TYPE ((obj), BOXES_TYPE_WIZARD_DOWNLOADABLE_ENTRY))
#define BOXES_IS_WIZARD_DOWNLOADABLE_ENTRY_CLASS(klass) (G_TYPE_CHECK_CLASS_TYPE ((klass), BOXES_TYPE_WIZARD_DOWNLOADABLE_ENTRY))
#define BOXES_WIZARD_DOWNLOADABLE_ENTRY_GET_CLASS(obj) (G_TYPE_INSTANCE_GET_CLASS ((obj), BOXES_TYPE_WIZARD_DOWNLOADABLE_ENTRY, BoxesWizardDownloadableEntryClass))

typedef struct _BoxesWizardDownloadableEntry BoxesWizardDownloadableEntry;
typedef struct _BoxesWizardDownloadableEntryClass BoxesWizardDownloadableEntryClass;
typedef struct _BoxesWizardDownloadableEntryPrivate BoxesWizardDownloadableEntryPrivate;
enum  {
	BOXES_WIZARD_DOWNLOADABLE_ENTRY_0_PROPERTY,
	BOXES_WIZARD_DOWNLOADABLE_ENTRY_NUM_PROPERTIES
};
static GParamSpec* boxes_wizard_downloadable_entry_properties[BOXES_WIZARD_DOWNLOADABLE_ENTRY_NUM_PROPERTIES];
enum  {
	BOXES_WIZARD_DOWNLOADABLE_ENTRY_ACTIVATED_SIGNAL,
	BOXES_WIZARD_DOWNLOADABLE_ENTRY_NUM_SIGNALS
};
static guint boxes_wizard_downloadable_entry_signals[BOXES_WIZARD_DOWNLOADABLE_ENTRY_NUM_SIGNALS] = {0};

#define BOXES_TYPE_WIZARD_MEDIA_ENTRY (boxes_wizard_media_entry_get_type ())
#define BOXES_WIZARD_MEDIA_ENTRY(obj) (G_TYPE_CHECK_INSTANCE_CAST ((obj), BOXES_TYPE_WIZARD_MEDIA_ENTRY, BoxesWizardMediaEntry))
#define BOXES_WIZARD_MEDIA_ENTRY_CLASS(klass) (G_TYPE_CHECK_CLASS_CAST ((klass), BOXES_TYPE_WIZARD_MEDIA_ENTRY, BoxesWizardMediaEntryClass))
#define BOXES_IS_WIZARD_MEDIA_ENTRY(obj) (G_TYPE_CHECK_INSTANCE_TYPE ((obj), BOXES_TYPE_WIZARD_MEDIA_ENTRY))
#define BOXES_IS_WIZARD_MEDIA_ENTRY_CLASS(klass) (G_TYPE_CHECK_CLASS_TYPE ((klass), BOXES_TYPE_WIZARD_MEDIA_ENTRY))
#define BOXES_WIZARD_MEDIA_ENTRY_GET_CLASS(obj) (G_TYPE_INSTANCE_GET_CLASS ((obj), BOXES_TYPE_WIZARD_MEDIA_ENTRY, BoxesWizardMediaEntryClass))

typedef struct _BoxesWizardMediaEntry BoxesWizardMediaEntry;
typedef struct _BoxesWizardMediaEntryClass BoxesWizardMediaEntryClass;
typedef struct _BoxesWizardMediaEntryPrivate BoxesWizardMediaEntryPrivate;

#define BOXES_TYPE_INSTALLER_MEDIA (boxes_installer_media_get_type ())
#define BOXES_INSTALLER_MEDIA(obj) (G_TYPE_CHECK_INSTANCE_CAST ((obj), BOXES_TYPE_INSTALLER_MEDIA, BoxesInstallerMedia))
#define BOXES_INSTALLER_MEDIA_CLASS(klass) (G_TYPE_CHECK_CLASS_CAST ((klass), BOXES_TYPE_INSTALLER_MEDIA, BoxesInstallerMediaClass))
#define BOXES_IS_INSTALLER_MEDIA(obj) (G_TYPE_CHECK_INSTANCE_TYPE ((obj), BOXES_TYPE_INSTALLER_MEDIA))
#define BOXES_IS_INSTALLER_MEDIA_CLASS(klass) (G_TYPE_CHECK_CLASS_TYPE ((klass), BOXES_TYPE_INSTALLER_MEDIA))
#define BOXES_INSTALLER_MEDIA_GET_CLASS(obj) (G_TYPE_INSTANCE_GET_CLASS ((obj), BOXES_TYPE_INSTALLER_MEDIA, BoxesInstallerMediaClass))

typedef struct _BoxesInstallerMedia BoxesInstallerMedia;
typedef struct _BoxesInstallerMediaClass BoxesInstallerMediaClass;
enum  {
	BOXES_WIZARD_MEDIA_ENTRY_0_PROPERTY,
	BOXES_WIZARD_MEDIA_ENTRY_NUM_PROPERTIES
};
static GParamSpec* boxes_wizard_media_entry_properties[BOXES_WIZARD_MEDIA_ENTRY_NUM_PROPERTIES];
typedef struct _BoxesInstallerMediaPrivate BoxesInstallerMediaPrivate;

#define BOXES_TYPE_VM_CREATOR (boxes_vm_creator_get_type ())
#define BOXES_VM_CREATOR(obj) (G_TYPE_CHECK_INSTANCE_CAST ((obj), BOXES_TYPE_VM_CREATOR, BoxesVMCreator))
#define BOXES_VM_CREATOR_CLASS(klass) (G_TYPE_CHECK_CLASS_CAST ((klass), BOXES_TYPE_VM_CREATOR, BoxesVMCreatorClass))
#define BOXES_IS_VM_CREATOR(obj) (G_TYPE_CHECK_INSTANCE_TYPE ((obj), BOXES_TYPE_VM_CREATOR))
#define BOXES_IS_VM_CREATOR_CLASS(klass) (G_TYPE_CHECK_CLASS_TYPE ((klass), BOXES_TYPE_VM_CREATOR))
#define BOXES_VM_CREATOR_GET_CLASS(obj) (G_TYPE_INSTANCE_GET_CLASS ((obj), BOXES_TYPE_VM_CREATOR, BoxesVMCreatorClass))

typedef struct _BoxesVMCreator BoxesVMCreator;
typedef struct _BoxesVMCreatorClass BoxesVMCreatorClass;

#define BOXES_TYPE_WIZARD_WEB_VIEW (boxes_wizard_web_view_get_type ())
#define BOXES_WIZARD_WEB_VIEW(obj) (G_TYPE_CHECK_INSTANCE_CAST ((obj), BOXES_TYPE_WIZARD_WEB_VIEW, BoxesWizardWebView))
#define BOXES_WIZARD_WEB_VIEW_CLASS(klass) (G_TYPE_CHECK_CLASS_CAST ((klass), BOXES_TYPE_WIZARD_WEB_VIEW, BoxesWizardWebViewClass))
#define BOXES_IS_WIZARD_WEB_VIEW(obj) (G_TYPE_CHECK_INSTANCE_TYPE ((obj), BOXES_TYPE_WIZARD_WEB_VIEW))
#define BOXES_IS_WIZARD_WEB_VIEW_CLASS(klass) (G_TYPE_CHECK_CLASS_TYPE ((klass), BOXES_TYPE_WIZARD_WEB_VIEW))
#define BOXES_WIZARD_WEB_VIEW_GET_CLASS(obj) (G_TYPE_INSTANCE_GET_CLASS ((obj), BOXES_TYPE_WIZARD_WEB_VIEW, BoxesWizardWebViewClass))

typedef struct _BoxesWizardWebView BoxesWizardWebView;
typedef struct _BoxesWizardWebViewClass BoxesWizardWebViewClass;
typedef struct _BoxesWizardWebViewPrivate BoxesWizardWebViewPrivate;
enum  {
	BOXES_WIZARD_WEB_VIEW_0_PROPERTY,
	BOXES_WIZARD_WEB_VIEW_VIEW_PROPERTY,
	BOXES_WIZARD_WEB_VIEW_NUM_PROPERTIES
};
static GParamSpec* boxes_wizard_web_view_properties[BOXES_WIZARD_WEB_VIEW_NUM_PROPERTIES];
#define __g_list_free__g_object_unref0_0(var) ((var == NULL) ? NULL : (var = (_g_list_free__g_object_unref0_ (var), NULL)))

#define BOXES_TYPE_WIZARD_SOURCE (boxes_wizard_source_get_type ())
#define BOXES_WIZARD_SOURCE(obj) (G_TYPE_CHECK_INSTANCE_CAST ((obj), BOXES_TYPE_WIZARD_SOURCE, BoxesWizardSource))
#define BOXES_WIZARD_SOURCE_CLASS(klass) (G_TYPE_CHECK_CLASS_CAST ((klass), BOXES_TYPE_WIZARD_SOURCE, BoxesWizardSourceClass))
#define BOXES_IS_WIZARD_SOURCE(obj) (G_TYPE_CHECK_INSTANCE_TYPE ((obj), BOXES_TYPE_WIZARD_SOURCE))
#define BOXES_IS_WIZARD_SOURCE_CLASS(klass) (G_TYPE_CHECK_CLASS_TYPE ((klass), BOXES_TYPE_WIZARD_SOURCE))
#define BOXES_WIZARD_SOURCE_GET_CLASS(obj) (G_TYPE_INSTANCE_GET_CLASS ((obj), BOXES_TYPE_WIZARD_SOURCE, BoxesWizardSourceClass))

typedef struct _BoxesWizardSource BoxesWizardSource;
typedef struct _BoxesWizardSourceClass BoxesWizardSourceClass;
typedef struct _BoxesWizardSourcePrivate BoxesWizardSourcePrivate;

#define BOXES_TYPE_MEDIA_MANAGER (boxes_media_manager_get_type ())
#define BOXES_MEDIA_MANAGER(obj) (G_TYPE_CHECK_INSTANCE_CAST ((obj), BOXES_TYPE_MEDIA_MANAGER, BoxesMediaManager))
#define BOXES_MEDIA_MANAGER_CLASS(klass) (G_TYPE_CHECK_CLASS_CAST ((klass), BOXES_TYPE_MEDIA_MANAGER, BoxesMediaManagerClass))
#define BOXES_IS_MEDIA_MANAGER(obj) (G_TYPE_CHECK_INSTANCE_TYPE ((obj), BOXES_TYPE_MEDIA_MANAGER))
#define BOXES_IS_MEDIA_MANAGER_CLASS(klass) (G_TYPE_CHECK_CLASS_TYPE ((klass), BOXES_TYPE_MEDIA_MANAGER))
#define BOXES_MEDIA_MANAGER_GET_CLASS(obj) (G_TYPE_INSTANCE_GET_CLASS ((obj), BOXES_TYPE_MEDIA_MANAGER, BoxesMediaManagerClass))

typedef struct _BoxesMediaManager BoxesMediaManager;
typedef struct _BoxesMediaManagerClass BoxesMediaManagerClass;

#define BOXES_TYPE_LIBVIRT_SYSTEM_IMPORTER (boxes_libvirt_system_importer_get_type ())
#define BOXES_LIBVIRT_SYSTEM_IMPORTER(obj) (G_TYPE_CHECK_INSTANCE_CAST ((obj), BOXES_TYPE_LIBVIRT_SYSTEM_IMPORTER, BoxesLibvirtSystemImporter))
#define BOXES_LIBVIRT_SYSTEM_IMPORTER_CLASS(klass) (G_TYPE_CHECK_CLASS_CAST ((klass), BOXES_TYPE_LIBVIRT_SYSTEM_IMPORTER, BoxesLibvirtSystemImporterClass))
#define BOXES_IS_LIBVIRT_SYSTEM_IMPORTER(obj) (G_TYPE_CHECK_INSTANCE_TYPE ((obj), BOXES_TYPE_LIBVIRT_SYSTEM_IMPORTER))
#define BOXES_IS_LIBVIRT_SYSTEM_IMPORTER_CLASS(klass) (G_TYPE_CHECK_CLASS_TYPE ((klass), BOXES_TYPE_LIBVIRT_SYSTEM_IMPORTER))
#define BOXES_LIBVIRT_SYSTEM_IMPORTER_GET_CLASS(obj) (G_TYPE_INSTANCE_GET_CLASS ((obj), BOXES_TYPE_LIBVIRT_SYSTEM_IMPORTER, BoxesLibvirtSystemImporterClass))

typedef struct _BoxesLibvirtSystemImporter BoxesLibvirtSystemImporter;
typedef struct _BoxesLibvirtSystemImporterClass BoxesLibvirtSystemImporterClass;

#define BOXES_TYPE_APP_WINDOW (boxes_app_window_get_type ())
#define BOXES_APP_WINDOW(obj) (G_TYPE_CHECK_INSTANCE_CAST ((obj), BOXES_TYPE_APP_WINDOW, BoxesAppWindow))
#define BOXES_APP_WINDOW_CLASS(klass) (G_TYPE_CHECK_CLASS_CAST ((klass), BOXES_TYPE_APP_WINDOW, BoxesAppWindowClass))
#define BOXES_IS_APP_WINDOW(obj) (G_TYPE_CHECK_INSTANCE_TYPE ((obj), BOXES_TYPE_APP_WINDOW))
#define BOXES_IS_APP_WINDOW_CLASS(klass) (G_TYPE_CHECK_CLASS_TYPE ((klass), BOXES_TYPE_APP_WINDOW))
#define BOXES_APP_WINDOW_GET_CLASS(obj) (G_TYPE_INSTANCE_GET_CLASS ((obj), BOXES_TYPE_APP_WINDOW, BoxesAppWindowClass))

typedef struct _BoxesAppWindow BoxesAppWindow;
typedef struct _BoxesAppWindowClass BoxesAppWindowClass;
enum  {
	BOXES_WIZARD_SOURCE_0_PROPERTY,
	BOXES_WIZARD_SOURCE_SELECTED_PROPERTY,
	BOXES_WIZARD_SOURCE_URI_PROPERTY,
	BOXES_WIZARD_SOURCE_INSTALL_MEDIA_PROPERTY,
	BOXES_WIZARD_SOURCE_LIBVIRT_SYS_IMPORTER_PROPERTY,
	BOXES_WIZARD_SOURCE_FILENAME_PROPERTY,
	BOXES_WIZARD_SOURCE_DOWNLOAD_REQUIRED_PROPERTY,
	BOXES_WIZARD_SOURCE_PAGE_PROPERTY,
	BOXES_WIZARD_SOURCE_NUM_PROPERTIES
};
static GParamSpec* boxes_wizard_source_properties[BOXES_WIZARD_SOURCE_NUM_PROPERTIES];
#define _gtk_tree_row_reference_free0(var) ((var == NULL) ? NULL : (var = (gtk_tree_row_reference_free (var), NULL)))
typedef struct _Block91Data Block91Data;

#define BOXES_OS_DATABASE_TYPE_MEDIA_UR_LS_COLUMNS (boxes_os_database_media_ur_ls_columns_get_type ())

#define BOXES_TYPE_OS_DATABASE (boxes_os_database_get_type ())
#define BOXES_OS_DATABASE(obj) (G_TYPE_CHECK_INSTANCE_CAST ((obj), BOXES_TYPE_OS_DATABASE, BoxesOSDatabase))
#define BOXES_OS_DATABASE_CLASS(klass) (G_TYPE_CHECK_CLASS_CAST ((klass), BOXES_TYPE_OS_DATABASE, BoxesOSDatabaseClass))
#define BOXES_IS_OS_DATABASE(obj) (G_TYPE_CHECK_INSTANCE_TYPE ((obj), BOXES_TYPE_OS_DATABASE))
#define BOXES_IS_OS_DATABASE_CLASS(klass) (G_TYPE_CHECK_CLASS_TYPE ((klass), BOXES_TYPE_OS_DATABASE))
#define BOXES_OS_DATABASE_GET_CLASS(obj) (G_TYPE_INSTANCE_GET_CLASS ((obj), BOXES_TYPE_OS_DATABASE, BoxesOSDatabaseClass))

typedef struct _BoxesOSDatabase BoxesOSDatabase;
typedef struct _BoxesOSDatabaseClass BoxesOSDatabaseClass;
typedef struct _Block92Data Block92Data;
#define _g_hash_table_unref0(var) ((var == NULL) ? NULL : (var = (g_hash_table_unref (var), NULL)))
typedef struct _BoxesWizardSourceAddMediaEntriesData BoxesWizardSourceAddMediaEntriesData;
typedef struct _BoxesWizardSourceUpdateLibvirtSytemEntryVisibilityData BoxesWizardSourceUpdateLibvirtSytemEntryVisibilityData;

#define BOXES_TYPE_UI (boxes_ui_get_type ())
#define BOXES_UI(obj) (G_TYPE_CHECK_INSTANCE_CAST ((obj), BOXES_TYPE_UI, BoxesUI))
#define BOXES_IS_UI(obj) (G_TYPE_CHECK_INSTANCE_TYPE ((obj), BOXES_TYPE_UI))
#define BOXES_UI_GET_INTERFACE(obj) (G_TYPE_INSTANCE_GET_INTERFACE ((obj), BOXES_TYPE_UI, BoxesUIIface))

typedef struct _BoxesUI BoxesUI;
typedef struct _BoxesUIIface BoxesUIIface;

#define BOXES_TYPE_UI_STATE (boxes_ui_state_get_type ())
typedef struct _BoxesAppWindowPrivate BoxesAppWindowPrivate;

#define BOXES_TYPE_WIZARD_WINDOW (boxes_wizard_window_get_type ())
#define BOXES_WIZARD_WINDOW(obj) (G_TYPE_CHECK_INSTANCE_CAST ((obj), BOXES_TYPE_WIZARD_WINDOW, BoxesWizardWindow))
#define BOXES_WIZARD_WINDOW_CLASS(klass) (G_TYPE_CHECK_CLASS_CAST ((klass), BOXES_TYPE_WIZARD_WINDOW, BoxesWizardWindowClass))
#define BOXES_IS_WIZARD_WINDOW(obj) (G_TYPE_CHECK_INSTANCE_TYPE ((obj), BOXES_TYPE_WIZARD_WINDOW))
#define BOXES_IS_WIZARD_WINDOW_CLASS(klass) (G_TYPE_CHECK_CLASS_TYPE ((klass), BOXES_TYPE_WIZARD_WINDOW))
#define BOXES_WIZARD_WINDOW_GET_CLASS(obj) (G_TYPE_INSTANCE_GET_CLASS ((obj), BOXES_TYPE_WIZARD_WINDOW, BoxesWizardWindowClass))

typedef struct _BoxesWizardWindow BoxesWizardWindow;
typedef struct _BoxesWizardWindowClass BoxesWizardWindowClass;

#define BOXES_TYPE_PROPERTIES_WINDOW (boxes_properties_window_get_type ())
#define BOXES_PROPERTIES_WINDOW(obj) (G_TYPE_CHECK_INSTANCE_CAST ((obj), BOXES_TYPE_PROPERTIES_WINDOW, BoxesPropertiesWindow))
#define BOXES_PROPERTIES_WINDOW_CLASS(klass) (G_TYPE_CHECK_CLASS_CAST ((klass), BOXES_TYPE_PROPERTIES_WINDOW, BoxesPropertiesWindowClass))
#define BOXES_IS_PROPERTIES_WINDOW(obj) (G_TYPE_CHECK_INSTANCE_TYPE ((obj), BOXES_TYPE_PROPERTIES_WINDOW))
#define BOXES_IS_PROPERTIES_WINDOW_CLASS(klass) (G_TYPE_CHECK_CLASS_TYPE ((klass), BOXES_TYPE_PROPERTIES_WINDOW))
#define BOXES_PROPERTIES_WINDOW_GET_CLASS(obj) (G_TYPE_INSTANCE_GET_CLASS ((obj), BOXES_TYPE_PROPERTIES_WINDOW, BoxesPropertiesWindowClass))

typedef struct _BoxesPropertiesWindow BoxesPropertiesWindow;
typedef struct _BoxesPropertiesWindowClass BoxesPropertiesWindowClass;

#define BOXES_TYPE_SEARCHBAR (boxes_searchbar_get_type ())
#define BOXES_SEARCHBAR(obj) (G_TYPE_CHECK_INSTANCE_CAST ((obj), BOXES_TYPE_SEARCHBAR, BoxesSearchbar))
#define BOXES_SEARCHBAR_CLASS(klass) (G_TYPE_CHECK_CLASS_CAST ((klass), BOXES_TYPE_SEARCHBAR, BoxesSearchbarClass))
#define BOXES_IS_SEARCHBAR(obj) (G_TYPE_CHECK_INSTANCE_TYPE ((obj), BOXES_TYPE_SEARCHBAR))
#define BOXES_IS_SEARCHBAR_CLASS(klass) (G_TYPE_CHECK_CLASS_TYPE ((klass), BOXES_TYPE_SEARCHBAR))
#define BOXES_SEARCHBAR_GET_CLASS(obj) (G_TYPE_INSTANCE_GET_CLASS ((obj), BOXES_TYPE_SEARCHBAR, BoxesSearchbarClass))

typedef struct _BoxesSearchbar BoxesSearchbar;
typedef struct _BoxesSearchbarClass BoxesSearchbarClass;

#define BOXES_TYPE_TOPBAR (boxes_topbar_get_type ())
#define BOXES_TOPBAR(obj) (G_TYPE_CHECK_INSTANCE_CAST ((obj), BOXES_TYPE_TOPBAR, BoxesTopbar))
#define BOXES_TOPBAR_CLASS(klass) (G_TYPE_CHECK_CLASS_CAST ((klass), BOXES_TYPE_TOPBAR, BoxesTopbarClass))
#define BOXES_IS_TOPBAR(obj) (G_TYPE_CHECK_INSTANCE_TYPE ((obj), BOXES_TYPE_TOPBAR))
#define BOXES_IS_TOPBAR_CLASS(klass) (G_TYPE_CHECK_CLASS_TYPE ((klass), BOXES_TYPE_TOPBAR))
#define BOXES_TOPBAR_GET_CLASS(obj) (G_TYPE_INSTANCE_GET_CLASS ((obj), BOXES_TYPE_TOPBAR, BoxesTopbarClass))

typedef struct _BoxesTopbar BoxesTopbar;
typedef struct _BoxesTopbarClass BoxesTopbarClass;

#define BOXES_TYPE_SELECTIONBAR (boxes_selectionbar_get_type ())
#define BOXES_SELECTIONBAR(obj) (G_TYPE_CHECK_INSTANCE_CAST ((obj), BOXES_TYPE_SELECTIONBAR, BoxesSelectionbar))
#define BOXES_SELECTIONBAR_CLASS(klass) (G_TYPE_CHECK_CLASS_CAST ((klass), BOXES_TYPE_SELECTIONBAR, BoxesSelectionbarClass))
#define BOXES_IS_SELECTIONBAR(obj) (G_TYPE_CHECK_INSTANCE_TYPE ((obj), BOXES_TYPE_SELECTIONBAR))
#define BOXES_IS_SELECTIONBAR_CLASS(klass) (G_TYPE_CHECK_CLASS_TYPE ((klass), BOXES_TYPE_SELECTIONBAR))
#define BOXES_SELECTIONBAR_GET_CLASS(obj) (G_TYPE_INSTANCE_GET_CLASS ((obj), BOXES_TYPE_SELECTIONBAR, BoxesSelectionbarClass))

typedef struct _BoxesSelectionbar BoxesSelectionbar;
typedef struct _BoxesSelectionbarClass BoxesSelectionbarClass;

#define BOXES_TYPE_DISPLAY_PAGE (boxes_display_page_get_type ())
#define BOXES_DISPLAY_PAGE(obj) (G_TYPE_CHECK_INSTANCE_CAST ((obj), BOXES_TYPE_DISPLAY_PAGE, BoxesDisplayPage))
#define BOXES_DISPLAY_PAGE_CLASS(klass) (G_TYPE_CHECK_CLASS_CAST ((klass), BOXES_TYPE_DISPLAY_PAGE, BoxesDisplayPageClass))
#define BOXES_IS_DISPLAY_PAGE(obj) (G_TYPE_CHECK_INSTANCE_TYPE ((obj), BOXES_TYPE_DISPLAY_PAGE))
#define BOXES_IS_DISPLAY_PAGE_CLASS(klass) (G_TYPE_CHECK_CLASS_TYPE ((klass), BOXES_TYPE_DISPLAY_PAGE))
#define BOXES_DISPLAY_PAGE_GET_CLASS(obj) (G_TYPE_INSTANCE_GET_CLASS ((obj), BOXES_TYPE_DISPLAY_PAGE, BoxesDisplayPageClass))

typedef struct _BoxesDisplayPage BoxesDisplayPage;
typedef struct _BoxesDisplayPageClass BoxesDisplayPageClass;

#define BOXES_TYPE_EMPTY_BOXES (boxes_empty_boxes_get_type ())
#define BOXES_EMPTY_BOXES(obj) (G_TYPE_CHECK_INSTANCE_CAST ((obj), BOXES_TYPE_EMPTY_BOXES, BoxesEmptyBoxes))
#define BOXES_EMPTY_BOXES_CLASS(klass) (G_TYPE_CHECK_CLASS_CAST ((klass), BOXES_TYPE_EMPTY_BOXES, BoxesEmptyBoxesClass))
#define BOXES_IS_EMPTY_BOXES(obj) (G_TYPE_CHECK_INSTANCE_TYPE ((obj), BOXES_TYPE_EMPTY_BOXES))
#define BOXES_IS_EMPTY_BOXES_CLASS(klass) (G_TYPE_CHECK_CLASS_TYPE ((klass), BOXES_TYPE_EMPTY_BOXES))
#define BOXES_EMPTY_BOXES_GET_CLASS(obj) (G_TYPE_INSTANCE_GET_CLASS ((obj), BOXES_TYPE_EMPTY_BOXES, BoxesEmptyBoxesClass))

typedef struct _BoxesEmptyBoxes BoxesEmptyBoxes;
typedef struct _BoxesEmptyBoxesClass BoxesEmptyBoxesClass;
#define __vala_WebKitNavigationAction_free0(var) ((var == NULL) ? NULL : (var = (_vala_WebKitNavigationAction_free (var), NULL)))
#define __vala_SoupURI_free0(var) ((var == NULL) ? NULL : (var = (_vala_SoupURI_free (var), NULL)))
#define _gtk_tree_path_free0(var) ((var == NULL) ? NULL : (var = (gtk_tree_path_free (var), NULL)))
enum  {
	BOXES_WIZARD_SOURCE_ACTIVATED_SIGNAL,
	BOXES_WIZARD_SOURCE_NUM_SIGNALS
};
static guint boxes_wizard_source_signals[BOXES_WIZARD_SOURCE_NUM_SIGNALS] = {0};
#define _vala_assert(expr, msg) if G_LIKELY (expr) ; else g_assertion_message_expr (G_LOG_DOMAIN, __FILE__, __LINE__, G_STRFUNC, msg);
#define _vala_return_if_fail(expr, msg) if G_LIKELY (expr) ; else { g_return_if_fail_warning (G_LOG_DOMAIN, G_STRFUNC, msg); return; }
#define _vala_return_val_if_fail(expr, msg, val) if G_LIKELY (expr) ; else { g_return_if_fail_warning (G_LOG_DOMAIN, G_STRFUNC, msg); return val; }
#define _vala_warn_if_fail(expr, msg) if G_LIKELY (expr) ; else g_warn_message (G_LOG_DOMAIN, __FILE__, __LINE__, G_STRFUNC, msg);

typedef enum  {
	BOXES_SOURCE_PAGE_MAIN,
	BOXES_SOURCE_PAGE_RHEL_WEB_VIEW,
	BOXES_SOURCE_PAGE_URL,
	BOXES_SOURCE_PAGE_LAST
} BoxesSourcePage;

typedef gboolean (*ClickedFunc) (void* user_data);
struct _BoxesWizardScrolled {
	GtkScrolledWindow parent_instance;
	BoxesWizardScrolledPrivate * priv;
	GtkListBox* vbox;
};

struct _BoxesWizardScrolledClass {
	GtkScrolledWindowClass parent_class;
};

struct _BoxesWizardScrolledPrivate {
	gint _num_visible;
};

struct _BoxesWizardDownloadableMediaEntry {
	GtkListBoxRow parent_instance;
	BoxesWizardDownloadableMediaEntryPrivate * priv;
	OsinfoMedia* media;
};

struct _BoxesWizardDownloadableMediaEntryClass {
	GtkListBoxRowClass parent_class;
};

struct _BoxesWizardDownloadableMediaEntryPrivate {
	GtkLabel* label;
};

struct _BoxesWizardDownloadableEntry {
	GtkListBoxRow parent_instance;
	BoxesWizardDownloadableEntryPrivate * priv;
	OsinfoMedia* single_media;
};

struct _BoxesWizardDownloadableEntryClass {
	GtkListBoxRowClass parent_class;
};

struct _BoxesWizardDownloadableEntryPrivate {
	GtkImage* media_image;
	GtkLabel* title_label;
	GtkLabel* details_label;
	GtkRevealer* revealer;
	GtkListBox* medias_listbox;
};

struct _BoxesWizardMediaEntry {
	GtkListBoxRow parent_instance;
	BoxesWizardMediaEntryPrivate * priv;
	BoxesInstallerMedia* media;
};

struct _BoxesWizardMediaEntryClass {
	GtkListBoxRowClass parent_class;
};

struct _BoxesWizardMediaEntryPrivate {
	GtkImage* media_image;
	GtkLabel* title_label;
	GtkLabel* details_label;
};

struct _BoxesInstallerMedia {
	GObject parent_instance;
	BoxesInstallerMediaPrivate * priv;
	OsinfoOs* os;
	OsinfoResources* resources;
	OsinfoMedia* os_media;
	gchar* label;
	gchar* device_file;
	gchar* mount_point;
	gboolean from_image;
};

struct _BoxesInstallerMediaClass {
	GObjectClass parent_class;
	void (*set_direct_boot_params) (BoxesInstallerMedia* self, GVirConfigDomainOs* os);
	void (*prepare) (BoxesInstallerMedia* self, BoxesActivityProgress* progress, GCancellable* cancellable, GAsyncReadyCallback _callback_, gpointer _user_data_);
	gboolean (*prepare_finish) (BoxesInstallerMedia* self, GAsyncResult* _res_);
	void (*prepare_for_installation) (BoxesInstallerMedia* self, const gchar* vm_name, GCancellable* cancellable, GAsyncReadyCallback _callback_, gpointer _user_data_);
	void (*prepare_for_installation_finish) (BoxesInstallerMedia* self, GAsyncResult* _res_);
	void (*prepare_to_continue_installation) (BoxesInstallerMedia* self, const gchar* vm_name);
	void (*clean_up) (BoxesInstallerMedia* self);
	void (*clean_up_preparation_cache) (BoxesInstallerMedia* self);
	void (*setup_domain_config) (BoxesInstallerMedia* self, GVirConfigDomain* domain);
	void (*setup_post_install_domain_config) (BoxesInstallerMedia* self, GVirConfigDomain* domain);
	void (*populate_setup_box) (BoxesInstallerMedia* self, GtkBox* setup_box);
	GList* (*get_vm_properties) (BoxesInstallerMedia* self);
	BoxesVMCreator* (*get_vm_creator) (BoxesInstallerMedia* self);
	OsinfoDeviceList* (*get_supported_devices) (BoxesInstallerMedia* self);
	guint64 (*get_installed_size) (BoxesInstallerMedia* self);
	gboolean (*get_need_user_input_for_vm_creation) (BoxesInstallerMedia* self);
	gboolean (*get_ready_to_create) (BoxesInstallerMedia* self);
	gboolean (*get_live) (BoxesInstallerMedia* self);
	gboolean (*get_eject_after_install) (BoxesInstallerMedia* self);
	gchar* (*get_architecture) (BoxesInstallerMedia* self);
};

struct _BoxesWizardWebView {
	GtkBin parent_instance;
	BoxesWizardWebViewPrivate * priv;
};

struct _BoxesWizardWebViewClass {
	GtkBinClass parent_class;
};

struct _BoxesWizardWebViewPrivate {
	GtkProgressBar* progress_bar;
	WebKitWebView* web_view;
	guint hide_progress_bar_id;
};

struct _BoxesWizardSource {
	GtkStack parent_instance;
	BoxesWizardSourcePrivate * priv;
	gboolean libvirt_sys_import;
	GtkEntry* url_entry;
	BoxesMediaManager* media_manager;
};

struct _BoxesWizardSourceClass {
	GtkStackClass parent_class;
};

struct _BoxesWizardSourcePrivate {
	GtkWidget* _selected;
	BoxesInstallerMedia* _install_media;
	BoxesLibvirtSystemImporter* _libvirt_sys_importer;
	GtkBox* main_vbox;
	BoxesWizardScrolled* media_scrolled;
	GtkBox* url_entry_vbox;
	GtkButton* select_file_button;
	GtkButton* libvirt_sys_import_button;
	GtkLabel* libvirt_sys_import_label;
	GtkListBox* available_downloads_listbox;
	GtkButton* install_rhel_button;
	GtkImage* install_rhel_image;
	BoxesWizardWebView* rhel_web_view;
	BoxesAppWindow* window;
	GtkListBox* media_vbox;
	GtkListStore* media_urls_store;
	GCancellable* rhel_cancellable;
	GtkTreeRowReference* rhel_os_row_reference;
	OsinfoOs* rhel_os;
	gchar* _filename;
	BoxesSourcePage _page;
};

struct _Block91Data {
	int _ref_count_;
	BoxesWizardSource* self;
	OsinfoOs* os;
	gchar* uri;
};

typedef enum  {
	BOXES_OS_DATABASE_MEDIA_UR_LS_COLUMNS_URL = 0,
	BOXES_OS_DATABASE_MEDIA_UR_LS_COLUMNS_OS = 1,
	BOXES_OS_DATABASE_MEDIA_UR_LS_COLUMNS_LAST
} BoxesOSDatabaseMediaURLsColumns;

struct _Block92Data {
	int _ref_count_;
	BoxesWizardSource* self;
	BoxesOSDatabase* os_db;
	GListStore* available_downloads_model;
	gchar* rhel_id;
};

typedef enum  {
	BOXES_OS_DATABASE_ERROR_NON_BOOTABLE,
	BOXES_OS_DATABASE_ERROR_DB_LOADING_FAILED,
	BOXES_OS_DATABASE_ERROR_UNKNOWN_OS_ID,
	BOXES_OS_DATABASE_ERROR_UNKNOWN_MEDIA_ID
} BoxesOSDatabaseError;
#define BOXES_OS_DATABASE_ERROR boxes_os_database_error_quark ()
struct _BoxesWizardSourceAddMediaEntriesData {
	int _state_;
	GObject* _source_object_;
	GAsyncResult* _res_;
	GTask* _async_result;
	BoxesWizardSource* self;
	GList* medias;
	BoxesMediaManager* _tmp0_;
	GList* _tmp1_;
	GtkListBox* _tmp2_;
	GList* _tmp3_;
	GList* child_collection;
	GList* child_it;
	GtkWidget* child;
	BoxesInstallerMedia* child_media;
	GtkWidget* _tmp4_;
	BoxesInstallerMedia* _tmp5_;
	BoxesInstallerMedia* _tmp6_;
	gboolean obsolete;
	GList* _tmp7_;
	GList* media_collection;
	GList* media_it;
	BoxesInstallerMedia* _tmp8_;
	BoxesInstallerMedia* media;
	BoxesInstallerMedia* _tmp9_;
	const gchar* _tmp10_;
	BoxesInstallerMedia* _tmp11_;
	const gchar* _tmp12_;
	gboolean _tmp13_;
	GtkListBox* _tmp14_;
	GtkWidget* _tmp15_;
	GList* _tmp16_;
	GList* _vala1_media_collection;
	GList* _vala1_media_it;
	BoxesInstallerMedia* _tmp17_;
	BoxesInstallerMedia* _vala1_media;
	gboolean nouveau;
	GtkListBox* _tmp18_;
	GList* _tmp19_;
	GList* _vala1_child_collection;
	GList* _vala1_child_it;
	GtkWidget* _vala1_child;
	BoxesInstallerMedia* _vala1_child_media;
	GtkWidget* _tmp20_;
	BoxesInstallerMedia* _tmp21_;
	BoxesInstallerMedia* _tmp22_;
	BoxesInstallerMedia* _tmp23_;
	const gchar* _tmp24_;
	BoxesInstallerMedia* _tmp25_;
	const gchar* _tmp26_;
	gboolean _tmp27_;
	BoxesInstallerMedia* _tmp28_;
	GtkListBox* _tmp29_;
	GList* _tmp30_;
	GList* _tmp31_;
	guint _tmp32_;
	gboolean _tmp33_;
	BoxesWizardScrolled* _tmp34_;
};

struct _BoxesWizardSourceUpdateLibvirtSytemEntryVisibilityData {
	int _state_;
	GObject* _source_object_;
	GAsyncResult* _res_;
	GTask* _async_result;
	BoxesWizardSource* self;
	BoxesLibvirtSystemImporter* _tmp0_;
	BoxesLibvirtSystemImporter* _tmp1_;
	GError* _error_;
	GError* _tmp2_;
	const gchar* _tmp3_;
	GtkLabel* _tmp4_;
	BoxesLibvirtSystemImporter* _tmp5_;
	gchar* _tmp6_;
	gchar* _tmp7_;
	gchar* _tmp8_;
	GtkButton* _tmp9_;
	GError * _inner_error_;
};

typedef enum  {
	BOXES_UI_STATE_NONE,
	BOXES_UI_STATE_COLLECTION,
	BOXES_UI_STATE_CREDS,
	BOXES_UI_STATE_DISPLAY,
	BOXES_UI_STATE_WIZARD,
	BOXES_UI_STATE_PROPERTIES
} BoxesUIState;

struct _BoxesUIIface {
	GTypeInterface parent_iface;
	BoxesUIState (*get_previous_ui_state) (BoxesUI* self);
	void (*set_previous_ui_state) (BoxesUI* self, BoxesUIState value);
	BoxesUIState (*get_ui_state) (BoxesUI* self);
	void (*set_ui_state) (BoxesUI* self, BoxesUIState value);
};

struct _BoxesAppWindow {
	GtkApplicationWindow parent_instance;
	BoxesAppWindowPrivate * priv;
	BoxesWizardWindow* wizard_window;
	BoxesPropertiesWindow* props_window;
	BoxesSearchbar* searchbar;
	BoxesTopbar* topbar;
	BoxesSelectionbar* selectionbar;
	BoxesDisplayPage* display_page;
	BoxesEmptyBoxes* empty_boxes;
	GtkStack* below_bin;
	GSettings* settings;
};

struct _BoxesAppWindowClass {
	GtkApplicationWindowClass parent_class;
};

typedef void (*BoxesWizardWindowFileChosenFunc) (const gchar* uri, void* user_data);

static gpointer boxes_wizard_scrolled_parent_class = NULL;
static gpointer boxes_wizard_downloadable_media_entry_parent_class = NULL;
static gpointer boxes_wizard_downloadable_entry_parent_class = NULL;
static gpointer boxes_wizard_media_entry_parent_class = NULL;
static gpointer boxes_wizard_web_view_parent_class = NULL;
static gpointer boxes_wizard_source_parent_class = NULL;
extern gchar** boxes_downloader_supported_schemes;
extern gint boxes_downloader_supported_schemes_length1;

GType boxes_source_page_get_type (void) G_GNUC_CONST;
GType boxes_wizard_scrolled_get_type (void) G_GNUC_CONST;
#define BOXES_WIZARD_SCROLLED_GET_PRIVATE(o) (G_TYPE_INSTANCE_GET_PRIVATE ((o), BOXES_TYPE_WIZARD_SCROLLED, BoxesWizardScrolledPrivate))
void boxes_wizard_scrolled_setup (BoxesWizardScrolled* self, gint num_visible);
static void boxes_wizard_scrolled_set_num_visible (BoxesWizardScrolled* self, gint value);
static void __lambda59_ (BoxesWizardScrolled* self);
static void ___lambda59__g_object_notify (GObject* _sender, GParamSpec* pspec, gpointer self);
static void __lambda60_ (BoxesWizardScrolled* self);
static void ___lambda60__gtk_widget_show (GtkWidget* _sender, gpointer self);
static void __lambda61_ (BoxesWizardScrolled* self);
static void ___lambda61__gtk_widget_hide (GtkWidget* _sender, gpointer self);
static void boxes_wizard_scrolled_real_get_preferred_height (GtkWidget* base, gint* minimum_height, gint* natural_height);
static gint boxes_wizard_scrolled_get_num_visible (BoxesWizardScrolled* self);
BoxesWizardScrolled* boxes_wizard_scrolled_new (void);
BoxesWizardScrolled* boxes_wizard_scrolled_construct (GType object_type);
static void boxes_wizard_scrolled_finalize (GObject * obj);
static void _vala_boxes_wizard_scrolled_get_property (GObject * object, guint property_id, GValue * value, GParamSpec * pspec);
static void _vala_boxes_wizard_scrolled_set_property (GObject * object, guint property_id, const GValue * value, GParamSpec * pspec);
GType boxes_wizard_downloadable_media_entry_get_type (void) G_GNUC_CONST;
#define BOXES_WIZARD_DOWNLOADABLE_MEDIA_ENTRY_GET_PRIVATE(o) (G_TYPE_INSTANCE_GET_PRIVATE ((o), BOXES_TYPE_WIZARD_DOWNLOADABLE_MEDIA_ENTRY, BoxesWizardDownloadableMediaEntryPrivate))
BoxesWizardDownloadableMediaEntry* boxes_wizard_downloadable_media_entry_new (OsinfoMedia* media);
BoxesWizardDownloadableMediaEntry* boxes_wizard_downloadable_media_entry_construct (GType object_type, OsinfoMedia* media);
static void boxes_wizard_downloadable_media_entry_setup_label (BoxesWizardDownloadableMediaEntry* self);
static void boxes_wizard_downloadable_media_entry_finalize (GObject * obj);
GType boxes_wizard_downloadable_entry_get_type (void) G_GNUC_CONST;
#define BOXES_WIZARD_DOWNLOADABLE_ENTRY_GET_PRIVATE(o) (G_TYPE_INSTANCE_GET_PRIVATE ((o), BOXES_TYPE_WIZARD_DOWNLOADABLE_ENTRY, BoxesWizardDownloadableEntryPrivate))
BoxesWizardDownloadableEntry* boxes_wizard_downloadable_entry_new (OsinfoOs* os);
BoxesWizardDownloadableEntry* boxes_wizard_downloadable_entry_construct (GType object_type, OsinfoOs* os);
void boxes_downloader_fetch_os_logo (GtkImage* image, OsinfoOs* os, gint size, GAsyncReadyCallback _callback_, gpointer _user_data_);
void boxes_downloader_fetch_os_logo_finish (GAsyncResult* _res_);
static void boxes_wizard_downloadable_entry_populate_media_listbox (BoxesWizardDownloadableEntry* self, OsinfoList* media_list);
static void boxes_wizard_downloadable_entry_on_media_listbox_activated (BoxesWizardDownloadableEntry* self, GtkListBoxRow* row);
static void _boxes_wizard_downloadable_entry_on_media_listbox_activated_gtk_list_box_row_activated (GtkListBox* _sender, GtkListBoxRow* row, gpointer self);
void boxes_wizard_downloadable_entry_toggle (BoxesWizardDownloadableEntry* self);
static void boxes_wizard_downloadable_entry_finalize (GObject * obj);
GType boxes_wizard_media_entry_get_type (void) G_GNUC_CONST;
GType boxes_installer_media_get_type (void) G_GNUC_CONST;
#define BOXES_WIZARD_MEDIA_ENTRY_GET_PRIVATE(o) (G_TYPE_INSTANCE_GET_PRIVATE ((o), BOXES_TYPE_WIZARD_MEDIA_ENTRY, BoxesWizardMediaEntryPrivate))
BoxesWizardMediaEntry* boxes_wizard_media_entry_new (BoxesInstallerMedia* media);
BoxesWizardMediaEntry* boxes_wizard_media_entry_construct (GType object_type, BoxesInstallerMedia* media);
gpointer boxes_vm_creator_ref (gpointer instance);
void boxes_vm_creator_unref (gpointer instance);
GParamSpec* boxes_param_spec_vm_creator (const gchar* name, const gchar* nick, const gchar* blurb, GType object_type, GParamFlags flags);
void boxes_value_set_vm_creator (GValue* value, gpointer v_object);
void boxes_value_take_vm_creator (GValue* value, gpointer v_object);
gpointer boxes_value_get_vm_creator (const GValue* value);
GType boxes_vm_creator_get_type (void) G_GNUC_CONST;
static void boxes_wizard_media_entry_finalize (GObject * obj);
GType boxes_wizard_web_view_get_type (void) G_GNUC_CONST;
#define BOXES_WIZARD_WEB_VIEW_GET_PRIVATE(o) (G_TYPE_INSTANCE_GET_PRIVATE ((o), BOXES_TYPE_WIZARD_WEB_VIEW, BoxesWizardWebViewPrivate))
#define BOXES_WIZARD_WEB_VIEW_progress_bar_id_timeout ((guint) 500)
static void boxes_wizard_web_view_real_dispose (GObject* base);
static gboolean boxes_wizard_web_view_on_context_menu (BoxesWizardWebView* self, WebKitWebView* web_view, WebKitContextMenu* context_menu, GdkEvent* event, WebKitHitTestResult* hit_test_result);
static void _g_object_unref0_ (gpointer var);
static inline void _g_list_free__g_object_unref0_ (GList* self);
static gboolean _boxes_wizard_web_view_on_context_menu_webkit_web_view_context_menu (WebKitWebView* _sender, WebKitContextMenu* context_menu, GdkEvent* event, WebKitHitTestResult* hit_test_result, gpointer self);
static void boxes_wizard_web_view_on_notify_estimated_load_progress (BoxesWizardWebView* self);
static gboolean ___lambda62_ (BoxesWizardWebView* self);
static gboolean ____lambda62__gsource_func (gpointer self);
static void _boxes_wizard_web_view_on_notify_estimated_load_progress_g_object_notify (GObject* _sender, GParamSpec* pspec, gpointer self);
BoxesWizardWebView* boxes_wizard_web_view_new (void);
BoxesWizardWebView* boxes_wizard_web_view_construct (GType object_type);
WebKitWebView* boxes_wizard_web_view_get_view (BoxesWizardWebView* self);
static GObject * boxes_wizard_web_view_constructor (GType type, guint n_construct_properties, GObjectConstructParam * construct_properties);
static gchar** _vala_array_dup6 (gchar** self, int length);
static void boxes_wizard_web_view_finalize (GObject * obj);
static void _vala_boxes_wizard_web_view_get_property (GObject * object, guint property_id, GValue * value, GParamSpec * pspec);
GType boxes_wizard_source_get_type (void) G_GNUC_CONST;
GType boxes_media_manager_get_type (void) G_GNUC_CONST;
GType boxes_libvirt_system_importer_get_type (void) G_GNUC_CONST;
GType boxes_app_window_get_type (void) G_GNUC_CONST;
#define BOXES_WIZARD_SOURCE_GET_PRIVATE(o) (G_TYPE_INSTANCE_GET_PRIVATE ((o), BOXES_TYPE_WIZARD_SOURCE, BoxesWizardSourcePrivate))
OsinfoOs* boxes_wizard_source_get_os_from_uri (BoxesWizardSource* self, const gchar* uri);
static Block91Data* block91_data_ref (Block91Data* _data91_);
static void block91_data_unref (void * _userdata_);
static gboolean __lambda63_ (Block91Data* _data91_, GtkTreeModel* store, GtkTreePath* path, GtkTreeIter* iter);
GType boxes_os_database_media_ur_ls_columns_get_type (void) G_GNUC_CONST;
static gboolean ___lambda63__gtk_tree_model_foreach_func (GtkTreeModel* model, GtkTreePath* path, GtkTreeIter* iter, gpointer self);
static void boxes_wizard_source_real_dispose (GObject* base);
void boxes_wizard_source_setup_ui (BoxesWizardSource* self, BoxesAppWindow* window);
GType boxes_os_database_get_type (void) G_GNUC_CONST;
static Block92Data* block92_data_ref (Block92Data* _data92_);
static void block92_data_unref (void * _userdata_);
BoxesOSDatabase* boxes_media_manager_get_os_db (BoxesMediaManager* self);
static GtkWidget* __lambda64_ (BoxesWizardSource* self, GObject* obj);
static void __lambda72_ (BoxesWizardSource* self, OsinfoMedia* media);
void boxes_wizard_source_set_uri (BoxesWizardSource* self, const gchar* value);
static void ___lambda72__boxes_wizard_downloadable_entry_activated (BoxesWizardDownloadableEntry* _sender, OsinfoMedia* media, gpointer self);
static GtkWidget* ___lambda64__gtk_list_box_create_widget_func (GObject* item, gpointer self);
static void __lambda73_ (BoxesWizardSource* self, GtkListBoxRow* row);
void boxes_wizard_source_set_selected (BoxesWizardSource* self, GtkWidget* value);
static void ___lambda73__gtk_list_box_row_activated (GtkListBox* _sender, GtkListBoxRow* row, gpointer self);
void boxes_os_database_list_latest_downloadable_oses (BoxesOSDatabase* self, GAsyncReadyCallback _callback_, gpointer _user_data_);
GQuark boxes_os_database_error_quark (void);
GHashTable* boxes_os_database_list_latest_downloadable_oses_finish (BoxesOSDatabase* self, GAsyncResult* _res_, GError** error);
static void __lambda74_ (Block92Data* _data92_, GObject* db, GAsyncResult* _result_);
static gint _____lambda75_ (BoxesWizardSource* self, GObject* a, GObject* b);
gchar* boxes_downloader_fetch_os_logo_url (OsinfoOs* os);
static gint ______lambda75__gcompare_data_func (gconstpointer a, gconstpointer b, gpointer self);
static void ___lambda74__gasync_ready_callback (GObject* source_object, GAsyncResult* res, gpointer self);
void boxes_os_database_get_all_media_urls_as_store (BoxesOSDatabase* self, GAsyncReadyCallback _callback_, gpointer _user_data_);
GtkListStore* boxes_os_database_get_all_media_urls_as_store_finish (BoxesOSDatabase* self, GAsyncResult* _res_, GError** error);
static void __lambda76_ (Block92Data* _data92_, GObject* db, GAsyncResult* _result_);
static gboolean ___lambda77_ (BoxesWizardSource* self, GtkEntryCompletion* store, const gchar* key, GtkTreeIter* iter);
static gboolean ____lambda77__gtk_entry_completion_match_func (GtkEntryCompletion* completion, const gchar* key, GtkTreeIter* iter, gpointer self);
static void ___lambda76__gasync_ready_callback (GObject* source_object, GAsyncResult* res, gpointer self);
void boxes_os_database_get_os_by_id (BoxesOSDatabase* self, const gchar* id, GAsyncReadyCallback _callback_, gpointer _user_data_);
OsinfoOs* boxes_os_database_get_os_by_id_finish (BoxesOSDatabase* self, GAsyncResult* _res_, GError** error);
static void __lambda78_ (Block92Data* _data92_, GObject* obj, GAsyncResult* res);
static void __lambda79_ (BoxesWizardSource* self, GObject* obj, GAsyncResult* res);
static void ___lambda79__gasync_ready_callback (GObject* source_object, GAsyncResult* res, gpointer self);
static void ___lambda78__gasync_ready_callback (GObject* source_object, GAsyncResult* res, gpointer self);
void boxes_wizard_source_cleanup (BoxesWizardSource* self);
void boxes_wizard_source_set_filename (BoxesWizardSource* self, const gchar* value);
static void boxes_wizard_source_set_install_media (BoxesWizardSource* self, BoxesInstallerMedia* value);
BoxesSourcePage boxes_wizard_source_get_page (BoxesWizardSource* self);
static void boxes_wizard_source_on_enter_url_button_clicked (BoxesWizardSource* self);
void boxes_wizard_source_set_page (BoxesWizardSource* self, BoxesSourcePage value);
static void _boxes_wizard_source_on_enter_url_button_clicked_gtk_button_clicked (GtkButton* _sender, gpointer self);
static void boxes_wizard_source_on_url_entry_activated (BoxesWizardSource* self);
static void _boxes_wizard_source_on_url_entry_activated_gtk_entry_activate (GtkEntry* _sender, gpointer self);
static void boxes_wizard_source_on_url_back_button_clicked (BoxesWizardSource* self);
static void _boxes_wizard_source_on_url_back_button_clicked_gtk_button_clicked (GtkButton* _sender, gpointer self);
static void boxes_wizard_source_add_media_entries_data_free (gpointer _data);
static void boxes_wizard_source_add_media_entries (BoxesWizardSource* self, GAsyncReadyCallback _callback_, gpointer _user_data_);
static void boxes_wizard_source_add_media_entries_finish (BoxesWizardSource* self, GAsyncResult* _res_);
static gboolean boxes_wizard_source_add_media_entries_co (BoxesWizardSourceAddMediaEntriesData* _data_);
void boxes_media_manager_list_installer_medias (BoxesMediaManager* self, GAsyncReadyCallback _callback_, gpointer _user_data_);
GList* boxes_media_manager_list_installer_medias_finish (BoxesMediaManager* self, GAsyncResult* _res_);
static void boxes_wizard_source_add_media_entries_ready (GObject* source_object, GAsyncResult* _res_, gpointer _user_data_);
static void boxes_wizard_source_add_media_entry (BoxesWizardSource* self, BoxesInstallerMedia* media);
static void boxes_wizard_source_update_libvirt_sytem_entry_visibility_data_free (gpointer _data);
static void boxes_wizard_source_update_libvirt_sytem_entry_visibility (BoxesWizardSource* self, GAsyncReadyCallback _callback_, gpointer _user_data_);
static void boxes_wizard_source_update_libvirt_sytem_entry_visibility_finish (BoxesWizardSource* self, GAsyncResult* _res_);
static gboolean boxes_wizard_source_update_libvirt_sytem_entry_visibility_co (BoxesWizardSourceUpdateLibvirtSytemEntryVisibilityData* _data_);
void boxes_libvirt_system_importer_new (GAsyncReadyCallback _callback_, gpointer _user_data_);
BoxesLibvirtSystemImporter* boxes_libvirt_system_importer_new_finish (GAsyncResult* _res_, GError** error);
void boxes_libvirt_system_importer_construct (GType object_type, GAsyncReadyCallback _callback_, gpointer _user_data_);
BoxesLibvirtSystemImporter* boxes_libvirt_system_importer_construct_finish (GAsyncResult* _res_, GError** error);
static void boxes_wizard_source_update_libvirt_sytem_entry_visibility_ready (GObject* source_object, GAsyncResult* _res_, gpointer _user_data_);
static void boxes_wizard_source_set_libvirt_sys_importer (BoxesWizardSource* self, BoxesLibvirtSystemImporter* value);
BoxesLibvirtSystemImporter* boxes_wizard_source_get_libvirt_sys_importer (BoxesWizardSource* self);
gchar* boxes_libvirt_system_importer_get_wizard_menu_label (BoxesLibvirtSystemImporter* self);
static void boxes_wizard_source_on_select_file_button_clicked (BoxesWizardSource* self);
GType boxes_ui_state_get_type (void) G_GNUC_CONST;
GType boxes_ui_get_type (void) G_GNUC_CONST;
GType boxes_wizard_window_get_type (void) G_GNUC_CONST;
GType boxes_properties_window_get_type (void) G_GNUC_CONST;
GType boxes_searchbar_get_type (void) G_GNUC_CONST;
GType boxes_topbar_get_type (void) G_GNUC_CONST;
GType boxes_selectionbar_get_type (void) G_GNUC_CONST;
GType boxes_display_page_get_type (void) G_GNUC_CONST;
GType boxes_empty_boxes_get_type (void) G_GNUC_CONST;
void boxes_wizard_window_show_file_chooser (BoxesWizardWindow* self, BoxesWizardWindowFileChosenFunc file_chosen_func, void* file_chosen_func_target, GDestroyNotify file_chosen_func_target_destroy_notify);
static void __lambda150_ (BoxesWizardSource* self, const gchar* uri);
static void ___lambda150__boxes_wizard_window_file_chosen_func (const gchar* uri, gpointer self);
static void _boxes_wizard_source_on_select_file_button_clicked_gtk_button_clicked (GtkButton* _sender, gpointer self);
static void boxes_wizard_source_on_libvirt_sys_import_button_clicked (BoxesWizardSource* self);
static void _boxes_wizard_source_on_libvirt_sys_import_button_clicked_gtk_button_clicked (GtkButton* _sender, gpointer self);
static void boxes_wizard_source_on_media_selected (BoxesWizardSource* self, BoxesInstallerMedia* media);
BoxesInstallerMedia* boxes_media_manager_create_installer_media_from_media (BoxesMediaManager* self, BoxesInstallerMedia* media, GError** error);
static void boxes_wizard_source_on_install_rhel_button_clicked (BoxesWizardSource* self);
static void __lambda151_ (BoxesWizardSource* self);
static void ___lambda151__gfunc (gconstpointer data, gpointer self);
static void _boxes_wizard_source_on_install_rhel_button_clicked_gtk_button_clicked (GtkButton* _sender, gpointer self);
static gboolean boxes_wizard_source_on_rhel_web_view_decide_policy (BoxesWizardSource* self, WebKitWebView* web_view, WebKitPolicyDecision* decision, WebKitPolicyDecisionType decision_type);
static WebKitNavigationAction* _vala_WebKitNavigationAction_copy (WebKitNavigationAction* self);
static void _vala_WebKitNavigationAction_free (WebKitNavigationAction* self);
static void _vala_SoupURI_free (SoupURI* self);
BoxesWizardSource* boxes_wizard_source_new (void);
BoxesWizardSource* boxes_wizard_source_construct (GType object_type);
GtkWidget* boxes_wizard_source_get_selected (BoxesWizardSource* self);
const gchar* boxes_wizard_source_get_uri (BoxesWizardSource* self);
BoxesInstallerMedia* boxes_wizard_source_get_install_media (BoxesWizardSource* self);
const gchar* boxes_wizard_source_get_filename (BoxesWizardSource* self);
gboolean boxes_wizard_source_get_download_required (BoxesWizardSource* self);
static gboolean _vala_string_array_contains (gchar* * stack, int stack_length, gchar* needle);
static GObject * boxes_wizard_source_constructor (GType type, guint n_construct_properties, GObjectConstructParam * construct_properties);
BoxesMediaManager* boxes_media_manager_get_instance (void);
static void _boxes_wizard_source___lambda152_ (BoxesWizardSource* self, GtkListBoxRow* row);
static void __boxes_wizard_source___lambda152__gtk_list_box_row_activated (GtkListBox* _sender, GtkListBoxRow* row, gpointer self);
void boxes_draw_as_css_box (GtkWidget* widget);
static gboolean _boxes_wizard_source_on_rhel_web_view_decide_policy_webkit_web_view_decide_policy (WebKitWebView* _sender, WebKitPolicyDecision* decision, WebKitPolicyDecisionType type, gpointer self);
static void boxes_wizard_source_finalize (GObject * obj);
static void _vala_boxes_wizard_source_get_property (GObject * object, guint property_id, GValue * value, GParamSpec * pspec);
static void _vala_boxes_wizard_source_set_property (GObject * object, guint property_id, const GValue * value, GParamSpec * pspec);
static void _vala_array_destroy (gpointer array, gint array_length, GDestroyNotify destroy_func);
static void _vala_array_free (gpointer array, gint array_length, GDestroyNotify destroy_func);
static gint _vala_array_length (gpointer array);

static const gchar* BOXES_WIZARD_SOURCE_page_names[3] = {"main-page", "rhel-web-view-page", "url-page"};

GType boxes_source_page_get_type (void) {
	static volatile gsize boxes_source_page_type_id__volatile = 0;
	if (g_once_init_enter (&boxes_source_page_type_id__volatile)) {
		static const GEnumValue values[] = {{BOXES_SOURCE_PAGE_MAIN, "BOXES_SOURCE_PAGE_MAIN", "main"}, {BOXES_SOURCE_PAGE_RHEL_WEB_VIEW, "BOXES_SOURCE_PAGE_RHEL_WEB_VIEW", "rhel-web-view"}, {BOXES_SOURCE_PAGE_URL, "BOXES_SOURCE_PAGE_URL", "url"}, {BOXES_SOURCE_PAGE_LAST, "BOXES_SOURCE_PAGE_LAST", "last"}, {0, NULL, NULL}};
		GType boxes_source_page_type_id;
		boxes_source_page_type_id = g_enum_register_static ("BoxesSourcePage", values);
		g_once_init_leave (&boxes_source_page_type_id__volatile, boxes_source_page_type_id);
	}
	return boxes_source_page_type_id__volatile;
}


static void __lambda59_ (BoxesWizardScrolled* self) {
#line 28 "/home/fborges/checkout/gnome-boxes/src/wizard-source.vala"
	gtk_widget_queue_resize ((GtkWidget*) self);
#line 823 "wizard-source.c"
}


static void ___lambda59__g_object_notify (GObject* _sender, GParamSpec* pspec, gpointer self) {
#line 27 "/home/fborges/checkout/gnome-boxes/src/wizard-source.vala"
	__lambda59_ ((BoxesWizardScrolled*) self);
#line 830 "wizard-source.c"
}


static void __lambda60_ (BoxesWizardScrolled* self) {
	GtkStyleContext* _tmp0_;
#line 31 "/home/fborges/checkout/gnome-boxes/src/wizard-source.vala"
	_tmp0_ = gtk_widget_get_style_context ((GtkWidget*) self);
#line 31 "/home/fborges/checkout/gnome-boxes/src/wizard-source.vala"
	gtk_style_context_add_class (_tmp0_, "boxes-menu-scrolled");
#line 32 "/home/fborges/checkout/gnome-boxes/src/wizard-source.vala"
	gtk_widget_reset_style ((GtkWidget*) self);
#line 842 "wizard-source.c"
}


static void ___lambda60__gtk_widget_show (GtkWidget* _sender, gpointer self) {
#line 30 "/home/fborges/checkout/gnome-boxes/src/wizard-source.vala"
	__lambda60_ ((BoxesWizardScrolled*) self);
#line 849 "wizard-source.c"
}


static void __lambda61_ (BoxesWizardScrolled* self) {
	GtkStyleContext* _tmp0_;
#line 35 "/home/fborges/checkout/gnome-boxes/src/wizard-source.vala"
	_tmp0_ = gtk_widget_get_style_context ((GtkWidget*) self);
#line 35 "/home/fborges/checkout/gnome-boxes/src/wizard-source.vala"
	gtk_style_context_remove_class (_tmp0_, "boxes-menu-scrolled");
#line 36 "/home/fborges/checkout/gnome-boxes/src/wizard-source.vala"
	gtk_widget_reset_style ((GtkWidget*) self);
#line 861 "wizard-source.c"
}


static void ___lambda61__gtk_widget_hide (GtkWidget* _sender, gpointer self) {
#line 34 "/home/fborges/checkout/gnome-boxes/src/wizard-source.vala"
	__lambda61_ ((BoxesWizardScrolled*) self);
#line 868 "wizard-source.c"
}


void boxes_wizard_scrolled_setup (BoxesWizardScrolled* self, gint num_visible) {
	gint _tmp0_;
	GtkWidget* _tmp1_;
	GtkWidget* _tmp2_;
#line 24 "/home/fborges/checkout/gnome-boxes/src/wizard-source.vala"
	g_return_if_fail (self != NULL);
#line 25 "/home/fborges/checkout/gnome-boxes/src/wizard-source.vala"
	_tmp0_ = num_visible;
#line 25 "/home/fborges/checkout/gnome-boxes/src/wizard-source.vala"
	boxes_wizard_scrolled_set_num_visible (self, _tmp0_);
#line 27 "/home/fborges/checkout/gnome-boxes/src/wizard-source.vala"
	g_signal_connect_object ((GObject*) self, "notify::num-visible", (GCallback) ___lambda59__g_object_notify, self, 0);
#line 30 "/home/fborges/checkout/gnome-boxes/src/wizard-source.vala"
	_tmp1_ = gtk_scrolled_window_get_vscrollbar ((GtkScrolledWindow*) self);
#line 30 "/home/fborges/checkout/gnome-boxes/src/wizard-source.vala"
	g_signal_connect_object (_tmp1_, "show", (GCallback) ___lambda60__gtk_widget_show, self, 0);
#line 34 "/home/fborges/checkout/gnome-boxes/src/wizard-source.vala"
	_tmp2_ = gtk_scrolled_window_get_vscrollbar ((GtkScrolledWindow*) self);
#line 34 "/home/fborges/checkout/gnome-boxes/src/wizard-source.vala"
	g_signal_connect_object (_tmp2_, "hide", (GCallback) ___lambda61__gtk_widget_hide, self, 0);
#line 892 "wizard-source.c"
}


static void boxes_wizard_scrolled_real_get_preferred_height (GtkWidget* base, gint* minimum_height, gint* natural_height) {
	BoxesWizardScrolled * self;
	gint _vala_minimum_height = 0;
	gint _vala_natural_height = 0;
	gint _tmp0_ = 0;
	gint _tmp1_ = 0;
	gint height = 0;
	gint i = 0;
	GtkListBox* _tmp2_;
	GList* _tmp3_;
	gint _tmp13_;
	gint _tmp14_;
	gint _tmp15_;
	gint _tmp16_;
	gint _tmp17_;
	gint _tmp18_;
#line 40 "/home/fborges/checkout/gnome-boxes/src/wizard-source.vala"
	self = (BoxesWizardScrolled*) base;
#line 41 "/home/fborges/checkout/gnome-boxes/src/wizard-source.vala"
	GTK_WIDGET_CLASS (boxes_wizard_scrolled_parent_class)->get_preferred_height ((GtkWidget*) G_TYPE_CHECK_INSTANCE_CAST (self, gtk_scrolled_window_get_type (), GtkScrolledWindow), &_tmp0_, &_tmp1_);
#line 41 "/home/fborges/checkout/gnome-boxes/src/wizard-source.vala"
	_vala_minimum_height = _tmp0_;
#line 41 "/home/fborges/checkout/gnome-boxes/src/wizard-source.vala"
	_vala_natural_height = _tmp1_;
#line 43 "/home/fborges/checkout/gnome-boxes/src/wizard-source.vala"
	height = 0;
#line 44 "/home/fborges/checkout/gnome-boxes/src/wizard-source.vala"
	i = 0;
#line 45 "/home/fborges/checkout/gnome-boxes/src/wizard-source.vala"
	_tmp2_ = self->vbox;
#line 45 "/home/fborges/checkout/gnome-boxes/src/wizard-source.vala"
	_tmp3_ = gtk_container_get_children ((GtkContainer*) _tmp2_);
#line 928 "wizard-source.c"
	{
		GList* w_collection = NULL;
		GList* w_it = NULL;
#line 45 "/home/fborges/checkout/gnome-boxes/src/wizard-source.vala"
		w_collection = _tmp3_;
#line 45 "/home/fborges/checkout/gnome-boxes/src/wizard-source.vala"
		for (w_it = w_collection; w_it != NULL; w_it = w_it->next) {
#line 936 "wizard-source.c"
			GtkWidget* w = NULL;
#line 45 "/home/fborges/checkout/gnome-boxes/src/wizard-source.vala"
			w = (GtkWidget*) w_it->data;
#line 940 "wizard-source.c"
			{
				GtkWidget* _tmp4_;
				gboolean _tmp5_;
				gint child_height = 0;
				GtkWidget* _tmp6_;
				gint _tmp7_ = 0;
				gint _tmp8_;
				gint _tmp9_;
				gint _tmp10_;
				gint _tmp11_;
				gint _tmp12_;
#line 46 "/home/fborges/checkout/gnome-boxes/src/wizard-source.vala"
				_tmp4_ = w;
#line 46 "/home/fborges/checkout/gnome-boxes/src/wizard-source.vala"
				_tmp5_ = gtk_widget_get_visible (_tmp4_);
#line 46 "/home/fborges/checkout/gnome-boxes/src/wizard-source.vala"
				if (!_tmp5_) {
#line 47 "/home/fborges/checkout/gnome-boxes/src/wizard-source.vala"
					continue;
#line 960 "wizard-source.c"
				}
#line 49 "/home/fborges/checkout/gnome-boxes/src/wizard-source.vala"
				_tmp6_ = w;
#line 49 "/home/fborges/checkout/gnome-boxes/src/wizard-source.vala"
				gtk_widget_get_preferred_height (_tmp6_, NULL, &_tmp7_);
#line 49 "/home/fborges/checkout/gnome-boxes/src/wizard-source.vala"
				child_height = _tmp7_;
#line 50 "/home/fborges/checkout/gnome-boxes/src/wizard-source.vala"
				_tmp8_ = height;
#line 50 "/home/fborges/checkout/gnome-boxes/src/wizard-source.vala"
				_tmp9_ = child_height;
#line 50 "/home/fborges/checkout/gnome-boxes/src/wizard-source.vala"
				height = _tmp8_ + _tmp9_;
#line 51 "/home/fborges/checkout/gnome-boxes/src/wizard-source.vala"
				_tmp10_ = i;
#line 51 "/home/fborges/checkout/gnome-boxes/src/wizard-source.vala"
				i = _tmp10_ + 1;
#line 52 "/home/fborges/checkout/gnome-boxes/src/wizard-source.vala"
				_tmp11_ = i;
#line 52 "/home/fborges/checkout/gnome-boxes/src/wizard-source.vala"
				_tmp12_ = self->priv->_num_visible;
#line 52 "/home/fborges/checkout/gnome-boxes/src/wizard-source.vala"
				if (_tmp11_ == _tmp12_) {
#line 53 "/home/fborges/checkout/gnome-boxes/src/wizard-source.vala"
					break;
#line 986 "wizard-source.c"
				}
			}
		}
#line 45 "/home/fborges/checkout/gnome-boxes/src/wizard-source.vala"
		_g_list_free0 (w_collection);
#line 992 "wizard-source.c"
	}
#line 55 "/home/fborges/checkout/gnome-boxes/src/wizard-source.vala"
	_tmp13_ = _vala_minimum_height;
#line 55 "/home/fborges/checkout/gnome-boxes/src/wizard-source.vala"
	_tmp14_ = height;
#line 55 "/home/fborges/checkout/gnome-boxes/src/wizard-source.vala"
	_tmp15_ = MAX (_tmp13_, _tmp14_);
#line 55 "/home/fborges/checkout/gnome-boxes/src/wizard-source.vala"
	_vala_minimum_height = _tmp15_;
#line 56 "/home/fborges/checkout/gnome-boxes/src/wizard-source.vala"
	_tmp16_ = _vala_natural_height;
#line 56 "/home/fborges/checkout/gnome-boxes/src/wizard-source.vala"
	_tmp17_ = height;
#line 56 "/home/fborges/checkout/gnome-boxes/src/wizard-source.vala"
	_tmp18_ = MAX (_tmp16_, _tmp17_);
#line 56 "/home/fborges/checkout/gnome-boxes/src/wizard-source.vala"
	_vala_natural_height = _tmp18_;
#line 40 "/home/fborges/checkout/gnome-boxes/src/wizard-source.vala"
	if (minimum_height) {
#line 40 "/home/fborges/checkout/gnome-boxes/src/wizard-source.vala"
		*minimum_height = _vala_minimum_height;
#line 1014 "wizard-source.c"
	}
#line 40 "/home/fborges/checkout/gnome-boxes/src/wizard-source.vala"
	if (natural_height) {
#line 40 "/home/fborges/checkout/gnome-boxes/src/wizard-source.vala"
		*natural_height = _vala_natural_height;
#line 1020 "wizard-source.c"
	}
}


BoxesWizardScrolled* boxes_wizard_scrolled_construct (GType object_type) {
	BoxesWizardScrolled * self = NULL;
#line 16 "/home/fborges/checkout/gnome-boxes/src/wizard-source.vala"
	self = (BoxesWizardScrolled*) g_object_new (object_type, NULL);
#line 16 "/home/fborges/checkout/gnome-boxes/src/wizard-source.vala"
	return self;
#line 1031 "wizard-source.c"
}


BoxesWizardScrolled* boxes_wizard_scrolled_new (void) {
#line 16 "/home/fborges/checkout/gnome-boxes/src/wizard-source.vala"
	return boxes_wizard_scrolled_construct (BOXES_TYPE_WIZARD_SCROLLED);
#line 1038 "wizard-source.c"
}


static gint boxes_wizard_scrolled_get_num_visible (BoxesWizardScrolled* self) {
	gint result;
	gint _tmp0_;
#line 20 "/home/fborges/checkout/gnome-boxes/src/wizard-source.vala"
	g_return_val_if_fail (self != NULL, 0);
#line 20 "/home/fborges/checkout/gnome-boxes/src/wizard-source.vala"
	_tmp0_ = self->priv->_num_visible;
#line 20 "/home/fborges/checkout/gnome-boxes/src/wizard-source.vala"
	result = _tmp0_;
#line 20 "/home/fborges/checkout/gnome-boxes/src/wizard-source.vala"
	return result;
#line 1053 "wizard-source.c"
}


static void boxes_wizard_scrolled_set_num_visible (BoxesWizardScrolled* self, gint value) {
	gint _tmp0_;
#line 20 "/home/fborges/checkout/gnome-boxes/src/wizard-source.vala"
	g_return_if_fail (self != NULL);
#line 20 "/home/fborges/checkout/gnome-boxes/src/wizard-source.vala"
	_tmp0_ = value;
#line 20 "/home/fborges/checkout/gnome-boxes/src/wizard-source.vala"
	self->priv->_num_visible = _tmp0_;
#line 1065 "wizard-source.c"
}


static void boxes_wizard_scrolled_class_init (BoxesWizardScrolledClass * klass) {
	gint BoxesWizardScrolled_private_offset;
#line 16 "/home/fborges/checkout/gnome-boxes/src/wizard-source.vala"
	boxes_wizard_scrolled_parent_class = g_type_class_peek_parent (klass);
#line 16 "/home/fborges/checkout/gnome-boxes/src/wizard-source.vala"
	g_type_class_add_private (klass, sizeof (BoxesWizardScrolledPrivate));
#line 16 "/home/fborges/checkout/gnome-boxes/src/wizard-source.vala"
	((GtkWidgetClass *) klass)->get_preferred_height = (void (*) (GtkWidget *, gint*, gint*)) boxes_wizard_scrolled_real_get_preferred_height;
#line 16 "/home/fborges/checkout/gnome-boxes/src/wizard-source.vala"
	G_OBJECT_CLASS (klass)->get_property = _vala_boxes_wizard_scrolled_get_property;
#line 16 "/home/fborges/checkout/gnome-boxes/src/wizard-source.vala"
	G_OBJECT_CLASS (klass)->set_property = _vala_boxes_wizard_scrolled_set_property;
#line 16 "/home/fborges/checkout/gnome-boxes/src/wizard-source.vala"
	G_OBJECT_CLASS (klass)->finalize = boxes_wizard_scrolled_finalize;
#line 16 "/home/fborges/checkout/gnome-boxes/src/wizard-source.vala"
	BoxesWizardScrolled_private_offset = g_type_class_get_instance_private_offset (klass);
#line 16 "/home/fborges/checkout/gnome-boxes/src/wizard-source.vala"
	gtk_widget_class_set_template_from_resource (GTK_WIDGET_CLASS (klass), "/org/gnome/Boxes/ui/wizard-scrolled.ui");
#line 16 "/home/fborges/checkout/gnome-boxes/src/wizard-source.vala"
	gtk_widget_class_bind_template_child_full (GTK_WIDGET_CLASS (klass), "vbox", FALSE, G_STRUCT_OFFSET (BoxesWizardScrolled, vbox));
#line 1089 "wizard-source.c"
}


static void boxes_wizard_scrolled_instance_init (BoxesWizardScrolled * self) {
#line 16 "/home/fborges/checkout/gnome-boxes/src/wizard-source.vala"
	self->priv = BOXES_WIZARD_SCROLLED_GET_PRIVATE (self);
#line 16 "/home/fborges/checkout/gnome-boxes/src/wizard-source.vala"
	gtk_widget_init_template (GTK_WIDGET (self));
#line 1098 "wizard-source.c"
}


static void boxes_wizard_scrolled_finalize (GObject * obj) {
	BoxesWizardScrolled * self;
#line 16 "/home/fborges/checkout/gnome-boxes/src/wizard-source.vala"
	self = G_TYPE_CHECK_INSTANCE_CAST (obj, BOXES_TYPE_WIZARD_SCROLLED, BoxesWizardScrolled);
#line 18 "/home/fborges/checkout/gnome-boxes/src/wizard-source.vala"
	_g_object_unref0 (self->vbox);
#line 16 "/home/fborges/checkout/gnome-boxes/src/wizard-source.vala"
	G_OBJECT_CLASS (boxes_wizard_scrolled_parent_class)->finalize (obj);
#line 1110 "wizard-source.c"
}


GType boxes_wizard_scrolled_get_type (void) {
	static volatile gsize boxes_wizard_scrolled_type_id__volatile = 0;
	if (g_once_init_enter (&boxes_wizard_scrolled_type_id__volatile)) {
		static const GTypeInfo g_define_type_info = { sizeof (BoxesWizardScrolledClass), (GBaseInitFunc) NULL, (GBaseFinalizeFunc) NULL, (GClassInitFunc) boxes_wizard_scrolled_class_init, (GClassFinalizeFunc) NULL, NULL, sizeof (BoxesWizardScrolled), 0, (GInstanceInitFunc) boxes_wizard_scrolled_instance_init, NULL };
		GType boxes_wizard_scrolled_type_id;
		boxes_wizard_scrolled_type_id = g_type_register_static (gtk_scrolled_window_get_type (), "BoxesWizardScrolled", &g_define_type_info, 0);
		g_once_init_leave (&boxes_wizard_scrolled_type_id__volatile, boxes_wizard_scrolled_type_id);
	}
	return boxes_wizard_scrolled_type_id__volatile;
}


static void _vala_boxes_wizard_scrolled_get_property (GObject * object, guint property_id, GValue * value, GParamSpec * pspec) {
	BoxesWizardScrolled * self;
	self = G_TYPE_CHECK_INSTANCE_CAST (object, BOXES_TYPE_WIZARD_SCROLLED, BoxesWizardScrolled);
#line 16 "/home/fborges/checkout/gnome-boxes/src/wizard-source.vala"
	switch (property_id) {
#line 1131 "wizard-source.c"
		default:
#line 16 "/home/fborges/checkout/gnome-boxes/src/wizard-source.vala"
		G_OBJECT_WARN_INVALID_PROPERTY_ID (object, property_id, pspec);
#line 16 "/home/fborges/checkout/gnome-boxes/src/wizard-source.vala"
		break;
#line 1137 "wizard-source.c"
	}
}


static void _vala_boxes_wizard_scrolled_set_property (GObject * object, guint property_id, const GValue * value, GParamSpec * pspec) {
	BoxesWizardScrolled * self;
	self = G_TYPE_CHECK_INSTANCE_CAST (object, BOXES_TYPE_WIZARD_SCROLLED, BoxesWizardScrolled);
#line 16 "/home/fborges/checkout/gnome-boxes/src/wizard-source.vala"
	switch (property_id) {
#line 1147 "wizard-source.c"
		default:
#line 16 "/home/fborges/checkout/gnome-boxes/src/wizard-source.vala"
		G_OBJECT_WARN_INVALID_PROPERTY_ID (object, property_id, pspec);
#line 16 "/home/fborges/checkout/gnome-boxes/src/wizard-source.vala"
		break;
#line 1153 "wizard-source.c"
	}
}


static gpointer _g_object_ref0 (gpointer self) {
#line 66 "/home/fborges/checkout/gnome-boxes/src/wizard-source.vala"
	return self ? g_object_ref (self) : NULL;
#line 1161 "wizard-source.c"
}


BoxesWizardDownloadableMediaEntry* boxes_wizard_downloadable_media_entry_construct (GType object_type, OsinfoMedia* media) {
	BoxesWizardDownloadableMediaEntry * self = NULL;
	OsinfoMedia* _tmp0_;
	OsinfoMedia* _tmp1_;
	GtkLabel* _tmp2_;
	GtkStyleContext* _tmp3_;
	GtkStyleContext* _tmp4_;
#line 65 "/home/fborges/checkout/gnome-boxes/src/wizard-source.vala"
	g_return_val_if_fail (media != NULL, NULL);
#line 65 "/home/fborges/checkout/gnome-boxes/src/wizard-source.vala"
	self = (BoxesWizardDownloadableMediaEntry*) g_object_new (object_type, NULL);
#line 66 "/home/fborges/checkout/gnome-boxes/src/wizard-source.vala"
	_tmp0_ = media;
#line 66 "/home/fborges/checkout/gnome-boxes/src/wizard-source.vala"
	_tmp1_ = _g_object_ref0 (_tmp0_);
#line 66 "/home/fborges/checkout/gnome-boxes/src/wizard-source.vala"
	_g_object_unref0 (self->media);
#line 66 "/home/fborges/checkout/gnome-boxes/src/wizard-source.vala"
	self->media = _tmp1_;
#line 68 "/home/fborges/checkout/gnome-boxes/src/wizard-source.vala"
	boxes_wizard_downloadable_media_entry_setup_label (self);
#line 69 "/home/fborges/checkout/gnome-boxes/src/wizard-source.vala"
	_tmp2_ = self->priv->label;
#line 69 "/home/fborges/checkout/gnome-boxes/src/wizard-source.vala"
	gtk_container_add ((GtkContainer*) self, (GtkWidget*) _tmp2_);
#line 71 "/home/fborges/checkout/gnome-boxes/src/wizard-source.vala"
	_tmp3_ = gtk_widget_get_style_context ((GtkWidget*) self);
#line 71 "/home/fborges/checkout/gnome-boxes/src/wizard-source.vala"
	gtk_style_context_add_class (_tmp3_, "boxes-menu-row");
#line 72 "/home/fborges/checkout/gnome-boxes/src/wizard-source.vala"
	_tmp4_ = gtk_widget_get_style_context ((GtkWidget*) self);
#line 72 "/home/fborges/checkout/gnome-boxes/src/wizard-source.vala"
	gtk_style_context_add_class (_tmp4_, "boxes-menu-subrow");
#line 65 "/home/fborges/checkout/gnome-boxes/src/wizard-source.vala"
	return self;
#line 1200 "wizard-source.c"
}


BoxesWizardDownloadableMediaEntry* boxes_wizard_downloadable_media_entry_new (OsinfoMedia* media) {
#line 65 "/home/fborges/checkout/gnome-boxes/src/wizard-source.vala"
	return boxes_wizard_downloadable_media_entry_construct (BOXES_TYPE_WIZARD_DOWNLOADABLE_MEDIA_ENTRY, media);
#line 1207 "wizard-source.c"
}


static gboolean string_contains (const gchar* self, const gchar* needle) {
	gboolean result = FALSE;
	const gchar* _tmp0_;
	gchar* _tmp1_;
#line 1411 "/usr/share/vala-0.38/vapi/glib-2.0.vapi"
	g_return_val_if_fail (self != NULL, FALSE);
#line 1411 "/usr/share/vala-0.38/vapi/glib-2.0.vapi"
	g_return_val_if_fail (needle != NULL, FALSE);
#line 1412 "/usr/share/vala-0.38/vapi/glib-2.0.vapi"
	_tmp0_ = needle;
#line 1412 "/usr/share/vala-0.38/vapi/glib-2.0.vapi"
	_tmp1_ = strstr ((gchar*) self, (gchar*) _tmp0_);
#line 1412 "/usr/share/vala-0.38/vapi/glib-2.0.vapi"
	result = _tmp1_ != NULL;
#line 1412 "/usr/share/vala-0.38/vapi/glib-2.0.vapi"
	return result;
#line 1227 "wizard-source.c"
}


static gchar* string_replace (const gchar* self, const gchar* old, const gchar* replacement) {
	gchar* result = NULL;
	gboolean _tmp0_ = FALSE;
	gboolean _tmp1_ = FALSE;
	GError * _inner_error_ = NULL;
#line 1415 "/usr/share/vala-0.38/vapi/glib-2.0.vapi"
	g_return_val_if_fail (self != NULL, NULL);
#line 1415 "/usr/share/vala-0.38/vapi/glib-2.0.vapi"
	g_return_val_if_fail (old != NULL, NULL);
#line 1415 "/usr/share/vala-0.38/vapi/glib-2.0.vapi"
	g_return_val_if_fail (replacement != NULL, NULL);
#line 1416 "/usr/share/vala-0.38/vapi/glib-2.0.vapi"
	if ((*((gchar*) self)) == '\0') {
#line 1416 "/usr/share/vala-0.38/vapi/glib-2.0.vapi"
		_tmp1_ = TRUE;
#line 1246 "wizard-source.c"
	} else {
		const gchar* _tmp2_;
#line 1416 "/usr/share/vala-0.38/vapi/glib-2.0.vapi"
		_tmp2_ = old;
#line 1416 "/usr/share/vala-0.38/vapi/glib-2.0.vapi"
		_tmp1_ = (*((gchar*) _tmp2_)) == '\0';
#line 1253 "wizard-source.c"
	}
#line 1416 "/usr/share/vala-0.38/vapi/glib-2.0.vapi"
	if (_tmp1_) {
#line 1416 "/usr/share/vala-0.38/vapi/glib-2.0.vapi"
		_tmp0_ = TRUE;
#line 1259 "wizard-source.c"
	} else {
		const gchar* _tmp3_;
		const gchar* _tmp4_;
#line 1416 "/usr/share/vala-0.38/vapi/glib-2.0.vapi"
		_tmp3_ = old;
#line 1416 "/usr/share/vala-0.38/vapi/glib-2.0.vapi"
		_tmp4_ = replacement;
#line 1416 "/usr/share/vala-0.38/vapi/glib-2.0.vapi"
		_tmp0_ = g_strcmp0 (_tmp3_, _tmp4_) == 0;
#line 1269 "wizard-source.c"
	}
#line 1416 "/usr/share/vala-0.38/vapi/glib-2.0.vapi"
	if (_tmp0_) {
#line 1273 "wizard-source.c"
		gchar* _tmp5_;
#line 1417 "/usr/share/vala-0.38/vapi/glib-2.0.vapi"
		_tmp5_ = g_strdup (self);
#line 1417 "/usr/share/vala-0.38/vapi/glib-2.0.vapi"
		result = _tmp5_;
#line 1417 "/usr/share/vala-0.38/vapi/glib-2.0.vapi"
		return result;
#line 1281 "wizard-source.c"
	}
	{
		GRegex* regex = NULL;
		const gchar* _tmp6_;
		gchar* _tmp7_;
		gchar* _tmp8_;
		GRegex* _tmp9_;
		GRegex* _tmp10_;
		gchar* _tmp11_ = NULL;
		GRegex* _tmp12_;
		const gchar* _tmp13_;
		gchar* _tmp14_;
		gchar* _tmp15_;
#line 1420 "/usr/share/vala-0.38/vapi/glib-2.0.vapi"
		_tmp6_ = old;
#line 1420 "/usr/share/vala-0.38/vapi/glib-2.0.vapi"
		_tmp7_ = g_regex_escape_string (_tmp6_, -1);
#line 1420 "/usr/share/vala-0.38/vapi/glib-2.0.vapi"
		_tmp8_ = _tmp7_;
#line 1420 "/usr/share/vala-0.38/vapi/glib-2.0.vapi"
		_tmp9_ = g_regex_new (_tmp8_, 0, 0, &_inner_error_);
#line 1420 "/usr/share/vala-0.38/vapi/glib-2.0.vapi"
		_tmp10_ = _tmp9_;
#line 1420 "/usr/share/vala-0.38/vapi/glib-2.0.vapi"
		_g_free0 (_tmp8_);
#line 1420 "/usr/share/vala-0.38/vapi/glib-2.0.vapi"
		regex = _tmp10_;
#line 1420 "/usr/share/vala-0.38/vapi/glib-2.0.vapi"
		if (G_UNLIKELY (_inner_error_ != NULL)) {
#line 1420 "/usr/share/vala-0.38/vapi/glib-2.0.vapi"
			if (_inner_error_->domain == G_REGEX_ERROR) {
#line 1313 "wizard-source.c"
				goto __catch133_g_regex_error;
			}
#line 1420 "/usr/share/vala-0.38/vapi/glib-2.0.vapi"
			g_critical ("file %s: line %d: unexpected error: %s (%s, %d)", __FILE__, __LINE__, _inner_error_->message, g_quark_to_string (_inner_error_->domain), _inner_error_->code);
#line 1420 "/usr/share/vala-0.38/vapi/glib-2.0.vapi"
			g_clear_error (&_inner_error_);
#line 1420 "/usr/share/vala-0.38/vapi/glib-2.0.vapi"
			return NULL;
#line 1322 "wizard-source.c"
		}
#line 1421 "/usr/share/vala-0.38/vapi/glib-2.0.vapi"
		_tmp12_ = regex;
#line 1421 "/usr/share/vala-0.38/vapi/glib-2.0.vapi"
		_tmp13_ = replacement;
#line 1421 "/usr/share/vala-0.38/vapi/glib-2.0.vapi"
		_tmp14_ = g_regex_replace_literal (_tmp12_, self, (gssize) -1, 0, _tmp13_, 0, &_inner_error_);
#line 1421 "/usr/share/vala-0.38/vapi/glib-2.0.vapi"
		_tmp11_ = _tmp14_;
#line 1421 "/usr/share/vala-0.38/vapi/glib-2.0.vapi"
		if (G_UNLIKELY (_inner_error_ != NULL)) {
#line 1421 "/usr/share/vala-0.38/vapi/glib-2.0.vapi"
			_g_regex_unref0 (regex);
#line 1421 "/usr/share/vala-0.38/vapi/glib-2.0.vapi"
			if (_inner_error_->domain == G_REGEX_ERROR) {
#line 1338 "wizard-source.c"
				goto __catch133_g_regex_error;
			}
#line 1421 "/usr/share/vala-0.38/vapi/glib-2.0.vapi"
			_g_regex_unref0 (regex);
#line 1421 "/usr/share/vala-0.38/vapi/glib-2.0.vapi"
			g_critical ("file %s: line %d: unexpected error: %s (%s, %d)", __FILE__, __LINE__, _inner_error_->message, g_quark_to_string (_inner_error_->domain), _inner_error_->code);
#line 1421 "/usr/share/vala-0.38/vapi/glib-2.0.vapi"
			g_clear_error (&_inner_error_);
#line 1421 "/usr/share/vala-0.38/vapi/glib-2.0.vapi"
			return NULL;
#line 1349 "wizard-source.c"
		}
#line 1421 "/usr/share/vala-0.38/vapi/glib-2.0.vapi"
		_tmp15_ = _tmp11_;
#line 1421 "/usr/share/vala-0.38/vapi/glib-2.0.vapi"
		_tmp11_ = NULL;
#line 1421 "/usr/share/vala-0.38/vapi/glib-2.0.vapi"
		result = _tmp15_;
#line 1421 "/usr/share/vala-0.38/vapi/glib-2.0.vapi"
		_g_free0 (_tmp11_);
#line 1421 "/usr/share/vala-0.38/vapi/glib-2.0.vapi"
		_g_regex_unref0 (regex);
#line 1421 "/usr/share/vala-0.38/vapi/glib-2.0.vapi"
		return result;
#line 1363 "wizard-source.c"
	}
	goto __finally133;
	__catch133_g_regex_error:
	{
		GError* e = NULL;
#line 1419 "/usr/share/vala-0.38/vapi/glib-2.0.vapi"
		e = _inner_error_;
#line 1419 "/usr/share/vala-0.38/vapi/glib-2.0.vapi"
		_inner_error_ = NULL;
#line 1423 "/usr/share/vala-0.38/vapi/glib-2.0.vapi"
		g_assert_not_reached ();
#line 1419 "/usr/share/vala-0.38/vapi/glib-2.0.vapi"
		_g_error_free0 (e);
#line 1377 "wizard-source.c"
	}
	__finally133:
#line 1419 "/usr/share/vala-0.38/vapi/glib-2.0.vapi"
	if (G_UNLIKELY (_inner_error_ != NULL)) {
#line 1419 "/usr/share/vala-0.38/vapi/glib-2.0.vapi"
		g_critical ("file %s: line %d: uncaught error: %s (%s, %d)", __FILE__, __LINE__, _inner_error_->message, g_quark_to_string (_inner_error_->domain), _inner_error_->code);
#line 1419 "/usr/share/vala-0.38/vapi/glib-2.0.vapi"
		g_clear_error (&_inner_error_);
#line 1419 "/usr/share/vala-0.38/vapi/glib-2.0.vapi"
		return NULL;
#line 1388 "wizard-source.c"
	}
}


static const gchar* string_to_string (const gchar* self) {
	const gchar* result = NULL;
#line 1450 "/usr/share/vala-0.38/vapi/glib-2.0.vapi"
	g_return_val_if_fail (self != NULL, NULL);
#line 1451 "/usr/share/vala-0.38/vapi/glib-2.0.vapi"
	result = self;
#line 1451 "/usr/share/vala-0.38/vapi/glib-2.0.vapi"
	return result;
#line 1401 "wizard-source.c"
}


static void boxes_wizard_downloadable_media_entry_setup_label (BoxesWizardDownloadableMediaEntry* self) {
	GtkLabel* _tmp0_;
	gchar* variant = NULL;
	gchar* _tmp1_;
	OsinfoOsVariantList* variants = NULL;
	OsinfoMedia* _tmp2_;
	OsinfoOsVariantList* _tmp3_;
	OsinfoOsVariantList* _tmp4_;
	gint _tmp5_;
	gchar* subvariant = NULL;
	gchar* _tmp46_;
	OsinfoMedia* _tmp47_;
	gchar* _tmp48_;
	gchar* _tmp49_;
	gchar* _tmp50_;
	gboolean _tmp51_;
	gboolean _tmp52_;
	gchar* _tmp68_ = NULL;
	OsinfoMedia* _tmp69_;
	gboolean _tmp70_;
	gboolean _tmp71_;
	gchar* is_live = NULL;
	gchar* _tmp76_;
	GtkLabel* _tmp77_;
	const gchar* _tmp78_;
	const gchar* _tmp79_;
	OsinfoMedia* _tmp80_;
	gchar* _tmp81_;
	gchar* _tmp82_;
	gchar* _tmp83_;
	const gchar* _tmp84_;
	const gchar* _tmp85_;
	const gchar* _tmp86_;
	const gchar* _tmp87_;
	gchar* _tmp88_;
	gchar* _tmp89_;
	GtkLabel* _tmp90_;
	GtkLabel* _tmp91_;
	const gchar* _tmp92_;
	const gchar* _tmp93_;
	gchar* _tmp94_;
	gchar* _tmp95_;
	GtkLabel* _tmp96_;
#line 75 "/home/fborges/checkout/gnome-boxes/src/wizard-source.vala"
	g_return_if_fail (self != NULL);
#line 79 "/home/fborges/checkout/gnome-boxes/src/wizard-source.vala"
	_tmp0_ = (GtkLabel*) gtk_label_new ("");
#line 79 "/home/fborges/checkout/gnome-boxes/src/wizard-source.vala"
	g_object_ref_sink (_tmp0_);
#line 79 "/home/fborges/checkout/gnome-boxes/src/wizard-source.vala"
	_g_object_unref0 (self->priv->label);
#line 79 "/home/fborges/checkout/gnome-boxes/src/wizard-source.vala"
	self->priv->label = _tmp0_;
#line 81 "/home/fborges/checkout/gnome-boxes/src/wizard-source.vala"
	_tmp1_ = g_strdup ("");
#line 81 "/home/fborges/checkout/gnome-boxes/src/wizard-source.vala"
	variant = _tmp1_;
#line 82 "/home/fborges/checkout/gnome-boxes/src/wizard-source.vala"
	_tmp2_ = self->media;
#line 82 "/home/fborges/checkout/gnome-boxes/src/wizard-source.vala"
	_tmp3_ = osinfo_media_get_os_variants (_tmp2_);
#line 82 "/home/fborges/checkout/gnome-boxes/src/wizard-source.vala"
	variants = _tmp3_;
#line 83 "/home/fborges/checkout/gnome-boxes/src/wizard-source.vala"
	_tmp4_ = variants;
#line 83 "/home/fborges/checkout/gnome-boxes/src/wizard-source.vala"
	_tmp5_ = osinfo_list_get_length ((OsinfoList*) _tmp4_);
#line 83 "/home/fborges/checkout/gnome-boxes/src/wizard-source.vala"
	if (_tmp5_ > 0) {
#line 1474 "wizard-source.c"
		OsinfoOsVariantList* _tmp6_;
		OsinfoEntity* _tmp7_;
		const gchar* _tmp8_;
		gchar* _tmp9_;
#line 84 "/home/fborges/checkout/gnome-boxes/src/wizard-source.vala"
		_tmp6_ = variants;
#line 84 "/home/fborges/checkout/gnome-boxes/src/wizard-source.vala"
		_tmp7_ = osinfo_list_get_nth ((OsinfoList*) _tmp6_, 0);
#line 84 "/home/fborges/checkout/gnome-boxes/src/wizard-source.vala"
		_tmp8_ = osinfo_os_variant_get_name (G_TYPE_CHECK_INSTANCE_TYPE (_tmp7_, osinfo_os_variant_get_type ()) ? ((OsinfoOsVariant*) _tmp7_) : NULL);
#line 84 "/home/fborges/checkout/gnome-boxes/src/wizard-source.vala"
		_tmp9_ = g_strdup (_tmp8_);
#line 84 "/home/fborges/checkout/gnome-boxes/src/wizard-source.vala"
		_g_free0 (variant);
#line 84 "/home/fborges/checkout/gnome-boxes/src/wizard-source.vala"
		variant = _tmp9_;
#line 1491 "wizard-source.c"
	} else {
		OsinfoMedia* _tmp10_;
		OsinfoOs* _tmp11_;
		OsinfoOs* _tmp12_;
		OsinfoProduct* _tmp13_;
		OsinfoProduct* _tmp14_;
		const gchar* _tmp15_;
		const gchar* _tmp16_;
		gboolean _tmp17_;
#line 85 "/home/fborges/checkout/gnome-boxes/src/wizard-source.vala"
		_tmp10_ = self->media;
#line 85 "/home/fborges/checkout/gnome-boxes/src/wizard-source.vala"
		g_object_get (_tmp10_, "os", &_tmp11_, NULL);
#line 85 "/home/fborges/checkout/gnome-boxes/src/wizard-source.vala"
		_tmp12_ = _tmp11_;
#line 85 "/home/fborges/checkout/gnome-boxes/src/wizard-source.vala"
		_tmp13_ = G_TYPE_CHECK_INSTANCE_TYPE (_tmp12_, osinfo_product_get_type ()) ? ((OsinfoProduct*) _tmp12_) : NULL;
#line 85 "/home/fborges/checkout/gnome-boxes/src/wizard-source.vala"
		if (_tmp13_ == NULL) {
#line 85 "/home/fborges/checkout/gnome-boxes/src/wizard-source.vala"
			_g_object_unref0 (_tmp12_);
#line 1513 "wizard-source.c"
		}
#line 85 "/home/fborges/checkout/gnome-boxes/src/wizard-source.vala"
		_tmp14_ = _tmp13_;
#line 85 "/home/fborges/checkout/gnome-boxes/src/wizard-source.vala"
		_tmp15_ = osinfo_product_get_name (_tmp14_);
#line 85 "/home/fborges/checkout/gnome-boxes/src/wizard-source.vala"
		_tmp16_ = _tmp15_;
#line 85 "/home/fborges/checkout/gnome-boxes/src/wizard-source.vala"
		_tmp17_ = _tmp16_ != NULL;
#line 85 "/home/fborges/checkout/gnome-boxes/src/wizard-source.vala"
		_g_object_unref0 (_tmp14_);
#line 85 "/home/fborges/checkout/gnome-boxes/src/wizard-source.vala"
		if (_tmp17_) {
#line 1527 "wizard-source.c"
			OsinfoMedia* _tmp18_;
			OsinfoOs* _tmp19_;
			OsinfoOs* _tmp20_;
			OsinfoProduct* _tmp21_;
			OsinfoProduct* _tmp22_;
			const gchar* _tmp23_;
			const gchar* _tmp24_;
			gchar* _tmp25_;
			OsinfoMedia* _tmp26_;
			gchar* _tmp27_;
			gchar* _tmp28_;
			gchar* _tmp29_;
			gboolean _tmp30_;
			gboolean _tmp31_;
#line 86 "/home/fborges/checkout/gnome-boxes/src/wizard-source.vala"
			_tmp18_ = self->media;
#line 86 "/home/fborges/checkout/gnome-boxes/src/wizard-source.vala"
			g_object_get (_tmp18_, "os", &_tmp19_, NULL);
#line 86 "/home/fborges/checkout/gnome-boxes/src/wizard-source.vala"
			_tmp20_ = _tmp19_;
#line 86 "/home/fborges/checkout/gnome-boxes/src/wizard-source.vala"
			_tmp21_ = G_TYPE_CHECK_INSTANCE_TYPE (_tmp20_, osinfo_product_get_type ()) ? ((OsinfoProduct*) _tmp20_) : NULL;
#line 86 "/home/fborges/checkout/gnome-boxes/src/wizard-source.vala"
			if (_tmp21_ == NULL) {
#line 86 "/home/fborges/checkout/gnome-boxes/src/wizard-source.vala"
				_g_object_unref0 (_tmp20_);
#line 1554 "wizard-source.c"
			}
#line 86 "/home/fborges/checkout/gnome-boxes/src/wizard-source.vala"
			_tmp22_ = _tmp21_;
#line 86 "/home/fborges/checkout/gnome-boxes/src/wizard-source.vala"
			_tmp23_ = osinfo_product_get_name (_tmp22_);
#line 86 "/home/fborges/checkout/gnome-boxes/src/wizard-source.vala"
			_tmp24_ = _tmp23_;
#line 86 "/home/fborges/checkout/gnome-boxes/src/wizard-source.vala"
			_tmp25_ = g_strdup (_tmp24_);
#line 86 "/home/fborges/checkout/gnome-boxes/src/wizard-source.vala"
			_g_free0 (variant);
#line 86 "/home/fborges/checkout/gnome-boxes/src/wizard-source.vala"
			variant = _tmp25_;
#line 86 "/home/fborges/checkout/gnome-boxes/src/wizard-source.vala"
			_g_object_unref0 (_tmp22_);
#line 87 "/home/fborges/checkout/gnome-boxes/src/wizard-source.vala"
			_tmp26_ = self->media;
#line 87 "/home/fborges/checkout/gnome-boxes/src/wizard-source.vala"
			g_object_get (_tmp26_, "url", &_tmp27_, NULL);
#line 87 "/home/fborges/checkout/gnome-boxes/src/wizard-source.vala"
			_tmp28_ = _tmp27_;
#line 87 "/home/fborges/checkout/gnome-boxes/src/wizard-source.vala"
			_tmp29_ = _tmp28_;
#line 87 "/home/fborges/checkout/gnome-boxes/src/wizard-source.vala"
			_tmp30_ = string_contains (_tmp29_, "server");
#line 87 "/home/fborges/checkout/gnome-boxes/src/wizard-source.vala"
			_tmp31_ = _tmp30_;
#line 87 "/home/fborges/checkout/gnome-boxes/src/wizard-source.vala"
			_g_free0 (_tmp29_);
#line 87 "/home/fborges/checkout/gnome-boxes/src/wizard-source.vala"
			if (_tmp31_) {
#line 1586 "wizard-source.c"
				const gchar* _tmp32_;
				gchar* _tmp33_;
#line 88 "/home/fborges/checkout/gnome-boxes/src/wizard-source.vala"
				_tmp32_ = variant;
#line 88 "/home/fborges/checkout/gnome-boxes/src/wizard-source.vala"
				_tmp33_ = g_strconcat (_tmp32_, " Server", NULL);
#line 88 "/home/fborges/checkout/gnome-boxes/src/wizard-source.vala"
				_g_free0 (variant);
#line 88 "/home/fborges/checkout/gnome-boxes/src/wizard-source.vala"
				variant = _tmp33_;
#line 1597 "wizard-source.c"
			}
		} else {
			GFile* file = NULL;
			OsinfoMedia* _tmp34_;
			gchar* _tmp35_;
			gchar* _tmp36_;
			gchar* _tmp37_;
			GFile* _tmp38_;
			GFile* _tmp39_;
			GtkLabel* _tmp40_;
			GFile* _tmp41_;
			gchar* _tmp42_;
			gchar* _tmp43_;
			gchar* _tmp44_;
			gchar* _tmp45_;
#line 90 "/home/fborges/checkout/gnome-boxes/src/wizard-source.vala"
			_tmp34_ = self->media;
#line 90 "/home/fborges/checkout/gnome-boxes/src/wizard-source.vala"
			g_object_get (_tmp34_, "url", &_tmp35_, NULL);
#line 90 "/home/fborges/checkout/gnome-boxes/src/wizard-source.vala"
			_tmp36_ = _tmp35_;
#line 90 "/home/fborges/checkout/gnome-boxes/src/wizard-source.vala"
			_tmp37_ = _tmp36_;
#line 90 "/home/fborges/checkout/gnome-boxes/src/wizard-source.vala"
			_tmp38_ = g_file_new_for_uri (_tmp37_);
#line 90 "/home/fborges/checkout/gnome-boxes/src/wizard-source.vala"
			_tmp39_ = _tmp38_;
#line 90 "/home/fborges/checkout/gnome-boxes/src/wizard-source.vala"
			_g_free0 (_tmp37_);
#line 90 "/home/fborges/checkout/gnome-boxes/src/wizard-source.vala"
			file = _tmp39_;
#line 92 "/home/fborges/checkout/gnome-boxes/src/wizard-source.vala"
			_tmp40_ = self->priv->label;
#line 92 "/home/fborges/checkout/gnome-boxes/src/wizard-source.vala"
			_tmp41_ = file;
#line 92 "/home/fborges/checkout/gnome-boxes/src/wizard-source.vala"
			_tmp42_ = g_file_get_basename (_tmp41_);
#line 92 "/home/fborges/checkout/gnome-boxes/src/wizard-source.vala"
			_tmp43_ = _tmp42_;
#line 92 "/home/fborges/checkout/gnome-boxes/src/wizard-source.vala"
			_tmp44_ = string_replace (_tmp43_, "_", "");
#line 92 "/home/fborges/checkout/gnome-boxes/src/wizard-source.vala"
			_tmp45_ = _tmp44_;
#line 92 "/home/fborges/checkout/gnome-boxes/src/wizard-source.vala"
			gtk_label_set_label (_tmp40_, _tmp45_);
#line 92 "/home/fborges/checkout/gnome-boxes/src/wizard-source.vala"
			_g_free0 (_tmp45_);
#line 92 "/home/fborges/checkout/gnome-boxes/src/wizard-source.vala"
			_g_free0 (_tmp43_);
#line 85 "/home/fborges/checkout/gnome-boxes/src/wizard-source.vala"
			_g_object_unref0 (file);
#line 1649 "wizard-source.c"
		}
	}
#line 95 "/home/fborges/checkout/gnome-boxes/src/wizard-source.vala"
	_tmp46_ = g_strdup ("");
#line 95 "/home/fborges/checkout/gnome-boxes/src/wizard-source.vala"
	subvariant = _tmp46_;
#line 96 "/home/fborges/checkout/gnome-boxes/src/wizard-source.vala"
	_tmp47_ = self->media;
#line 96 "/home/fborges/checkout/gnome-boxes/src/wizard-source.vala"
	g_object_get (_tmp47_, "url", &_tmp48_, NULL);
#line 96 "/home/fborges/checkout/gnome-boxes/src/wizard-source.vala"
	_tmp49_ = _tmp48_;
#line 96 "/home/fborges/checkout/gnome-boxes/src/wizard-source.vala"
	_tmp50_ = _tmp49_;
#line 96 "/home/fborges/checkout/gnome-boxes/src/wizard-source.vala"
	_tmp51_ = string_contains (_tmp50_, "netinst");
#line 96 "/home/fborges/checkout/gnome-boxes/src/wizard-source.vala"
	_tmp52_ = _tmp51_;
#line 96 "/home/fborges/checkout/gnome-boxes/src/wizard-source.vala"
	_g_free0 (_tmp50_);
#line 96 "/home/fborges/checkout/gnome-boxes/src/wizard-source.vala"
	if (_tmp52_) {
#line 1672 "wizard-source.c"
		gchar* _tmp53_;
#line 97 "/home/fborges/checkout/gnome-boxes/src/wizard-source.vala"
		_tmp53_ = g_strdup ("(netinst)");
#line 97 "/home/fborges/checkout/gnome-boxes/src/wizard-source.vala"
		_g_free0 (subvariant);
#line 97 "/home/fborges/checkout/gnome-boxes/src/wizard-source.vala"
		subvariant = _tmp53_;
#line 1680 "wizard-source.c"
	} else {
		OsinfoMedia* _tmp54_;
		gchar* _tmp55_;
		gchar* _tmp56_;
		gchar* _tmp57_;
		gboolean _tmp58_;
		gboolean _tmp59_;
#line 98 "/home/fborges/checkout/gnome-boxes/src/wizard-source.vala"
		_tmp54_ = self->media;
#line 98 "/home/fborges/checkout/gnome-boxes/src/wizard-source.vala"
		g_object_get (_tmp54_, "url", &_tmp55_, NULL);
#line 98 "/home/fborges/checkout/gnome-boxes/src/wizard-source.vala"
		_tmp56_ = _tmp55_;
#line 98 "/home/fborges/checkout/gnome-boxes/src/wizard-source.vala"
		_tmp57_ = _tmp56_;
#line 98 "/home/fborges/checkout/gnome-boxes/src/wizard-source.vala"
		_tmp58_ = string_contains (_tmp57_, "minimal");
#line 98 "/home/fborges/checkout/gnome-boxes/src/wizard-source.vala"
		_tmp59_ = _tmp58_;
#line 98 "/home/fborges/checkout/gnome-boxes/src/wizard-source.vala"
		_g_free0 (_tmp57_);
#line 98 "/home/fborges/checkout/gnome-boxes/src/wizard-source.vala"
		if (_tmp59_) {
#line 1704 "wizard-source.c"
			gchar* _tmp60_;
#line 99 "/home/fborges/checkout/gnome-boxes/src/wizard-source.vala"
			_tmp60_ = g_strdup ("(minimal)");
#line 99 "/home/fborges/checkout/gnome-boxes/src/wizard-source.vala"
			_g_free0 (subvariant);
#line 99 "/home/fborges/checkout/gnome-boxes/src/wizard-source.vala"
			subvariant = _tmp60_;
#line 1712 "wizard-source.c"
		} else {
			OsinfoMedia* _tmp61_;
			gchar* _tmp62_;
			gchar* _tmp63_;
			gchar* _tmp64_;
			gboolean _tmp65_;
			gboolean _tmp66_;
#line 100 "/home/fborges/checkout/gnome-boxes/src/wizard-source.vala"
			_tmp61_ = self->media;
#line 100 "/home/fborges/checkout/gnome-boxes/src/wizard-source.vala"
			g_object_get (_tmp61_, "url", &_tmp62_, NULL);
#line 100 "/home/fborges/checkout/gnome-boxes/src/wizard-source.vala"
			_tmp63_ = _tmp62_;
#line 100 "/home/fborges/checkout/gnome-boxes/src/wizard-source.vala"
			_tmp64_ = _tmp63_;
#line 100 "/home/fborges/checkout/gnome-boxes/src/wizard-source.vala"
			_tmp65_ = string_contains (_tmp64_, "dvd");
#line 100 "/home/fborges/checkout/gnome-boxes/src/wizard-source.vala"
			_tmp66_ = _tmp65_;
#line 100 "/home/fborges/checkout/gnome-boxes/src/wizard-source.vala"
			_g_free0 (_tmp64_);
#line 100 "/home/fborges/checkout/gnome-boxes/src/wizard-source.vala"
			if (_tmp66_) {
#line 1736 "wizard-source.c"
				gchar* _tmp67_;
#line 101 "/home/fborges/checkout/gnome-boxes/src/wizard-source.vala"
				_tmp67_ = g_strdup ("(DVD)");
#line 101 "/home/fborges/checkout/gnome-boxes/src/wizard-source.vala"
				_g_free0 (subvariant);
#line 101 "/home/fborges/checkout/gnome-boxes/src/wizard-source.vala"
				subvariant = _tmp67_;
#line 1744 "wizard-source.c"
			}
		}
	}
#line 103 "/home/fborges/checkout/gnome-boxes/src/wizard-source.vala"
	_tmp69_ = self->media;
#line 103 "/home/fborges/checkout/gnome-boxes/src/wizard-source.vala"
	g_object_get (_tmp69_, "live", &_tmp70_, NULL);
#line 103 "/home/fborges/checkout/gnome-boxes/src/wizard-source.vala"
	_tmp71_ = _tmp70_;
#line 103 "/home/fborges/checkout/gnome-boxes/src/wizard-source.vala"
	if (_tmp71_) {
#line 1756 "wizard-source.c"
		gchar* _tmp72_;
		gchar* _tmp73_;
		gchar* _tmp74_;
#line 103 "/home/fborges/checkout/gnome-boxes/src/wizard-source.vala"
		_tmp72_ = g_strconcat (" (", _ ("Live"), NULL);
#line 103 "/home/fborges/checkout/gnome-boxes/src/wizard-source.vala"
		_tmp73_ = _tmp72_;
#line 103 "/home/fborges/checkout/gnome-boxes/src/wizard-source.vala"
		_tmp74_ = g_strconcat (_tmp73_, ")", NULL);
#line 103 "/home/fborges/checkout/gnome-boxes/src/wizard-source.vala"
		_g_free0 (_tmp68_);
#line 103 "/home/fborges/checkout/gnome-boxes/src/wizard-source.vala"
		_tmp68_ = _tmp74_;
#line 103 "/home/fborges/checkout/gnome-boxes/src/wizard-source.vala"
		_g_free0 (_tmp73_);
#line 1772 "wizard-source.c"
	} else {
		gchar* _tmp75_;
#line 103 "/home/fborges/checkout/gnome-boxes/src/wizard-source.vala"
		_tmp75_ = g_strdup ("");
#line 103 "/home/fborges/checkout/gnome-boxes/src/wizard-source.vala"
		_g_free0 (_tmp68_);
#line 103 "/home/fborges/checkout/gnome-boxes/src/wizard-source.vala"
		_tmp68_ = _tmp75_;
#line 1781 "wizard-source.c"
	}
#line 103 "/home/fborges/checkout/gnome-boxes/src/wizard-source.vala"
	_tmp76_ = g_strdup (_tmp68_);
#line 103 "/home/fborges/checkout/gnome-boxes/src/wizard-source.vala"
	is_live = _tmp76_;
#line 105 "/home/fborges/checkout/gnome-boxes/src/wizard-source.vala"
	_tmp77_ = self->priv->label;
#line 105 "/home/fborges/checkout/gnome-boxes/src/wizard-source.vala"
	_tmp78_ = variant;
#line 105 "/home/fborges/checkout/gnome-boxes/src/wizard-source.vala"
	_tmp79_ = string_to_string (_tmp78_);
#line 105 "/home/fborges/checkout/gnome-boxes/src/wizard-source.vala"
	_tmp80_ = self->media;
#line 105 "/home/fborges/checkout/gnome-boxes/src/wizard-source.vala"
	g_object_get (_tmp80_, "architecture", &_tmp81_, NULL);
#line 105 "/home/fborges/checkout/gnome-boxes/src/wizard-source.vala"
	_tmp82_ = _tmp81_;
#line 105 "/home/fborges/checkout/gnome-boxes/src/wizard-source.vala"
	_tmp83_ = _tmp82_;
#line 105 "/home/fborges/checkout/gnome-boxes/src/wizard-source.vala"
	_tmp84_ = string_to_string (_tmp83_);
#line 105 "/home/fborges/checkout/gnome-boxes/src/wizard-source.vala"
	_tmp85_ = subvariant;
#line 105 "/home/fborges/checkout/gnome-boxes/src/wizard-source.vala"
	_tmp86_ = string_to_string (_tmp85_);
#line 105 "/home/fborges/checkout/gnome-boxes/src/wizard-source.vala"
	_tmp87_ = string_to_string (is_live);
#line 105 "/home/fborges/checkout/gnome-boxes/src/wizard-source.vala"
	_tmp88_ = g_strconcat (_tmp79_, " ", _tmp84_, " ", _tmp86_, " ", _tmp87_, NULL);
#line 105 "/home/fborges/checkout/gnome-boxes/src/wizard-source.vala"
	_tmp89_ = _tmp88_;
#line 105 "/home/fborges/checkout/gnome-boxes/src/wizard-source.vala"
	gtk_label_set_label (_tmp77_, _tmp89_);
#line 105 "/home/fborges/checkout/gnome-boxes/src/wizard-source.vala"
	_g_free0 (_tmp89_);
#line 105 "/home/fborges/checkout/gnome-boxes/src/wizard-source.vala"
	_g_free0 (_tmp83_);
#line 108 "/home/fborges/checkout/gnome-boxes/src/wizard-source.vala"
	_tmp90_ = self->priv->label;
#line 108 "/home/fborges/checkout/gnome-boxes/src/wizard-source.vala"
	_tmp91_ = self->priv->label;
#line 108 "/home/fborges/checkout/gnome-boxes/src/wizard-source.vala"
	_tmp92_ = gtk_label_get_label (_tmp91_);
#line 108 "/home/fborges/checkout/gnome-boxes/src/wizard-source.vala"
	_tmp93_ = _tmp92_;
#line 108 "/home/fborges/checkout/gnome-boxes/src/wizard-source.vala"
	_tmp94_ = string_replace (_tmp93_, "  ", "");
#line 108 "/home/fborges/checkout/gnome-boxes/src/wizard-source.vala"
	_tmp95_ = _tmp94_;
#line 108 "/home/fborges/checkout/gnome-boxes/src/wizard-source.vala"
	gtk_label_set_label (_tmp90_, _tmp95_);
#line 108 "/home/fborges/checkout/gnome-boxes/src/wizard-source.vala"
	_g_free0 (_tmp95_);
#line 110 "/home/fborges/checkout/gnome-boxes/src/wizard-source.vala"
	_tmp96_ = self->priv->label;
#line 110 "/home/fborges/checkout/gnome-boxes/src/wizard-source.vala"
	gtk_widget_set_halign ((GtkWidget*) _tmp96_, GTK_ALIGN_START);
#line 75 "/home/fborges/checkout/gnome-boxes/src/wizard-source.vala"
	_g_free0 (is_live);
#line 75 "/home/fborges/checkout/gnome-boxes/src/wizard-source.vala"
	_g_free0 (_tmp68_);
#line 75 "/home/fborges/checkout/gnome-boxes/src/wizard-source.vala"
	_g_free0 (subvariant);
#line 75 "/home/fborges/checkout/gnome-boxes/src/wizard-source.vala"
	_g_object_unref0 (variants);
#line 75 "/home/fborges/checkout/gnome-boxes/src/wizard-source.vala"
	_g_free0 (variant);
#line 1849 "wizard-source.c"
}


static void boxes_wizard_downloadable_media_entry_class_init (BoxesWizardDownloadableMediaEntryClass * klass) {
#line 60 "/home/fborges/checkout/gnome-boxes/src/wizard-source.vala"
	boxes_wizard_downloadable_media_entry_parent_class = g_type_class_peek_parent (klass);
#line 60 "/home/fborges/checkout/gnome-boxes/src/wizard-source.vala"
	g_type_class_add_private (klass, sizeof (BoxesWizardDownloadableMediaEntryPrivate));
#line 60 "/home/fborges/checkout/gnome-boxes/src/wizard-source.vala"
	G_OBJECT_CLASS (klass)->finalize = boxes_wizard_downloadable_media_entry_finalize;
#line 1860 "wizard-source.c"
}


static void boxes_wizard_downloadable_media_entry_instance_init (BoxesWizardDownloadableMediaEntry * self) {
#line 60 "/home/fborges/checkout/gnome-boxes/src/wizard-source.vala"
	self->priv = BOXES_WIZARD_DOWNLOADABLE_MEDIA_ENTRY_GET_PRIVATE (self);
#line 1867 "wizard-source.c"
}


static void boxes_wizard_downloadable_media_entry_finalize (GObject * obj) {
	BoxesWizardDownloadableMediaEntry * self;
#line 60 "/home/fborges/checkout/gnome-boxes/src/wizard-source.vala"
	self = G_TYPE_CHECK_INSTANCE_CAST (obj, BOXES_TYPE_WIZARD_DOWNLOADABLE_MEDIA_ENTRY, BoxesWizardDownloadableMediaEntry);
#line 61 "/home/fborges/checkout/gnome-boxes/src/wizard-source.vala"
	_g_object_unref0 (self->media);
#line 63 "/home/fborges/checkout/gnome-boxes/src/wizard-source.vala"
	_g_object_unref0 (self->priv->label);
#line 60 "/home/fborges/checkout/gnome-boxes/src/wizard-source.vala"
	G_OBJECT_CLASS (boxes_wizard_downloadable_media_entry_parent_class)->finalize (obj);
#line 1881 "wizard-source.c"
}


GType boxes_wizard_downloadable_media_entry_get_type (void) {
	static volatile gsize boxes_wizard_downloadable_media_entry_type_id__volatile = 0;
	if (g_once_init_enter (&boxes_wizard_downloadable_media_entry_type_id__volatile)) {
		static const GTypeInfo g_define_type_info = { sizeof (BoxesWizardDownloadableMediaEntryClass), (GBaseInitFunc) NULL, (GBaseFinalizeFunc) NULL, (GClassInitFunc) boxes_wizard_downloadable_media_entry_class_init, (GClassFinalizeFunc) NULL, NULL, sizeof (BoxesWizardDownloadableMediaEntry), 0, (GInstanceInitFunc) boxes_wizard_downloadable_media_entry_instance_init, NULL };
		GType boxes_wizard_downloadable_media_entry_type_id;
		boxes_wizard_downloadable_media_entry_type_id = g_type_register_static (gtk_list_box_row_get_type (), "BoxesWizardDownloadableMediaEntry", &g_define_type_info, 0);
		g_once_init_leave (&boxes_wizard_downloadable_media_entry_type_id__volatile, boxes_wizard_downloadable_media_entry_type_id);
	}
	return boxes_wizard_downloadable_media_entry_type_id__volatile;
}


BoxesWizardDownloadableEntry* boxes_wizard_downloadable_entry_construct (GType object_type, OsinfoOs* os) {
	BoxesWizardDownloadableEntry * self = NULL;
	GtkImage* _tmp0_;
	OsinfoOs* _tmp1_;
	GtkLabel* _tmp2_;
	OsinfoOs* _tmp3_;
	const gchar* _tmp4_;
	const gchar* _tmp5_;
	GtkLabel* _tmp6_;
	OsinfoOs* _tmp7_;
	const gchar* _tmp8_;
	const gchar* _tmp9_;
	OsinfoList* media_list = NULL;
	OsinfoOs* _tmp10_;
	OsinfoMediaList* _tmp11_;
	OsinfoList* _tmp12_;
	OsinfoList* _tmp13_;
	gint _tmp14_;
#line 131 "/home/fborges/checkout/gnome-boxes/src/wizard-source.vala"
	g_return_val_if_fail (os != NULL, NULL);
#line 131 "/home/fborges/checkout/gnome-boxes/src/wizard-source.vala"
	self = (BoxesWizardDownloadableEntry*) g_object_new (object_type, NULL);
#line 132 "/home/fborges/checkout/gnome-boxes/src/wizard-source.vala"
	_tmp0_ = self->priv->media_image;
#line 132 "/home/fborges/checkout/gnome-boxes/src/wizard-source.vala"
	_tmp1_ = os;
#line 132 "/home/fborges/checkout/gnome-boxes/src/wizard-source.vala"
	boxes_downloader_fetch_os_logo (_tmp0_, _tmp1_, 64, NULL, NULL);
#line 134 "/home/fborges/checkout/gnome-boxes/src/wizard-source.vala"
	_tmp2_ = self->priv->title_label;
#line 134 "/home/fborges/checkout/gnome-boxes/src/wizard-source.vala"
	_tmp3_ = os;
#line 134 "/home/fborges/checkout/gnome-boxes/src/wizard-source.vala"
	_tmp4_ = osinfo_product_get_name ((OsinfoProduct*) _tmp3_);
#line 134 "/home/fborges/checkout/gnome-boxes/src/wizard-source.vala"
	_tmp5_ = _tmp4_;
#line 134 "/home/fborges/checkout/gnome-boxes/src/wizard-source.vala"
	gtk_label_set_label (_tmp2_, _tmp5_);
#line 135 "/home/fborges/checkout/gnome-boxes/src/wizard-source.vala"
	_tmp6_ = self->priv->details_label;
#line 135 "/home/fborges/checkout/gnome-boxes/src/wizard-source.vala"
	_tmp7_ = os;
#line 135 "/home/fborges/checkout/gnome-boxes/src/wizard-source.vala"
	_tmp8_ = osinfo_product_get_vendor ((OsinfoProduct*) _tmp7_);
#line 135 "/home/fborges/checkout/gnome-boxes/src/wizard-source.vala"
	_tmp9_ = _tmp8_;
#line 135 "/home/fborges/checkout/gnome-boxes/src/wizard-source.vala"
	gtk_label_set_label (_tmp6_, _tmp9_);
#line 137 "/home/fborges/checkout/gnome-boxes/src/wizard-source.vala"
	_tmp10_ = os;
#line 137 "/home/fborges/checkout/gnome-boxes/src/wizard-source.vala"
	_tmp11_ = osinfo_os_get_media_list (_tmp10_);
#line 137 "/home/fborges/checkout/gnome-boxes/src/wizard-source.vala"
	_tmp12_ = G_TYPE_CHECK_INSTANCE_TYPE (_tmp11_, osinfo_list_get_type ()) ? ((OsinfoList*) _tmp11_) : NULL;
#line 137 "/home/fborges/checkout/gnome-boxes/src/wizard-source.vala"
	if (_tmp12_ == NULL) {
#line 137 "/home/fborges/checkout/gnome-boxes/src/wizard-source.vala"
		_g_object_unref0 (_tmp11_);
#line 1955 "wizard-source.c"
	}
#line 137 "/home/fborges/checkout/gnome-boxes/src/wizard-source.vala"
	media_list = _tmp12_;
#line 138 "/home/fborges/checkout/gnome-boxes/src/wizard-source.vala"
	_tmp13_ = media_list;
#line 138 "/home/fborges/checkout/gnome-boxes/src/wizard-source.vala"
	_tmp14_ = osinfo_list_get_length (_tmp13_);
#line 138 "/home/fborges/checkout/gnome-boxes/src/wizard-source.vala"
	if (_tmp14_ == 1) {
#line 1965 "wizard-source.c"
		OsinfoList* _tmp15_;
		OsinfoEntity* _tmp16_;
		OsinfoMedia* _tmp17_;
#line 139 "/home/fborges/checkout/gnome-boxes/src/wizard-source.vala"
		_tmp15_ = media_list;
#line 139 "/home/fborges/checkout/gnome-boxes/src/wizard-source.vala"
		_tmp16_ = osinfo_list_get_nth (_tmp15_, 0);
#line 139 "/home/fborges/checkout/gnome-boxes/src/wizard-source.vala"
		_tmp17_ = _g_object_ref0 (G_TYPE_CHECK_INSTANCE_TYPE (_tmp16_, osinfo_media_get_type ()) ? ((OsinfoMedia*) _tmp16_) : NULL);
#line 139 "/home/fborges/checkout/gnome-boxes/src/wizard-source.vala"
		_g_object_unref0 (self->single_media);
#line 139 "/home/fborges/checkout/gnome-boxes/src/wizard-source.vala"
		self->single_media = _tmp17_;
#line 1979 "wizard-source.c"
	} else {
		OsinfoList* _tmp18_;
#line 141 "/home/fborges/checkout/gnome-boxes/src/wizard-source.vala"
		_tmp18_ = media_list;
#line 141 "/home/fborges/checkout/gnome-boxes/src/wizard-source.vala"
		boxes_wizard_downloadable_entry_populate_media_listbox (self, _tmp18_);
#line 1986 "wizard-source.c"
	}
#line 131 "/home/fborges/checkout/gnome-boxes/src/wizard-source.vala"
	_g_object_unref0 (media_list);
#line 131 "/home/fborges/checkout/gnome-boxes/src/wizard-source.vala"
	return self;
#line 1992 "wizard-source.c"
}


BoxesWizardDownloadableEntry* boxes_wizard_downloadable_entry_new (OsinfoOs* os) {
#line 131 "/home/fborges/checkout/gnome-boxes/src/wizard-source.vala"
	return boxes_wizard_downloadable_entry_construct (BOXES_TYPE_WIZARD_DOWNLOADABLE_ENTRY, os);
#line 1999 "wizard-source.c"
}


static void boxes_wizard_downloadable_entry_populate_media_listbox (BoxesWizardDownloadableEntry* self, OsinfoList* media_list) {
	OsinfoList* _tmp0_;
	GList* _tmp1_;
	GtkListBox* _tmp8_;
#line 144 "/home/fborges/checkout/gnome-boxes/src/wizard-source.vala"
	g_return_if_fail (self != NULL);
#line 144 "/home/fborges/checkout/gnome-boxes/src/wizard-source.vala"
	g_return_if_fail (media_list != NULL);
#line 145 "/home/fborges/checkout/gnome-boxes/src/wizard-source.vala"
	_tmp0_ = media_list;
#line 145 "/home/fborges/checkout/gnome-boxes/src/wizard-source.vala"
	_tmp1_ = osinfo_list_get_elements (_tmp0_);
#line 2015 "wizard-source.c"
	{
		GList* media_entity_collection = NULL;
		GList* media_entity_it = NULL;
#line 145 "/home/fborges/checkout/gnome-boxes/src/wizard-source.vala"
		media_entity_collection = _tmp1_;
#line 145 "/home/fborges/checkout/gnome-boxes/src/wizard-source.vala"
		for (media_entity_it = media_entity_collection; media_entity_it != NULL; media_entity_it = media_entity_it->next) {
#line 2023 "wizard-source.c"
			OsinfoEntity* media_entity = NULL;
#line 145 "/home/fborges/checkout/gnome-boxes/src/wizard-source.vala"
			media_entity = (OsinfoEntity*) media_entity_it->data;
#line 2027 "wizard-source.c"
			{
				OsinfoMedia* media = NULL;
				OsinfoEntity* _tmp2_;
				OsinfoMedia* _tmp3_;
				GtkListBox* _tmp4_;
				OsinfoMedia* _tmp5_;
				BoxesWizardDownloadableMediaEntry* _tmp6_;
				BoxesWizardDownloadableMediaEntry* _tmp7_;
#line 146 "/home/fborges/checkout/gnome-boxes/src/wizard-source.vala"
				_tmp2_ = media_entity;
#line 146 "/home/fborges/checkout/gnome-boxes/src/wizard-source.vala"
				_tmp3_ = _g_object_ref0 (G_TYPE_CHECK_INSTANCE_TYPE (_tmp2_, osinfo_media_get_type ()) ? ((OsinfoMedia*) _tmp2_) : NULL);
#line 146 "/home/fborges/checkout/gnome-boxes/src/wizard-source.vala"
				media = _tmp3_;
#line 148 "/home/fborges/checkout/gnome-boxes/src/wizard-source.vala"
				_tmp4_ = self->priv->medias_listbox;
#line 148 "/home/fborges/checkout/gnome-boxes/src/wizard-source.vala"
				_tmp5_ = media;
#line 148 "/home/fborges/checkout/gnome-boxes/src/wizard-source.vala"
				_tmp6_ = boxes_wizard_downloadable_media_entry_new (_tmp5_);
#line 148 "/home/fborges/checkout/gnome-boxes/src/wizard-source.vala"
				g_object_ref_sink (_tmp6_);
#line 148 "/home/fborges/checkout/gnome-boxes/src/wizard-source.vala"
				_tmp7_ = _tmp6_;
#line 148 "/home/fborges/checkout/gnome-boxes/src/wizard-source.vala"
				gtk_list_box_insert (_tmp4_, (GtkWidget*) _tmp7_, -1);
#line 148 "/home/fborges/checkout/gnome-boxes/src/wizard-source.vala"
				_g_object_unref0 (_tmp7_);
#line 145 "/home/fborges/checkout/gnome-boxes/src/wizard-source.vala"
				_g_object_unref0 (media);
#line 2058 "wizard-source.c"
			}
		}
#line 145 "/home/fborges/checkout/gnome-boxes/src/wizard-source.vala"
		_g_list_free0 (media_entity_collection);
#line 2063 "wizard-source.c"
	}
#line 151 "/home/fborges/checkout/gnome-boxes/src/wizard-source.vala"
	_tmp8_ = self->priv->medias_listbox;
#line 151 "/home/fborges/checkout/gnome-boxes/src/wizard-source.vala"
	gtk_widget_show_all ((GtkWidget*) _tmp8_);
#line 2069 "wizard-source.c"
}


static void boxes_wizard_downloadable_entry_on_media_listbox_activated (BoxesWizardDownloadableEntry* self, GtkListBoxRow* row) {
	BoxesWizardDownloadableMediaEntry* entry = NULL;
	GtkListBoxRow* _tmp0_;
	BoxesWizardDownloadableMediaEntry* _tmp1_;
	OsinfoMedia* _tmp2_;
#line 155 "/home/fborges/checkout/gnome-boxes/src/wizard-source.vala"
	g_return_if_fail (self != NULL);
#line 155 "/home/fborges/checkout/gnome-boxes/src/wizard-source.vala"
	g_return_if_fail (row != NULL);
#line 156 "/home/fborges/checkout/gnome-boxes/src/wizard-source.vala"
	_tmp0_ = row;
#line 156 "/home/fborges/checkout/gnome-boxes/src/wizard-source.vala"
	_tmp1_ = _g_object_ref0 (G_TYPE_CHECK_INSTANCE_TYPE (_tmp0_, BOXES_TYPE_WIZARD_DOWNLOADABLE_MEDIA_ENTRY) ? ((BoxesWizardDownloadableMediaEntry*) _tmp0_) : NULL);
#line 156 "/home/fborges/checkout/gnome-boxes/src/wizard-source.vala"
	entry = _tmp1_;
#line 158 "/home/fborges/checkout/gnome-boxes/src/wizard-source.vala"
	_tmp2_ = entry->media;
#line 158 "/home/fborges/checkout/gnome-boxes/src/wizard-source.vala"
	g_signal_emit (self, boxes_wizard_downloadable_entry_signals[BOXES_WIZARD_DOWNLOADABLE_ENTRY_ACTIVATED_SIGNAL], 0, _tmp2_);
#line 155 "/home/fborges/checkout/gnome-boxes/src/wizard-source.vala"
	_g_object_unref0 (entry);
#line 2094 "wizard-source.c"
}


static void _boxes_wizard_downloadable_entry_on_media_listbox_activated_gtk_list_box_row_activated (GtkListBox* _sender, GtkListBoxRow* row, gpointer self) {
#line 115 "/home/fborges/checkout/gnome-boxes/src/wizard-source.vala"
	boxes_wizard_downloadable_entry_on_media_listbox_activated ((BoxesWizardDownloadableEntry*) self, row);
#line 2101 "wizard-source.c"
}


void boxes_wizard_downloadable_entry_toggle (BoxesWizardDownloadableEntry* self) {
	GtkRevealer* _tmp0_;
	GtkRevealer* _tmp1_;
	gboolean _tmp2_;
	gboolean _tmp3_;
#line 161 "/home/fborges/checkout/gnome-boxes/src/wizard-source.vala"
	g_return_if_fail (self != NULL);
#line 162 "/home/fborges/checkout/gnome-boxes/src/wizard-source.vala"
	_tmp0_ = self->priv->revealer;
#line 162 "/home/fborges/checkout/gnome-boxes/src/wizard-source.vala"
	_tmp1_ = self->priv->revealer;
#line 162 "/home/fborges/checkout/gnome-boxes/src/wizard-source.vala"
	_tmp2_ = gtk_revealer_get_child_revealed (_tmp1_);
#line 162 "/home/fborges/checkout/gnome-boxes/src/wizard-source.vala"
	_tmp3_ = _tmp2_;
#line 162 "/home/fborges/checkout/gnome-boxes/src/wizard-source.vala"
	gtk_revealer_set_reveal_child (_tmp0_, !_tmp3_);
#line 2122 "wizard-source.c"
}


static void boxes_wizard_downloadable_entry_class_init (BoxesWizardDownloadableEntryClass * klass) {
	gint BoxesWizardDownloadableEntry_private_offset;
#line 115 "/home/fborges/checkout/gnome-boxes/src/wizard-source.vala"
	boxes_wizard_downloadable_entry_parent_class = g_type_class_peek_parent (klass);
#line 115 "/home/fborges/checkout/gnome-boxes/src/wizard-source.vala"
	g_type_class_add_private (klass, sizeof (BoxesWizardDownloadableEntryPrivate));
#line 115 "/home/fborges/checkout/gnome-boxes/src/wizard-source.vala"
	G_OBJECT_CLASS (klass)->finalize = boxes_wizard_downloadable_entry_finalize;
#line 115 "/home/fborges/checkout/gnome-boxes/src/wizard-source.vala"
	BoxesWizardDownloadableEntry_private_offset = g_type_class_get_instance_private_offset (klass);
#line 115 "/home/fborges/checkout/gnome-boxes/src/wizard-source.vala"
	gtk_widget_class_set_template_from_resource (GTK_WIDGET_CLASS (klass), "/org/gnome/Boxes/ui/wizard-downloadable-entry.ui");
#line 115 "/home/fborges/checkout/gnome-boxes/src/wizard-source.vala"
	boxes_wizard_downloadable_entry_signals[BOXES_WIZARD_DOWNLOADABLE_ENTRY_ACTIVATED_SIGNAL] = g_signal_new ("activated", BOXES_TYPE_WIZARD_DOWNLOADABLE_ENTRY, G_SIGNAL_RUN_LAST, 0, NULL, NULL, g_cclosure_marshal_VOID__OBJECT, G_TYPE_NONE, 1, osinfo_media_get_type ());
#line 115 "/home/fborges/checkout/gnome-boxes/src/wizard-source.vala"
	gtk_widget_class_bind_template_child_full (GTK_WIDGET_CLASS (klass), "media_image", FALSE, BoxesWizardDownloadableEntry_private_offset + G_STRUCT_OFFSET (BoxesWizardDownloadableEntryPrivate, media_image));
#line 115 "/home/fborges/checkout/gnome-boxes/src/wizard-source.vala"
	gtk_widget_class_bind_template_child_full (GTK_WIDGET_CLASS (klass), "title_label", FALSE, BoxesWizardDownloadableEntry_private_offset + G_STRUCT_OFFSET (BoxesWizardDownloadableEntryPrivate, title_label));
#line 115 "/home/fborges/checkout/gnome-boxes/src/wizard-source.vala"
	gtk_widget_class_bind_template_child_full (GTK_WIDGET_CLASS (klass), "details_label", FALSE, BoxesWizardDownloadableEntry_private_offset + G_STRUCT_OFFSET (BoxesWizardDownloadableEntryPrivate, details_label));
#line 115 "/home/fborges/checkout/gnome-boxes/src/wizard-source.vala"
	gtk_widget_class_bind_template_child_full (GTK_WIDGET_CLASS (klass), "revealer", FALSE, BoxesWizardDownloadableEntry_private_offset + G_STRUCT_OFFSET (BoxesWizardDownloadableEntryPrivate, revealer));
#line 115 "/home/fborges/checkout/gnome-boxes/src/wizard-source.vala"
	gtk_widget_class_bind_template_child_full (GTK_WIDGET_CLASS (klass), "medias_listbox", FALSE, BoxesWizardDownloadableEntry_private_offset + G_STRUCT_OFFSET (BoxesWizardDownloadableEntryPrivate, medias_listbox));
#line 115 "/home/fborges/checkout/gnome-boxes/src/wizard-source.vala"
	gtk_widget_class_bind_template_callback_full (GTK_WIDGET_CLASS (klass), "on_media_listbox_activated", G_CALLBACK(_boxes_wizard_downloadable_entry_on_media_listbox_activated_gtk_list_box_row_activated));
#line 2152 "wizard-source.c"
}


static void boxes_wizard_downloadable_entry_instance_init (BoxesWizardDownloadableEntry * self) {
#line 115 "/home/fborges/checkout/gnome-boxes/src/wizard-source.vala"
	self->priv = BOXES_WIZARD_DOWNLOADABLE_ENTRY_GET_PRIVATE (self);
#line 115 "/home/fborges/checkout/gnome-boxes/src/wizard-source.vala"
	gtk_widget_init_template (GTK_WIDGET (self));
#line 2161 "wizard-source.c"
}


static void boxes_wizard_downloadable_entry_finalize (GObject * obj) {
	BoxesWizardDownloadableEntry * self;
#line 115 "/home/fborges/checkout/gnome-boxes/src/wizard-source.vala"
	self = G_TYPE_CHECK_INSTANCE_CAST (obj, BOXES_TYPE_WIZARD_DOWNLOADABLE_ENTRY, BoxesWizardDownloadableEntry);
#line 117 "/home/fborges/checkout/gnome-boxes/src/wizard-source.vala"
	_g_object_unref0 (self->priv->media_image);
#line 119 "/home/fborges/checkout/gnome-boxes/src/wizard-source.vala"
	_g_object_unref0 (self->priv->title_label);
#line 121 "/home/fborges/checkout/gnome-boxes/src/wizard-source.vala"
	_g_object_unref0 (self->priv->details_label);
#line 123 "/home/fborges/checkout/gnome-boxes/src/wizard-source.vala"
	_g_object_unref0 (self->priv->revealer);
#line 125 "/home/fborges/checkout/gnome-boxes/src/wizard-source.vala"
	_g_object_unref0 (self->priv->medias_listbox);
#line 127 "/home/fborges/checkout/gnome-boxes/src/wizard-source.vala"
	_g_object_unref0 (self->single_media);
#line 115 "/home/fborges/checkout/gnome-boxes/src/wizard-source.vala"
	G_OBJECT_CLASS (boxes_wizard_downloadable_entry_parent_class)->finalize (obj);
#line 2183 "wizard-source.c"
}


GType boxes_wizard_downloadable_entry_get_type (void) {
	static volatile gsize boxes_wizard_downloadable_entry_type_id__volatile = 0;
	if (g_once_init_enter (&boxes_wizard_downloadable_entry_type_id__volatile)) {
		static const GTypeInfo g_define_type_info = { sizeof (BoxesWizardDownloadableEntryClass), (GBaseInitFunc) NULL, (GBaseFinalizeFunc) NULL, (GClassInitFunc) boxes_wizard_downloadable_entry_class_init, (GClassFinalizeFunc) NULL, NULL, sizeof (BoxesWizardDownloadableEntry), 0, (GInstanceInitFunc) boxes_wizard_downloadable_entry_instance_init, NULL };
		GType boxes_wizard_downloadable_entry_type_id;
		boxes_wizard_downloadable_entry_type_id = g_type_register_static (gtk_list_box_row_get_type (), "BoxesWizardDownloadableEntry", &g_define_type_info, 0);
		g_once_init_leave (&boxes_wizard_downloadable_entry_type_id__volatile, boxes_wizard_downloadable_entry_type_id);
	}
	return boxes_wizard_downloadable_entry_type_id__volatile;
}


BoxesWizardMediaEntry* boxes_wizard_media_entry_construct (GType object_type, BoxesInstallerMedia* media) {
	BoxesWizardMediaEntry * self = NULL;
	BoxesInstallerMedia* _tmp0_;
	BoxesInstallerMedia* _tmp1_;
	BoxesInstallerMedia* _tmp2_;
	OsinfoOs* _tmp3_;
	GtkLabel* _tmp7_;
	BoxesInstallerMedia* _tmp8_;
	const gchar* _tmp9_;
	gboolean _tmp10_ = FALSE;
	BoxesInstallerMedia* _tmp11_;
	OsinfoMedia* _tmp12_;
	BoxesInstallerMedia* _tmp27_;
	OsinfoMedia* _tmp28_;
#line 177 "/home/fborges/checkout/gnome-boxes/src/wizard-source.vala"
	g_return_val_if_fail (media != NULL, NULL);
#line 177 "/home/fborges/checkout/gnome-boxes/src/wizard-source.vala"
	self = (BoxesWizardMediaEntry*) g_object_new (object_type, NULL);
#line 178 "/home/fborges/checkout/gnome-boxes/src/wizard-source.vala"
	_tmp0_ = media;
#line 178 "/home/fborges/checkout/gnome-boxes/src/wizard-source.vala"
	_tmp1_ = _g_object_ref0 (_tmp0_);
#line 178 "/home/fborges/checkout/gnome-boxes/src/wizard-source.vala"
	_g_object_unref0 (self->media);
#line 178 "/home/fborges/checkout/gnome-boxes/src/wizard-source.vala"
	self->media = _tmp1_;
#line 180 "/home/fborges/checkout/gnome-boxes/src/wizard-source.vala"
	_tmp2_ = media;
#line 180 "/home/fborges/checkout/gnome-boxes/src/wizard-source.vala"
	_tmp3_ = _tmp2_->os;
#line 180 "/home/fborges/checkout/gnome-boxes/src/wizard-source.vala"
	if (_tmp3_ != NULL) {
#line 2231 "wizard-source.c"
		GtkImage* _tmp4_;
		BoxesInstallerMedia* _tmp5_;
		OsinfoOs* _tmp6_;
#line 181 "/home/fborges/checkout/gnome-boxes/src/wizard-source.vala"
		_tmp4_ = self->priv->media_image;
#line 181 "/home/fborges/checkout/gnome-boxes/src/wizard-source.vala"
		_tmp5_ = media;
#line 181 "/home/fborges/checkout/gnome-boxes/src/wizard-source.vala"
		_tmp6_ = _tmp5_->os;
#line 181 "/home/fborges/checkout/gnome-boxes/src/wizard-source.vala"
		boxes_downloader_fetch_os_logo (_tmp4_, _tmp6_, 64, NULL, NULL);
#line 2243 "wizard-source.c"
	}
#line 183 "/home/fborges/checkout/gnome-boxes/src/wizard-source.vala"
	_tmp7_ = self->priv->title_label;
#line 183 "/home/fborges/checkout/gnome-boxes/src/wizard-source.vala"
	_tmp8_ = media;
#line 183 "/home/fborges/checkout/gnome-boxes/src/wizard-source.vala"
	_tmp9_ = _tmp8_->label;
#line 183 "/home/fborges/checkout/gnome-boxes/src/wizard-source.vala"
	gtk_label_set_label (_tmp7_, _tmp9_);
#line 184 "/home/fborges/checkout/gnome-boxes/src/wizard-source.vala"
	_tmp11_ = media;
#line 184 "/home/fborges/checkout/gnome-boxes/src/wizard-source.vala"
	_tmp12_ = _tmp11_->os_media;
#line 184 "/home/fborges/checkout/gnome-boxes/src/wizard-source.vala"
	if (_tmp12_ != NULL) {
#line 2259 "wizard-source.c"
		BoxesInstallerMedia* _tmp13_;
		OsinfoMedia* _tmp14_;
		gboolean _tmp15_;
		gboolean _tmp16_;
#line 184 "/home/fborges/checkout/gnome-boxes/src/wizard-source.vala"
		_tmp13_ = media;
#line 184 "/home/fborges/checkout/gnome-boxes/src/wizard-source.vala"
		_tmp14_ = _tmp13_->os_media;
#line 184 "/home/fborges/checkout/gnome-boxes/src/wizard-source.vala"
		g_object_get (_tmp14_, "live", &_tmp15_, NULL);
#line 184 "/home/fborges/checkout/gnome-boxes/src/wizard-source.vala"
		_tmp16_ = _tmp15_;
#line 184 "/home/fborges/checkout/gnome-boxes/src/wizard-source.vala"
		_tmp10_ = _tmp16_;
#line 2274 "wizard-source.c"
	} else {
#line 184 "/home/fborges/checkout/gnome-boxes/src/wizard-source.vala"
		_tmp10_ = FALSE;
#line 2278 "wizard-source.c"
	}
#line 184 "/home/fborges/checkout/gnome-boxes/src/wizard-source.vala"
	if (_tmp10_) {
#line 2282 "wizard-source.c"
		GtkLabel* _tmp17_;
		GtkLabel* _tmp18_;
		const gchar* _tmp19_;
		const gchar* _tmp20_;
		gchar* _tmp21_;
		gchar* _tmp22_;
		gchar* _tmp23_;
		gchar* _tmp24_;
		gchar* _tmp25_;
		gchar* _tmp26_;
#line 187 "/home/fborges/checkout/gnome-boxes/src/wizard-source.vala"
		_tmp17_ = self->priv->title_label;
#line 187 "/home/fborges/checkout/gnome-boxes/src/wizard-source.vala"
		_tmp18_ = self->priv->title_label;
#line 187 "/home/fborges/checkout/gnome-boxes/src/wizard-source.vala"
		_tmp19_ = gtk_label_get_label (_tmp18_);
#line 187 "/home/fborges/checkout/gnome-boxes/src/wizard-source.vala"
		_tmp20_ = _tmp19_;
#line 187 "/home/fborges/checkout/gnome-boxes/src/wizard-source.vala"
		_tmp21_ = g_strconcat (" (", _ ("Live"), NULL);
#line 187 "/home/fborges/checkout/gnome-boxes/src/wizard-source.vala"
		_tmp22_ = _tmp21_;
#line 187 "/home/fborges/checkout/gnome-boxes/src/wizard-source.vala"
		_tmp23_ = g_strconcat (_tmp22_, ")", NULL);
#line 187 "/home/fborges/checkout/gnome-boxes/src/wizard-source.vala"
		_tmp24_ = _tmp23_;
#line 187 "/home/fborges/checkout/gnome-boxes/src/wizard-source.vala"
		_tmp25_ = g_strconcat (_tmp20_, _tmp24_, NULL);
#line 187 "/home/fborges/checkout/gnome-boxes/src/wizard-source.vala"
		_tmp26_ = _tmp25_;
#line 187 "/home/fborges/checkout/gnome-boxes/src/wizard-source.vala"
		gtk_label_set_label (_tmp18_, _tmp26_);
#line 187 "/home/fborges/checkout/gnome-boxes/src/wizard-source.vala"
		_g_free0 (_tmp26_);
#line 187 "/home/fborges/checkout/gnome-boxes/src/wizard-source.vala"
		_g_free0 (_tmp24_);
#line 187 "/home/fborges/checkout/gnome-boxes/src/wizard-source.vala"
		_g_free0 (_tmp22_);
#line 2321 "wizard-source.c"
	}
#line 189 "/home/fborges/checkout/gnome-boxes/src/wizard-source.vala"
	_tmp27_ = media;
#line 189 "/home/fborges/checkout/gnome-boxes/src/wizard-source.vala"
	_tmp28_ = _tmp27_->os_media;
#line 189 "/home/fborges/checkout/gnome-boxes/src/wizard-source.vala"
	if (_tmp28_ != NULL) {
#line 2329 "wizard-source.c"
		const gchar* _tmp29_ = NULL;
		gboolean _tmp30_ = FALSE;
		BoxesInstallerMedia* _tmp31_;
		OsinfoMedia* _tmp32_;
		gchar* _tmp33_;
		gchar* _tmp34_;
		gchar* _tmp35_;
		gboolean _tmp36_;
		gchar* architecture = NULL;
		gchar* _tmp42_;
		GtkLabel* _tmp43_;
		const gchar* _tmp44_;
		BoxesInstallerMedia* _tmp45_;
		OsinfoOs* _tmp46_;
		const gchar* _tmp47_;
		const gchar* _tmp48_;
#line 190 "/home/fborges/checkout/gnome-boxes/src/wizard-source.vala"
		_tmp31_ = media;
#line 190 "/home/fborges/checkout/gnome-boxes/src/wizard-source.vala"
		_tmp32_ = _tmp31_->os_media;
#line 190 "/home/fborges/checkout/gnome-boxes/src/wizard-source.vala"
		g_object_get (_tmp32_, "architecture", &_tmp33_, NULL);
#line 190 "/home/fborges/checkout/gnome-boxes/src/wizard-source.vala"
		_tmp34_ = _tmp33_;
#line 190 "/home/fborges/checkout/gnome-boxes/src/wizard-source.vala"
		_tmp35_ = _tmp34_;
#line 190 "/home/fborges/checkout/gnome-boxes/src/wizard-source.vala"
		_tmp36_ = g_strcmp0 (_tmp35_, "i386") == 0;
#line 190 "/home/fborges/checkout/gnome-boxes/src/wizard-source.vala"
		_g_free0 (_tmp35_);
#line 190 "/home/fborges/checkout/gnome-boxes/src/wizard-source.vala"
		if (_tmp36_) {
#line 190 "/home/fborges/checkout/gnome-boxes/src/wizard-source.vala"
			_tmp30_ = TRUE;
#line 2364 "wizard-source.c"
		} else {
			BoxesInstallerMedia* _tmp37_;
			OsinfoMedia* _tmp38_;
			gchar* _tmp39_;
			gchar* _tmp40_;
			gchar* _tmp41_;
#line 190 "/home/fborges/checkout/gnome-boxes/src/wizard-source.vala"
			_tmp37_ = media;
#line 190 "/home/fborges/checkout/gnome-boxes/src/wizard-source.vala"
			_tmp38_ = _tmp37_->os_media;
#line 190 "/home/fborges/checkout/gnome-boxes/src/wizard-source.vala"
			g_object_get (_tmp38_, "architecture", &_tmp39_, NULL);
#line 190 "/home/fborges/checkout/gnome-boxes/src/wizard-source.vala"
			_tmp40_ = _tmp39_;
#line 190 "/home/fborges/checkout/gnome-boxes/src/wizard-source.vala"
			_tmp41_ = _tmp40_;
#line 190 "/home/fborges/checkout/gnome-boxes/src/wizard-source.vala"
			_tmp30_ = g_strcmp0 (_tmp41_, "i686") == 0;
#line 190 "/home/fborges/checkout/gnome-boxes/src/wizard-source.vala"
			_g_free0 (_tmp41_);
#line 2385 "wizard-source.c"
		}
#line 190 "/home/fborges/checkout/gnome-boxes/src/wizard-source.vala"
		if (_tmp30_) {
#line 191 "/home/fborges/checkout/gnome-boxes/src/wizard-source.vala"
			_tmp29_ = _ ("32-bit x86 system");
#line 2391 "wizard-source.c"
		} else {
#line 192 "/home/fborges/checkout/gnome-boxes/src/wizard-source.vala"
			_tmp29_ = _ ("64-bit x86 system");
#line 2395 "wizard-source.c"
		}
#line 190 "/home/fborges/checkout/gnome-boxes/src/wizard-source.vala"
		_tmp42_ = g_strdup (_tmp29_);
#line 190 "/home/fborges/checkout/gnome-boxes/src/wizard-source.vala"
		architecture = _tmp42_;
#line 193 "/home/fborges/checkout/gnome-boxes/src/wizard-source.vala"
		_tmp43_ = self->priv->details_label;
#line 193 "/home/fborges/checkout/gnome-boxes/src/wizard-source.vala"
		_tmp44_ = architecture;
#line 193 "/home/fborges/checkout/gnome-boxes/src/wizard-source.vala"
		gtk_label_set_label (_tmp43_, _tmp44_);
#line 195 "/home/fborges/checkout/gnome-boxes/src/wizard-source.vala"
		_tmp45_ = media;
#line 195 "/home/fborges/checkout/gnome-boxes/src/wizard-source.vala"
		_tmp46_ = _tmp45_->os;
#line 195 "/home/fborges/checkout/gnome-boxes/src/wizard-source.vala"
		_tmp47_ = osinfo_product_get_vendor ((OsinfoProduct*) _tmp46_);
#line 195 "/home/fborges/checkout/gnome-boxes/src/wizard-source.vala"
		_tmp48_ = _tmp47_;
#line 195 "/home/fborges/checkout/gnome-boxes/src/wizard-source.vala"
		if (_tmp48_ != NULL) {
#line 2417 "wizard-source.c"
			GtkLabel* _tmp49_;
			GtkLabel* _tmp50_;
			const gchar* _tmp51_;
			const gchar* _tmp52_;
			BoxesInstallerMedia* _tmp53_;
			OsinfoOs* _tmp54_;
			const gchar* _tmp55_;
			const gchar* _tmp56_;
			gchar* _tmp57_;
			gchar* _tmp58_;
			gchar* _tmp59_;
			gchar* _tmp60_;
#line 197 "/home/fborges/checkout/gnome-boxes/src/wizard-source.vala"
			_tmp49_ = self->priv->details_label;
#line 197 "/home/fborges/checkout/gnome-boxes/src/wizard-source.vala"
			_tmp50_ = self->priv->details_label;
#line 197 "/home/fborges/checkout/gnome-boxes/src/wizard-source.vala"
			_tmp51_ = gtk_label_get_label (_tmp50_);
#line 197 "/home/fborges/checkout/gnome-boxes/src/wizard-source.vala"
			_tmp52_ = _tmp51_;
#line 197 "/home/fborges/checkout/gnome-boxes/src/wizard-source.vala"
			_tmp53_ = media;
#line 197 "/home/fborges/checkout/gnome-boxes/src/wizard-source.vala"
			_tmp54_ = _tmp53_->os;
#line 197 "/home/fborges/checkout/gnome-boxes/src/wizard-source.vala"
			_tmp55_ = osinfo_product_get_vendor ((OsinfoProduct*) _tmp54_);
#line 197 "/home/fborges/checkout/gnome-boxes/src/wizard-source.vala"
			_tmp56_ = _tmp55_;
#line 197 "/home/fborges/checkout/gnome-boxes/src/wizard-source.vala"
			_tmp57_ = g_strdup_printf (_ (" from %s"), _tmp56_);
#line 197 "/home/fborges/checkout/gnome-boxes/src/wizard-source.vala"
			_tmp58_ = _tmp57_;
#line 197 "/home/fborges/checkout/gnome-boxes/src/wizard-source.vala"
			_tmp59_ = g_strconcat (_tmp52_, _tmp58_, NULL);
#line 197 "/home/fborges/checkout/gnome-boxes/src/wizard-source.vala"
			_tmp60_ = _tmp59_;
#line 197 "/home/fborges/checkout/gnome-boxes/src/wizard-source.vala"
			gtk_label_set_label (_tmp50_, _tmp60_);
#line 197 "/home/fborges/checkout/gnome-boxes/src/wizard-source.vala"
			_g_free0 (_tmp60_);
#line 197 "/home/fborges/checkout/gnome-boxes/src/wizard-source.vala"
			_g_free0 (_tmp58_);
#line 2460 "wizard-source.c"
		}
#line 189 "/home/fborges/checkout/gnome-boxes/src/wizard-source.vala"
		_g_free0 (architecture);
#line 2464 "wizard-source.c"
	}
#line 177 "/home/fborges/checkout/gnome-boxes/src/wizard-source.vala"
	return self;
#line 2468 "wizard-source.c"
}


BoxesWizardMediaEntry* boxes_wizard_media_entry_new (BoxesInstallerMedia* media) {
#line 177 "/home/fborges/checkout/gnome-boxes/src/wizard-source.vala"
	return boxes_wizard_media_entry_construct (BOXES_TYPE_WIZARD_MEDIA_ENTRY, media);
#line 2475 "wizard-source.c"
}


static void boxes_wizard_media_entry_class_init (BoxesWizardMediaEntryClass * klass) {
	gint BoxesWizardMediaEntry_private_offset;
#line 167 "/home/fborges/checkout/gnome-boxes/src/wizard-source.vala"
	boxes_wizard_media_entry_parent_class = g_type_class_peek_parent (klass);
#line 167 "/home/fborges/checkout/gnome-boxes/src/wizard-source.vala"
	g_type_class_add_private (klass, sizeof (BoxesWizardMediaEntryPrivate));
#line 167 "/home/fborges/checkout/gnome-boxes/src/wizard-source.vala"
	G_OBJECT_CLASS (klass)->finalize = boxes_wizard_media_entry_finalize;
#line 167 "/home/fborges/checkout/gnome-boxes/src/wizard-source.vala"
	BoxesWizardMediaEntry_private_offset = g_type_class_get_instance_private_offset (klass);
#line 167 "/home/fborges/checkout/gnome-boxes/src/wizard-source.vala"
	gtk_widget_class_set_template_from_resource (GTK_WIDGET_CLASS (klass), "/org/gnome/Boxes/ui/wizard-media-entry.ui");
#line 167 "/home/fborges/checkout/gnome-boxes/src/wizard-source.vala"
	gtk_widget_class_bind_template_child_full (GTK_WIDGET_CLASS (klass), "media_image", FALSE, BoxesWizardMediaEntry_private_offset + G_STRUCT_OFFSET (BoxesWizardMediaEntryPrivate, media_image));
#line 167 "/home/fborges/checkout/gnome-boxes/src/wizard-source.vala"
	gtk_widget_class_bind_template_child_full (GTK_WIDGET_CLASS (klass), "title_label", FALSE, BoxesWizardMediaEntry_private_offset + G_STRUCT_OFFSET (BoxesWizardMediaEntryPrivate, title_label));
#line 167 "/home/fborges/checkout/gnome-boxes/src/wizard-source.vala"
	gtk_widget_class_bind_template_child_full (GTK_WIDGET_CLASS (klass), "details_label", FALSE, BoxesWizardMediaEntry_private_offset + G_STRUCT_OFFSET (BoxesWizardMediaEntryPrivate, details_label));
#line 2497 "wizard-source.c"
}


static void boxes_wizard_media_entry_instance_init (BoxesWizardMediaEntry * self) {
#line 167 "/home/fborges/checkout/gnome-boxes/src/wizard-source.vala"
	self->priv = BOXES_WIZARD_MEDIA_ENTRY_GET_PRIVATE (self);
#line 167 "/home/fborges/checkout/gnome-boxes/src/wizard-source.vala"
	gtk_widget_init_template (GTK_WIDGET (self));
#line 2506 "wizard-source.c"
}


static void boxes_wizard_media_entry_finalize (GObject * obj) {
	BoxesWizardMediaEntry * self;
#line 167 "/home/fborges/checkout/gnome-boxes/src/wizard-source.vala"
	self = G_TYPE_CHECK_INSTANCE_CAST (obj, BOXES_TYPE_WIZARD_MEDIA_ENTRY, BoxesWizardMediaEntry);
#line 168 "/home/fborges/checkout/gnome-boxes/src/wizard-source.vala"
	_g_object_unref0 (self->media);
#line 171 "/home/fborges/checkout/gnome-boxes/src/wizard-source.vala"
	_g_object_unref0 (self->priv->media_image);
#line 173 "/home/fborges/checkout/gnome-boxes/src/wizard-source.vala"
	_g_object_unref0 (self->priv->title_label);
#line 175 "/home/fborges/checkout/gnome-boxes/src/wizard-source.vala"
	_g_object_unref0 (self->priv->details_label);
#line 167 "/home/fborges/checkout/gnome-boxes/src/wizard-source.vala"
	G_OBJECT_CLASS (boxes_wizard_media_entry_parent_class)->finalize (obj);
#line 2524 "wizard-source.c"
}


GType boxes_wizard_media_entry_get_type (void) {
	static volatile gsize boxes_wizard_media_entry_type_id__volatile = 0;
	if (g_once_init_enter (&boxes_wizard_media_entry_type_id__volatile)) {
		static const GTypeInfo g_define_type_info = { sizeof (BoxesWizardMediaEntryClass), (GBaseInitFunc) NULL, (GBaseFinalizeFunc) NULL, (GClassInitFunc) boxes_wizard_media_entry_class_init, (GClassFinalizeFunc) NULL, NULL, sizeof (BoxesWizardMediaEntry), 0, (GInstanceInitFunc) boxes_wizard_media_entry_instance_init, NULL };
		GType boxes_wizard_media_entry_type_id;
		boxes_wizard_media_entry_type_id = g_type_register_static (gtk_list_box_row_get_type (), "BoxesWizardMediaEntry", &g_define_type_info, 0);
		g_once_init_leave (&boxes_wizard_media_entry_type_id__volatile, boxes_wizard_media_entry_type_id);
	}
	return boxes_wizard_media_entry_type_id__volatile;
}


static void boxes_wizard_web_view_real_dispose (GObject* base) {
	BoxesWizardWebView * self;
	guint _tmp0_;
#line 222 "/home/fborges/checkout/gnome-boxes/src/wizard-source.vala"
	self = (BoxesWizardWebView*) base;
#line 223 "/home/fborges/checkout/gnome-boxes/src/wizard-source.vala"
	_tmp0_ = self->priv->hide_progress_bar_id;
#line 223 "/home/fborges/checkout/gnome-boxes/src/wizard-source.vala"
	if (_tmp0_ != ((guint) 0)) {
#line 2549 "wizard-source.c"
		guint _tmp1_;
#line 224 "/home/fborges/checkout/gnome-boxes/src/wizard-source.vala"
		_tmp1_ = self->priv->hide_progress_bar_id;
#line 224 "/home/fborges/checkout/gnome-boxes/src/wizard-source.vala"
		g_source_remove (_tmp1_);
#line 225 "/home/fborges/checkout/gnome-boxes/src/wizard-source.vala"
		self->priv->hide_progress_bar_id = (guint) 0;
#line 2557 "wizard-source.c"
	}
#line 228 "/home/fborges/checkout/gnome-boxes/src/wizard-source.vala"
	G_OBJECT_CLASS (boxes_wizard_web_view_parent_class)->dispose ((GObject*) G_TYPE_CHECK_INSTANCE_CAST (self, gtk_bin_get_type (), GtkBin));
#line 2561 "wizard-source.c"
}


static void _g_object_unref0_ (gpointer var) {
#line 277 "/home/fborges/checkout/gnome-boxes/src/wizard-source.vala"
	(var == NULL) ? NULL : (var = (g_object_unref (var), NULL));
#line 2568 "wizard-source.c"
}


static inline void _g_list_free__g_object_unref0_ (GList* self) {
#line 277 "/home/fborges/checkout/gnome-boxes/src/wizard-source.vala"
	g_list_free_full (self, (GDestroyNotify) _g_object_unref0_);
#line 2575 "wizard-source.c"
}


static gboolean boxes_wizard_web_view_on_context_menu (BoxesWizardWebView* self, WebKitWebView* web_view, WebKitContextMenu* context_menu, GdkEvent* event, WebKitHitTestResult* hit_test_result) {
	gboolean result = FALSE;
	GList* items_to_remove = NULL;
	WebKitContextMenu* _tmp0_;
	GList* _tmp1_;
	GList* _tmp32_;
	GList* separators_to_remove = NULL;
	WebKitContextMenuAction previous_action = 0;
	WebKitContextMenu* _tmp36_;
	GList* _tmp37_;
	GList* _tmp48_;
	guint n_items = 0U;
	WebKitContextMenu* _tmp52_;
	guint _tmp53_;
#line 232 "/home/fborges/checkout/gnome-boxes/src/wizard-source.vala"
	g_return_val_if_fail (self != NULL, FALSE);
#line 232 "/home/fborges/checkout/gnome-boxes/src/wizard-source.vala"
	g_return_val_if_fail (web_view != NULL, FALSE);
#line 232 "/home/fborges/checkout/gnome-boxes/src/wizard-source.vala"
	g_return_val_if_fail (context_menu != NULL, FALSE);
#line 232 "/home/fborges/checkout/gnome-boxes/src/wizard-source.vala"
	g_return_val_if_fail (event != NULL, FALSE);
#line 232 "/home/fborges/checkout/gnome-boxes/src/wizard-source.vala"
	g_return_val_if_fail (hit_test_result != NULL, FALSE);
#line 236 "/home/fborges/checkout/gnome-boxes/src/wizard-source.vala"
	items_to_remove = NULL;
#line 238 "/home/fborges/checkout/gnome-boxes/src/wizard-source.vala"
	_tmp0_ = context_menu;
#line 238 "/home/fborges/checkout/gnome-boxes/src/wizard-source.vala"
	_tmp1_ = webkit_context_menu_get_items (_tmp0_);
#line 2609 "wizard-source.c"
	{
		GList* item_collection = NULL;
		GList* item_it = NULL;
#line 238 "/home/fborges/checkout/gnome-boxes/src/wizard-source.vala"
		item_collection = _tmp1_;
#line 238 "/home/fborges/checkout/gnome-boxes/src/wizard-source.vala"
		for (item_it = item_collection; item_it != NULL; item_it = item_it->next) {
#line 2617 "wizard-source.c"
			WebKitContextMenuItem* _tmp2_;
			WebKitContextMenuItem* item = NULL;
#line 238 "/home/fborges/checkout/gnome-boxes/src/wizard-source.vala"
			_tmp2_ = _g_object_ref0 ((WebKitContextMenuItem*) item_it->data);
#line 238 "/home/fborges/checkout/gnome-boxes/src/wizard-source.vala"
			item = _tmp2_;
#line 2624 "wizard-source.c"
			{
				WebKitContextMenuAction action = 0;
				WebKitContextMenuItem* _tmp3_;
				WebKitContextMenuAction _tmp4_;
				gboolean _tmp5_ = FALSE;
				gboolean _tmp6_ = FALSE;
				gboolean _tmp7_ = FALSE;
				gboolean _tmp8_ = FALSE;
				gboolean _tmp9_ = FALSE;
				gboolean _tmp10_ = FALSE;
				gboolean _tmp11_ = FALSE;
				gboolean _tmp12_ = FALSE;
				gboolean _tmp13_ = FALSE;
				gboolean _tmp14_ = FALSE;
				gboolean _tmp15_ = FALSE;
				gboolean _tmp16_ = FALSE;
				WebKitContextMenuAction _tmp17_;
#line 239 "/home/fborges/checkout/gnome-boxes/src/wizard-source.vala"
				_tmp3_ = item;
#line 239 "/home/fborges/checkout/gnome-boxes/src/wizard-source.vala"
				_tmp4_ = webkit_context_menu_item_get_stock_action (_tmp3_);
#line 239 "/home/fborges/checkout/gnome-boxes/src/wizard-source.vala"
				action = _tmp4_;
#line 240 "/home/fborges/checkout/gnome-boxes/src/wizard-source.vala"
				_tmp17_ = action;
#line 240 "/home/fborges/checkout/gnome-boxes/src/wizard-source.vala"
				if (_tmp17_ == WEBKIT_CONTEXT_MENU_ACTION_GO_BACK) {
#line 240 "/home/fborges/checkout/gnome-boxes/src/wizard-source.vala"
					_tmp16_ = TRUE;
#line 2654 "wizard-source.c"
				} else {
					WebKitContextMenuAction _tmp18_;
#line 241 "/home/fborges/checkout/gnome-boxes/src/wizard-source.vala"
					_tmp18_ = action;
#line 241 "/home/fborges/checkout/gnome-boxes/src/wizard-source.vala"
					_tmp16_ = _tmp18_ == WEBKIT_CONTEXT_MENU_ACTION_GO_FORWARD;
#line 2661 "wizard-source.c"
				}
#line 240 "/home/fborges/checkout/gnome-boxes/src/wizard-source.vala"
				if (_tmp16_) {
#line 240 "/home/fborges/checkout/gnome-boxes/src/wizard-source.vala"
					_tmp15_ = TRUE;
#line 2667 "wizard-source.c"
				} else {
					WebKitContextMenuAction _tmp19_;
#line 242 "/home/fborges/checkout/gnome-boxes/src/wizard-source.vala"
					_tmp19_ = action;
#line 242 "/home/fborges/checkout/gnome-boxes/src/wizard-source.vala"
					_tmp15_ = _tmp19_ == WEBKIT_CONTEXT_MENU_ACTION_DOWNLOAD_AUDIO_TO_DISK;
#line 2674 "wizard-source.c"
				}
#line 240 "/home/fborges/checkout/gnome-boxes/src/wizard-source.vala"
				if (_tmp15_) {
#line 240 "/home/fborges/checkout/gnome-boxes/src/wizard-source.vala"
					_tmp14_ = TRUE;
#line 2680 "wizard-source.c"
				} else {
					WebKitContextMenuAction _tmp20_;
#line 243 "/home/fborges/checkout/gnome-boxes/src/wizard-source.vala"
					_tmp20_ = action;
#line 243 "/home/fborges/checkout/gnome-boxes/src/wizard-source.vala"
					_tmp14_ = _tmp20_ == WEBKIT_CONTEXT_MENU_ACTION_DOWNLOAD_IMAGE_TO_DISK;
#line 2687 "wizard-source.c"
				}
#line 240 "/home/fborges/checkout/gnome-boxes/src/wizard-source.vala"
				if (_tmp14_) {
#line 240 "/home/fborges/checkout/gnome-boxes/src/wizard-source.vala"
					_tmp13_ = TRUE;
#line 2693 "wizard-source.c"
				} else {
					WebKitContextMenuAction _tmp21_;
#line 244 "/home/fborges/checkout/gnome-boxes/src/wizard-source.vala"
					_tmp21_ = action;
#line 244 "/home/fborges/checkout/gnome-boxes/src/wizard-source.vala"
					_tmp13_ = _tmp21_ == WEBKIT_CONTEXT_MENU_ACTION_DOWNLOAD_LINK_TO_DISK;
#line 2700 "wizard-source.c"
				}
#line 240 "/home/fborges/checkout/gnome-boxes/src/wizard-source.vala"
				if (_tmp13_) {
#line 240 "/home/fborges/checkout/gnome-boxes/src/wizard-source.vala"
					_tmp12_ = TRUE;
#line 2706 "wizard-source.c"
				} else {
					WebKitContextMenuAction _tmp22_;
#line 245 "/home/fborges/checkout/gnome-boxes/src/wizard-source.vala"
					_tmp22_ = action;
#line 245 "/home/fborges/checkout/gnome-boxes/src/wizard-source.vala"
					_tmp12_ = _tmp22_ == WEBKIT_CONTEXT_MENU_ACTION_DOWNLOAD_VIDEO_TO_DISK;
#line 2713 "wizard-source.c"
				}
#line 240 "/home/fborges/checkout/gnome-boxes/src/wizard-source.vala"
				if (_tmp12_) {
#line 240 "/home/fborges/checkout/gnome-boxes/src/wizard-source.vala"
					_tmp11_ = TRUE;
#line 2719 "wizard-source.c"
				} else {
					WebKitContextMenuAction _tmp23_;
#line 246 "/home/fborges/checkout/gnome-boxes/src/wizard-source.vala"
					_tmp23_ = action;
#line 246 "/home/fborges/checkout/gnome-boxes/src/wizard-source.vala"
					_tmp11_ = _tmp23_ == WEBKIT_CONTEXT_MENU_ACTION_OPEN_AUDIO_IN_NEW_WINDOW;
#line 2726 "wizard-source.c"
				}
#line 240 "/home/fborges/checkout/gnome-boxes/src/wizard-source.vala"
				if (_tmp11_) {
#line 240 "/home/fborges/checkout/gnome-boxes/src/wizard-source.vala"
					_tmp10_ = TRUE;
#line 2732 "wizard-source.c"
				} else {
					WebKitContextMenuAction _tmp24_;
#line 247 "/home/fborges/checkout/gnome-boxes/src/wizard-source.vala"
					_tmp24_ = action;
#line 247 "/home/fborges/checkout/gnome-boxes/src/wizard-source.vala"
					_tmp10_ = _tmp24_ == WEBKIT_CONTEXT_MENU_ACTION_OPEN_FRAME_IN_NEW_WINDOW;
#line 2739 "wizard-source.c"
				}
#line 240 "/home/fborges/checkout/gnome-boxes/src/wizard-source.vala"
				if (_tmp10_) {
#line 240 "/home/fborges/checkout/gnome-boxes/src/wizard-source.vala"
					_tmp9_ = TRUE;
#line 2745 "wizard-source.c"
				} else {
					WebKitContextMenuAction _tmp25_;
#line 248 "/home/fborges/checkout/gnome-boxes/src/wizard-source.vala"
					_tmp25_ = action;
#line 248 "/home/fborges/checkout/gnome-boxes/src/wizard-source.vala"
					_tmp9_ = _tmp25_ == WEBKIT_CONTEXT_MENU_ACTION_OPEN_IMAGE_IN_NEW_WINDOW;
#line 2752 "wizard-source.c"
				}
#line 240 "/home/fborges/checkout/gnome-boxes/src/wizard-source.vala"
				if (_tmp9_) {
#line 240 "/home/fborges/checkout/gnome-boxes/src/wizard-source.vala"
					_tmp8_ = TRUE;
#line 2758 "wizard-source.c"
				} else {
					WebKitContextMenuAction _tmp26_;
#line 249 "/home/fborges/checkout/gnome-boxes/src/wizard-source.vala"
					_tmp26_ = action;
#line 249 "/home/fborges/checkout/gnome-boxes/src/wizard-source.vala"
					_tmp8_ = _tmp26_ == WEBKIT_CONTEXT_MENU_ACTION_OPEN_LINK_IN_NEW_WINDOW;
#line 2765 "wizard-source.c"
				}
#line 240 "/home/fborges/checkout/gnome-boxes/src/wizard-source.vala"
				if (_tmp8_) {
#line 240 "/home/fborges/checkout/gnome-boxes/src/wizard-source.vala"
					_tmp7_ = TRUE;
#line 2771 "wizard-source.c"
				} else {
					WebKitContextMenuAction _tmp27_;
#line 250 "/home/fborges/checkout/gnome-boxes/src/wizard-source.vala"
					_tmp27_ = action;
#line 250 "/home/fborges/checkout/gnome-boxes/src/wizard-source.vala"
					_tmp7_ = _tmp27_ == WEBKIT_CONTEXT_MENU_ACTION_OPEN_VIDEO_IN_NEW_WINDOW;
#line 2778 "wizard-source.c"
				}
#line 240 "/home/fborges/checkout/gnome-boxes/src/wizard-source.vala"
				if (_tmp7_) {
#line 240 "/home/fborges/checkout/gnome-boxes/src/wizard-source.vala"
					_tmp6_ = TRUE;
#line 2784 "wizard-source.c"
				} else {
					WebKitContextMenuAction _tmp28_;
#line 251 "/home/fborges/checkout/gnome-boxes/src/wizard-source.vala"
					_tmp28_ = action;
#line 251 "/home/fborges/checkout/gnome-boxes/src/wizard-source.vala"
					_tmp6_ = _tmp28_ == WEBKIT_CONTEXT_MENU_ACTION_RELOAD;
#line 2791 "wizard-source.c"
				}
#line 240 "/home/fborges/checkout/gnome-boxes/src/wizard-source.vala"
				if (_tmp6_) {
#line 240 "/home/fborges/checkout/gnome-boxes/src/wizard-source.vala"
					_tmp5_ = TRUE;
#line 2797 "wizard-source.c"
				} else {
					WebKitContextMenuAction _tmp29_;
#line 252 "/home/fborges/checkout/gnome-boxes/src/wizard-source.vala"
					_tmp29_ = action;
#line 252 "/home/fborges/checkout/gnome-boxes/src/wizard-source.vala"
					_tmp5_ = _tmp29_ == WEBKIT_CONTEXT_MENU_ACTION_STOP;
#line 2804 "wizard-source.c"
				}
#line 240 "/home/fborges/checkout/gnome-boxes/src/wizard-source.vala"
				if (_tmp5_) {
#line 2808 "wizard-source.c"
					WebKitContextMenuItem* _tmp30_;
					WebKitContextMenuItem* _tmp31_;
#line 253 "/home/fborges/checkout/gnome-boxes/src/wizard-source.vala"
					_tmp30_ = item;
#line 253 "/home/fborges/checkout/gnome-boxes/src/wizard-source.vala"
					_tmp31_ = _g_object_ref0 (_tmp30_);
#line 253 "/home/fborges/checkout/gnome-boxes/src/wizard-source.vala"
					items_to_remove = g_list_prepend (items_to_remove, _tmp31_);
#line 2817 "wizard-source.c"
				}
#line 238 "/home/fborges/checkout/gnome-boxes/src/wizard-source.vala"
				_g_object_unref0 (item);
#line 2821 "wizard-source.c"
			}
		}
	}
#line 257 "/home/fborges/checkout/gnome-boxes/src/wizard-source.vala"
	_tmp32_ = items_to_remove;
#line 2827 "wizard-source.c"
	{
		GList* item_collection = NULL;
		GList* item_it = NULL;
#line 257 "/home/fborges/checkout/gnome-boxes/src/wizard-source.vala"
		item_collection = _tmp32_;
#line 257 "/home/fborges/checkout/gnome-boxes/src/wizard-source.vala"
		for (item_it = item_collection; item_it != NULL; item_it = item_it->next) {
#line 2835 "wizard-source.c"
			WebKitContextMenuItem* _tmp33_;
			WebKitContextMenuItem* item = NULL;
#line 257 "/home/fborges/checkout/gnome-boxes/src/wizard-source.vala"
			_tmp33_ = _g_object_ref0 ((WebKitContextMenuItem*) item_it->data);
#line 257 "/home/fborges/checkout/gnome-boxes/src/wizard-source.vala"
			item = _tmp33_;
#line 2842 "wizard-source.c"
			{
				WebKitContextMenu* _tmp34_;
				WebKitContextMenuItem* _tmp35_;
#line 258 "/home/fborges/checkout/gnome-boxes/src/wizard-source.vala"
				_tmp34_ = context_menu;
#line 258 "/home/fborges/checkout/gnome-boxes/src/wizard-source.vala"
				_tmp35_ = item;
#line 258 "/home/fborges/checkout/gnome-boxes/src/wizard-source.vala"
				webkit_context_menu_remove (_tmp34_, _tmp35_);
#line 257 "/home/fborges/checkout/gnome-boxes/src/wizard-source.vala"
				_g_object_unref0 (item);
#line 2854 "wizard-source.c"
			}
		}
	}
#line 261 "/home/fborges/checkout/gnome-boxes/src/wizard-source.vala"
	separators_to_remove = NULL;
#line 262 "/home/fborges/checkout/gnome-boxes/src/wizard-source.vala"
	previous_action = WEBKIT_CONTEXT_MENU_ACTION_NO_ACTION;
#line 264 "/home/fborges/checkout/gnome-boxes/src/wizard-source.vala"
	_tmp36_ = context_menu;
#line 264 "/home/fborges/checkout/gnome-boxes/src/wizard-source.vala"
	_tmp37_ = webkit_context_menu_get_items (_tmp36_);
#line 2866 "wizard-source.c"
	{
		GList* item_collection = NULL;
		GList* item_it = NULL;
#line 264 "/home/fborges/checkout/gnome-boxes/src/wizard-source.vala"
		item_collection = _tmp37_;
#line 264 "/home/fborges/checkout/gnome-boxes/src/wizard-source.vala"
		for (item_it = item_collection; item_it != NULL; item_it = item_it->next) {
#line 2874 "wizard-source.c"
			WebKitContextMenuItem* _tmp38_;
			WebKitContextMenuItem* item = NULL;
#line 264 "/home/fborges/checkout/gnome-boxes/src/wizard-source.vala"
			_tmp38_ = _g_object_ref0 ((WebKitContextMenuItem*) item_it->data);
#line 264 "/home/fborges/checkout/gnome-boxes/src/wizard-source.vala"
			item = _tmp38_;
#line 2881 "wizard-source.c"
			{
				WebKitContextMenuAction action = 0;
				WebKitContextMenuItem* _tmp39_;
				WebKitContextMenuAction _tmp40_;
				gboolean _tmp41_ = FALSE;
				WebKitContextMenuAction _tmp42_;
				WebKitContextMenuAction _tmp47_;
#line 265 "/home/fborges/checkout/gnome-boxes/src/wizard-source.vala"
				_tmp39_ = item;
#line 265 "/home/fborges/checkout/gnome-boxes/src/wizard-source.vala"
				_tmp40_ = webkit_context_menu_item_get_stock_action (_tmp39_);
#line 265 "/home/fborges/checkout/gnome-boxes/src/wizard-source.vala"
				action = _tmp40_;
#line 266 "/home/fborges/checkout/gnome-boxes/src/wizard-source.vala"
				_tmp42_ = action;
#line 266 "/home/fborges/checkout/gnome-boxes/src/wizard-source.vala"
				if (_tmp42_ == WEBKIT_CONTEXT_MENU_ACTION_NO_ACTION) {
#line 2899 "wizard-source.c"
					WebKitContextMenuAction _tmp43_;
					WebKitContextMenuAction _tmp44_;
#line 266 "/home/fborges/checkout/gnome-boxes/src/wizard-source.vala"
					_tmp43_ = action;
#line 266 "/home/fborges/checkout/gnome-boxes/src/wizard-source.vala"
					_tmp44_ = previous_action;
#line 266 "/home/fborges/checkout/gnome-boxes/src/wizard-source.vala"
					_tmp41_ = _tmp43_ == _tmp44_;
#line 2908 "wizard-source.c"
				} else {
#line 266 "/home/fborges/checkout/gnome-boxes/src/wizard-source.vala"
					_tmp41_ = FALSE;
#line 2912 "wizard-source.c"
				}
#line 266 "/home/fborges/checkout/gnome-boxes/src/wizard-source.vala"
				if (_tmp41_) {
#line 2916 "wizard-source.c"
					WebKitContextMenuItem* _tmp45_;
					WebKitContextMenuItem* _tmp46_;
#line 267 "/home/fborges/checkout/gnome-boxes/src/wizard-source.vala"
					_tmp45_ = item;
#line 267 "/home/fborges/checkout/gnome-boxes/src/wizard-source.vala"
					_tmp46_ = _g_object_ref0 (_tmp45_);
#line 267 "/home/fborges/checkout/gnome-boxes/src/wizard-source.vala"
					separators_to_remove = g_list_prepend (separators_to_remove, _tmp46_);
#line 2925 "wizard-source.c"
				}
#line 269 "/home/fborges/checkout/gnome-boxes/src/wizard-source.vala"
				_tmp47_ = action;
#line 269 "/home/fborges/checkout/gnome-boxes/src/wizard-source.vala"
				previous_action = _tmp47_;
#line 264 "/home/fborges/checkout/gnome-boxes/src/wizard-source.vala"
				_g_object_unref0 (item);
#line 2933 "wizard-source.c"
			}
		}
	}
#line 272 "/home/fborges/checkout/gnome-boxes/src/wizard-source.vala"
	_tmp48_ = separators_to_remove;
#line 2939 "wizard-source.c"
	{
		GList* item_collection = NULL;
		GList* item_it = NULL;
#line 272 "/home/fborges/checkout/gnome-boxes/src/wizard-source.vala"
		item_collection = _tmp48_;
#line 272 "/home/fborges/checkout/gnome-boxes/src/wizard-source.vala"
		for (item_it = item_collection; item_it != NULL; item_it = item_it->next) {
#line 2947 "wizard-source.c"
			WebKitContextMenuItem* _tmp49_;
			WebKitContextMenuItem* item = NULL;
#line 272 "/home/fborges/checkout/gnome-boxes/src/wizard-source.vala"
			_tmp49_ = _g_object_ref0 ((WebKitContextMenuItem*) item_it->data);
#line 272 "/home/fborges/checkout/gnome-boxes/src/wizard-source.vala"
			item = _tmp49_;
#line 2954 "wizard-source.c"
			{
				WebKitContextMenu* _tmp50_;
				WebKitContextMenuItem* _tmp51_;
#line 273 "/home/fborges/checkout/gnome-boxes/src/wizard-source.vala"
				_tmp50_ = context_menu;
#line 273 "/home/fborges/checkout/gnome-boxes/src/wizard-source.vala"
				_tmp51_ = item;
#line 273 "/home/fborges/checkout/gnome-boxes/src/wizard-source.vala"
				webkit_context_menu_remove (_tmp50_, _tmp51_);
#line 272 "/home/fborges/checkout/gnome-boxes/src/wizard-source.vala"
				_g_object_unref0 (item);
#line 2966 "wizard-source.c"
			}
		}
	}
#line 276 "/home/fborges/checkout/gnome-boxes/src/wizard-source.vala"
	_tmp52_ = context_menu;
#line 276 "/home/fborges/checkout/gnome-boxes/src/wizard-source.vala"
	_tmp53_ = webkit_context_menu_get_n_items (_tmp52_);
#line 276 "/home/fborges/checkout/gnome-boxes/src/wizard-source.vala"
	n_items = _tmp53_;
#line 277 "/home/fborges/checkout/gnome-boxes/src/wizard-source.vala"
	result = n_items == ((guint) 0);
#line 277 "/home/fborges/checkout/gnome-boxes/src/wizard-source.vala"
	__g_list_free__g_object_unref0_0 (separators_to_remove);
#line 277 "/home/fborges/checkout/gnome-boxes/src/wizard-source.vala"
	__g_list_free__g_object_unref0_0 (items_to_remove);
#line 277 "/home/fborges/checkout/gnome-boxes/src/wizard-source.vala"
	return result;
#line 2984 "wizard-source.c"
}


static gboolean _boxes_wizard_web_view_on_context_menu_webkit_web_view_context_menu (WebKitWebView* _sender, WebKitContextMenu* context_menu, GdkEvent* event, WebKitHitTestResult* hit_test_result, gpointer self) {
	gboolean result;
	result = boxes_wizard_web_view_on_context_menu ((BoxesWizardWebView*) self, _sender, context_menu, event, hit_test_result);
#line 203 "/home/fborges/checkout/gnome-boxes/src/wizard-source.vala"
	return result;
#line 2993 "wizard-source.c"
}


static gboolean ___lambda62_ (BoxesWizardWebView* self) {
	gboolean result = FALSE;
	GtkProgressBar* _tmp0_;
#line 296 "/home/fborges/checkout/gnome-boxes/src/wizard-source.vala"
	_tmp0_ = self->priv->progress_bar;
#line 296 "/home/fborges/checkout/gnome-boxes/src/wizard-source.vala"
	gtk_widget_hide ((GtkWidget*) _tmp0_);
#line 297 "/home/fborges/checkout/gnome-boxes/src/wizard-source.vala"
	self->priv->hide_progress_bar_id = (guint) 0;
#line 298 "/home/fborges/checkout/gnome-boxes/src/wizard-source.vala"
	result = G_SOURCE_REMOVE;
#line 298 "/home/fborges/checkout/gnome-boxes/src/wizard-source.vala"
	return result;
#line 3010 "wizard-source.c"
}


static gboolean ____lambda62__gsource_func (gpointer self) {
	gboolean result;
	result = ___lambda62_ ((BoxesWizardWebView*) self);
#line 295 "/home/fborges/checkout/gnome-boxes/src/wizard-source.vala"
	return result;
#line 3019 "wizard-source.c"
}


static void boxes_wizard_web_view_on_notify_estimated_load_progress (BoxesWizardWebView* self) {
	guint _tmp0_;
	gchar* uri = NULL;
	WebKitWebView* _tmp2_;
	const gchar* _tmp3_;
	gchar* _tmp4_;
	gboolean _tmp5_ = FALSE;
	const gchar* _tmp6_;
	gdouble progress = 0.0;
	WebKitWebView* _tmp8_;
	gdouble _tmp9_;
	gboolean loading = FALSE;
	WebKitWebView* _tmp10_;
	gboolean _tmp11_;
	gboolean _tmp12_;
	gboolean _tmp13_ = FALSE;
	gdouble _tmp14_;
	gdouble _tmp18_ = 0.0;
	gboolean _tmp19_ = FALSE;
	gboolean _tmp20_;
	GtkProgressBar* _tmp23_;
#line 281 "/home/fborges/checkout/gnome-boxes/src/wizard-source.vala"
	g_return_if_fail (self != NULL);
#line 282 "/home/fborges/checkout/gnome-boxes/src/wizard-source.vala"
	_tmp0_ = self->priv->hide_progress_bar_id;
#line 282 "/home/fborges/checkout/gnome-boxes/src/wizard-source.vala"
	if (_tmp0_ != ((guint) 0)) {
#line 3050 "wizard-source.c"
		guint _tmp1_;
#line 283 "/home/fborges/checkout/gnome-boxes/src/wizard-source.vala"
		_tmp1_ = self->priv->hide_progress_bar_id;
#line 283 "/home/fborges/checkout/gnome-boxes/src/wizard-source.vala"
		g_source_remove (_tmp1_);
#line 284 "/home/fborges/checkout/gnome-boxes/src/wizard-source.vala"
		self->priv->hide_progress_bar_id = (guint) 0;
#line 3058 "wizard-source.c"
	}
#line 287 "/home/fborges/checkout/gnome-boxes/src/wizard-source.vala"
	_tmp2_ = self->priv->web_view;
#line 287 "/home/fborges/checkout/gnome-boxes/src/wizard-source.vala"
	_tmp3_ = webkit_web_view_get_uri (_tmp2_);
#line 287 "/home/fborges/checkout/gnome-boxes/src/wizard-source.vala"
	_tmp4_ = g_strdup (_tmp3_);
#line 287 "/home/fborges/checkout/gnome-boxes/src/wizard-source.vala"
	uri = _tmp4_;
#line 288 "/home/fborges/checkout/gnome-boxes/src/wizard-source.vala"
	_tmp6_ = uri;
#line 288 "/home/fborges/checkout/gnome-boxes/src/wizard-source.vala"
	if (_tmp6_ == NULL) {
#line 288 "/home/fborges/checkout/gnome-boxes/src/wizard-source.vala"
		_tmp5_ = TRUE;
#line 3074 "wizard-source.c"
	} else {
		const gchar* _tmp7_;
#line 288 "/home/fborges/checkout/gnome-boxes/src/wizard-source.vala"
		_tmp7_ = uri;
#line 288 "/home/fborges/checkout/gnome-boxes/src/wizard-source.vala"
		_tmp5_ = g_strcmp0 (_tmp7_, "about:blank") == 0;
#line 3081 "wizard-source.c"
	}
#line 288 "/home/fborges/checkout/gnome-boxes/src/wizard-source.vala"
	if (_tmp5_) {
#line 289 "/home/fborges/checkout/gnome-boxes/src/wizard-source.vala"
		_g_free0 (uri);
#line 289 "/home/fborges/checkout/gnome-boxes/src/wizard-source.vala"
		return;
#line 3089 "wizard-source.c"
	}
#line 291 "/home/fborges/checkout/gnome-boxes/src/wizard-source.vala"
	_tmp8_ = self->priv->web_view;
#line 291 "/home/fborges/checkout/gnome-boxes/src/wizard-source.vala"
	_tmp9_ = webkit_web_view_get_estimated_load_progress (_tmp8_);
#line 291 "/home/fborges/checkout/gnome-boxes/src/wizard-source.vala"
	progress = _tmp9_;
#line 292 "/home/fborges/checkout/gnome-boxes/src/wizard-source.vala"
	_tmp10_ = self->priv->web_view;
#line 292 "/home/fborges/checkout/gnome-boxes/src/wizard-source.vala"
	g_object_get (_tmp10_, "is-loading", &_tmp11_, NULL);
#line 292 "/home/fborges/checkout/gnome-boxes/src/wizard-source.vala"
	_tmp12_ = _tmp11_;
#line 292 "/home/fborges/checkout/gnome-boxes/src/wizard-source.vala"
	loading = _tmp12_;
#line 294 "/home/fborges/checkout/gnome-boxes/src/wizard-source.vala"
	_tmp14_ = progress;
#line 294 "/home/fborges/checkout/gnome-boxes/src/wizard-source.vala"
	if (_tmp14_ == 1.0) {
#line 294 "/home/fborges/checkout/gnome-boxes/src/wizard-source.vala"
		_tmp13_ = TRUE;
#line 3111 "wizard-source.c"
	} else {
		gboolean _tmp15_;
#line 294 "/home/fborges/checkout/gnome-boxes/src/wizard-source.vala"
		_tmp15_ = loading;
#line 294 "/home/fborges/checkout/gnome-boxes/src/wizard-source.vala"
		_tmp13_ = !_tmp15_;
#line 3118 "wizard-source.c"
	}
#line 294 "/home/fborges/checkout/gnome-boxes/src/wizard-source.vala"
	if (_tmp13_) {
#line 3122 "wizard-source.c"
		guint _tmp16_;
#line 295 "/home/fborges/checkout/gnome-boxes/src/wizard-source.vala"
		_tmp16_ = g_timeout_add_full (G_PRIORITY_DEFAULT, BOXES_WIZARD_WEB_VIEW_progress_bar_id_timeout, ____lambda62__gsource_func, g_object_ref (self), g_object_unref);
#line 295 "/home/fborges/checkout/gnome-boxes/src/wizard-source.vala"
		self->priv->hide_progress_bar_id = _tmp16_;
#line 3128 "wizard-source.c"
	} else {
		GtkProgressBar* _tmp17_;
#line 301 "/home/fborges/checkout/gnome-boxes/src/wizard-source.vala"
		_tmp17_ = self->priv->progress_bar;
#line 301 "/home/fborges/checkout/gnome-boxes/src/wizard-source.vala"
		gtk_widget_show ((GtkWidget*) _tmp17_);
#line 3135 "wizard-source.c"
	}
#line 304 "/home/fborges/checkout/gnome-boxes/src/wizard-source.vala"
	_tmp20_ = loading;
#line 304 "/home/fborges/checkout/gnome-boxes/src/wizard-source.vala"
	if (_tmp20_) {
#line 304 "/home/fborges/checkout/gnome-boxes/src/wizard-source.vala"
		_tmp19_ = TRUE;
#line 3143 "wizard-source.c"
	} else {
		gdouble _tmp21_;
#line 304 "/home/fborges/checkout/gnome-boxes/src/wizard-source.vala"
		_tmp21_ = progress;
#line 304 "/home/fborges/checkout/gnome-boxes/src/wizard-source.vala"
		_tmp19_ = _tmp21_ == 1.0;
#line 3150 "wizard-source.c"
	}
#line 304 "/home/fborges/checkout/gnome-boxes/src/wizard-source.vala"
	if (_tmp19_) {
#line 3154 "wizard-source.c"
		gdouble _tmp22_;
#line 304 "/home/fborges/checkout/gnome-boxes/src/wizard-source.vala"
		_tmp22_ = progress;
#line 304 "/home/fborges/checkout/gnome-boxes/src/wizard-source.vala"
		_tmp18_ = _tmp22_;
#line 3160 "wizard-source.c"
	} else {
#line 304 "/home/fborges/checkout/gnome-boxes/src/wizard-source.vala"
		_tmp18_ = 0.0;
#line 3164 "wizard-source.c"
	}
#line 304 "/home/fborges/checkout/gnome-boxes/src/wizard-source.vala"
	_tmp23_ = self->priv->progress_bar;
#line 304 "/home/fborges/checkout/gnome-boxes/src/wizard-source.vala"
	gtk_progress_bar_set_fraction (_tmp23_, _tmp18_);
#line 281 "/home/fborges/checkout/gnome-boxes/src/wizard-source.vala"
	_g_free0 (uri);
#line 3172 "wizard-source.c"
}


static void _boxes_wizard_web_view_on_notify_estimated_load_progress_g_object_notify (GObject* _sender, GParamSpec* pspec, gpointer self) {
#line 203 "/home/fborges/checkout/gnome-boxes/src/wizard-source.vala"
	boxes_wizard_web_view_on_notify_estimated_load_progress ((BoxesWizardWebView*) self);
#line 3179 "wizard-source.c"
}


BoxesWizardWebView* boxes_wizard_web_view_construct (GType object_type) {
	BoxesWizardWebView * self = NULL;
#line 203 "/home/fborges/checkout/gnome-boxes/src/wizard-source.vala"
	self = (BoxesWizardWebView*) g_object_new (object_type, NULL);
#line 203 "/home/fborges/checkout/gnome-boxes/src/wizard-source.vala"
	return self;
#line 3189 "wizard-source.c"
}


BoxesWizardWebView* boxes_wizard_web_view_new (void) {
#line 203 "/home/fborges/checkout/gnome-boxes/src/wizard-source.vala"
	return boxes_wizard_web_view_construct (BOXES_TYPE_WIZARD_WEB_VIEW);
#line 3196 "wizard-source.c"
}


WebKitWebView* boxes_wizard_web_view_get_view (BoxesWizardWebView* self) {
	WebKitWebView* result;
	WebKitWebView* _tmp0_;
#line 219 "/home/fborges/checkout/gnome-boxes/src/wizard-source.vala"
	g_return_val_if_fail (self != NULL, NULL);
#line 219 "/home/fborges/checkout/gnome-boxes/src/wizard-source.vala"
	_tmp0_ = self->priv->web_view;
#line 219 "/home/fborges/checkout/gnome-boxes/src/wizard-source.vala"
	result = _tmp0_;
#line 219 "/home/fborges/checkout/gnome-boxes/src/wizard-source.vala"
	return result;
#line 3211 "wizard-source.c"
}


static gchar** _vala_array_dup6 (gchar** self, int length) {
	gchar** result;
	int i;
#line 214 "/home/fborges/checkout/gnome-boxes/src/wizard-source.vala"
	result = g_new0 (gchar*, length + 1);
#line 214 "/home/fborges/checkout/gnome-boxes/src/wizard-source.vala"
	for (i = 0; i < length; i++) {
#line 3222 "wizard-source.c"
		gchar* _tmp0_;
#line 214 "/home/fborges/checkout/gnome-boxes/src/wizard-source.vala"
		_tmp0_ = g_strdup (self[i]);
#line 214 "/home/fborges/checkout/gnome-boxes/src/wizard-source.vala"
		result[i] = _tmp0_;
#line 3228 "wizard-source.c"
	}
#line 214 "/home/fborges/checkout/gnome-boxes/src/wizard-source.vala"
	return result;
#line 3232 "wizard-source.c"
}


static GObject * boxes_wizard_web_view_constructor (GType type, guint n_construct_properties, GObjectConstructParam * construct_properties) {
	GObject * obj;
	GObjectClass * parent_class;
	BoxesWizardWebView * self;
	WebKitWebContext* context = NULL;
	WebKitWebView* _tmp0_;
	WebKitWebContext* _tmp1_;
	WebKitWebContext* _tmp2_;
	gchar** language_names = NULL;
	gchar** _tmp3_;
	gchar** _tmp4_;
	gchar** _tmp5_;
	gint _tmp5__length1;
	gint language_names_length1;
	gint _language_names_size_;
	WebKitWebContext* _tmp6_;
	gchar** _tmp7_;
	gint _tmp7__length1;
#line 212 "/home/fborges/checkout/gnome-boxes/src/wizard-source.vala"
	parent_class = G_OBJECT_CLASS (boxes_wizard_web_view_parent_class);
#line 212 "/home/fborges/checkout/gnome-boxes/src/wizard-source.vala"
	obj = parent_class->constructor (type, n_construct_properties, construct_properties);
#line 212 "/home/fborges/checkout/gnome-boxes/src/wizard-source.vala"
	self = G_TYPE_CHECK_INSTANCE_CAST (obj, BOXES_TYPE_WIZARD_WEB_VIEW, BoxesWizardWebView);
#line 213 "/home/fborges/checkout/gnome-boxes/src/wizard-source.vala"
	_tmp0_ = self->priv->web_view;
#line 213 "/home/fborges/checkout/gnome-boxes/src/wizard-source.vala"
	_tmp1_ = webkit_web_view_get_context (_tmp0_);
#line 213 "/home/fborges/checkout/gnome-boxes/src/wizard-source.vala"
	_tmp2_ = _g_object_ref0 (_tmp1_);
#line 213 "/home/fborges/checkout/gnome-boxes/src/wizard-source.vala"
	context = _tmp2_;
#line 214 "/home/fborges/checkout/gnome-boxes/src/wizard-source.vala"
	_tmp4_ = _tmp3_ = g_get_language_names ();
#line 214 "/home/fborges/checkout/gnome-boxes/src/wizard-source.vala"
	_tmp5_ = (_tmp4_ != NULL) ? _vala_array_dup6 (_tmp4_, _vala_array_length (_tmp3_)) : ((gpointer) _tmp4_);
#line 214 "/home/fborges/checkout/gnome-boxes/src/wizard-source.vala"
	_tmp5__length1 = _vala_array_length (_tmp3_);
#line 214 "/home/fborges/checkout/gnome-boxes/src/wizard-source.vala"
	language_names = _tmp5_;
#line 214 "/home/fborges/checkout/gnome-boxes/src/wizard-source.vala"
	language_names_length1 = _tmp5__length1;
#line 214 "/home/fborges/checkout/gnome-boxes/src/wizard-source.vala"
	_language_names_size_ = language_names_length1;
#line 215 "/home/fborges/checkout/gnome-boxes/src/wizard-source.vala"
	_tmp6_ = context;
#line 215 "/home/fborges/checkout/gnome-boxes/src/wizard-source.vala"
	_tmp7_ = language_names;
#line 215 "/home/fborges/checkout/gnome-boxes/src/wizard-source.vala"
	_tmp7__length1 = language_names_length1;
#line 215 "/home/fborges/checkout/gnome-boxes/src/wizard-source.vala"
	webkit_web_context_set_preferred_languages (_tmp6_, _tmp7_);
#line 212 "/home/fborges/checkout/gnome-boxes/src/wizard-source.vala"
	language_names = (_vala_array_free (language_names, language_names_length1, (GDestroyNotify) g_free), NULL);
#line 212 "/home/fborges/checkout/gnome-boxes/src/wizard-source.vala"
	_g_object_unref0 (context);
#line 212 "/home/fborges/checkout/gnome-boxes/src/wizard-source.vala"
	return obj;
#line 3294 "wizard-source.c"
}


static void boxes_wizard_web_view_class_init (BoxesWizardWebViewClass * klass) {
	gint BoxesWizardWebView_private_offset;
#line 203 "/home/fborges/checkout/gnome-boxes/src/wizard-source.vala"
	boxes_wizard_web_view_parent_class = g_type_class_peek_parent (klass);
#line 203 "/home/fborges/checkout/gnome-boxes/src/wizard-source.vala"
	g_type_class_add_private (klass, sizeof (BoxesWizardWebViewPrivate));
#line 203 "/home/fborges/checkout/gnome-boxes/src/wizard-source.vala"
	((GObjectClass *) klass)->dispose = (void (*) (GObject *)) boxes_wizard_web_view_real_dispose;
#line 203 "/home/fborges/checkout/gnome-boxes/src/wizard-source.vala"
	G_OBJECT_CLASS (klass)->get_property = _vala_boxes_wizard_web_view_get_property;
#line 203 "/home/fborges/checkout/gnome-boxes/src/wizard-source.vala"
	G_OBJECT_CLASS (klass)->constructor = boxes_wizard_web_view_constructor;
#line 203 "/home/fborges/checkout/gnome-boxes/src/wizard-source.vala"
	G_OBJECT_CLASS (klass)->finalize = boxes_wizard_web_view_finalize;
#line 203 "/home/fborges/checkout/gnome-boxes/src/wizard-source.vala"
	g_object_class_install_property (G_OBJECT_CLASS (klass), BOXES_WIZARD_WEB_VIEW_VIEW_PROPERTY, boxes_wizard_web_view_properties[BOXES_WIZARD_WEB_VIEW_VIEW_PROPERTY] = g_param_spec_object ("view", "view", "view", webkit_web_view_get_type (), G_PARAM_STATIC_NAME | G_PARAM_STATIC_NICK | G_PARAM_STATIC_BLURB | G_PARAM_READABLE));
#line 203 "/home/fborges/checkout/gnome-boxes/src/wizard-source.vala"
	BoxesWizardWebView_private_offset = g_type_class_get_instance_private_offset (klass);
#line 203 "/home/fborges/checkout/gnome-boxes/src/wizard-source.vala"
	gtk_widget_class_set_template_from_resource (GTK_WIDGET_CLASS (klass), "/org/gnome/Boxes/ui/wizard-web-view.ui");
#line 203 "/home/fborges/checkout/gnome-boxes/src/wizard-source.vala"
	gtk_widget_class_bind_template_child_full (GTK_WIDGET_CLASS (klass), "progress_bar", FALSE, BoxesWizardWebView_private_offset + G_STRUCT_OFFSET (BoxesWizardWebViewPrivate, progress_bar));
#line 203 "/home/fborges/checkout/gnome-boxes/src/wizard-source.vala"
	gtk_widget_class_bind_template_child_full (GTK_WIDGET_CLASS (klass), "web_view", FALSE, BoxesWizardWebView_private_offset + G_STRUCT_OFFSET (BoxesWizardWebViewPrivate, web_view));
#line 203 "/home/fborges/checkout/gnome-boxes/src/wizard-source.vala"
	gtk_widget_class_bind_template_callback_full (GTK_WIDGET_CLASS (klass), "on_context_menu", G_CALLBACK(_boxes_wizard_web_view_on_context_menu_webkit_web_view_context_menu));
#line 203 "/home/fborges/checkout/gnome-boxes/src/wizard-source.vala"
	gtk_widget_class_bind_template_callback_full (GTK_WIDGET_CLASS (klass), "on_notify_estimated_load_progress", G_CALLBACK(_boxes_wizard_web_view_on_notify_estimated_load_progress_g_object_notify));
#line 3326 "wizard-source.c"
}


static void boxes_wizard_web_view_instance_init (BoxesWizardWebView * self) {
#line 203 "/home/fborges/checkout/gnome-boxes/src/wizard-source.vala"
	self->priv = BOXES_WIZARD_WEB_VIEW_GET_PRIVATE (self);
#line 203 "/home/fborges/checkout/gnome-boxes/src/wizard-source.vala"
	gtk_widget_init_template (GTK_WIDGET (self));
#line 3335 "wizard-source.c"
}


static void boxes_wizard_web_view_finalize (GObject * obj) {
	BoxesWizardWebView * self;
#line 203 "/home/fborges/checkout/gnome-boxes/src/wizard-source.vala"
	self = G_TYPE_CHECK_INSTANCE_CAST (obj, BOXES_TYPE_WIZARD_WEB_VIEW, BoxesWizardWebView);
#line 205 "/home/fborges/checkout/gnome-boxes/src/wizard-source.vala"
	_g_object_unref0 (self->priv->progress_bar);
#line 207 "/home/fborges/checkout/gnome-boxes/src/wizard-source.vala"
	_g_object_unref0 (self->priv->web_view);
#line 203 "/home/fborges/checkout/gnome-boxes/src/wizard-source.vala"
	G_OBJECT_CLASS (boxes_wizard_web_view_parent_class)->finalize (obj);
#line 3349 "wizard-source.c"
}


GType boxes_wizard_web_view_get_type (void) {
	static volatile gsize boxes_wizard_web_view_type_id__volatile = 0;
	if (g_once_init_enter (&boxes_wizard_web_view_type_id__volatile)) {
		static const GTypeInfo g_define_type_info = { sizeof (BoxesWizardWebViewClass), (GBaseInitFunc) NULL, (GBaseFinalizeFunc) NULL, (GClassInitFunc) boxes_wizard_web_view_class_init, (GClassFinalizeFunc) NULL, NULL, sizeof (BoxesWizardWebView), 0, (GInstanceInitFunc) boxes_wizard_web_view_instance_init, NULL };
		GType boxes_wizard_web_view_type_id;
		boxes_wizard_web_view_type_id = g_type_register_static (gtk_bin_get_type (), "BoxesWizardWebView", &g_define_type_info, 0);
		g_once_init_leave (&boxes_wizard_web_view_type_id__volatile, boxes_wizard_web_view_type_id);
	}
	return boxes_wizard_web_view_type_id__volatile;
}


static void _vala_boxes_wizard_web_view_get_property (GObject * object, guint property_id, GValue * value, GParamSpec * pspec) {
	BoxesWizardWebView * self;
	self = G_TYPE_CHECK_INSTANCE_CAST (object, BOXES_TYPE_WIZARD_WEB_VIEW, BoxesWizardWebView);
#line 203 "/home/fborges/checkout/gnome-boxes/src/wizard-source.vala"
	switch (property_id) {
#line 203 "/home/fborges/checkout/gnome-boxes/src/wizard-source.vala"
		case BOXES_WIZARD_WEB_VIEW_VIEW_PROPERTY:
#line 203 "/home/fborges/checkout/gnome-boxes/src/wizard-source.vala"
		g_value_set_object (value, boxes_wizard_web_view_get_view (self));
#line 203 "/home/fborges/checkout/gnome-boxes/src/wizard-source.vala"
		break;
#line 3376 "wizard-source.c"
		default:
#line 203 "/home/fborges/checkout/gnome-boxes/src/wizard-source.vala"
		G_OBJECT_WARN_INVALID_PROPERTY_ID (object, property_id, pspec);
#line 203 "/home/fborges/checkout/gnome-boxes/src/wizard-source.vala"
		break;
#line 3382 "wizard-source.c"
	}
}


static Block91Data* block91_data_ref (Block91Data* _data91_) {
#line 368 "/home/fborges/checkout/gnome-boxes/src/wizard-source.vala"
	g_atomic_int_inc (&_data91_->_ref_count_);
#line 368 "/home/fborges/checkout/gnome-boxes/src/wizard-source.vala"
	return _data91_;
#line 3392 "wizard-source.c"
}


static void block91_data_unref (void * _userdata_) {
	Block91Data* _data91_;
	_data91_ = (Block91Data*) _userdata_;
#line 368 "/home/fborges/checkout/gnome-boxes/src/wizard-source.vala"
	if (g_atomic_int_dec_and_test (&_data91_->_ref_count_)) {
#line 3401 "wizard-source.c"
		BoxesWizardSource* self;
#line 368 "/home/fborges/checkout/gnome-boxes/src/wizard-source.vala"
		self = _data91_->self;
#line 368 "/home/fborges/checkout/gnome-boxes/src/wizard-source.vala"
		_g_object_unref0 (_data91_->os);
#line 368 "/home/fborges/checkout/gnome-boxes/src/wizard-source.vala"
		_g_free0 (_data91_->uri);
#line 368 "/home/fborges/checkout/gnome-boxes/src/wizard-source.vala"
		_g_object_unref0 (self);
#line 368 "/home/fborges/checkout/gnome-boxes/src/wizard-source.vala"
		g_slice_free (Block91Data, _data91_);
#line 3413 "wizard-source.c"
	}
}


static gboolean __lambda63_ (Block91Data* _data91_, GtkTreeModel* store, GtkTreePath* path, GtkTreeIter* iter) {
	BoxesWizardSource* self;
	gboolean result = FALSE;
	gchar* os_uri = NULL;
	GtkListStore* _tmp0_;
	GtkTreeIter _tmp1_;
	const gchar* _tmp2_;
#line 371 "/home/fborges/checkout/gnome-boxes/src/wizard-source.vala"
	self = _data91_->self;
#line 371 "/home/fborges/checkout/gnome-boxes/src/wizard-source.vala"
	g_return_val_if_fail (store != NULL, FALSE);
#line 371 "/home/fborges/checkout/gnome-boxes/src/wizard-source.vala"
	g_return_val_if_fail (path != NULL, FALSE);
#line 371 "/home/fborges/checkout/gnome-boxes/src/wizard-source.vala"
	g_return_val_if_fail (iter != NULL, FALSE);
#line 373 "/home/fborges/checkout/gnome-boxes/src/wizard-source.vala"
	_tmp0_ = self->priv->media_urls_store;
#line 373 "/home/fborges/checkout/gnome-boxes/src/wizard-source.vala"
	_tmp1_ = *iter;
#line 373 "/home/fborges/checkout/gnome-boxes/src/wizard-source.vala"
	gtk_tree_model_get ((GtkTreeModel*) _tmp0_, &_tmp1_, BOXES_OS_DATABASE_MEDIA_UR_LS_COLUMNS_URL, &os_uri, BOXES_OS_DATABASE_MEDIA_UR_LS_COLUMNS_OS, &_data91_->os, -1);
#line 376 "/home/fborges/checkout/gnome-boxes/src/wizard-source.vala"
	_tmp2_ = _data91_->uri;
#line 376 "/home/fborges/checkout/gnome-boxes/src/wizard-source.vala"
	result = g_strcmp0 (os_uri, _tmp2_) == 0;
#line 376 "/home/fborges/checkout/gnome-boxes/src/wizard-source.vala"
	_g_free0 (os_uri);
#line 376 "/home/fborges/checkout/gnome-boxes/src/wizard-source.vala"
	return result;
#line 3447 "wizard-source.c"
}


static gboolean ___lambda63__gtk_tree_model_foreach_func (GtkTreeModel* model, GtkTreePath* path, GtkTreeIter* iter, gpointer self) {
	gboolean result;
	result = __lambda63_ (self, model, path, iter);
#line 371 "/home/fborges/checkout/gnome-boxes/src/wizard-source.vala"
	return result;
#line 3456 "wizard-source.c"
}


OsinfoOs* boxes_wizard_source_get_os_from_uri (BoxesWizardSource* self, const gchar* uri) {
	OsinfoOs* result = NULL;
	Block91Data* _data91_;
	const gchar* _tmp0_;
	gchar* _tmp1_;
	GtkListStore* _tmp2_;
	OsinfoOs* _tmp3_;
#line 368 "/home/fborges/checkout/gnome-boxes/src/wizard-source.vala"
	g_return_val_if_fail (self != NULL, NULL);
#line 368 "/home/fborges/checkout/gnome-boxes/src/wizard-source.vala"
	g_return_val_if_fail (uri != NULL, NULL);
#line 368 "/home/fborges/checkout/gnome-boxes/src/wizard-source.vala"
	_data91_ = g_slice_new0 (Block91Data);
#line 368 "/home/fborges/checkout/gnome-boxes/src/wizard-source.vala"
	_data91_->_ref_count_ = 1;
#line 368 "/home/fborges/checkout/gnome-boxes/src/wizard-source.vala"
	_data91_->self = g_object_ref (self);
#line 368 "/home/fborges/checkout/gnome-boxes/src/wizard-source.vala"
	_tmp0_ = uri;
#line 368 "/home/fborges/checkout/gnome-boxes/src/wizard-source.vala"
	_tmp1_ = g_strdup (_tmp0_);
#line 368 "/home/fborges/checkout/gnome-boxes/src/wizard-source.vala"
	_g_free0 (_data91_->uri);
#line 368 "/home/fborges/checkout/gnome-boxes/src/wizard-source.vala"
	_data91_->uri = _tmp1_;
#line 369 "/home/fborges/checkout/gnome-boxes/src/wizard-source.vala"
	_data91_->os = NULL;
#line 371 "/home/fborges/checkout/gnome-boxes/src/wizard-source.vala"
	_tmp2_ = self->priv->media_urls_store;
#line 371 "/home/fborges/checkout/gnome-boxes/src/wizard-source.vala"
	gtk_tree_model_foreach ((GtkTreeModel*) _tmp2_, ___lambda63__gtk_tree_model_foreach_func, _data91_);
#line 379 "/home/fborges/checkout/gnome-boxes/src/wizard-source.vala"
	_tmp3_ = _g_object_ref0 (_data91_->os);
#line 379 "/home/fborges/checkout/gnome-boxes/src/wizard-source.vala"
	result = _tmp3_;
#line 379 "/home/fborges/checkout/gnome-boxes/src/wizard-source.vala"
	block91_data_unref (_data91_);
#line 379 "/home/fborges/checkout/gnome-boxes/src/wizard-source.vala"
	_data91_ = NULL;
#line 379 "/home/fborges/checkout/gnome-boxes/src/wizard-source.vala"
	return result;
#line 3501 "wizard-source.c"
}


static void boxes_wizard_source_real_dispose (GObject* base) {
	BoxesWizardSource * self;
	GCancellable* _tmp0_;
#line 435 "/home/fborges/checkout/gnome-boxes/src/wizard-source.vala"
	self = (BoxesWizardSource*) base;
#line 436 "/home/fborges/checkout/gnome-boxes/src/wizard-source.vala"
	_tmp0_ = self->priv->rhel_cancellable;
#line 436 "/home/fborges/checkout/gnome-boxes/src/wizard-source.vala"
	if (_tmp0_ != NULL) {
#line 3514 "wizard-source.c"
		GCancellable* _tmp1_;
#line 437 "/home/fborges/checkout/gnome-boxes/src/wizard-source.vala"
		_tmp1_ = self->priv->rhel_cancellable;
#line 437 "/home/fborges/checkout/gnome-boxes/src/wizard-source.vala"
		g_cancellable_cancel (_tmp1_);
#line 438 "/home/fborges/checkout/gnome-boxes/src/wizard-source.vala"
		_g_object_unref0 (self->priv->rhel_cancellable);
#line 438 "/home/fborges/checkout/gnome-boxes/src/wizard-source.vala"
		self->priv->rhel_cancellable = NULL;
#line 3524 "wizard-source.c"
	}
#line 441 "/home/fborges/checkout/gnome-boxes/src/wizard-source.vala"
	G_OBJECT_CLASS (boxes_wizard_source_parent_class)->dispose ((GObject*) G_TYPE_CHECK_INSTANCE_CAST (self, gtk_stack_get_type (), GtkStack));
#line 3528 "wizard-source.c"
}


static Block92Data* block92_data_ref (Block92Data* _data92_) {
#line 444 "/home/fborges/checkout/gnome-boxes/src/wizard-source.vala"
	g_atomic_int_inc (&_data92_->_ref_count_);
#line 444 "/home/fborges/checkout/gnome-boxes/src/wizard-source.vala"
	return _data92_;
#line 3537 "wizard-source.c"
}


static void block92_data_unref (void * _userdata_) {
	Block92Data* _data92_;
	_data92_ = (Block92Data*) _userdata_;
#line 444 "/home/fborges/checkout/gnome-boxes/src/wizard-source.vala"
	if (g_atomic_int_dec_and_test (&_data92_->_ref_count_)) {
#line 3546 "wizard-source.c"
		BoxesWizardSource* self;
#line 444 "/home/fborges/checkout/gnome-boxes/src/wizard-source.vala"
		self = _data92_->self;
#line 444 "/home/fborges/checkout/gnome-boxes/src/wizard-source.vala"
		_g_free0 (_data92_->rhel_id);
#line 444 "/home/fborges/checkout/gnome-boxes/src/wizard-source.vala"
		_g_object_unref0 (_data92_->available_downloads_model);
#line 444 "/home/fborges/checkout/gnome-boxes/src/wizard-source.vala"
		_g_object_unref0 (_data92_->os_db);
#line 444 "/home/fborges/checkout/gnome-boxes/src/wizard-source.vala"
		_g_object_unref0 (self);
#line 444 "/home/fborges/checkout/gnome-boxes/src/wizard-source.vala"
		g_slice_free (Block92Data, _data92_);
#line 3560 "wizard-source.c"
	}
}


static void __lambda72_ (BoxesWizardSource* self, OsinfoMedia* media) {
	OsinfoMedia* _tmp0_;
	gchar* _tmp1_;
	gchar* _tmp2_;
	gchar* _tmp3_;
#line 456 "/home/fborges/checkout/gnome-boxes/src/wizard-source.vala"
	g_return_if_fail (media != NULL);
#line 457 "/home/fborges/checkout/gnome-boxes/src/wizard-source.vala"
	_tmp0_ = media;
#line 457 "/home/fborges/checkout/gnome-boxes/src/wizard-source.vala"
	g_object_get (_tmp0_, "url", &_tmp1_, NULL);
#line 457 "/home/fborges/checkout/gnome-boxes/src/wizard-source.vala"
	_tmp2_ = _tmp1_;
#line 457 "/home/fborges/checkout/gnome-boxes/src/wizard-source.vala"
	_tmp3_ = _tmp2_;
#line 457 "/home/fborges/checkout/gnome-boxes/src/wizard-source.vala"
	boxes_wizard_source_set_uri (self, _tmp3_);
#line 457 "/home/fborges/checkout/gnome-boxes/src/wizard-source.vala"
	_g_free0 (_tmp3_);
#line 459 "/home/fborges/checkout/gnome-boxes/src/wizard-source.vala"
	g_signal_emit (self, boxes_wizard_source_signals[BOXES_WIZARD_SOURCE_ACTIVATED_SIGNAL], 0);
#line 3586 "wizard-source.c"
}


static void ___lambda72__boxes_wizard_downloadable_entry_activated (BoxesWizardDownloadableEntry* _sender, OsinfoMedia* media, gpointer self) {
#line 456 "/home/fborges/checkout/gnome-boxes/src/wizard-source.vala"
	__lambda72_ ((BoxesWizardSource*) self, media);
#line 3593 "wizard-source.c"
}


static GtkWidget* __lambda64_ (BoxesWizardSource* self, GObject* obj) {
	GtkWidget* result = NULL;
	OsinfoOs* os = NULL;
	GObject* _tmp0_;
	OsinfoOs* _tmp1_;
	BoxesWizardDownloadableEntry* entry = NULL;
	BoxesWizardDownloadableEntry* _tmp2_;
#line 452 "/home/fborges/checkout/gnome-boxes/src/wizard-source.vala"
	g_return_val_if_fail (obj != NULL, NULL);
#line 453 "/home/fborges/checkout/gnome-boxes/src/wizard-source.vala"
	_tmp0_ = obj;
#line 453 "/home/fborges/checkout/gnome-boxes/src/wizard-source.vala"
	_tmp1_ = _g_object_ref0 (G_TYPE_CHECK_INSTANCE_TYPE (_tmp0_, osinfo_os_get_type ()) ? ((OsinfoOs*) _tmp0_) : NULL);
#line 453 "/home/fborges/checkout/gnome-boxes/src/wizard-source.vala"
	os = _tmp1_;
#line 455 "/home/fborges/checkout/gnome-boxes/src/wizard-source.vala"
	_tmp2_ = boxes_wizard_downloadable_entry_new (os);
#line 455 "/home/fborges/checkout/gnome-boxes/src/wizard-source.vala"
	g_object_ref_sink (_tmp2_);
#line 455 "/home/fborges/checkout/gnome-boxes/src/wizard-source.vala"
	entry = _tmp2_;
#line 456 "/home/fborges/checkout/gnome-boxes/src/wizard-source.vala"
	g_signal_connect_object (entry, "activated", (GCallback) ___lambda72__boxes_wizard_downloadable_entry_activated, self, 0);
#line 462 "/home/fborges/checkout/gnome-boxes/src/wizard-source.vala"
	result = (GtkWidget*) entry;
#line 462 "/home/fborges/checkout/gnome-boxes/src/wizard-source.vala"
	_g_object_unref0 (os);
#line 462 "/home/fborges/checkout/gnome-boxes/src/wizard-source.vala"
	return result;
#line 3626 "wizard-source.c"
}


static GtkWidget* ___lambda64__gtk_list_box_create_widget_func (GObject* item, gpointer self) {
	GtkWidget* result;
	result = __lambda64_ ((BoxesWizardSource*) self, item);
#line 452 "/home/fborges/checkout/gnome-boxes/src/wizard-source.vala"
	return result;
#line 3635 "wizard-source.c"
}


static void __lambda73_ (BoxesWizardSource* self, GtkListBoxRow* row) {
	BoxesWizardDownloadableEntry* entry = NULL;
	GtkListBoxRow* _tmp0_;
	BoxesWizardDownloadableEntry* _tmp1_;
	BoxesWizardDownloadableEntry* _tmp2_;
	BoxesWizardDownloadableEntry* _tmp3_;
	OsinfoMedia* _tmp4_;
#line 465 "/home/fborges/checkout/gnome-boxes/src/wizard-source.vala"
	g_return_if_fail (row != NULL);
#line 466 "/home/fborges/checkout/gnome-boxes/src/wizard-source.vala"
	_tmp0_ = row;
#line 466 "/home/fborges/checkout/gnome-boxes/src/wizard-source.vala"
	_tmp1_ = _g_object_ref0 (G_TYPE_CHECK_INSTANCE_TYPE (_tmp0_, BOXES_TYPE_WIZARD_DOWNLOADABLE_ENTRY) ? ((BoxesWizardDownloadableEntry*) _tmp0_) : NULL);
#line 466 "/home/fborges/checkout/gnome-boxes/src/wizard-source.vala"
	entry = _tmp1_;
#line 468 "/home/fborges/checkout/gnome-boxes/src/wizard-source.vala"
	_tmp2_ = entry;
#line 468 "/home/fborges/checkout/gnome-boxes/src/wizard-source.vala"
	boxes_wizard_source_set_selected (self, (GtkWidget*) _tmp2_);
#line 469 "/home/fborges/checkout/gnome-boxes/src/wizard-source.vala"
	_tmp3_ = entry;
#line 469 "/home/fborges/checkout/gnome-boxes/src/wizard-source.vala"
	_tmp4_ = _tmp3_->single_media;
#line 469 "/home/fborges/checkout/gnome-boxes/src/wizard-source.vala"
	if (_tmp4_ != NULL) {
#line 3664 "wizard-source.c"
		BoxesWizardDownloadableEntry* _tmp5_;
		OsinfoMedia* _tmp6_;
		gchar* _tmp7_;
		gchar* _tmp8_;
		gchar* _tmp9_;
#line 470 "/home/fborges/checkout/gnome-boxes/src/wizard-source.vala"
		_tmp5_ = entry;
#line 470 "/home/fborges/checkout/gnome-boxes/src/wizard-source.vala"
		_tmp6_ = _tmp5_->single_media;
#line 470 "/home/fborges/checkout/gnome-boxes/src/wizard-source.vala"
		g_object_get (_tmp6_, "url", &_tmp7_, NULL);
#line 470 "/home/fborges/checkout/gnome-boxes/src/wizard-source.vala"
		_tmp8_ = _tmp7_;
#line 470 "/home/fborges/checkout/gnome-boxes/src/wizard-source.vala"
		_tmp9_ = _tmp8_;
#line 470 "/home/fborges/checkout/gnome-boxes/src/wizard-source.vala"
		boxes_wizard_source_set_uri (self, _tmp9_);
#line 470 "/home/fborges/checkout/gnome-boxes/src/wizard-source.vala"
		_g_free0 (_tmp9_);
#line 472 "/home/fborges/checkout/gnome-boxes/src/wizard-source.vala"
		g_signal_emit (self, boxes_wizard_source_signals[BOXES_WIZARD_SOURCE_ACTIVATED_SIGNAL], 0);
#line 3686 "wizard-source.c"
	} else {
		BoxesWizardDownloadableEntry* _tmp10_;
#line 474 "/home/fborges/checkout/gnome-boxes/src/wizard-source.vala"
		_tmp10_ = entry;
#line 474 "/home/fborges/checkout/gnome-boxes/src/wizard-source.vala"
		boxes_wizard_downloadable_entry_toggle (_tmp10_);
#line 3693 "wizard-source.c"
	}
#line 465 "/home/fborges/checkout/gnome-boxes/src/wizard-source.vala"
	_g_object_unref0 (entry);
#line 3697 "wizard-source.c"
}


static void ___lambda73__gtk_list_box_row_activated (GtkListBox* _sender, GtkListBoxRow* row, gpointer self) {
#line 465 "/home/fborges/checkout/gnome-boxes/src/wizard-source.vala"
	__lambda73_ ((BoxesWizardSource*) self, row);
#line 3704 "wizard-source.c"
}


static gint _____lambda75_ (BoxesWizardSource* self, GObject* a, GObject* b) {
	gint result = 0;
	OsinfoOs* os1 = NULL;
	GObject* _tmp0_;
	OsinfoOs* _tmp1_;
	OsinfoOs* os2 = NULL;
	GObject* _tmp2_;
	OsinfoOs* _tmp3_;
	OsinfoOs* _tmp4_;
	gchar* _tmp5_;
	gchar* _tmp6_;
	gboolean _tmp7_;
	OsinfoOs* _tmp8_;
	gchar* _tmp9_;
	gchar* _tmp10_;
	gboolean _tmp11_;
#line 483 "/home/fborges/checkout/gnome-boxes/src/wizard-source.vala"
	g_return_val_if_fail (a != NULL, 0);
#line 483 "/home/fborges/checkout/gnome-boxes/src/wizard-source.vala"
	g_return_val_if_fail (b != NULL, 0);
#line 484 "/home/fborges/checkout/gnome-boxes/src/wizard-source.vala"
	_tmp0_ = a;
#line 484 "/home/fborges/checkout/gnome-boxes/src/wizard-source.vala"
	_tmp1_ = _g_object_ref0 (G_TYPE_CHECK_INSTANCE_TYPE (_tmp0_, osinfo_os_get_type ()) ? ((OsinfoOs*) _tmp0_) : NULL);
#line 484 "/home/fborges/checkout/gnome-boxes/src/wizard-source.vala"
	os1 = _tmp1_;
#line 485 "/home/fborges/checkout/gnome-boxes/src/wizard-source.vala"
	_tmp2_ = b;
#line 485 "/home/fborges/checkout/gnome-boxes/src/wizard-source.vala"
	_tmp3_ = _g_object_ref0 (G_TYPE_CHECK_INSTANCE_TYPE (_tmp2_, osinfo_os_get_type ()) ? ((OsinfoOs*) _tmp2_) : NULL);
#line 485 "/home/fborges/checkout/gnome-boxes/src/wizard-source.vala"
	os2 = _tmp3_;
#line 487 "/home/fborges/checkout/gnome-boxes/src/wizard-source.vala"
	_tmp4_ = os1;
#line 487 "/home/fborges/checkout/gnome-boxes/src/wizard-source.vala"
	_tmp5_ = boxes_downloader_fetch_os_logo_url (_tmp4_);
#line 487 "/home/fborges/checkout/gnome-boxes/src/wizard-source.vala"
	_tmp6_ = _tmp5_;
#line 487 "/home/fborges/checkout/gnome-boxes/src/wizard-source.vala"
	_tmp7_ = _tmp6_ != NULL;
#line 487 "/home/fborges/checkout/gnome-boxes/src/wizard-source.vala"
	_g_free0 (_tmp6_);
#line 487 "/home/fborges/checkout/gnome-boxes/src/wizard-source.vala"
	if (_tmp7_) {
#line 488 "/home/fborges/checkout/gnome-boxes/src/wizard-source.vala"
		result = -1;
#line 488 "/home/fborges/checkout/gnome-boxes/src/wizard-source.vala"
		_g_object_unref0 (os2);
#line 488 "/home/fborges/checkout/gnome-boxes/src/wizard-source.vala"
		_g_object_unref0 (os1);
#line 488 "/home/fborges/checkout/gnome-boxes/src/wizard-source.vala"
		return result;
#line 3760 "wizard-source.c"
	}
#line 490 "/home/fborges/checkout/gnome-boxes/src/wizard-source.vala"
	_tmp8_ = os2;
#line 490 "/home/fborges/checkout/gnome-boxes/src/wizard-source.vala"
	_tmp9_ = boxes_downloader_fetch_os_logo_url (_tmp8_);
#line 490 "/home/fborges/checkout/gnome-boxes/src/wizard-source.vala"
	_tmp10_ = _tmp9_;
#line 490 "/home/fborges/checkout/gnome-boxes/src/wizard-source.vala"
	_tmp11_ = _tmp10_ != NULL;
#line 490 "/home/fborges/checkout/gnome-boxes/src/wizard-source.vala"
	_g_free0 (_tmp10_);
#line 490 "/home/fborges/checkout/gnome-boxes/src/wizard-source.vala"
	if (_tmp11_) {
#line 491 "/home/fborges/checkout/gnome-boxes/src/wizard-source.vala"
		result = 1;
#line 491 "/home/fborges/checkout/gnome-boxes/src/wizard-source.vala"
		_g_object_unref0 (os2);
#line 491 "/home/fborges/checkout/gnome-boxes/src/wizard-source.vala"
		_g_object_unref0 (os1);
#line 491 "/home/fborges/checkout/gnome-boxes/src/wizard-source.vala"
		return result;
#line 3782 "wizard-source.c"
	}
#line 493 "/home/fborges/checkout/gnome-boxes/src/wizard-source.vala"
	result = 0;
#line 493 "/home/fborges/checkout/gnome-boxes/src/wizard-source.vala"
	_g_object_unref0 (os2);
#line 493 "/home/fborges/checkout/gnome-boxes/src/wizard-source.vala"
	_g_object_unref0 (os1);
#line 493 "/home/fborges/checkout/gnome-boxes/src/wizard-source.vala"
	return result;
#line 3792 "wizard-source.c"
}


static gint ______lambda75__gcompare_data_func (gconstpointer a, gconstpointer b, gpointer self) {
	gint result;
	result = _____lambda75_ ((BoxesWizardSource*) self, (GObject*) a, (GObject*) b);
#line 483 "/home/fborges/checkout/gnome-boxes/src/wizard-source.vala"
	return result;
#line 3801 "wizard-source.c"
}


static void __lambda74_ (Block92Data* _data92_, GObject* db, GAsyncResult* _result_) {
	BoxesWizardSource* self;
	GError * _inner_error_ = NULL;
#line 478 "/home/fborges/checkout/gnome-boxes/src/wizard-source.vala"
	self = _data92_->self;
#line 478 "/home/fborges/checkout/gnome-boxes/src/wizard-source.vala"
	g_return_if_fail (_result_ != NULL);
#line 3812 "wizard-source.c"
	{
		GHashTable* table = NULL;
		GAsyncResult* _tmp0_;
		GHashTable* _tmp1_;
		GList* _tmp2_;
#line 480 "/home/fborges/checkout/gnome-boxes/src/wizard-source.vala"
		_tmp0_ = _result_;
#line 480 "/home/fborges/checkout/gnome-boxes/src/wizard-source.vala"
		_tmp1_ = boxes_os_database_list_latest_downloadable_oses_finish (_data92_->os_db, _tmp0_, &_inner_error_);
#line 480 "/home/fborges/checkout/gnome-boxes/src/wizard-source.vala"
		table = _tmp1_;
#line 480 "/home/fborges/checkout/gnome-boxes/src/wizard-source.vala"
		if (G_UNLIKELY (_inner_error_ != NULL)) {
#line 480 "/home/fborges/checkout/gnome-boxes/src/wizard-source.vala"
			if (_inner_error_->domain == BOXES_OS_DATABASE_ERROR) {
#line 3828 "wizard-source.c"
				goto __catch134_boxes_os_database_error;
			}
#line 480 "/home/fborges/checkout/gnome-boxes/src/wizard-source.vala"
			g_critical ("file %s: line %d: unexpected error: %s (%s, %d)", __FILE__, __LINE__, _inner_error_->message, g_quark_to_string (_inner_error_->domain), _inner_error_->code);
#line 480 "/home/fborges/checkout/gnome-boxes/src/wizard-source.vala"
			g_clear_error (&_inner_error_);
#line 480 "/home/fborges/checkout/gnome-boxes/src/wizard-source.vala"
			return;
#line 3837 "wizard-source.c"
		}
#line 482 "/home/fborges/checkout/gnome-boxes/src/wizard-source.vala"
		_tmp2_ = g_hash_table_get_values (table);
#line 3841 "wizard-source.c"
		{
			GList* os_collection = NULL;
			GList* os_it = NULL;
#line 482 "/home/fborges/checkout/gnome-boxes/src/wizard-source.vala"
			os_collection = _tmp2_;
#line 482 "/home/fborges/checkout/gnome-boxes/src/wizard-source.vala"
			for (os_it = os_collection; os_it != NULL; os_it = os_it->next) {
#line 3849 "wizard-source.c"
				OsinfoOs* os = NULL;
#line 482 "/home/fborges/checkout/gnome-boxes/src/wizard-source.vala"
				os = (OsinfoOs*) os_it->data;
#line 3853 "wizard-source.c"
				{
					OsinfoOs* _tmp3_;
#line 483 "/home/fborges/checkout/gnome-boxes/src/wizard-source.vala"
					_tmp3_ = os;
#line 483 "/home/fborges/checkout/gnome-boxes/src/wizard-source.vala"
					g_list_store_insert_sorted (_data92_->available_downloads_model, (GObject*) _tmp3_, ______lambda75__gcompare_data_func, self);
#line 3860 "wizard-source.c"
				}
			}
#line 482 "/home/fborges/checkout/gnome-boxes/src/wizard-source.vala"
			_g_list_free0 (os_collection);
#line 3865 "wizard-source.c"
		}
#line 479 "/home/fborges/checkout/gnome-boxes/src/wizard-source.vala"
		_g_hash_table_unref0 (table);
#line 3869 "wizard-source.c"
	}
	goto __finally134;
	__catch134_boxes_os_database_error:
	{
		GError* _error_ = NULL;
		GError* _tmp4_;
		const gchar* _tmp5_;
#line 479 "/home/fborges/checkout/gnome-boxes/src/wizard-source.vala"
		_error_ = _inner_error_;
#line 479 "/home/fborges/checkout/gnome-boxes/src/wizard-source.vala"
		_inner_error_ = NULL;
#line 497 "/home/fborges/checkout/gnome-boxes/src/wizard-source.vala"
		_tmp4_ = _error_;
#line 497 "/home/fborges/checkout/gnome-boxes/src/wizard-source.vala"
		_tmp5_ = _tmp4_->message;
#line 497 "/home/fborges/checkout/gnome-boxes/src/wizard-source.vala"
		g_debug ("wizard-source.vala:497: Failed to populate the list of downloadable OS" \
"es: %s", _tmp5_);
#line 479 "/home/fborges/checkout/gnome-boxes/src/wizard-source.vala"
		_g_error_free0 (_error_);
#line 3889 "wizard-source.c"
	}
	__finally134:
#line 479 "/home/fborges/checkout/gnome-boxes/src/wizard-source.vala"
	if (G_UNLIKELY (_inner_error_ != NULL)) {
#line 479 "/home/fborges/checkout/gnome-boxes/src/wizard-source.vala"
		g_critical ("file %s: line %d: uncaught error: %s (%s, %d)", __FILE__, __LINE__, _inner_error_->message, g_quark_to_string (_inner_error_->domain), _inner_error_->code);
#line 479 "/home/fborges/checkout/gnome-boxes/src/wizard-source.vala"
		g_clear_error (&_inner_error_);
#line 479 "/home/fborges/checkout/gnome-boxes/src/wizard-source.vala"
		return;
#line 3900 "wizard-source.c"
	}
}


static void ___lambda74__gasync_ready_callback (GObject* source_object, GAsyncResult* res, gpointer self) {
#line 478 "/home/fborges/checkout/gnome-boxes/src/wizard-source.vala"
	__lambda74_ (self, source_object, res);
#line 478 "/home/fborges/checkout/gnome-boxes/src/wizard-source.vala"
	block92_data_unref (self);
#line 3910 "wizard-source.c"
}


static gboolean ___lambda77_ (BoxesWizardSource* self, GtkEntryCompletion* store, const gchar* key, GtkTreeIter* iter) {
	gboolean result = FALSE;
	gchar* url = NULL;
	GtkListStore* _tmp0_;
	GtkTreeIter _tmp1_;
	const gchar* _tmp2_;
	gboolean _tmp3_;
#line 509 "/home/fborges/checkout/gnome-boxes/src/wizard-source.vala"
	g_return_val_if_fail (store != NULL, FALSE);
#line 509 "/home/fborges/checkout/gnome-boxes/src/wizard-source.vala"
	g_return_val_if_fail (key != NULL, FALSE);
#line 509 "/home/fborges/checkout/gnome-boxes/src/wizard-source.vala"
	g_return_val_if_fail (iter != NULL, FALSE);
#line 512 "/home/fborges/checkout/gnome-boxes/src/wizard-source.vala"
	_tmp0_ = self->priv->media_urls_store;
#line 512 "/home/fborges/checkout/gnome-boxes/src/wizard-source.vala"
	_tmp1_ = *iter;
#line 512 "/home/fborges/checkout/gnome-boxes/src/wizard-source.vala"
	gtk_tree_model_get ((GtkTreeModel*) _tmp0_, &_tmp1_, BOXES_OS_DATABASE_MEDIA_UR_LS_COLUMNS_URL, &url, -1);
#line 514 "/home/fborges/checkout/gnome-boxes/src/wizard-source.vala"
	_tmp2_ = key;
#line 514 "/home/fborges/checkout/gnome-boxes/src/wizard-source.vala"
	_tmp3_ = string_contains (url, _tmp2_);
#line 514 "/home/fborges/checkout/gnome-boxes/src/wizard-source.vala"
	result = _tmp3_;
#line 514 "/home/fborges/checkout/gnome-boxes/src/wizard-source.vala"
	_g_free0 (url);
#line 514 "/home/fborges/checkout/gnome-boxes/src/wizard-source.vala"
	return result;
#line 3943 "wizard-source.c"
}


static gboolean ____lambda77__gtk_entry_completion_match_func (GtkEntryCompletion* completion, const gchar* key, GtkTreeIter* iter, gpointer self) {
	gboolean result;
	result = ___lambda77_ ((BoxesWizardSource*) self, completion, key, iter);
#line 509 "/home/fborges/checkout/gnome-boxes/src/wizard-source.vala"
	return result;
#line 3952 "wizard-source.c"
}


static void __lambda76_ (Block92Data* _data92_, GObject* db, GAsyncResult* _result_) {
	BoxesWizardSource* self;
	GError * _inner_error_ = NULL;
#line 501 "/home/fborges/checkout/gnome-boxes/src/wizard-source.vala"
	self = _data92_->self;
#line 501 "/home/fborges/checkout/gnome-boxes/src/wizard-source.vala"
	g_return_if_fail (_result_ != NULL);
#line 3963 "wizard-source.c"
	{
		GtkListStore* _tmp0_ = NULL;
		GAsyncResult* _tmp1_;
		GtkListStore* _tmp2_;
		GtkListStore* _tmp3_;
		GtkEntryCompletion* completion = NULL;
		GtkEntryCompletion* _tmp4_;
		GtkEntryCompletion* _tmp5_;
		GtkEntryCompletion* _tmp6_;
		GtkListStore* _tmp7_;
		GtkCellRendererText* cell = NULL;
		GtkEntryCompletion* _tmp8_;
		GList* _tmp9_;
		GList* _tmp10_;
		gconstpointer _tmp11_;
		GtkCellRenderer* _tmp12_;
		GtkCellRendererText* _tmp13_;
		GtkCellRendererText* _tmp14_;
		GtkEntryCompletion* _tmp15_;
		GtkEntry* _tmp16_;
		GtkEntryCompletion* _tmp17_;
#line 503 "/home/fborges/checkout/gnome-boxes/src/wizard-source.vala"
		_tmp1_ = _result_;
#line 503 "/home/fborges/checkout/gnome-boxes/src/wizard-source.vala"
		_tmp2_ = boxes_os_database_get_all_media_urls_as_store_finish (_data92_->os_db, _tmp1_, &_inner_error_);
#line 503 "/home/fborges/checkout/gnome-boxes/src/wizard-source.vala"
		_tmp0_ = _tmp2_;
#line 503 "/home/fborges/checkout/gnome-boxes/src/wizard-source.vala"
		if (G_UNLIKELY (_inner_error_ != NULL)) {
#line 503 "/home/fborges/checkout/gnome-boxes/src/wizard-source.vala"
			if (_inner_error_->domain == BOXES_OS_DATABASE_ERROR) {
#line 3995 "wizard-source.c"
				goto __catch135_boxes_os_database_error;
			}
#line 503 "/home/fborges/checkout/gnome-boxes/src/wizard-source.vala"
			g_critical ("file %s: line %d: unexpected error: %s (%s, %d)", __FILE__, __LINE__, _inner_error_->message, g_quark_to_string (_inner_error_->domain), _inner_error_->code);
#line 503 "/home/fborges/checkout/gnome-boxes/src/wizard-source.vala"
			g_clear_error (&_inner_error_);
#line 503 "/home/fborges/checkout/gnome-boxes/src/wizard-source.vala"
			return;
#line 4004 "wizard-source.c"
		}
#line 503 "/home/fborges/checkout/gnome-boxes/src/wizard-source.vala"
		_tmp3_ = _tmp0_;
#line 503 "/home/fborges/checkout/gnome-boxes/src/wizard-source.vala"
		_tmp0_ = NULL;
#line 503 "/home/fborges/checkout/gnome-boxes/src/wizard-source.vala"
		_g_object_unref0 (self->priv->media_urls_store);
#line 503 "/home/fborges/checkout/gnome-boxes/src/wizard-source.vala"
		self->priv->media_urls_store = _tmp3_;
#line 504 "/home/fborges/checkout/gnome-boxes/src/wizard-source.vala"
		_tmp4_ = gtk_entry_completion_new ();
#line 504 "/home/fborges/checkout/gnome-boxes/src/wizard-source.vala"
		completion = _tmp4_;
#line 505 "/home/fborges/checkout/gnome-boxes/src/wizard-source.vala"
		_tmp5_ = completion;
#line 505 "/home/fborges/checkout/gnome-boxes/src/wizard-source.vala"
		gtk_entry_completion_set_text_column (_tmp5_, (gint) BOXES_OS_DATABASE_MEDIA_UR_LS_COLUMNS_URL);
#line 506 "/home/fborges/checkout/gnome-boxes/src/wizard-source.vala"
		_tmp6_ = completion;
#line 506 "/home/fborges/checkout/gnome-boxes/src/wizard-source.vala"
		_tmp7_ = self->priv->media_urls_store;
#line 506 "/home/fborges/checkout/gnome-boxes/src/wizard-source.vala"
		gtk_entry_completion_set_model (_tmp6_, (GtkTreeModel*) _tmp7_);
#line 507 "/home/fborges/checkout/gnome-boxes/src/wizard-source.vala"
		_tmp8_ = completion;
#line 507 "/home/fborges/checkout/gnome-boxes/src/wizard-source.vala"
		_tmp9_ = gtk_cell_layout_get_cells ((GtkCellLayout*) _tmp8_);
#line 507 "/home/fborges/checkout/gnome-boxes/src/wizard-source.vala"
		_tmp10_ = _tmp9_;
#line 507 "/home/fborges/checkout/gnome-boxes/src/wizard-source.vala"
		_tmp11_ = g_list_nth_data (_tmp10_, (guint) 0);
#line 507 "/home/fborges/checkout/gnome-boxes/src/wizard-source.vala"
		_tmp12_ = (GtkCellRenderer*) _tmp11_;
#line 507 "/home/fborges/checkout/gnome-boxes/src/wizard-source.vala"
		_tmp13_ = G_TYPE_CHECK_INSTANCE_TYPE (_tmp12_, gtk_cell_renderer_text_get_type ()) ? ((GtkCellRendererText*) _tmp12_) : NULL;
#line 507 "/home/fborges/checkout/gnome-boxes/src/wizard-source.vala"
		_g_list_free0 (_tmp10_);
#line 507 "/home/fborges/checkout/gnome-boxes/src/wizard-source.vala"
		cell = _tmp13_;
#line 508 "/home/fborges/checkout/gnome-boxes/src/wizard-source.vala"
		_tmp14_ = cell;
#line 508 "/home/fborges/checkout/gnome-boxes/src/wizard-source.vala"
		g_object_set (_tmp14_, "ellipsize", PANGO_ELLIPSIZE_MIDDLE, NULL);
#line 509 "/home/fborges/checkout/gnome-boxes/src/wizard-source.vala"
		_tmp15_ = completion;
#line 509 "/home/fborges/checkout/gnome-boxes/src/wizard-source.vala"
		gtk_entry_completion_set_match_func (_tmp15_, ____lambda77__gtk_entry_completion_match_func, g_object_ref (self), g_object_unref);
#line 516 "/home/fborges/checkout/gnome-boxes/src/wizard-source.vala"
		_tmp16_ = self->url_entry;
#line 516 "/home/fborges/checkout/gnome-boxes/src/wizard-source.vala"
		_tmp17_ = completion;
#line 516 "/home/fborges/checkout/gnome-boxes/src/wizard-source.vala"
		gtk_entry_set_completion (_tmp16_, _tmp17_);
#line 502 "/home/fborges/checkout/gnome-boxes/src/wizard-source.vala"
		_g_object_unref0 (completion);
#line 502 "/home/fborges/checkout/gnome-boxes/src/wizard-source.vala"
		_g_object_unref0 (_tmp0_);
#line 4062 "wizard-source.c"
	}
	goto __finally135;
	__catch135_boxes_os_database_error:
	{
		GError* _error_ = NULL;
		GError* _tmp18_;
		const gchar* _tmp19_;
#line 502 "/home/fborges/checkout/gnome-boxes/src/wizard-source.vala"
		_error_ = _inner_error_;
#line 502 "/home/fborges/checkout/gnome-boxes/src/wizard-source.vala"
		_inner_error_ = NULL;
#line 518 "/home/fborges/checkout/gnome-boxes/src/wizard-source.vala"
		_tmp18_ = _error_;
#line 518 "/home/fborges/checkout/gnome-boxes/src/wizard-source.vala"
		_tmp19_ = _tmp18_->message;
#line 518 "/home/fborges/checkout/gnome-boxes/src/wizard-source.vala"
		g_debug ("wizard-source.vala:518: Failed to get all known media URLs: %s", _tmp19_);
#line 502 "/home/fborges/checkout/gnome-boxes/src/wizard-source.vala"
		_g_error_free0 (_error_);
#line 4082 "wizard-source.c"
	}
	__finally135:
#line 502 "/home/fborges/checkout/gnome-boxes/src/wizard-source.vala"
	if (G_UNLIKELY (_inner_error_ != NULL)) {
#line 502 "/home/fborges/checkout/gnome-boxes/src/wizard-source.vala"
		g_critical ("file %s: line %d: uncaught error: %s (%s, %d)", __FILE__, __LINE__, _inner_error_->message, g_quark_to_string (_inner_error_->domain), _inner_error_->code);
#line 502 "/home/fborges/checkout/gnome-boxes/src/wizard-source.vala"
		g_clear_error (&_inner_error_);
#line 502 "/home/fborges/checkout/gnome-boxes/src/wizard-source.vala"
		return;
#line 4093 "wizard-source.c"
	}
}


static void ___lambda76__gasync_ready_callback (GObject* source_object, GAsyncResult* res, gpointer self) {
#line 501 "/home/fborges/checkout/gnome-boxes/src/wizard-source.vala"
	__lambda76_ (self, source_object, res);
#line 501 "/home/fborges/checkout/gnome-boxes/src/wizard-source.vala"
	block92_data_unref (self);
#line 4103 "wizard-source.c"
}


static void __lambda79_ (BoxesWizardSource* self, GObject* obj, GAsyncResult* res) {
	GAsyncResult* _tmp0_;
	GdkPixbuf* pixbuf = NULL;
	GtkImage* _tmp1_;
	GdkPixbuf* _tmp2_;
	GdkPixbuf* _tmp3_;
	GtkImage* _tmp4_;
#line 543 "/home/fborges/checkout/gnome-boxes/src/wizard-source.vala"
	g_return_if_fail (res != NULL);
#line 544 "/home/fborges/checkout/gnome-boxes/src/wizard-source.vala"
	_tmp0_ = res;
#line 544 "/home/fborges/checkout/gnome-boxes/src/wizard-source.vala"
	boxes_downloader_fetch_os_logo_finish (_tmp0_);
#line 545 "/home/fborges/checkout/gnome-boxes/src/wizard-source.vala"
	_tmp1_ = self->priv->install_rhel_image;
#line 545 "/home/fborges/checkout/gnome-boxes/src/wizard-source.vala"
	g_object_get (_tmp1_, "pixbuf", &_tmp2_, NULL);
#line 545 "/home/fborges/checkout/gnome-boxes/src/wizard-source.vala"
	_tmp3_ = _tmp2_;
#line 545 "/home/fborges/checkout/gnome-boxes/src/wizard-source.vala"
	pixbuf = _tmp3_;
#line 546 "/home/fborges/checkout/gnome-boxes/src/wizard-source.vala"
	_tmp4_ = self->priv->install_rhel_image;
#line 546 "/home/fborges/checkout/gnome-boxes/src/wizard-source.vala"
	gtk_widget_set_visible ((GtkWidget*) _tmp4_, pixbuf != NULL);
#line 543 "/home/fborges/checkout/gnome-boxes/src/wizard-source.vala"
	_g_object_unref0 (pixbuf);
#line 4134 "wizard-source.c"
}


static void ___lambda79__gasync_ready_callback (GObject* source_object, GAsyncResult* res, gpointer self) {
#line 543 "/home/fborges/checkout/gnome-boxes/src/wizard-source.vala"
	__lambda79_ ((BoxesWizardSource*) self, source_object, res);
#line 543 "/home/fborges/checkout/gnome-boxes/src/wizard-source.vala"
	g_object_unref (self);
#line 4143 "wizard-source.c"
}


static void __lambda78_ (Block92Data* _data92_, GObject* obj, GAsyncResult* res) {
	BoxesWizardSource* self;
	GtkImage* _tmp6_;
	OsinfoOs* _tmp7_;
	GError * _inner_error_ = NULL;
#line 535 "/home/fborges/checkout/gnome-boxes/src/wizard-source.vala"
	self = _data92_->self;
#line 535 "/home/fborges/checkout/gnome-boxes/src/wizard-source.vala"
	g_return_if_fail (res != NULL);
#line 4156 "wizard-source.c"
	{
		OsinfoOs* _tmp0_ = NULL;
		GAsyncResult* _tmp1_;
		OsinfoOs* _tmp2_;
		OsinfoOs* _tmp3_;
#line 537 "/home/fborges/checkout/gnome-boxes/src/wizard-source.vala"
		_tmp1_ = res;
#line 537 "/home/fborges/checkout/gnome-boxes/src/wizard-source.vala"
		_tmp2_ = boxes_os_database_get_os_by_id_finish (_data92_->os_db, _tmp1_, &_inner_error_);
#line 537 "/home/fborges/checkout/gnome-boxes/src/wizard-source.vala"
		_tmp0_ = _tmp2_;
#line 537 "/home/fborges/checkout/gnome-boxes/src/wizard-source.vala"
		if (G_UNLIKELY (_inner_error_ != NULL)) {
#line 537 "/home/fborges/checkout/gnome-boxes/src/wizard-source.vala"
			if (_inner_error_->domain == BOXES_OS_DATABASE_ERROR) {
#line 4172 "wizard-source.c"
				goto __catch136_boxes_os_database_error;
			}
#line 537 "/home/fborges/checkout/gnome-boxes/src/wizard-source.vala"
			g_critical ("file %s: line %d: unexpected error: %s (%s, %d)", __FILE__, __LINE__, _inner_error_->message, g_quark_to_string (_inner_error_->domain), _inner_error_->code);
#line 537 "/home/fborges/checkout/gnome-boxes/src/wizard-source.vala"
			g_clear_error (&_inner_error_);
#line 537 "/home/fborges/checkout/gnome-boxes/src/wizard-source.vala"
			return;
#line 4181 "wizard-source.c"
		}
#line 537 "/home/fborges/checkout/gnome-boxes/src/wizard-source.vala"
		_tmp3_ = _tmp0_;
#line 537 "/home/fborges/checkout/gnome-boxes/src/wizard-source.vala"
		_tmp0_ = NULL;
#line 537 "/home/fborges/checkout/gnome-boxes/src/wizard-source.vala"
		_g_object_unref0 (self->priv->rhel_os);
#line 537 "/home/fborges/checkout/gnome-boxes/src/wizard-source.vala"
		self->priv->rhel_os = _tmp3_;
#line 536 "/home/fborges/checkout/gnome-boxes/src/wizard-source.vala"
		_g_object_unref0 (_tmp0_);
#line 4193 "wizard-source.c"
	}
	goto __finally136;
	__catch136_boxes_os_database_error:
	{
		GError* _error_ = NULL;
		GError* _tmp4_;
		const gchar* _tmp5_;
#line 536 "/home/fborges/checkout/gnome-boxes/src/wizard-source.vala"
		_error_ = _inner_error_;
#line 536 "/home/fborges/checkout/gnome-boxes/src/wizard-source.vala"
		_inner_error_ = NULL;
#line 539 "/home/fborges/checkout/gnome-boxes/src/wizard-source.vala"
		_tmp4_ = _error_;
#line 539 "/home/fborges/checkout/gnome-boxes/src/wizard-source.vala"
		_tmp5_ = _tmp4_->message;
#line 539 "/home/fborges/checkout/gnome-boxes/src/wizard-source.vala"
		g_warning ("wizard-source.vala:539: Failed to find OS with ID '%s': %s", _data92_->rhel_id, _tmp5_);
#line 540 "/home/fborges/checkout/gnome-boxes/src/wizard-source.vala"
		_g_error_free0 (_error_);
#line 540 "/home/fborges/checkout/gnome-boxes/src/wizard-source.vala"
		return;
#line 4215 "wizard-source.c"
	}
	__finally136:
#line 536 "/home/fborges/checkout/gnome-boxes/src/wizard-source.vala"
	if (G_UNLIKELY (_inner_error_ != NULL)) {
#line 536 "/home/fborges/checkout/gnome-boxes/src/wizard-source.vala"
		g_critical ("file %s: line %d: uncaught error: %s (%s, %d)", __FILE__, __LINE__, _inner_error_->message, g_quark_to_string (_inner_error_->domain), _inner_error_->code);
#line 536 "/home/fborges/checkout/gnome-boxes/src/wizard-source.vala"
		g_clear_error (&_inner_error_);
#line 536 "/home/fborges/checkout/gnome-boxes/src/wizard-source.vala"
		return;
#line 4226 "wizard-source.c"
	}
#line 543 "/home/fborges/checkout/gnome-boxes/src/wizard-source.vala"
	_tmp6_ = self->priv->install_rhel_image;
#line 543 "/home/fborges/checkout/gnome-boxes/src/wizard-source.vala"
	_tmp7_ = self->priv->rhel_os;
#line 543 "/home/fborges/checkout/gnome-boxes/src/wizard-source.vala"
	boxes_downloader_fetch_os_logo (_tmp6_, _tmp7_, 64, ___lambda79__gasync_ready_callback, g_object_ref (self));
#line 4234 "wizard-source.c"
}


static void ___lambda78__gasync_ready_callback (GObject* source_object, GAsyncResult* res, gpointer self) {
#line 535 "/home/fborges/checkout/gnome-boxes/src/wizard-source.vala"
	__lambda78_ (self, source_object, res);
#line 535 "/home/fborges/checkout/gnome-boxes/src/wizard-source.vala"
	block92_data_unref (self);
#line 4243 "wizard-source.c"
}


void boxes_wizard_source_setup_ui (BoxesWizardSource* self, BoxesAppWindow* window) {
	Block92Data* _data92_;
	BoxesAppWindow* _tmp0_;
	BoxesAppWindow* _tmp1_;
	BoxesAppWindow* _tmp2_;
	BoxesMediaManager* _tmp3_;
	BoxesOSDatabase* _tmp4_;
	BoxesOSDatabase* _tmp5_;
	BoxesOSDatabase* _tmp6_;
	GListStore* _tmp7_;
	GtkListBox* _tmp8_;
	GtkListBox* _tmp9_;
	gchar* _tmp10_;
#line 444 "/home/fborges/checkout/gnome-boxes/src/wizard-source.vala"
	g_return_if_fail (self != NULL);
#line 444 "/home/fborges/checkout/gnome-boxes/src/wizard-source.vala"
	g_return_if_fail (window != NULL);
#line 444 "/home/fborges/checkout/gnome-boxes/src/wizard-source.vala"
	_data92_ = g_slice_new0 (Block92Data);
#line 444 "/home/fborges/checkout/gnome-boxes/src/wizard-source.vala"
	_data92_->_ref_count_ = 1;
#line 444 "/home/fborges/checkout/gnome-boxes/src/wizard-source.vala"
	_data92_->self = g_object_ref (self);
#line 445 "/home/fborges/checkout/gnome-boxes/src/wizard-source.vala"
	_tmp0_ = window;
#line 445 "/home/fborges/checkout/gnome-boxes/src/wizard-source.vala"
	_vala_assert (_tmp0_ != NULL, "window != null");
#line 447 "/home/fborges/checkout/gnome-boxes/src/wizard-source.vala"
	_tmp1_ = window;
#line 447 "/home/fborges/checkout/gnome-boxes/src/wizard-source.vala"
	_tmp2_ = _g_object_ref0 (_tmp1_);
#line 447 "/home/fborges/checkout/gnome-boxes/src/wizard-source.vala"
	_g_object_unref0 (self->priv->window);
#line 447 "/home/fborges/checkout/gnome-boxes/src/wizard-source.vala"
	self->priv->window = _tmp2_;
#line 449 "/home/fborges/checkout/gnome-boxes/src/wizard-source.vala"
	_tmp3_ = self->media_manager;
#line 449 "/home/fborges/checkout/gnome-boxes/src/wizard-source.vala"
	_tmp4_ = boxes_media_manager_get_os_db (_tmp3_);
#line 449 "/home/fborges/checkout/gnome-boxes/src/wizard-source.vala"
	_tmp5_ = _tmp4_;
#line 449 "/home/fborges/checkout/gnome-boxes/src/wizard-source.vala"
	_tmp6_ = _g_object_ref0 (_tmp5_);
#line 449 "/home/fborges/checkout/gnome-boxes/src/wizard-source.vala"
	_data92_->os_db = _tmp6_;
#line 451 "/home/fborges/checkout/gnome-boxes/src/wizard-source.vala"
	_tmp7_ = g_list_store_new (osinfo_os_get_type ());
#line 451 "/home/fborges/checkout/gnome-boxes/src/wizard-source.vala"
	_data92_->available_downloads_model = _tmp7_;
#line 452 "/home/fborges/checkout/gnome-boxes/src/wizard-source.vala"
	_tmp8_ = self->priv->available_downloads_listbox;
#line 452 "/home/fborges/checkout/gnome-boxes/src/wizard-source.vala"
	gtk_list_box_bind_model (_tmp8_, (GListModel*) _data92_->available_downloads_model, ___lambda64__gtk_list_box_create_widget_func, g_object_ref (self), g_object_unref);
#line 465 "/home/fborges/checkout/gnome-boxes/src/wizard-source.vala"
	_tmp9_ = self->priv->available_downloads_listbox;
#line 465 "/home/fborges/checkout/gnome-boxes/src/wizard-source.vala"
	g_signal_connect_object (_tmp9_, "row-activated", (GCallback) ___lambda73__gtk_list_box_row_activated, self, 0);
#line 478 "/home/fborges/checkout/gnome-boxes/src/wizard-source.vala"
	boxes_os_database_list_latest_downloadable_oses (_data92_->os_db, ___lambda74__gasync_ready_callback, block92_data_ref (_data92_));
#line 501 "/home/fborges/checkout/gnome-boxes/src/wizard-source.vala"
	boxes_os_database_get_all_media_urls_as_store (_data92_->os_db, ___lambda76__gasync_ready_callback, block92_data_ref (_data92_));
#line 533 "/home/fborges/checkout/gnome-boxes/src/wizard-source.vala"
	_tmp10_ = g_strdup ("http://redhat.com/rhel/7.4");
#line 533 "/home/fborges/checkout/gnome-boxes/src/wizard-source.vala"
	_data92_->rhel_id = _tmp10_;
#line 535 "/home/fborges/checkout/gnome-boxes/src/wizard-source.vala"
	boxes_os_database_get_os_by_id (_data92_->os_db, _data92_->rhel_id, ___lambda78__gasync_ready_callback, block92_data_ref (_data92_));
#line 444 "/home/fborges/checkout/gnome-boxes/src/wizard-source.vala"
	block92_data_unref (_data92_);
#line 444 "/home/fborges/checkout/gnome-boxes/src/wizard-source.vala"
	_data92_ = NULL;
#line 4318 "wizard-source.c"
}


void boxes_wizard_source_cleanup (BoxesWizardSource* self) {
	BoxesSourcePage _tmp0_;
	BoxesSourcePage _tmp1_;
	GCancellable* _tmp2_;
#line 551 "/home/fborges/checkout/gnome-boxes/src/wizard-source.vala"
	g_return_if_fail (self != NULL);
#line 552 "/home/fborges/checkout/gnome-boxes/src/wizard-source.vala"
	boxes_wizard_source_set_filename (self, NULL);
#line 553 "/home/fborges/checkout/gnome-boxes/src/wizard-source.vala"
	boxes_wizard_source_set_install_media (self, NULL);
#line 554 "/home/fborges/checkout/gnome-boxes/src/wizard-source.vala"
	self->libvirt_sys_import = FALSE;
#line 555 "/home/fborges/checkout/gnome-boxes/src/wizard-source.vala"
	boxes_wizard_source_set_selected (self, NULL);
#line 556 "/home/fborges/checkout/gnome-boxes/src/wizard-source.vala"
	_tmp0_ = boxes_wizard_source_get_page (self);
#line 556 "/home/fborges/checkout/gnome-boxes/src/wizard-source.vala"
	_tmp1_ = _tmp0_;
#line 556 "/home/fborges/checkout/gnome-boxes/src/wizard-source.vala"
	if (_tmp1_ != BOXES_SOURCE_PAGE_URL) {
#line 557 "/home/fborges/checkout/gnome-boxes/src/wizard-source.vala"
		boxes_wizard_source_set_uri (self, "");
#line 4344 "wizard-source.c"
	}
#line 559 "/home/fborges/checkout/gnome-boxes/src/wizard-source.vala"
	_tmp2_ = self->priv->rhel_cancellable;
#line 559 "/home/fborges/checkout/gnome-boxes/src/wizard-source.vala"
	if (_tmp2_ != NULL) {
#line 4350 "wizard-source.c"
		GCancellable* _tmp3_;
#line 560 "/home/fborges/checkout/gnome-boxes/src/wizard-source.vala"
		_tmp3_ = self->priv->rhel_cancellable;
#line 560 "/home/fborges/checkout/gnome-boxes/src/wizard-source.vala"
		g_cancellable_cancel (_tmp3_);
#line 561 "/home/fborges/checkout/gnome-boxes/src/wizard-source.vala"
		_g_object_unref0 (self->priv->rhel_cancellable);
#line 561 "/home/fborges/checkout/gnome-boxes/src/wizard-source.vala"
		self->priv->rhel_cancellable = NULL;
#line 4360 "wizard-source.c"
	}
}


static void boxes_wizard_source_on_enter_url_button_clicked (BoxesWizardSource* self) {
#line 566 "/home/fborges/checkout/gnome-boxes/src/wizard-source.vala"
	g_return_if_fail (self != NULL);
#line 567 "/home/fborges/checkout/gnome-boxes/src/wizard-source.vala"
	boxes_wizard_source_set_page (self, BOXES_SOURCE_PAGE_URL);
#line 4370 "wizard-source.c"
}


static void _boxes_wizard_source_on_enter_url_button_clicked_gtk_button_clicked (GtkButton* _sender, gpointer self) {
#line 309 "/home/fborges/checkout/gnome-boxes/src/wizard-source.vala"
	boxes_wizard_source_on_enter_url_button_clicked ((BoxesWizardSource*) self);
#line 4377 "wizard-source.c"
}


static void boxes_wizard_source_on_url_entry_activated (BoxesWizardSource* self) {
#line 571 "/home/fborges/checkout/gnome-boxes/src/wizard-source.vala"
	g_return_if_fail (self != NULL);
#line 572 "/home/fborges/checkout/gnome-boxes/src/wizard-source.vala"
	g_signal_emit (self, boxes_wizard_source_signals[BOXES_WIZARD_SOURCE_ACTIVATED_SIGNAL], 0);
#line 4386 "wizard-source.c"
}


static void _boxes_wizard_source_on_url_entry_activated_gtk_entry_activate (GtkEntry* _sender, gpointer self) {
#line 309 "/home/fborges/checkout/gnome-boxes/src/wizard-source.vala"
	boxes_wizard_source_on_url_entry_activated ((BoxesWizardSource*) self);
#line 4393 "wizard-source.c"
}


static void boxes_wizard_source_on_url_back_button_clicked (BoxesWizardSource* self) {
#line 576 "/home/fborges/checkout/gnome-boxes/src/wizard-source.vala"
	g_return_if_fail (self != NULL);
#line 577 "/home/fborges/checkout/gnome-boxes/src/wizard-source.vala"
	boxes_wizard_source_set_selected (self, NULL);
#line 578 "/home/fborges/checkout/gnome-boxes/src/wizard-source.vala"
	boxes_wizard_source_set_page (self, BOXES_SOURCE_PAGE_MAIN);
#line 4404 "wizard-source.c"
}


static void _boxes_wizard_source_on_url_back_button_clicked_gtk_button_clicked (GtkButton* _sender, gpointer self) {
#line 309 "/home/fborges/checkout/gnome-boxes/src/wizard-source.vala"
	boxes_wizard_source_on_url_back_button_clicked ((BoxesWizardSource*) self);
#line 4411 "wizard-source.c"
}


static void boxes_wizard_source_add_media_entries_data_free (gpointer _data) {
	BoxesWizardSourceAddMediaEntriesData* _data_;
	_data_ = _data;
#line 309 "/home/fborges/checkout/gnome-boxes/src/wizard-source.vala"
	_g_object_unref0 (_data_->self);
#line 309 "/home/fborges/checkout/gnome-boxes/src/wizard-source.vala"
	g_slice_free (BoxesWizardSourceAddMediaEntriesData, _data_);
#line 4422 "wizard-source.c"
}


static void boxes_wizard_source_add_media_entries (BoxesWizardSource* self, GAsyncReadyCallback _callback_, gpointer _user_data_) {
	BoxesWizardSourceAddMediaEntriesData* _data_;
	BoxesWizardSource* _tmp0_;
#line 309 "/home/fborges/checkout/gnome-boxes/src/wizard-source.vala"
	_data_ = g_slice_new0 (BoxesWizardSourceAddMediaEntriesData);
#line 309 "/home/fborges/checkout/gnome-boxes/src/wizard-source.vala"
	_data_->_async_result = g_task_new (G_OBJECT (self), NULL, _callback_, _user_data_);
#line 309 "/home/fborges/checkout/gnome-boxes/src/wizard-source.vala"
	g_task_set_task_data (_data_->_async_result, _data_, boxes_wizard_source_add_media_entries_data_free);
#line 309 "/home/fborges/checkout/gnome-boxes/src/wizard-source.vala"
	_tmp0_ = _g_object_ref0 (self);
#line 309 "/home/fborges/checkout/gnome-boxes/src/wizard-source.vala"
	_data_->self = _tmp0_;
#line 309 "/home/fborges/checkout/gnome-boxes/src/wizard-source.vala"
	boxes_wizard_source_add_media_entries_co (_data_);
#line 4441 "wizard-source.c"
}


static void boxes_wizard_source_add_media_entries_finish (BoxesWizardSource* self, GAsyncResult* _res_) {
	BoxesWizardSourceAddMediaEntriesData* _data_;
#line 309 "/home/fborges/checkout/gnome-boxes/src/wizard-source.vala"
	_data_ = g_task_propagate_pointer (G_TASK (_res_), NULL);
#line 4449 "wizard-source.c"
}


static void boxes_wizard_source_add_media_entries_ready (GObject* source_object, GAsyncResult* _res_, gpointer _user_data_) {
	BoxesWizardSourceAddMediaEntriesData* _data_;
#line 582 "/home/fborges/checkout/gnome-boxes/src/wizard-source.vala"
	_data_ = _user_data_;
#line 582 "/home/fborges/checkout/gnome-boxes/src/wizard-source.vala"
	_data_->_source_object_ = source_object;
#line 582 "/home/fborges/checkout/gnome-boxes/src/wizard-source.vala"
	_data_->_res_ = _res_;
#line 582 "/home/fborges/checkout/gnome-boxes/src/wizard-source.vala"
	boxes_wizard_source_add_media_entries_co (_data_);
#line 4463 "wizard-source.c"
}


static gboolean boxes_wizard_source_add_media_entries_co (BoxesWizardSourceAddMediaEntriesData* _data_) {
#line 581 "/home/fborges/checkout/gnome-boxes/src/wizard-source.vala"
	switch (_data_->_state_) {
#line 581 "/home/fborges/checkout/gnome-boxes/src/wizard-source.vala"
		case 0:
#line 4472 "wizard-source.c"
		goto _state_0;
#line 581 "/home/fborges/checkout/gnome-boxes/src/wizard-source.vala"
		case 1:
#line 4476 "wizard-source.c"
		goto _state_1;
		default:
#line 581 "/home/fborges/checkout/gnome-boxes/src/wizard-source.vala"
		g_assert_not_reached ();
#line 4481 "wizard-source.c"
	}
	_state_0:
#line 582 "/home/fborges/checkout/gnome-boxes/src/wizard-source.vala"
	_data_->_tmp0_ = _data_->self->media_manager;
#line 582 "/home/fborges/checkout/gnome-boxes/src/wizard-source.vala"
	_data_->_state_ = 1;
#line 582 "/home/fborges/checkout/gnome-boxes/src/wizard-source.vala"
	boxes_media_manager_list_installer_medias (_data_->_tmp0_, boxes_wizard_source_add_media_entries_ready, _data_);
#line 582 "/home/fborges/checkout/gnome-boxes/src/wizard-source.vala"
	return FALSE;
#line 4492 "wizard-source.c"
	_state_1:
#line 582 "/home/fborges/checkout/gnome-boxes/src/wizard-source.vala"
	_data_->_tmp1_ = boxes_media_manager_list_installer_medias_finish (_data_->_tmp0_, _data_->_res_);
#line 582 "/home/fborges/checkout/gnome-boxes/src/wizard-source.vala"
	_data_->medias = _data_->_tmp1_;
#line 584 "/home/fborges/checkout/gnome-boxes/src/wizard-source.vala"
	_data_->_tmp2_ = _data_->self->priv->media_vbox;
#line 584 "/home/fborges/checkout/gnome-boxes/src/wizard-source.vala"
	_data_->_tmp3_ = gtk_container_get_children ((GtkContainer*) _data_->_tmp2_);
#line 4502 "wizard-source.c"
	{
#line 584 "/home/fborges/checkout/gnome-boxes/src/wizard-source.vala"
		_data_->child_collection = _data_->_tmp3_;
#line 584 "/home/fborges/checkout/gnome-boxes/src/wizard-source.vala"
		for (_data_->child_it = _data_->child_collection; _data_->child_it != NULL; _data_->child_it = _data_->child_it->next) {
#line 584 "/home/fborges/checkout/gnome-boxes/src/wizard-source.vala"
			_data_->child = (GtkWidget*) _data_->child_it->data;
#line 4510 "wizard-source.c"
			{
#line 585 "/home/fborges/checkout/gnome-boxes/src/wizard-source.vala"
				_data_->_tmp4_ = _data_->child;
#line 585 "/home/fborges/checkout/gnome-boxes/src/wizard-source.vala"
				_data_->_tmp5_ = (G_TYPE_CHECK_INSTANCE_TYPE (_data_->_tmp4_, BOXES_TYPE_WIZARD_MEDIA_ENTRY) ? ((BoxesWizardMediaEntry*) _data_->_tmp4_) : NULL)->media;
#line 585 "/home/fborges/checkout/gnome-boxes/src/wizard-source.vala"
				_data_->_tmp6_ = _g_object_ref0 (_data_->_tmp5_);
#line 585 "/home/fborges/checkout/gnome-boxes/src/wizard-source.vala"
				_data_->child_media = _data_->_tmp6_;
#line 587 "/home/fborges/checkout/gnome-boxes/src/wizard-source.vala"
				_data_->obsolete = TRUE;
#line 588 "/home/fborges/checkout/gnome-boxes/src/wizard-source.vala"
				_data_->_tmp7_ = _data_->medias;
#line 4524 "wizard-source.c"
				{
#line 588 "/home/fborges/checkout/gnome-boxes/src/wizard-source.vala"
					_data_->media_collection = _data_->_tmp7_;
#line 588 "/home/fborges/checkout/gnome-boxes/src/wizard-source.vala"
					for (_data_->media_it = _data_->media_collection; _data_->media_it != NULL; _data_->media_it = _data_->media_it->next) {
#line 588 "/home/fborges/checkout/gnome-boxes/src/wizard-source.vala"
						_data_->_tmp8_ = _g_object_ref0 ((BoxesInstallerMedia*) _data_->media_it->data);
#line 588 "/home/fborges/checkout/gnome-boxes/src/wizard-source.vala"
						_data_->media = _data_->_tmp8_;
#line 4534 "wizard-source.c"
						{
#line 589 "/home/fborges/checkout/gnome-boxes/src/wizard-source.vala"
							_data_->_tmp9_ = _data_->child_media;
#line 589 "/home/fborges/checkout/gnome-boxes/src/wizard-source.vala"
							_data_->_tmp10_ = _data_->_tmp9_->device_file;
#line 589 "/home/fborges/checkout/gnome-boxes/src/wizard-source.vala"
							_data_->_tmp11_ = _data_->media;
#line 589 "/home/fborges/checkout/gnome-boxes/src/wizard-source.vala"
							_data_->_tmp12_ = _data_->_tmp11_->device_file;
#line 589 "/home/fborges/checkout/gnome-boxes/src/wizard-source.vala"
							if (g_strcmp0 (_data_->_tmp10_, _data_->_tmp12_) == 0) {
#line 590 "/home/fborges/checkout/gnome-boxes/src/wizard-source.vala"
								_data_->obsolete = FALSE;
#line 592 "/home/fborges/checkout/gnome-boxes/src/wizard-source.vala"
								_g_object_unref0 (_data_->media);
#line 592 "/home/fborges/checkout/gnome-boxes/src/wizard-source.vala"
								break;
#line 4552 "wizard-source.c"
							}
#line 588 "/home/fborges/checkout/gnome-boxes/src/wizard-source.vala"
							_g_object_unref0 (_data_->media);
#line 4556 "wizard-source.c"
						}
					}
				}
#line 595 "/home/fborges/checkout/gnome-boxes/src/wizard-source.vala"
				_data_->_tmp13_ = _data_->obsolete;
#line 595 "/home/fborges/checkout/gnome-boxes/src/wizard-source.vala"
				if (_data_->_tmp13_) {
#line 596 "/home/fborges/checkout/gnome-boxes/src/wizard-source.vala"
					_data_->_tmp14_ = _data_->self->priv->media_vbox;
#line 596 "/home/fborges/checkout/gnome-boxes/src/wizard-source.vala"
					_data_->_tmp15_ = _data_->child;
#line 596 "/home/fborges/checkout/gnome-boxes/src/wizard-source.vala"
					gtk_container_remove ((GtkContainer*) _data_->_tmp14_, _data_->_tmp15_);
#line 4570 "wizard-source.c"
				}
#line 584 "/home/fborges/checkout/gnome-boxes/src/wizard-source.vala"
				_g_object_unref0 (_data_->child_media);
#line 4574 "wizard-source.c"
			}
		}
#line 584 "/home/fborges/checkout/gnome-boxes/src/wizard-source.vala"
		_g_list_free0 (_data_->child_collection);
#line 4579 "wizard-source.c"
	}
#line 599 "/home/fborges/checkout/gnome-boxes/src/wizard-source.vala"
	_data_->_tmp16_ = _data_->medias;
#line 4583 "wizard-source.c"
	{
#line 599 "/home/fborges/checkout/gnome-boxes/src/wizard-source.vala"
		_data_->_vala1_media_collection = _data_->_tmp16_;
#line 599 "/home/fborges/checkout/gnome-boxes/src/wizard-source.vala"
		for (_data_->_vala1_media_it = _data_->_vala1_media_collection; _data_->_vala1_media_it != NULL; _data_->_vala1_media_it = _data_->_vala1_media_it->next) {
#line 599 "/home/fborges/checkout/gnome-boxes/src/wizard-source.vala"
			_data_->_tmp17_ = _g_object_ref0 ((BoxesInstallerMedia*) _data_->_vala1_media_it->data);
#line 599 "/home/fborges/checkout/gnome-boxes/src/wizard-source.vala"
			_data_->_vala1_media = _data_->_tmp17_;
#line 4593 "wizard-source.c"
			{
#line 600 "/home/fborges/checkout/gnome-boxes/src/wizard-source.vala"
				_data_->nouveau = TRUE;
#line 601 "/home/fborges/checkout/gnome-boxes/src/wizard-source.vala"
				_data_->_tmp18_ = _data_->self->priv->media_vbox;
#line 601 "/home/fborges/checkout/gnome-boxes/src/wizard-source.vala"
				_data_->_tmp19_ = gtk_container_get_children ((GtkContainer*) _data_->_tmp18_);
#line 4601 "wizard-source.c"
				{
#line 601 "/home/fborges/checkout/gnome-boxes/src/wizard-source.vala"
					_data_->_vala1_child_collection = _data_->_tmp19_;
#line 601 "/home/fborges/checkout/gnome-boxes/src/wizard-source.vala"
					for (_data_->_vala1_child_it = _data_->_vala1_child_collection; _data_->_vala1_child_it != NULL; _data_->_vala1_child_it = _data_->_vala1_child_it->next) {
#line 601 "/home/fborges/checkout/gnome-boxes/src/wizard-source.vala"
						_data_->_vala1_child = (GtkWidget*) _data_->_vala1_child_it->data;
#line 4609 "wizard-source.c"
						{
#line 602 "/home/fborges/checkout/gnome-boxes/src/wizard-source.vala"
							_data_->_tmp20_ = _data_->_vala1_child;
#line 602 "/home/fborges/checkout/gnome-boxes/src/wizard-source.vala"
							_data_->_tmp21_ = (G_TYPE_CHECK_INSTANCE_TYPE (_data_->_tmp20_, BOXES_TYPE_WIZARD_MEDIA_ENTRY) ? ((BoxesWizardMediaEntry*) _data_->_tmp20_) : NULL)->media;
#line 602 "/home/fborges/checkout/gnome-boxes/src/wizard-source.vala"
							_data_->_tmp22_ = _g_object_ref0 (_data_->_tmp21_);
#line 602 "/home/fborges/checkout/gnome-boxes/src/wizard-source.vala"
							_data_->_vala1_child_media = _data_->_tmp22_;
#line 603 "/home/fborges/checkout/gnome-boxes/src/wizard-source.vala"
							_data_->_tmp23_ = _data_->_vala1_child_media;
#line 603 "/home/fborges/checkout/gnome-boxes/src/wizard-source.vala"
							_data_->_tmp24_ = _data_->_tmp23_->device_file;
#line 603 "/home/fborges/checkout/gnome-boxes/src/wizard-source.vala"
							_data_->_tmp25_ = _data_->_vala1_media;
#line 603 "/home/fborges/checkout/gnome-boxes/src/wizard-source.vala"
							_data_->_tmp26_ = _data_->_tmp25_->device_file;
#line 603 "/home/fborges/checkout/gnome-boxes/src/wizard-source.vala"
							if (g_strcmp0 (_data_->_tmp24_, _data_->_tmp26_) == 0) {
#line 604 "/home/fborges/checkout/gnome-boxes/src/wizard-source.vala"
								_data_->nouveau = FALSE;
#line 606 "/home/fborges/checkout/gnome-boxes/src/wizard-source.vala"
								_g_object_unref0 (_data_->_vala1_child_media);
#line 606 "/home/fborges/checkout/gnome-boxes/src/wizard-source.vala"
								break;
#line 4635 "wizard-source.c"
							}
#line 601 "/home/fborges/checkout/gnome-boxes/src/wizard-source.vala"
							_g_object_unref0 (_data_->_vala1_child_media);
#line 4639 "wizard-source.c"
						}
					}
#line 601 "/home/fborges/checkout/gnome-boxes/src/wizard-source.vala"
					_g_list_free0 (_data_->_vala1_child_collection);
#line 4644 "wizard-source.c"
				}
#line 610 "/home/fborges/checkout/gnome-boxes/src/wizard-source.vala"
				_data_->_tmp27_ = _data_->nouveau;
#line 610 "/home/fborges/checkout/gnome-boxes/src/wizard-source.vala"
				if (_data_->_tmp27_) {
#line 611 "/home/fborges/checkout/gnome-boxes/src/wizard-source.vala"
					_data_->_tmp28_ = _data_->_vala1_media;
#line 611 "/home/fborges/checkout/gnome-boxes/src/wizard-source.vala"
					boxes_wizard_source_add_media_entry (_data_->self, _data_->_tmp28_);
#line 4654 "wizard-source.c"
				}
#line 599 "/home/fborges/checkout/gnome-boxes/src/wizard-source.vala"
				_g_object_unref0 (_data_->_vala1_media);
#line 4658 "wizard-source.c"
			}
		}
	}
#line 615 "/home/fborges/checkout/gnome-boxes/src/wizard-source.vala"
	_data_->_tmp29_ = _data_->self->priv->media_vbox;
#line 615 "/home/fborges/checkout/gnome-boxes/src/wizard-source.vala"
	_data_->_tmp30_ = gtk_container_get_children ((GtkContainer*) _data_->_tmp29_);
#line 615 "/home/fborges/checkout/gnome-boxes/src/wizard-source.vala"
	_data_->_tmp31_ = _data_->_tmp30_;
#line 615 "/home/fborges/checkout/gnome-boxes/src/wizard-source.vala"
	_data_->_tmp32_ = g_list_length (_data_->_tmp31_);
#line 615 "/home/fborges/checkout/gnome-boxes/src/wizard-source.vala"
	_data_->_tmp33_ = _data_->_tmp32_ == ((guint) 0);
#line 615 "/home/fborges/checkout/gnome-boxes/src/wizard-source.vala"
	_g_list_free0 (_data_->_tmp31_);
#line 615 "/home/fborges/checkout/gnome-boxes/src/wizard-source.vala"
	if (_data_->_tmp33_) {
#line 616 "/home/fborges/checkout/gnome-boxes/src/wizard-source.vala"
		_data_->_tmp34_ = _data_->self->priv->media_scrolled;
#line 616 "/home/fborges/checkout/gnome-boxes/src/wizard-source.vala"
		gtk_widget_hide ((GtkWidget*) _data_->_tmp34_);
#line 4680 "wizard-source.c"
	}
#line 581 "/home/fborges/checkout/gnome-boxes/src/wizard-source.vala"
	__g_list_free__g_object_unref0_0 (_data_->medias);
#line 581 "/home/fborges/checkout/gnome-boxes/src/wizard-source.vala"
	g_task_return_pointer (_data_->_async_result, _data_, NULL);
#line 581 "/home/fborges/checkout/gnome-boxes/src/wizard-source.vala"
	if (_data_->_state_ != 0) {
#line 581 "/home/fborges/checkout/gnome-boxes/src/wizard-source.vala"
		while (g_task_get_completed (_data_->_async_result) != TRUE) {
#line 581 "/home/fborges/checkout/gnome-boxes/src/wizard-source.vala"
			g_main_context_iteration (g_task_get_context (_data_->_async_result), TRUE);
#line 4692 "wizard-source.c"
		}
	}
#line 581 "/home/fborges/checkout/gnome-boxes/src/wizard-source.vala"
	g_object_unref (_data_->_async_result);
#line 581 "/home/fborges/checkout/gnome-boxes/src/wizard-source.vala"
	return FALSE;
#line 4699 "wizard-source.c"
}


static void boxes_wizard_source_add_media_entry (BoxesWizardSource* self, BoxesInstallerMedia* media) {
	BoxesWizardMediaEntry* entry = NULL;
	BoxesInstallerMedia* _tmp0_;
	BoxesWizardMediaEntry* _tmp1_;
	GtkListBox* _tmp2_;
	BoxesWizardScrolled* _tmp3_;
#line 619 "/home/fborges/checkout/gnome-boxes/src/wizard-source.vala"
	g_return_if_fail (self != NULL);
#line 619 "/home/fborges/checkout/gnome-boxes/src/wizard-source.vala"
	g_return_if_fail (media != NULL);
#line 620 "/home/fborges/checkout/gnome-boxes/src/wizard-source.vala"
	_tmp0_ = media;
#line 620 "/home/fborges/checkout/gnome-boxes/src/wizard-source.vala"
	_tmp1_ = boxes_wizard_media_entry_new (_tmp0_);
#line 620 "/home/fborges/checkout/gnome-boxes/src/wizard-source.vala"
	g_object_ref_sink (_tmp1_);
#line 620 "/home/fborges/checkout/gnome-boxes/src/wizard-source.vala"
	entry = _tmp1_;
#line 621 "/home/fborges/checkout/gnome-boxes/src/wizard-source.vala"
	_tmp2_ = self->priv->media_vbox;
#line 621 "/home/fborges/checkout/gnome-boxes/src/wizard-source.vala"
	gtk_container_add ((GtkContainer*) _tmp2_, (GtkWidget*) entry);
#line 623 "/home/fborges/checkout/gnome-boxes/src/wizard-source.vala"
	_tmp3_ = self->priv->media_scrolled;
#line 623 "/home/fborges/checkout/gnome-boxes/src/wizard-source.vala"
	gtk_widget_show ((GtkWidget*) _tmp3_);
#line 619 "/home/fborges/checkout/gnome-boxes/src/wizard-source.vala"
	_g_object_unref0 (entry);
#line 4731 "wizard-source.c"
}


static void boxes_wizard_source_update_libvirt_sytem_entry_visibility_data_free (gpointer _data) {
	BoxesWizardSourceUpdateLibvirtSytemEntryVisibilityData* _data_;
	_data_ = _data;
#line 309 "/home/fborges/checkout/gnome-boxes/src/wizard-source.vala"
	_g_object_unref0 (_data_->self);
#line 309 "/home/fborges/checkout/gnome-boxes/src/wizard-source.vala"
	g_slice_free (BoxesWizardSourceUpdateLibvirtSytemEntryVisibilityData, _data_);
#line 4742 "wizard-source.c"
}


static void boxes_wizard_source_update_libvirt_sytem_entry_visibility (BoxesWizardSource* self, GAsyncReadyCallback _callback_, gpointer _user_data_) {
	BoxesWizardSourceUpdateLibvirtSytemEntryVisibilityData* _data_;
	BoxesWizardSource* _tmp0_;
#line 309 "/home/fborges/checkout/gnome-boxes/src/wizard-source.vala"
	_data_ = g_slice_new0 (BoxesWizardSourceUpdateLibvirtSytemEntryVisibilityData);
#line 309 "/home/fborges/checkout/gnome-boxes/src/wizard-source.vala"
	_data_->_async_result = g_task_new (G_OBJECT (self), NULL, _callback_, _user_data_);
#line 309 "/home/fborges/checkout/gnome-boxes/src/wizard-source.vala"
	g_task_set_task_data (_data_->_async_result, _data_, boxes_wizard_source_update_libvirt_sytem_entry_visibility_data_free);
#line 309 "/home/fborges/checkout/gnome-boxes/src/wizard-source.vala"
	_tmp0_ = _g_object_ref0 (self);
#line 309 "/home/fborges/checkout/gnome-boxes/src/wizard-source.vala"
	_data_->self = _tmp0_;
#line 309 "/home/fborges/checkout/gnome-boxes/src/wizard-source.vala"
	boxes_wizard_source_update_libvirt_sytem_entry_visibility_co (_data_);
#line 4761 "wizard-source.c"
}


static void boxes_wizard_source_update_libvirt_sytem_entry_visibility_finish (BoxesWizardSource* self, GAsyncResult* _res_) {
	BoxesWizardSourceUpdateLibvirtSytemEntryVisibilityData* _data_;
#line 309 "/home/fborges/checkout/gnome-boxes/src/wizard-source.vala"
	_data_ = g_task_propagate_pointer (G_TASK (_res_), NULL);
#line 4769 "wizard-source.c"
}


static void boxes_wizard_source_update_libvirt_sytem_entry_visibility_ready (GObject* source_object, GAsyncResult* _res_, gpointer _user_data_) {
	BoxesWizardSourceUpdateLibvirtSytemEntryVisibilityData* _data_;
#line 628 "/home/fborges/checkout/gnome-boxes/src/wizard-source.vala"
	_data_ = _user_data_;
#line 628 "/home/fborges/checkout/gnome-boxes/src/wizard-source.vala"
	_data_->_source_object_ = source_object;
#line 628 "/home/fborges/checkout/gnome-boxes/src/wizard-source.vala"
	_data_->_res_ = _res_;
#line 628 "/home/fborges/checkout/gnome-boxes/src/wizard-source.vala"
	boxes_wizard_source_update_libvirt_sytem_entry_visibility_co (_data_);
#line 4783 "wizard-source.c"
}


static gboolean boxes_wizard_source_update_libvirt_sytem_entry_visibility_co (BoxesWizardSourceUpdateLibvirtSytemEntryVisibilityData* _data_) {
#line 626 "/home/fborges/checkout/gnome-boxes/src/wizard-source.vala"
	switch (_data_->_state_) {
#line 626 "/home/fborges/checkout/gnome-boxes/src/wizard-source.vala"
		case 0:
#line 4792 "wizard-source.c"
		goto _state_0;
#line 626 "/home/fborges/checkout/gnome-boxes/src/wizard-source.vala"
		case 1:
#line 4796 "wizard-source.c"
		goto _state_1;
		default:
#line 626 "/home/fborges/checkout/gnome-boxes/src/wizard-source.vala"
		g_assert_not_reached ();
#line 4801 "wizard-source.c"
	}
	_state_0:
	{
#line 628 "/home/fborges/checkout/gnome-boxes/src/wizard-source.vala"
		_data_->_state_ = 1;
#line 628 "/home/fborges/checkout/gnome-boxes/src/wizard-source.vala"
		boxes_libvirt_system_importer_new (boxes_wizard_source_update_libvirt_sytem_entry_visibility_ready, _data_);
#line 628 "/home/fborges/checkout/gnome-boxes/src/wizard-source.vala"
		return FALSE;
#line 4811 "wizard-source.c"
		_state_1:
#line 628 "/home/fborges/checkout/gnome-boxes/src/wizard-source.vala"
		_data_->_tmp1_ = boxes_libvirt_system_importer_new_finish (_data_->_res_, &_data_->_inner_error_);
#line 628 "/home/fborges/checkout/gnome-boxes/src/wizard-source.vala"
		_data_->_tmp0_ = _data_->_tmp1_;
#line 628 "/home/fborges/checkout/gnome-boxes/src/wizard-source.vala"
		if (G_UNLIKELY (_data_->_inner_error_ != NULL)) {
#line 4819 "wizard-source.c"
			goto __catch137_g_error;
		}
#line 628 "/home/fborges/checkout/gnome-boxes/src/wizard-source.vala"
		boxes_wizard_source_set_libvirt_sys_importer (_data_->self, _data_->_tmp0_);
#line 627 "/home/fborges/checkout/gnome-boxes/src/wizard-source.vala"
		_g_object_unref0 (_data_->_tmp0_);
#line 4826 "wizard-source.c"
	}
	goto __finally137;
	__catch137_g_error:
	{
#line 627 "/home/fborges/checkout/gnome-boxes/src/wizard-source.vala"
		_data_->_error_ = _data_->_inner_error_;
#line 627 "/home/fborges/checkout/gnome-boxes/src/wizard-source.vala"
		_data_->_inner_error_ = NULL;
#line 630 "/home/fborges/checkout/gnome-boxes/src/wizard-source.vala"
		_data_->_tmp2_ = _data_->_error_;
#line 630 "/home/fborges/checkout/gnome-boxes/src/wizard-source.vala"
		_data_->_tmp3_ = _data_->_tmp2_->message;
#line 630 "/home/fborges/checkout/gnome-boxes/src/wizard-source.vala"
		g_debug ("wizard-source.vala:630: %s", _data_->_tmp3_);
#line 632 "/home/fborges/checkout/gnome-boxes/src/wizard-source.vala"
		_g_error_free0 (_data_->_error_);
#line 632 "/home/fborges/checkout/gnome-boxes/src/wizard-source.vala"
		g_task_return_pointer (_data_->_async_result, _data_, NULL);
#line 632 "/home/fborges/checkout/gnome-boxes/src/wizard-source.vala"
		if (_data_->_state_ != 0) {
#line 632 "/home/fborges/checkout/gnome-boxes/src/wizard-source.vala"
			while (g_task_get_completed (_data_->_async_result) != TRUE) {
#line 632 "/home/fborges/checkout/gnome-boxes/src/wizard-source.vala"
				g_main_context_iteration (g_task_get_context (_data_->_async_result), TRUE);
#line 4851 "wizard-source.c"
			}
		}
#line 632 "/home/fborges/checkout/gnome-boxes/src/wizard-source.vala"
		g_object_unref (_data_->_async_result);
#line 632 "/home/fborges/checkout/gnome-boxes/src/wizard-source.vala"
		return FALSE;
#line 4858 "wizard-source.c"
	}
	__finally137:
#line 627 "/home/fborges/checkout/gnome-boxes/src/wizard-source.vala"
	if (G_UNLIKELY (_data_->_inner_error_ != NULL)) {
#line 627 "/home/fborges/checkout/gnome-boxes/src/wizard-source.vala"
		g_critical ("file %s: line %d: uncaught error: %s (%s, %d)", __FILE__, __LINE__, _data_->_inner_error_->message, g_quark_to_string (_data_->_inner_error_->domain), _data_->_inner_error_->code);
#line 627 "/home/fborges/checkout/gnome-boxes/src/wizard-source.vala"
		g_clear_error (&_data_->_inner_error_);
#line 627 "/home/fborges/checkout/gnome-boxes/src/wizard-source.vala"
		g_object_unref (_data_->_async_result);
#line 627 "/home/fborges/checkout/gnome-boxes/src/wizard-source.vala"
		return FALSE;
#line 4871 "wizard-source.c"
	}
#line 634 "/home/fborges/checkout/gnome-boxes/src/wizard-source.vala"
	_data_->_tmp4_ = _data_->self->priv->libvirt_sys_import_label;
#line 634 "/home/fborges/checkout/gnome-boxes/src/wizard-source.vala"
	_data_->_tmp5_ = _data_->self->priv->_libvirt_sys_importer;
#line 634 "/home/fborges/checkout/gnome-boxes/src/wizard-source.vala"
	_data_->_tmp6_ = boxes_libvirt_system_importer_get_wizard_menu_label (_data_->_tmp5_);
#line 634 "/home/fborges/checkout/gnome-boxes/src/wizard-source.vala"
	_data_->_tmp7_ = _data_->_tmp6_;
#line 634 "/home/fborges/checkout/gnome-boxes/src/wizard-source.vala"
	_data_->_tmp8_ = _data_->_tmp7_;
#line 634 "/home/fborges/checkout/gnome-boxes/src/wizard-source.vala"
	gtk_label_set_label (_data_->_tmp4_, _data_->_tmp8_);
#line 634 "/home/fborges/checkout/gnome-boxes/src/wizard-source.vala"
	_g_free0 (_data_->_tmp8_);
#line 635 "/home/fborges/checkout/gnome-boxes/src/wizard-source.vala"
	_data_->_tmp9_ = _data_->self->priv->libvirt_sys_import_button;
#line 635 "/home/fborges/checkout/gnome-boxes/src/wizard-source.vala"
	gtk_widget_show_all ((GtkWidget*) _data_->_tmp9_);
#line 626 "/home/fborges/checkout/gnome-boxes/src/wizard-source.vala"
	g_task_return_pointer (_data_->_async_result, _data_, NULL);
#line 626 "/home/fborges/checkout/gnome-boxes/src/wizard-source.vala"
	if (_data_->_state_ != 0) {
#line 626 "/home/fborges/checkout/gnome-boxes/src/wizard-source.vala"
		while (g_task_get_completed (_data_->_async_result) != TRUE) {
#line 626 "/home/fborges/checkout/gnome-boxes/src/wizard-source.vala"
			g_main_context_iteration (g_task_get_context (_data_->_async_result), TRUE);
#line 4899 "wizard-source.c"
		}
	}
#line 626 "/home/fborges/checkout/gnome-boxes/src/wizard-source.vala"
	g_object_unref (_data_->_async_result);
#line 626 "/home/fborges/checkout/gnome-boxes/src/wizard-source.vala"
	return FALSE;
#line 4906 "wizard-source.c"
}


static void __lambda150_ (BoxesWizardSource* self, const gchar* uri) {
	const gchar* _tmp0_;
	GtkButton* _tmp1_;
#line 640 "/home/fborges/checkout/gnome-boxes/src/wizard-source.vala"
	g_return_if_fail (uri != NULL);
#line 641 "/home/fborges/checkout/gnome-boxes/src/wizard-source.vala"
	_tmp0_ = uri;
#line 641 "/home/fborges/checkout/gnome-boxes/src/wizard-source.vala"
	boxes_wizard_source_set_uri (self, _tmp0_);
#line 643 "/home/fborges/checkout/gnome-boxes/src/wizard-source.vala"
	boxes_wizard_source_set_install_media (self, NULL);
#line 644 "/home/fborges/checkout/gnome-boxes/src/wizard-source.vala"
	g_signal_emit (self, boxes_wizard_source_signals[BOXES_WIZARD_SOURCE_ACTIVATED_SIGNAL], 0);
#line 646 "/home/fborges/checkout/gnome-boxes/src/wizard-source.vala"
	_tmp1_ = self->priv->select_file_button;
#line 646 "/home/fborges/checkout/gnome-boxes/src/wizard-source.vala"
	boxes_wizard_source_set_selected (self, (GtkWidget*) _tmp1_);
#line 4927 "wizard-source.c"
}


static void ___lambda150__boxes_wizard_window_file_chosen_func (const gchar* uri, gpointer self) {
#line 640 "/home/fborges/checkout/gnome-boxes/src/wizard-source.vala"
	__lambda150_ ((BoxesWizardSource*) self, uri);
#line 4934 "wizard-source.c"
}


static void boxes_wizard_source_on_select_file_button_clicked (BoxesWizardSource* self) {
	BoxesAppWindow* _tmp0_;
	BoxesWizardWindow* _tmp1_;
#line 639 "/home/fborges/checkout/gnome-boxes/src/wizard-source.vala"
	g_return_if_fail (self != NULL);
#line 640 "/home/fborges/checkout/gnome-boxes/src/wizard-source.vala"
	_tmp0_ = self->priv->window;
#line 640 "/home/fborges/checkout/gnome-boxes/src/wizard-source.vala"
	_tmp1_ = _tmp0_->wizard_window;
#line 640 "/home/fborges/checkout/gnome-boxes/src/wizard-source.vala"
	boxes_wizard_window_show_file_chooser (_tmp1_, ___lambda150__boxes_wizard_window_file_chosen_func, g_object_ref (self), g_object_unref);
#line 4949 "wizard-source.c"
}


static void _boxes_wizard_source_on_select_file_button_clicked_gtk_button_clicked (GtkButton* _sender, gpointer self) {
#line 309 "/home/fborges/checkout/gnome-boxes/src/wizard-source.vala"
	boxes_wizard_source_on_select_file_button_clicked ((BoxesWizardSource*) self);
#line 4956 "wizard-source.c"
}


static void boxes_wizard_source_on_libvirt_sys_import_button_clicked (BoxesWizardSource* self) {
	GtkButton* _tmp0_;
#line 651 "/home/fborges/checkout/gnome-boxes/src/wizard-source.vala"
	g_return_if_fail (self != NULL);
#line 652 "/home/fborges/checkout/gnome-boxes/src/wizard-source.vala"
	self->libvirt_sys_import = TRUE;
#line 653 "/home/fborges/checkout/gnome-boxes/src/wizard-source.vala"
	g_signal_emit (self, boxes_wizard_source_signals[BOXES_WIZARD_SOURCE_ACTIVATED_SIGNAL], 0);
#line 655 "/home/fborges/checkout/gnome-boxes/src/wizard-source.vala"
	_tmp0_ = self->priv->libvirt_sys_import_button;
#line 655 "/home/fborges/checkout/gnome-boxes/src/wizard-source.vala"
	boxes_wizard_source_set_selected (self, (GtkWidget*) _tmp0_);
#line 4972 "wizard-source.c"
}


static void _boxes_wizard_source_on_libvirt_sys_import_button_clicked_gtk_button_clicked (GtkButton* _sender, gpointer self) {
#line 309 "/home/fborges/checkout/gnome-boxes/src/wizard-source.vala"
	boxes_wizard_source_on_libvirt_sys_import_button_clicked ((BoxesWizardSource*) self);
#line 4979 "wizard-source.c"
}


static void boxes_wizard_source_on_media_selected (BoxesWizardSource* self, BoxesInstallerMedia* media) {
	GError * _inner_error_ = NULL;
#line 658 "/home/fborges/checkout/gnome-boxes/src/wizard-source.vala"
	g_return_if_fail (self != NULL);
#line 658 "/home/fborges/checkout/gnome-boxes/src/wizard-source.vala"
	g_return_if_fail (media != NULL);
#line 4989 "wizard-source.c"
	{
		BoxesInstallerMedia* _tmp0_ = NULL;
		BoxesMediaManager* _tmp1_;
		BoxesInstallerMedia* _tmp2_;
		BoxesInstallerMedia* _tmp3_;
		BoxesInstallerMedia* _tmp4_;
		const gchar* _tmp5_;
#line 660 "/home/fborges/checkout/gnome-boxes/src/wizard-source.vala"
		_tmp1_ = self->media_manager;
#line 660 "/home/fborges/checkout/gnome-boxes/src/wizard-source.vala"
		_tmp2_ = media;
#line 660 "/home/fborges/checkout/gnome-boxes/src/wizard-source.vala"
		_tmp3_ = boxes_media_manager_create_installer_media_from_media (_tmp1_, _tmp2_, &_inner_error_);
#line 660 "/home/fborges/checkout/gnome-boxes/src/wizard-source.vala"
		_tmp0_ = _tmp3_;
#line 660 "/home/fborges/checkout/gnome-boxes/src/wizard-source.vala"
		if (G_UNLIKELY (_inner_error_ != NULL)) {
#line 5007 "wizard-source.c"
			goto __catch138_g_error;
		}
#line 660 "/home/fborges/checkout/gnome-boxes/src/wizard-source.vala"
		boxes_wizard_source_set_install_media (self, _tmp0_);
#line 661 "/home/fborges/checkout/gnome-boxes/src/wizard-source.vala"
		_tmp4_ = media;
#line 661 "/home/fborges/checkout/gnome-boxes/src/wizard-source.vala"
		_tmp5_ = _tmp4_->device_file;
#line 661 "/home/fborges/checkout/gnome-boxes/src/wizard-source.vala"
		boxes_wizard_source_set_uri (self, _tmp5_);
#line 662 "/home/fborges/checkout/gnome-boxes/src/wizard-source.vala"
		g_signal_emit (self, boxes_wizard_source_signals[BOXES_WIZARD_SOURCE_ACTIVATED_SIGNAL], 0);
#line 659 "/home/fborges/checkout/gnome-boxes/src/wizard-source.vala"
		_g_object_unref0 (_tmp0_);
#line 5022 "wizard-source.c"
	}
	goto __finally138;
	__catch138_g_error:
	{
		GError* _error_ = NULL;
		BoxesInstallerMedia* _tmp6_;
		const gchar* _tmp7_;
		GError* _tmp8_;
		const gchar* _tmp9_;
#line 659 "/home/fborges/checkout/gnome-boxes/src/wizard-source.vala"
		_error_ = _inner_error_;
#line 659 "/home/fborges/checkout/gnome-boxes/src/wizard-source.vala"
		_inner_error_ = NULL;
#line 665 "/home/fborges/checkout/gnome-boxes/src/wizard-source.vala"
		_tmp6_ = media;
#line 665 "/home/fborges/checkout/gnome-boxes/src/wizard-source.vala"
		_tmp7_ = _tmp6_->device_file;
#line 665 "/home/fborges/checkout/gnome-boxes/src/wizard-source.vala"
		_tmp8_ = _error_;
#line 665 "/home/fborges/checkout/gnome-boxes/src/wizard-source.vala"
		_tmp9_ = _tmp8_->message;
#line 665 "/home/fborges/checkout/gnome-boxes/src/wizard-source.vala"
		g_warning ("wizard-source.vala:665: Failed to setup installation media '%s': %s", _tmp7_, _tmp9_);
#line 659 "/home/fborges/checkout/gnome-boxes/src/wizard-source.vala"
		_g_error_free0 (_error_);
#line 5048 "wizard-source.c"
	}
	__finally138:
#line 659 "/home/fborges/checkout/gnome-boxes/src/wizard-source.vala"
	if (G_UNLIKELY (_inner_error_ != NULL)) {
#line 659 "/home/fborges/checkout/gnome-boxes/src/wizard-source.vala"
		g_critical ("file %s: line %d: uncaught error: %s (%s, %d)", __FILE__, __LINE__, _inner_error_->message, g_quark_to_string (_inner_error_->domain), _inner_error_->code);
#line 659 "/home/fborges/checkout/gnome-boxes/src/wizard-source.vala"
		g_clear_error (&_inner_error_);
#line 659 "/home/fborges/checkout/gnome-boxes/src/wizard-source.vala"
		return;
#line 5059 "wizard-source.c"
	}
}


static void __lambda151_ (BoxesWizardSource* self) {
	BoxesWizardWebView* _tmp0_;
	WebKitWebView* _tmp1_;
	WebKitWebView* _tmp2_;
	BoxesWizardWebView* _tmp3_;
	WebKitWebView* _tmp4_;
	WebKitWebView* _tmp5_;
	WebKitWebsiteDataManager* data_manager = NULL;
	BoxesWizardWebView* _tmp6_;
	WebKitWebView* _tmp7_;
	WebKitWebView* _tmp8_;
	WebKitWebsiteDataManager* _tmp9_;
	WebKitWebsiteDataManager* _tmp10_;
#line 675 "/home/fborges/checkout/gnome-boxes/src/wizard-source.vala"
	_tmp0_ = self->priv->rhel_web_view;
#line 675 "/home/fborges/checkout/gnome-boxes/src/wizard-source.vala"
	_tmp1_ = boxes_wizard_web_view_get_view (_tmp0_);
#line 675 "/home/fborges/checkout/gnome-boxes/src/wizard-source.vala"
	_tmp2_ = _tmp1_;
#line 675 "/home/fborges/checkout/gnome-boxes/src/wizard-source.vala"
	webkit_web_view_stop_loading (_tmp2_);
#line 676 "/home/fborges/checkout/gnome-boxes/src/wizard-source.vala"
	_tmp3_ = self->priv->rhel_web_view;
#line 676 "/home/fborges/checkout/gnome-boxes/src/wizard-source.vala"
	_tmp4_ = boxes_wizard_web_view_get_view (_tmp3_);
#line 676 "/home/fborges/checkout/gnome-boxes/src/wizard-source.vala"
	_tmp5_ = _tmp4_;
#line 676 "/home/fborges/checkout/gnome-boxes/src/wizard-source.vala"
	webkit_web_view_load_uri (_tmp5_, "about:blank");
#line 678 "/home/fborges/checkout/gnome-boxes/src/wizard-source.vala"
	_tmp6_ = self->priv->rhel_web_view;
#line 678 "/home/fborges/checkout/gnome-boxes/src/wizard-source.vala"
	_tmp7_ = boxes_wizard_web_view_get_view (_tmp6_);
#line 678 "/home/fborges/checkout/gnome-boxes/src/wizard-source.vala"
	_tmp8_ = _tmp7_;
#line 678 "/home/fborges/checkout/gnome-boxes/src/wizard-source.vala"
	_tmp9_ = webkit_web_view_get_website_data_manager (_tmp8_);
#line 678 "/home/fborges/checkout/gnome-boxes/src/wizard-source.vala"
	_tmp10_ = _g_object_ref0 (_tmp9_);
#line 678 "/home/fborges/checkout/gnome-boxes/src/wizard-source.vala"
	data_manager = _tmp10_;
#line 679 "/home/fborges/checkout/gnome-boxes/src/wizard-source.vala"
	webkit_website_data_manager_clear (data_manager, WEBKIT_WEBSITE_DATA_COOKIES, (GTimeSpan) 0, NULL, NULL, NULL);
#line 674 "/home/fborges/checkout/gnome-boxes/src/wizard-source.vala"
	_g_object_unref0 (data_manager);
#line 5109 "wizard-source.c"
}


static void ___lambda151__gfunc (gconstpointer data, gpointer self) {
#line 674 "/home/fborges/checkout/gnome-boxes/src/wizard-source.vala"
	__lambda151_ ((BoxesWizardSource*) self);
#line 5116 "wizard-source.c"
}


static void boxes_wizard_source_on_install_rhel_button_clicked (BoxesWizardSource* self) {
	GCancellable* _tmp0_;
	GCancellable* _tmp1_;
	gchar* user_agent = NULL;
	gchar* _tmp2_;
	gchar* user_agent_escaped = NULL;
	gchar* _tmp3_;
	gchar* authentication_uri = NULL;
	gchar* _tmp4_;
	BoxesWizardWebView* _tmp5_;
	WebKitWebView* _tmp6_;
	WebKitWebView* _tmp7_;
#line 670 "/home/fborges/checkout/gnome-boxes/src/wizard-source.vala"
	g_return_if_fail (self != NULL);
#line 671 "/home/fborges/checkout/gnome-boxes/src/wizard-source.vala"
	boxes_wizard_source_set_page (self, BOXES_SOURCE_PAGE_RHEL_WEB_VIEW);
#line 673 "/home/fborges/checkout/gnome-boxes/src/wizard-source.vala"
	_tmp0_ = g_cancellable_new ();
#line 673 "/home/fborges/checkout/gnome-boxes/src/wizard-source.vala"
	_g_object_unref0 (self->priv->rhel_cancellable);
#line 673 "/home/fborges/checkout/gnome-boxes/src/wizard-source.vala"
	self->priv->rhel_cancellable = _tmp0_;
#line 674 "/home/fborges/checkout/gnome-boxes/src/wizard-source.vala"
	_tmp1_ = self->priv->rhel_cancellable;
#line 674 "/home/fborges/checkout/gnome-boxes/src/wizard-source.vala"
	g_cancellable_connect (_tmp1_, (GCallback) ___lambda151__gfunc, g_object_ref (self), g_object_unref);
#line 682 "/home/fborges/checkout/gnome-boxes/src/wizard-source.vala"
	_tmp2_ = boxes_get_user_agent ();
#line 682 "/home/fborges/checkout/gnome-boxes/src/wizard-source.vala"
	user_agent = _tmp2_;
#line 683 "/home/fborges/checkout/gnome-boxes/src/wizard-source.vala"
	_tmp3_ = g_uri_escape_string (user_agent, NULL, FALSE);
#line 683 "/home/fborges/checkout/gnome-boxes/src/wizard-source.vala"
	user_agent_escaped = _tmp3_;
#line 684 "/home/fborges/checkout/gnome-boxes/src/wizard-source.vala"
	_tmp4_ = g_strconcat ("https://developers.redhat.com/download-manager/rest/featured/file/rhel" "?tag=", user_agent_escaped, NULL);
#line 684 "/home/fborges/checkout/gnome-boxes/src/wizard-source.vala"
	authentication_uri = _tmp4_;
#line 687 "/home/fborges/checkout/gnome-boxes/src/wizard-source.vala"
	g_debug ("wizard-source.vala:687: RHEL ISO authentication URI: %s", authentication_uri);
#line 689 "/home/fborges/checkout/gnome-boxes/src/wizard-source.vala"
	_tmp5_ = self->priv->rhel_web_view;
#line 689 "/home/fborges/checkout/gnome-boxes/src/wizard-source.vala"
	_tmp6_ = boxes_wizard_web_view_get_view (_tmp5_);
#line 689 "/home/fborges/checkout/gnome-boxes/src/wizard-source.vala"
	_tmp7_ = _tmp6_;
#line 689 "/home/fborges/checkout/gnome-boxes/src/wizard-source.vala"
	webkit_web_view_load_uri (_tmp7_, authentication_uri);
#line 670 "/home/fborges/checkout/gnome-boxes/src/wizard-source.vala"
	_g_free0 (authentication_uri);
#line 670 "/home/fborges/checkout/gnome-boxes/src/wizard-source.vala"
	_g_free0 (user_agent_escaped);
#line 670 "/home/fborges/checkout/gnome-boxes/src/wizard-source.vala"
	_g_free0 (user_agent);
#line 5174 "wizard-source.c"
}


static void _boxes_wizard_source_on_install_rhel_button_clicked_gtk_button_clicked (GtkButton* _sender, gpointer self) {
#line 309 "/home/fborges/checkout/gnome-boxes/src/wizard-source.vala"
	boxes_wizard_source_on_install_rhel_button_clicked ((BoxesWizardSource*) self);
#line 5181 "wizard-source.c"
}


static WebKitNavigationAction* _vala_WebKitNavigationAction_copy (WebKitNavigationAction* self) {
#line 698 "/home/fborges/checkout/gnome-boxes/src/wizard-source.vala"
	return g_boxed_copy (webkit_navigation_action_get_type (), self);
#line 5188 "wizard-source.c"
}


static gpointer __vala_WebKitNavigationAction_copy0 (gpointer self) {
#line 698 "/home/fborges/checkout/gnome-boxes/src/wizard-source.vala"
	return self ? _vala_WebKitNavigationAction_copy (self) : NULL;
#line 5195 "wizard-source.c"
}


static void _vala_WebKitNavigationAction_free (WebKitNavigationAction* self) {
#line 702 "/home/fborges/checkout/gnome-boxes/src/wizard-source.vala"
	g_boxed_free (webkit_navigation_action_get_type (), self);
#line 5202 "wizard-source.c"
}


static void _vala_SoupURI_free (SoupURI* self) {
#line 707 "/home/fborges/checkout/gnome-boxes/src/wizard-source.vala"
	g_boxed_free (soup_uri_get_type (), self);
#line 5209 "wizard-source.c"
}


static gboolean boxes_wizard_source_on_rhel_web_view_decide_policy (BoxesWizardSource* self, WebKitWebView* web_view, WebKitPolicyDecision* decision, WebKitPolicyDecisionType decision_type) {
	gboolean result = FALSE;
	WebKitPolicyDecisionType _tmp0_;
	WebKitNavigationAction* action = NULL;
	WebKitPolicyDecision* _tmp1_;
	WebKitNavigationAction* _tmp2_;
	WebKitNavigationAction* _tmp3_;
	WebKitURIRequest* request = NULL;
	WebKitNavigationAction* _tmp4_;
	WebKitURIRequest* _tmp5_;
	WebKitURIRequest* _tmp6_;
	gchar* request_uri = NULL;
	WebKitURIRequest* _tmp7_;
	const gchar* _tmp8_;
	gchar* _tmp9_;
	const gchar* _tmp10_;
	gboolean _tmp11_;
	SoupURI* soup_request_uri = NULL;
	const gchar* _tmp12_;
	SoupURI* _tmp13_;
	gchar* query = NULL;
	SoupURI* _tmp14_;
	const gchar* _tmp15_;
	gchar* _tmp16_;
	const gchar* _tmp17_;
	GHashTable* key_value_pairs = NULL;
	const gchar* _tmp18_;
	GHashTable* _tmp19_;
	gchar* download_uri = NULL;
	GHashTable* _tmp20_;
	gconstpointer _tmp21_;
	gchar* _tmp22_;
	const gchar* _tmp23_;
	const gchar* _tmp24_;
	OsinfoOs* _tmp25_;
	SoupURI* soup_download_uri = NULL;
	const gchar* _tmp46_;
	SoupURI* _tmp47_;
	gchar* download_path = NULL;
	SoupURI* _tmp48_;
	const gchar* _tmp49_;
	gchar* _tmp50_;
	const gchar* _tmp51_;
	const gchar* _tmp52_;
	gint _tmp53_;
	gint _tmp54_;
	const gchar* _tmp55_;
	gboolean _tmp56_;
	const gchar* _tmp58_;
	gchar* _tmp59_;
	gchar* _tmp60_;
	const gchar* _tmp61_;
	GtkButton* _tmp62_;
	WebKitPolicyDecision* _tmp63_;
#line 692 "/home/fborges/checkout/gnome-boxes/src/wizard-source.vala"
	g_return_val_if_fail (self != NULL, FALSE);
#line 692 "/home/fborges/checkout/gnome-boxes/src/wizard-source.vala"
	g_return_val_if_fail (web_view != NULL, FALSE);
#line 692 "/home/fborges/checkout/gnome-boxes/src/wizard-source.vala"
	g_return_val_if_fail (decision != NULL, FALSE);
#line 695 "/home/fborges/checkout/gnome-boxes/src/wizard-source.vala"
	_tmp0_ = decision_type;
#line 695 "/home/fborges/checkout/gnome-boxes/src/wizard-source.vala"
	if (_tmp0_ != WEBKIT_POLICY_DECISION_TYPE_NAVIGATION_ACTION) {
#line 696 "/home/fborges/checkout/gnome-boxes/src/wizard-source.vala"
		result = FALSE;
#line 696 "/home/fborges/checkout/gnome-boxes/src/wizard-source.vala"
		return result;
#line 5281 "wizard-source.c"
	}
#line 698 "/home/fborges/checkout/gnome-boxes/src/wizard-source.vala"
	_tmp1_ = decision;
#line 698 "/home/fborges/checkout/gnome-boxes/src/wizard-source.vala"
	_tmp2_ = webkit_navigation_policy_decision_get_navigation_action (G_TYPE_CHECK_INSTANCE_TYPE (_tmp1_, webkit_navigation_policy_decision_get_type ()) ? ((WebKitNavigationPolicyDecision*) _tmp1_) : NULL);
#line 698 "/home/fborges/checkout/gnome-boxes/src/wizard-source.vala"
	_tmp3_ = __vala_WebKitNavigationAction_copy0 (_tmp2_);
#line 698 "/home/fborges/checkout/gnome-boxes/src/wizard-source.vala"
	action = _tmp3_;
#line 699 "/home/fborges/checkout/gnome-boxes/src/wizard-source.vala"
	_tmp4_ = action;
#line 699 "/home/fborges/checkout/gnome-boxes/src/wizard-source.vala"
	_tmp5_ = webkit_navigation_action_get_request (_tmp4_);
#line 699 "/home/fborges/checkout/gnome-boxes/src/wizard-source.vala"
	_tmp6_ = _g_object_ref0 (_tmp5_);
#line 699 "/home/fborges/checkout/gnome-boxes/src/wizard-source.vala"
	request = _tmp6_;
#line 700 "/home/fborges/checkout/gnome-boxes/src/wizard-source.vala"
	_tmp7_ = request;
#line 700 "/home/fborges/checkout/gnome-boxes/src/wizard-source.vala"
	_tmp8_ = webkit_uri_request_get_uri (_tmp7_);
#line 700 "/home/fborges/checkout/gnome-boxes/src/wizard-source.vala"
	_tmp9_ = g_strdup (_tmp8_);
#line 700 "/home/fborges/checkout/gnome-boxes/src/wizard-source.vala"
	request_uri = _tmp9_;
#line 701 "/home/fborges/checkout/gnome-boxes/src/wizard-source.vala"
	_tmp10_ = request_uri;
#line 701 "/home/fborges/checkout/gnome-boxes/src/wizard-source.vala"
	_tmp11_ = g_str_has_prefix (_tmp10_, "https://developers.redhat.com/products/rhel");
#line 701 "/home/fborges/checkout/gnome-boxes/src/wizard-source.vala"
	if (!_tmp11_) {
#line 702 "/home/fborges/checkout/gnome-boxes/src/wizard-source.vala"
		result = FALSE;
#line 702 "/home/fborges/checkout/gnome-boxes/src/wizard-source.vala"
		_g_free0 (request_uri);
#line 702 "/home/fborges/checkout/gnome-boxes/src/wizard-source.vala"
		_g_object_unref0 (request);
#line 702 "/home/fborges/checkout/gnome-boxes/src/wizard-source.vala"
		__vala_WebKitNavigationAction_free0 (action);
#line 702 "/home/fborges/checkout/gnome-boxes/src/wizard-source.vala"
		return result;
#line 5323 "wizard-source.c"
	}
#line 704 "/home/fborges/checkout/gnome-boxes/src/wizard-source.vala"
	_tmp12_ = request_uri;
#line 704 "/home/fborges/checkout/gnome-boxes/src/wizard-source.vala"
	_tmp13_ = soup_uri_new (_tmp12_);
#line 704 "/home/fborges/checkout/gnome-boxes/src/wizard-source.vala"
	soup_request_uri = _tmp13_;
#line 705 "/home/fborges/checkout/gnome-boxes/src/wizard-source.vala"
	_tmp14_ = soup_request_uri;
#line 705 "/home/fborges/checkout/gnome-boxes/src/wizard-source.vala"
	_tmp15_ = soup_uri_get_query (_tmp14_);
#line 705 "/home/fborges/checkout/gnome-boxes/src/wizard-source.vala"
	_tmp16_ = g_strdup (_tmp15_);
#line 705 "/home/fborges/checkout/gnome-boxes/src/wizard-source.vala"
	query = _tmp16_;
#line 706 "/home/fborges/checkout/gnome-boxes/src/wizard-source.vala"
	_tmp17_ = query;
#line 706 "/home/fborges/checkout/gnome-boxes/src/wizard-source.vala"
	if (_tmp17_ == NULL) {
#line 707 "/home/fborges/checkout/gnome-boxes/src/wizard-source.vala"
		result = FALSE;
#line 707 "/home/fborges/checkout/gnome-boxes/src/wizard-source.vala"
		_g_free0 (query);
#line 707 "/home/fborges/checkout/gnome-boxes/src/wizard-source.vala"
		__vala_SoupURI_free0 (soup_request_uri);
#line 707 "/home/fborges/checkout/gnome-boxes/src/wizard-source.vala"
		_g_free0 (request_uri);
#line 707 "/home/fborges/checkout/gnome-boxes/src/wizard-source.vala"
		_g_object_unref0 (request);
#line 707 "/home/fborges/checkout/gnome-boxes/src/wizard-source.vala"
		__vala_WebKitNavigationAction_free0 (action);
#line 707 "/home/fborges/checkout/gnome-boxes/src/wizard-source.vala"
		return result;
#line 5357 "wizard-source.c"
	}
#line 709 "/home/fborges/checkout/gnome-boxes/src/wizard-source.vala"
	_tmp18_ = query;
#line 709 "/home/fborges/checkout/gnome-boxes/src/wizard-source.vala"
	_tmp19_ = soup_form_decode (_tmp18_);
#line 709 "/home/fborges/checkout/gnome-boxes/src/wizard-source.vala"
	key_value_pairs = _tmp19_;
#line 710 "/home/fborges/checkout/gnome-boxes/src/wizard-source.vala"
	_tmp20_ = key_value_pairs;
#line 710 "/home/fborges/checkout/gnome-boxes/src/wizard-source.vala"
	_tmp21_ = g_hash_table_lookup (_tmp20_, "tcDownloadURL");
#line 710 "/home/fborges/checkout/gnome-boxes/src/wizard-source.vala"
	_tmp22_ = g_strdup ((const gchar*) _tmp21_);
#line 710 "/home/fborges/checkout/gnome-boxes/src/wizard-source.vala"
	download_uri = _tmp22_;
#line 711 "/home/fborges/checkout/gnome-boxes/src/wizard-source.vala"
	_tmp23_ = download_uri;
#line 711 "/home/fborges/checkout/gnome-boxes/src/wizard-source.vala"
	if (_tmp23_ == NULL) {
#line 712 "/home/fborges/checkout/gnome-boxes/src/wizard-source.vala"
		result = FALSE;
#line 712 "/home/fborges/checkout/gnome-boxes/src/wizard-source.vala"
		_g_free0 (download_uri);
#line 712 "/home/fborges/checkout/gnome-boxes/src/wizard-source.vala"
		_g_hash_table_unref0 (key_value_pairs);
#line 712 "/home/fborges/checkout/gnome-boxes/src/wizard-source.vala"
		_g_free0 (query);
#line 712 "/home/fborges/checkout/gnome-boxes/src/wizard-source.vala"
		__vala_SoupURI_free0 (soup_request_uri);
#line 712 "/home/fborges/checkout/gnome-boxes/src/wizard-source.vala"
		_g_free0 (request_uri);
#line 712 "/home/fborges/checkout/gnome-boxes/src/wizard-source.vala"
		_g_object_unref0 (request);
#line 712 "/home/fborges/checkout/gnome-boxes/src/wizard-source.vala"
		__vala_WebKitNavigationAction_free0 (action);
#line 712 "/home/fborges/checkout/gnome-boxes/src/wizard-source.vala"
		return result;
#line 5395 "wizard-source.c"
	}
#line 714 "/home/fborges/checkout/gnome-boxes/src/wizard-source.vala"
	_tmp24_ = download_uri;
#line 714 "/home/fborges/checkout/gnome-boxes/src/wizard-source.vala"
	g_debug ("wizard-source.vala:714: RHEL ISO download URI: %s", _tmp24_);
#line 716 "/home/fborges/checkout/gnome-boxes/src/wizard-source.vala"
	_tmp25_ = self->priv->rhel_os;
#line 716 "/home/fborges/checkout/gnome-boxes/src/wizard-source.vala"
	if (_tmp25_ != NULL) {
#line 5405 "wizard-source.c"
		GtkTreeIter iter = {0};
		GtkTreePath* path = NULL;
		gboolean iter_is_valid = FALSE;
		const GtkTreeRowReference* _tmp26_;
		gboolean _tmp41_;
#line 719 "/home/fborges/checkout/gnome-boxes/src/wizard-source.vala"
		iter_is_valid = FALSE;
#line 721 "/home/fborges/checkout/gnome-boxes/src/wizard-source.vala"
		_tmp26_ = self->priv->rhel_os_row_reference;
#line 721 "/home/fborges/checkout/gnome-boxes/src/wizard-source.vala"
		if (_tmp26_ == NULL) {
#line 5417 "wizard-source.c"
			GtkListStore* _tmp27_;
			GtkTreeIter _tmp28_ = {0};
			GtkListStore* _tmp29_;
			GtkTreeIter _tmp30_;
			GtkTreePath* _tmp31_;
			GtkListStore* _tmp32_;
			GtkTreePath* _tmp33_;
			GtkTreeRowReference* _tmp34_;
#line 722 "/home/fborges/checkout/gnome-boxes/src/wizard-source.vala"
			_tmp27_ = self->priv->media_urls_store;
#line 722 "/home/fborges/checkout/gnome-boxes/src/wizard-source.vala"
			gtk_list_store_append (_tmp27_, &_tmp28_);
#line 722 "/home/fborges/checkout/gnome-boxes/src/wizard-source.vala"
			iter = _tmp28_;
#line 723 "/home/fborges/checkout/gnome-boxes/src/wizard-source.vala"
			iter_is_valid = TRUE;
#line 725 "/home/fborges/checkout/gnome-boxes/src/wizard-source.vala"
			_tmp29_ = self->priv->media_urls_store;
#line 725 "/home/fborges/checkout/gnome-boxes/src/wizard-source.vala"
			_tmp30_ = iter;
#line 725 "/home/fborges/checkout/gnome-boxes/src/wizard-source.vala"
			_tmp31_ = gtk_tree_model_get_path ((GtkTreeModel*) _tmp29_, &_tmp30_);
#line 725 "/home/fborges/checkout/gnome-boxes/src/wizard-source.vala"
			_gtk_tree_path_free0 (path);
#line 725 "/home/fborges/checkout/gnome-boxes/src/wizard-source.vala"
			path = _tmp31_;
#line 726 "/home/fborges/checkout/gnome-boxes/src/wizard-source.vala"
			_tmp32_ = self->priv->media_urls_store;
#line 726 "/home/fborges/checkout/gnome-boxes/src/wizard-source.vala"
			_tmp33_ = path;
#line 726 "/home/fborges/checkout/gnome-boxes/src/wizard-source.vala"
			_tmp34_ = gtk_tree_row_reference_new ((GtkTreeModel*) _tmp32_, _tmp33_);
#line 726 "/home/fborges/checkout/gnome-boxes/src/wizard-source.vala"
			_gtk_tree_row_reference_free0 (self->priv->rhel_os_row_reference);
#line 726 "/home/fborges/checkout/gnome-boxes/src/wizard-source.vala"
			self->priv->rhel_os_row_reference = _tmp34_;
#line 5454 "wizard-source.c"
		} else {
			const GtkTreeRowReference* _tmp35_;
			GtkTreePath* _tmp36_;
			GtkListStore* _tmp37_;
			GtkTreePath* _tmp38_;
			GtkTreeIter _tmp39_ = {0};
			gboolean _tmp40_;
#line 728 "/home/fborges/checkout/gnome-boxes/src/wizard-source.vala"
			_tmp35_ = self->priv->rhel_os_row_reference;
#line 728 "/home/fborges/checkout/gnome-boxes/src/wizard-source.vala"
			_tmp36_ = gtk_tree_row_reference_get_path (_tmp35_);
#line 728 "/home/fborges/checkout/gnome-boxes/src/wizard-source.vala"
			_gtk_tree_path_free0 (path);
#line 728 "/home/fborges/checkout/gnome-boxes/src/wizard-source.vala"
			path = _tmp36_;
#line 729 "/home/fborges/checkout/gnome-boxes/src/wizard-source.vala"
			_tmp37_ = self->priv->media_urls_store;
#line 729 "/home/fborges/checkout/gnome-boxes/src/wizard-source.vala"
			_tmp38_ = path;
#line 729 "/home/fborges/checkout/gnome-boxes/src/wizard-source.vala"
			_tmp40_ = gtk_tree_model_get_iter ((GtkTreeModel*) _tmp37_, &_tmp39_, _tmp38_);
#line 729 "/home/fborges/checkout/gnome-boxes/src/wizard-source.vala"
			iter = _tmp39_;
#line 729 "/home/fborges/checkout/gnome-boxes/src/wizard-source.vala"
			iter_is_valid = _tmp40_;
#line 5480 "wizard-source.c"
		}
#line 732 "/home/fborges/checkout/gnome-boxes/src/wizard-source.vala"
		_tmp41_ = iter_is_valid;
#line 732 "/home/fborges/checkout/gnome-boxes/src/wizard-source.vala"
		if (_tmp41_) {
#line 5486 "wizard-source.c"
			GtkListStore* _tmp42_;
			GtkTreeIter _tmp43_;
			const gchar* _tmp44_;
			OsinfoOs* _tmp45_;
#line 733 "/home/fborges/checkout/gnome-boxes/src/wizard-source.vala"
			_tmp42_ = self->priv->media_urls_store;
#line 733 "/home/fborges/checkout/gnome-boxes/src/wizard-source.vala"
			_tmp43_ = iter;
#line 733 "/home/fborges/checkout/gnome-boxes/src/wizard-source.vala"
			_tmp44_ = download_uri;
#line 733 "/home/fborges/checkout/gnome-boxes/src/wizard-source.vala"
			_tmp45_ = self->priv->rhel_os;
#line 733 "/home/fborges/checkout/gnome-boxes/src/wizard-source.vala"
			gtk_list_store_set (_tmp42_, &_tmp43_, BOXES_OS_DATABASE_MEDIA_UR_LS_COLUMNS_URL, _tmp44_, BOXES_OS_DATABASE_MEDIA_UR_LS_COLUMNS_OS, _tmp45_, -1);
#line 5501 "wizard-source.c"
		}
#line 716 "/home/fborges/checkout/gnome-boxes/src/wizard-source.vala"
		_gtk_tree_path_free0 (path);
#line 5505 "wizard-source.c"
	}
#line 739 "/home/fborges/checkout/gnome-boxes/src/wizard-source.vala"
	_tmp46_ = download_uri;
#line 739 "/home/fborges/checkout/gnome-boxes/src/wizard-source.vala"
	_tmp47_ = soup_uri_new (_tmp46_);
#line 739 "/home/fborges/checkout/gnome-boxes/src/wizard-source.vala"
	soup_download_uri = _tmp47_;
#line 740 "/home/fborges/checkout/gnome-boxes/src/wizard-source.vala"
	_tmp48_ = soup_download_uri;
#line 740 "/home/fborges/checkout/gnome-boxes/src/wizard-source.vala"
	_tmp49_ = soup_uri_get_path (_tmp48_);
#line 740 "/home/fborges/checkout/gnome-boxes/src/wizard-source.vala"
	_tmp50_ = g_strdup (_tmp49_);
#line 740 "/home/fborges/checkout/gnome-boxes/src/wizard-source.vala"
	download_path = _tmp50_;
#line 743 "/home/fborges/checkout/gnome-boxes/src/wizard-source.vala"
	_tmp51_ = download_path;
#line 743 "/home/fborges/checkout/gnome-boxes/src/wizard-source.vala"
	g_return_val_if_fail (_tmp51_ != NULL, FALSE);
#line 744 "/home/fborges/checkout/gnome-boxes/src/wizard-source.vala"
	_tmp52_ = download_path;
#line 744 "/home/fborges/checkout/gnome-boxes/src/wizard-source.vala"
	_tmp53_ = strlen (_tmp52_);
#line 744 "/home/fborges/checkout/gnome-boxes/src/wizard-source.vala"
	_tmp54_ = _tmp53_;
#line 744 "/home/fborges/checkout/gnome-boxes/src/wizard-source.vala"
	g_return_val_if_fail (_tmp54_ > 0, FALSE);
#line 746 "/home/fborges/checkout/gnome-boxes/src/wizard-source.vala"
	_tmp55_ = download_path;
#line 746 "/home/fborges/checkout/gnome-boxes/src/wizard-source.vala"
	_tmp56_ = g_str_has_suffix (_tmp55_, ".iso");
#line 746 "/home/fborges/checkout/gnome-boxes/src/wizard-source.vala"
	if (!_tmp56_) {
#line 5539 "wizard-source.c"
		gchar* _tmp57_;
#line 747 "/home/fborges/checkout/gnome-boxes/src/wizard-source.vala"
		_tmp57_ = g_strdup ("/rhel.iso");
#line 747 "/home/fborges/checkout/gnome-boxes/src/wizard-source.vala"
		_g_free0 (download_path);
#line 747 "/home/fborges/checkout/gnome-boxes/src/wizard-source.vala"
		download_path = _tmp57_;
#line 5547 "wizard-source.c"
	}
#line 750 "/home/fborges/checkout/gnome-boxes/src/wizard-source.vala"
	_tmp58_ = download_path;
#line 750 "/home/fborges/checkout/gnome-boxes/src/wizard-source.vala"
	_tmp59_ = g_path_get_basename (_tmp58_);
#line 750 "/home/fborges/checkout/gnome-boxes/src/wizard-source.vala"
	_tmp60_ = _tmp59_;
#line 750 "/home/fborges/checkout/gnome-boxes/src/wizard-source.vala"
	boxes_wizard_source_set_filename (self, _tmp60_);
#line 750 "/home/fborges/checkout/gnome-boxes/src/wizard-source.vala"
	_g_free0 (_tmp60_);
#line 752 "/home/fborges/checkout/gnome-boxes/src/wizard-source.vala"
	_tmp61_ = download_uri;
#line 752 "/home/fborges/checkout/gnome-boxes/src/wizard-source.vala"
	boxes_wizard_source_set_uri (self, _tmp61_);
#line 753 "/home/fborges/checkout/gnome-boxes/src/wizard-source.vala"
	g_signal_emit (self, boxes_wizard_source_signals[BOXES_WIZARD_SOURCE_ACTIVATED_SIGNAL], 0);
#line 755 "/home/fborges/checkout/gnome-boxes/src/wizard-source.vala"
	_tmp62_ = self->priv->install_rhel_button;
#line 755 "/home/fborges/checkout/gnome-boxes/src/wizard-source.vala"
	boxes_wizard_source_set_selected (self, (GtkWidget*) _tmp62_);
#line 757 "/home/fborges/checkout/gnome-boxes/src/wizard-source.vala"
	_tmp63_ = decision;
#line 757 "/home/fborges/checkout/gnome-boxes/src/wizard-source.vala"
	webkit_policy_decision_ignore (_tmp63_);
#line 758 "/home/fborges/checkout/gnome-boxes/src/wizard-source.vala"
	result = TRUE;
#line 758 "/home/fborges/checkout/gnome-boxes/src/wizard-source.vala"
	_g_free0 (download_path);
#line 758 "/home/fborges/checkout/gnome-boxes/src/wizard-source.vala"
	__vala_SoupURI_free0 (soup_download_uri);
#line 758 "/home/fborges/checkout/gnome-boxes/src/wizard-source.vala"
	_g_free0 (download_uri);
#line 758 "/home/fborges/checkout/gnome-boxes/src/wizard-source.vala"
	_g_hash_table_unref0 (key_value_pairs);
#line 758 "/home/fborges/checkout/gnome-boxes/src/wizard-source.vala"
	_g_free0 (query);
#line 758 "/home/fborges/checkout/gnome-boxes/src/wizard-source.vala"
	__vala_SoupURI_free0 (soup_request_uri);
#line 758 "/home/fborges/checkout/gnome-boxes/src/wizard-source.vala"
	_g_free0 (request_uri);
#line 758 "/home/fborges/checkout/gnome-boxes/src/wizard-source.vala"
	_g_object_unref0 (request);
#line 758 "/home/fborges/checkout/gnome-boxes/src/wizard-source.vala"
	__vala_WebKitNavigationAction_free0 (action);
#line 758 "/home/fborges/checkout/gnome-boxes/src/wizard-source.vala"
	return result;
#line 5595 "wizard-source.c"
}


BoxesWizardSource* boxes_wizard_source_construct (GType object_type) {
	BoxesWizardSource * self = NULL;
#line 309 "/home/fborges/checkout/gnome-boxes/src/wizard-source.vala"
	self = (BoxesWizardSource*) g_object_new (object_type, NULL);
#line 309 "/home/fborges/checkout/gnome-boxes/src/wizard-source.vala"
	return self;
#line 5605 "wizard-source.c"
}


BoxesWizardSource* boxes_wizard_source_new (void) {
#line 309 "/home/fborges/checkout/gnome-boxes/src/wizard-source.vala"
	return boxes_wizard_source_construct (BOXES_TYPE_WIZARD_SOURCE);
#line 5612 "wizard-source.c"
}


GtkWidget* boxes_wizard_source_get_selected (BoxesWizardSource* self) {
	GtkWidget* result;
	GtkWidget* _tmp0_;
#line 312 "/home/fborges/checkout/gnome-boxes/src/wizard-source.vala"
	g_return_val_if_fail (self != NULL, NULL);
#line 312 "/home/fborges/checkout/gnome-boxes/src/wizard-source.vala"
	_tmp0_ = self->priv->_selected;
#line 312 "/home/fborges/checkout/gnome-boxes/src/wizard-source.vala"
	result = _tmp0_;
#line 312 "/home/fborges/checkout/gnome-boxes/src/wizard-source.vala"
	return result;
#line 5627 "wizard-source.c"
}


void boxes_wizard_source_set_selected (BoxesWizardSource* self, GtkWidget* value) {
#line 312 "/home/fborges/checkout/gnome-boxes/src/wizard-source.vala"
	g_return_if_fail (self != NULL);
#line 312 "/home/fborges/checkout/gnome-boxes/src/wizard-source.vala"
	if (boxes_wizard_source_get_selected (self) != value) {
#line 5636 "wizard-source.c"
		GtkWidget* _tmp0_;
		GtkWidget* _tmp1_;
#line 312 "/home/fborges/checkout/gnome-boxes/src/wizard-source.vala"
		_tmp0_ = value;
#line 312 "/home/fborges/checkout/gnome-boxes/src/wizard-source.vala"
		_tmp1_ = _g_object_ref0 (_tmp0_);
#line 312 "/home/fborges/checkout/gnome-boxes/src/wizard-source.vala"
		_g_object_unref0 (self->priv->_selected);
#line 312 "/home/fborges/checkout/gnome-boxes/src/wizard-source.vala"
		self->priv->_selected = _tmp1_;
#line 312 "/home/fborges/checkout/gnome-boxes/src/wizard-source.vala"
		g_object_notify_by_pspec ((GObject *) self, boxes_wizard_source_properties[BOXES_WIZARD_SOURCE_SELECTED_PROPERTY]);
#line 5649 "wizard-source.c"
	}
}


const gchar* boxes_wizard_source_get_uri (BoxesWizardSource* self) {
	const gchar* result;
	GtkEntry* _tmp0_;
	const gchar* _tmp1_;
#line 314 "/home/fborges/checkout/gnome-boxes/src/wizard-source.vala"
	g_return_val_if_fail (self != NULL, NULL);
#line 314 "/home/fborges/checkout/gnome-boxes/src/wizard-source.vala"
	_tmp0_ = self->url_entry;
#line 314 "/home/fborges/checkout/gnome-boxes/src/wizard-source.vala"
	_tmp1_ = gtk_entry_get_text (_tmp0_);
#line 314 "/home/fborges/checkout/gnome-boxes/src/wizard-source.vala"
	result = _tmp1_;
#line 314 "/home/fborges/checkout/gnome-boxes/src/wizard-source.vala"
	return result;
#line 5668 "wizard-source.c"
}


void boxes_wizard_source_set_uri (BoxesWizardSource* self, const gchar* value) {
	GtkEntry* _tmp0_;
	const gchar* _tmp1_;
#line 315 "/home/fborges/checkout/gnome-boxes/src/wizard-source.vala"
	g_return_if_fail (self != NULL);
#line 315 "/home/fborges/checkout/gnome-boxes/src/wizard-source.vala"
	_tmp0_ = self->url_entry;
#line 315 "/home/fborges/checkout/gnome-boxes/src/wizard-source.vala"
	_tmp1_ = value;
#line 315 "/home/fborges/checkout/gnome-boxes/src/wizard-source.vala"
	gtk_entry_set_text (_tmp0_, _tmp1_);
#line 315 "/home/fborges/checkout/gnome-boxes/src/wizard-source.vala"
	g_object_notify_by_pspec ((GObject *) self, boxes_wizard_source_properties[BOXES_WIZARD_SOURCE_URI_PROPERTY]);
#line 5685 "wizard-source.c"
}


BoxesInstallerMedia* boxes_wizard_source_get_install_media (BoxesWizardSource* self) {
	BoxesInstallerMedia* result;
	BoxesInstallerMedia* _tmp0_;
#line 317 "/home/fborges/checkout/gnome-boxes/src/wizard-source.vala"
	g_return_val_if_fail (self != NULL, NULL);
#line 317 "/home/fborges/checkout/gnome-boxes/src/wizard-source.vala"
	_tmp0_ = self->priv->_install_media;
#line 317 "/home/fborges/checkout/gnome-boxes/src/wizard-source.vala"
	result = _tmp0_;
#line 317 "/home/fborges/checkout/gnome-boxes/src/wizard-source.vala"
	return result;
#line 5700 "wizard-source.c"
}


static void boxes_wizard_source_set_install_media (BoxesWizardSource* self, BoxesInstallerMedia* value) {
#line 317 "/home/fborges/checkout/gnome-boxes/src/wizard-source.vala"
	g_return_if_fail (self != NULL);
#line 317 "/home/fborges/checkout/gnome-boxes/src/wizard-source.vala"
	if (boxes_wizard_source_get_install_media (self) != value) {
#line 5709 "wizard-source.c"
		BoxesInstallerMedia* _tmp0_;
		BoxesInstallerMedia* _tmp1_;
#line 317 "/home/fborges/checkout/gnome-boxes/src/wizard-source.vala"
		_tmp0_ = value;
#line 317 "/home/fborges/checkout/gnome-boxes/src/wizard-source.vala"
		_tmp1_ = _g_object_ref0 (_tmp0_);
#line 317 "/home/fborges/checkout/gnome-boxes/src/wizard-source.vala"
		_g_object_unref0 (self->priv->_install_media);
#line 317 "/home/fborges/checkout/gnome-boxes/src/wizard-source.vala"
		self->priv->_install_media = _tmp1_;
#line 317 "/home/fborges/checkout/gnome-boxes/src/wizard-source.vala"
		g_object_notify_by_pspec ((GObject *) self, boxes_wizard_source_properties[BOXES_WIZARD_SOURCE_INSTALL_MEDIA_PROPERTY]);
#line 5722 "wizard-source.c"
	}
}


BoxesLibvirtSystemImporter* boxes_wizard_source_get_libvirt_sys_importer (BoxesWizardSource* self) {
	BoxesLibvirtSystemImporter* result;
	BoxesLibvirtSystemImporter* _tmp0_;
#line 318 "/home/fborges/checkout/gnome-boxes/src/wizard-source.vala"
	g_return_val_if_fail (self != NULL, NULL);
#line 318 "/home/fborges/checkout/gnome-boxes/src/wizard-source.vala"
	_tmp0_ = self->priv->_libvirt_sys_importer;
#line 318 "/home/fborges/checkout/gnome-boxes/src/wizard-source.vala"
	result = _tmp0_;
#line 318 "/home/fborges/checkout/gnome-boxes/src/wizard-source.vala"
	return result;
#line 5738 "wizard-source.c"
}


static void boxes_wizard_source_set_libvirt_sys_importer (BoxesWizardSource* self, BoxesLibvirtSystemImporter* value) {
#line 318 "/home/fborges/checkout/gnome-boxes/src/wizard-source.vala"
	g_return_if_fail (self != NULL);
#line 318 "/home/fborges/checkout/gnome-boxes/src/wizard-source.vala"
	if (boxes_wizard_source_get_libvirt_sys_importer (self) != value) {
#line 5747 "wizard-source.c"
		BoxesLibvirtSystemImporter* _tmp0_;
		BoxesLibvirtSystemImporter* _tmp1_;
#line 318 "/home/fborges/checkout/gnome-boxes/src/wizard-source.vala"
		_tmp0_ = value;
#line 318 "/home/fborges/checkout/gnome-boxes/src/wizard-source.vala"
		_tmp1_ = _g_object_ref0 (_tmp0_);
#line 318 "/home/fborges/checkout/gnome-boxes/src/wizard-source.vala"
		_g_object_unref0 (self->priv->_libvirt_sys_importer);
#line 318 "/home/fborges/checkout/gnome-boxes/src/wizard-source.vala"
		self->priv->_libvirt_sys_importer = _tmp1_;
#line 318 "/home/fborges/checkout/gnome-boxes/src/wizard-source.vala"
		g_object_notify_by_pspec ((GObject *) self, boxes_wizard_source_properties[BOXES_WIZARD_SOURCE_LIBVIRT_SYS_IMPORTER_PROPERTY]);
#line 5760 "wizard-source.c"
	}
}


const gchar* boxes_wizard_source_get_filename (BoxesWizardSource* self) {
	const gchar* result;
	const gchar* _tmp0_;
#line 358 "/home/fborges/checkout/gnome-boxes/src/wizard-source.vala"
	g_return_val_if_fail (self != NULL, NULL);
#line 358 "/home/fborges/checkout/gnome-boxes/src/wizard-source.vala"
	_tmp0_ = self->priv->_filename;
#line 358 "/home/fborges/checkout/gnome-boxes/src/wizard-source.vala"
	result = _tmp0_;
#line 358 "/home/fborges/checkout/gnome-boxes/src/wizard-source.vala"
	return result;
#line 5776 "wizard-source.c"
}


void boxes_wizard_source_set_filename (BoxesWizardSource* self, const gchar* value) {
#line 358 "/home/fborges/checkout/gnome-boxes/src/wizard-source.vala"
	g_return_if_fail (self != NULL);
#line 358 "/home/fborges/checkout/gnome-boxes/src/wizard-source.vala"
	if (g_strcmp0 (value, boxes_wizard_source_get_filename (self)) != 0) {
#line 5785 "wizard-source.c"
		const gchar* _tmp0_;
		gchar* _tmp1_;
#line 358 "/home/fborges/checkout/gnome-boxes/src/wizard-source.vala"
		_tmp0_ = value;
#line 358 "/home/fborges/checkout/gnome-boxes/src/wizard-source.vala"
		_tmp1_ = g_strdup (_tmp0_);
#line 358 "/home/fborges/checkout/gnome-boxes/src/wizard-source.vala"
		_g_free0 (self->priv->_filename);
#line 358 "/home/fborges/checkout/gnome-boxes/src/wizard-source.vala"
		self->priv->_filename = _tmp1_;
#line 358 "/home/fborges/checkout/gnome-boxes/src/wizard-source.vala"
		g_object_notify_by_pspec ((GObject *) self, boxes_wizard_source_properties[BOXES_WIZARD_SOURCE_FILENAME_PROPERTY]);
#line 5798 "wizard-source.c"
	}
}


static gboolean _vala_string_array_contains (gchar* * stack, int stack_length, gchar* needle) {
	int i;
#line 364 "/home/fborges/checkout/gnome-boxes/src/wizard-source.vala"
	for (i = 0; i < stack_length; i++) {
#line 364 "/home/fborges/checkout/gnome-boxes/src/wizard-source.vala"
		if (g_strcmp0 (stack[i], needle) == 0) {
#line 364 "/home/fborges/checkout/gnome-boxes/src/wizard-source.vala"
			return TRUE;
#line 5811 "wizard-source.c"
		}
	}
#line 364 "/home/fborges/checkout/gnome-boxes/src/wizard-source.vala"
	return FALSE;
#line 5816 "wizard-source.c"
}


gboolean boxes_wizard_source_get_download_required (BoxesWizardSource* self) {
	gboolean result;
	gchar* scheme = NULL;
	const gchar* _tmp0_;
	const gchar* _tmp1_;
	gchar* _tmp2_;
	gboolean _tmp3_ = FALSE;
	const gchar* _tmp4_;
#line 361 "/home/fborges/checkout/gnome-boxes/src/wizard-source.vala"
	g_return_val_if_fail (self != NULL, FALSE);
#line 362 "/home/fborges/checkout/gnome-boxes/src/wizard-source.vala"
	_tmp0_ = boxes_wizard_source_get_uri (self);
#line 362 "/home/fborges/checkout/gnome-boxes/src/wizard-source.vala"
	_tmp1_ = _tmp0_;
#line 362 "/home/fborges/checkout/gnome-boxes/src/wizard-source.vala"
	_tmp2_ = g_uri_parse_scheme (_tmp1_);
#line 362 "/home/fborges/checkout/gnome-boxes/src/wizard-source.vala"
	scheme = _tmp2_;
#line 364 "/home/fborges/checkout/gnome-boxes/src/wizard-source.vala"
	_tmp4_ = scheme;
#line 364 "/home/fborges/checkout/gnome-boxes/src/wizard-source.vala"
	if (_tmp4_ != NULL) {
#line 5842 "wizard-source.c"
		const gchar* _tmp5_;
		gchar** _tmp6_;
		gint _tmp6__length1;
#line 364 "/home/fborges/checkout/gnome-boxes/src/wizard-source.vala"
		_tmp5_ = scheme;
#line 364 "/home/fborges/checkout/gnome-boxes/src/wizard-source.vala"
		_tmp6_ = boxes_downloader_supported_schemes;
#line 364 "/home/fborges/checkout/gnome-boxes/src/wizard-source.vala"
		_tmp6__length1 = boxes_downloader_supported_schemes_length1;
#line 364 "/home/fborges/checkout/gnome-boxes/src/wizard-source.vala"
		_tmp3_ = _vala_string_array_contains (_tmp6_, _tmp6__length1, _tmp5_);
#line 5854 "wizard-source.c"
	} else {
#line 364 "/home/fborges/checkout/gnome-boxes/src/wizard-source.vala"
		_tmp3_ = FALSE;
#line 5858 "wizard-source.c"
	}
#line 364 "/home/fborges/checkout/gnome-boxes/src/wizard-source.vala"
	result = _tmp3_;
#line 364 "/home/fborges/checkout/gnome-boxes/src/wizard-source.vala"
	_g_free0 (scheme);
#line 364 "/home/fborges/checkout/gnome-boxes/src/wizard-source.vala"
	return result;
#line 5866 "wizard-source.c"
}


BoxesSourcePage boxes_wizard_source_get_page (BoxesWizardSource* self) {
	BoxesSourcePage result;
	BoxesSourcePage _tmp0_;
#line 384 "/home/fborges/checkout/gnome-boxes/src/wizard-source.vala"
	g_return_val_if_fail (self != NULL, 0);
#line 384 "/home/fborges/checkout/gnome-boxes/src/wizard-source.vala"
	_tmp0_ = self->priv->_page;
#line 384 "/home/fborges/checkout/gnome-boxes/src/wizard-source.vala"
	result = _tmp0_;
#line 384 "/home/fborges/checkout/gnome-boxes/src/wizard-source.vala"
	return result;
#line 5881 "wizard-source.c"
}


void boxes_wizard_source_set_page (BoxesWizardSource* self, BoxesSourcePage value) {
	BoxesSourcePage _tmp0_;
	GCancellable* _tmp1_;
	BoxesSourcePage _tmp3_;
	const gchar* _tmp4_;
	GtkWidget* _tmp5_;
	BoxesSourcePage _tmp7_;
#line 385 "/home/fborges/checkout/gnome-boxes/src/wizard-source.vala"
	g_return_if_fail (self != NULL);
#line 386 "/home/fborges/checkout/gnome-boxes/src/wizard-source.vala"
	_tmp0_ = value;
#line 386 "/home/fborges/checkout/gnome-boxes/src/wizard-source.vala"
	self->priv->_page = _tmp0_;
#line 388 "/home/fborges/checkout/gnome-boxes/src/wizard-source.vala"
	_tmp1_ = self->priv->rhel_cancellable;
#line 388 "/home/fborges/checkout/gnome-boxes/src/wizard-source.vala"
	if (_tmp1_ != NULL) {
#line 5902 "wizard-source.c"
		GCancellable* _tmp2_;
#line 389 "/home/fborges/checkout/gnome-boxes/src/wizard-source.vala"
		_tmp2_ = self->priv->rhel_cancellable;
#line 389 "/home/fborges/checkout/gnome-boxes/src/wizard-source.vala"
		g_cancellable_cancel (_tmp2_);
#line 390 "/home/fborges/checkout/gnome-boxes/src/wizard-source.vala"
		_g_object_unref0 (self->priv->rhel_cancellable);
#line 390 "/home/fborges/checkout/gnome-boxes/src/wizard-source.vala"
		self->priv->rhel_cancellable = NULL;
#line 5912 "wizard-source.c"
	}
#line 393 "/home/fborges/checkout/gnome-boxes/src/wizard-source.vala"
	_tmp3_ = value;
#line 393 "/home/fborges/checkout/gnome-boxes/src/wizard-source.vala"
	_tmp4_ = BOXES_WIZARD_SOURCE_page_names[_tmp3_];
#line 393 "/home/fborges/checkout/gnome-boxes/src/wizard-source.vala"
	gtk_stack_set_visible_child_name ((GtkStack*) self, _tmp4_);
#line 395 "/home/fborges/checkout/gnome-boxes/src/wizard-source.vala"
	_tmp5_ = self->priv->_selected;
#line 395 "/home/fborges/checkout/gnome-boxes/src/wizard-source.vala"
	if (_tmp5_ != NULL) {
#line 5924 "wizard-source.c"
		GtkWidget* _tmp6_;
#line 396 "/home/fborges/checkout/gnome-boxes/src/wizard-source.vala"
		_tmp6_ = self->priv->_selected;
#line 396 "/home/fborges/checkout/gnome-boxes/src/wizard-source.vala"
		gtk_widget_grab_focus (_tmp6_);
#line 5930 "wizard-source.c"
	}
#line 397 "/home/fborges/checkout/gnome-boxes/src/wizard-source.vala"
	_tmp7_ = value;
#line 397 "/home/fborges/checkout/gnome-boxes/src/wizard-source.vala"
	switch (_tmp7_) {
#line 397 "/home/fborges/checkout/gnome-boxes/src/wizard-source.vala"
		case BOXES_SOURCE_PAGE_MAIN:
#line 5938 "wizard-source.c"
		{
			GtkBox* _tmp8_;
#line 399 "/home/fborges/checkout/gnome-boxes/src/wizard-source.vala"
			boxes_wizard_source_add_media_entries (self, NULL, NULL);
#line 401 "/home/fborges/checkout/gnome-boxes/src/wizard-source.vala"
			_tmp8_ = self->priv->main_vbox;
#line 401 "/home/fborges/checkout/gnome-boxes/src/wizard-source.vala"
			gtk_widget_grab_focus ((GtkWidget*) _tmp8_);
#line 402 "/home/fborges/checkout/gnome-boxes/src/wizard-source.vala"
			break;
#line 5949 "wizard-source.c"
		}
#line 397 "/home/fborges/checkout/gnome-boxes/src/wizard-source.vala"
		case BOXES_SOURCE_PAGE_RHEL_WEB_VIEW:
#line 5953 "wizard-source.c"
		{
#line 404 "/home/fborges/checkout/gnome-boxes/src/wizard-source.vala"
			break;
#line 5957 "wizard-source.c"
		}
#line 397 "/home/fborges/checkout/gnome-boxes/src/wizard-source.vala"
		case BOXES_SOURCE_PAGE_URL:
#line 5961 "wizard-source.c"
		{
			GtkEntry* _tmp9_;
			GtkEntry* _tmp10_;
#line 406 "/home/fborges/checkout/gnome-boxes/src/wizard-source.vala"
			_tmp9_ = self->url_entry;
#line 406 "/home/fborges/checkout/gnome-boxes/src/wizard-source.vala"
			g_signal_emit_by_name ((GtkEditable*) _tmp9_, "changed");
#line 407 "/home/fborges/checkout/gnome-boxes/src/wizard-source.vala"
			_tmp10_ = self->url_entry;
#line 407 "/home/fborges/checkout/gnome-boxes/src/wizard-source.vala"
			gtk_widget_grab_focus ((GtkWidget*) _tmp10_);
#line 408 "/home/fborges/checkout/gnome-boxes/src/wizard-source.vala"
			break;
#line 5975 "wizard-source.c"
		}
		default:
#line 397 "/home/fborges/checkout/gnome-boxes/src/wizard-source.vala"
		break;
#line 5980 "wizard-source.c"
	}
#line 385 "/home/fborges/checkout/gnome-boxes/src/wizard-source.vala"
	g_object_notify_by_pspec ((GObject *) self, boxes_wizard_source_properties[BOXES_WIZARD_SOURCE_PAGE_PROPERTY]);
#line 5984 "wizard-source.c"
}


static void _boxes_wizard_source___lambda152_ (BoxesWizardSource* self, GtkListBoxRow* row) {
	BoxesWizardMediaEntry* entry = NULL;
	GtkListBoxRow* _tmp0_;
	BoxesWizardMediaEntry* _tmp1_;
	BoxesWizardMediaEntry* _tmp2_;
	BoxesInstallerMedia* _tmp3_;
	BoxesWizardMediaEntry* _tmp4_;
#line 420 "/home/fborges/checkout/gnome-boxes/src/wizard-source.vala"
	g_return_if_fail (row != NULL);
#line 421 "/home/fborges/checkout/gnome-boxes/src/wizard-source.vala"
	_tmp0_ = row;
#line 421 "/home/fborges/checkout/gnome-boxes/src/wizard-source.vala"
	_tmp1_ = _g_object_ref0 (G_TYPE_CHECK_INSTANCE_TYPE (_tmp0_, BOXES_TYPE_WIZARD_MEDIA_ENTRY) ? ((BoxesWizardMediaEntry*) _tmp0_) : NULL);
#line 421 "/home/fborges/checkout/gnome-boxes/src/wizard-source.vala"
	entry = _tmp1_;
#line 422 "/home/fborges/checkout/gnome-boxes/src/wizard-source.vala"
	_tmp2_ = entry;
#line 422 "/home/fborges/checkout/gnome-boxes/src/wizard-source.vala"
	_tmp3_ = _tmp2_->media;
#line 422 "/home/fborges/checkout/gnome-boxes/src/wizard-source.vala"
	boxes_wizard_source_on_media_selected (self, _tmp3_);
#line 424 "/home/fborges/checkout/gnome-boxes/src/wizard-source.vala"
	_tmp4_ = entry;
#line 424 "/home/fborges/checkout/gnome-boxes/src/wizard-source.vala"
	boxes_wizard_source_set_selected (self, (GtkWidget*) _tmp4_);
#line 420 "/home/fborges/checkout/gnome-boxes/src/wizard-source.vala"
	_g_object_unref0 (entry);
#line 6015 "wizard-source.c"
}


static void __boxes_wizard_source___lambda152__gtk_list_box_row_activated (GtkListBox* _sender, GtkListBoxRow* row, gpointer self) {
#line 420 "/home/fborges/checkout/gnome-boxes/src/wizard-source.vala"
	_boxes_wizard_source___lambda152_ ((BoxesWizardSource*) self, row);
#line 6022 "wizard-source.c"
}


static gboolean _boxes_wizard_source_on_rhel_web_view_decide_policy_webkit_web_view_decide_policy (WebKitWebView* _sender, WebKitPolicyDecision* decision, WebKitPolicyDecisionType type, gpointer self) {
	gboolean result;
	result = boxes_wizard_source_on_rhel_web_view_decide_policy ((BoxesWizardSource*) self, _sender, decision, type);
#line 432 "/home/fborges/checkout/gnome-boxes/src/wizard-source.vala"
	return result;
#line 6031 "wizard-source.c"
}


static GObject * boxes_wizard_source_constructor (GType type, guint n_construct_properties, GObjectConstructParam * construct_properties) {
	GObject * obj;
	GObjectClass * parent_class;
	BoxesWizardSource * self;
	BoxesMediaManager* _tmp0_;
	GtkBox* _tmp1_;
	gint _tmp2_ = 0;
	gint _tmp3_;
	gint num_visible = 0;
	BoxesWizardScrolled* _tmp4_;
	gint _tmp5_;
	BoxesWizardScrolled* _tmp6_;
	GtkListBox* _tmp7_;
	GtkListBox* _tmp8_;
	GtkListBox* _tmp9_;
	GtkBox* _tmp10_;
	BoxesWizardWebView* _tmp11_;
	WebKitWebView* _tmp12_;
	WebKitWebView* _tmp13_;
#line 413 "/home/fborges/checkout/gnome-boxes/src/wizard-source.vala"
	parent_class = G_OBJECT_CLASS (boxes_wizard_source_parent_class);
#line 413 "/home/fborges/checkout/gnome-boxes/src/wizard-source.vala"
	obj = parent_class->constructor (type, n_construct_properties, construct_properties);
#line 413 "/home/fborges/checkout/gnome-boxes/src/wizard-source.vala"
	self = G_TYPE_CHECK_INSTANCE_CAST (obj, BOXES_TYPE_WIZARD_SOURCE, BoxesWizardSource);
#line 414 "/home/fborges/checkout/gnome-boxes/src/wizard-source.vala"
	_tmp0_ = boxes_media_manager_get_instance ();
#line 414 "/home/fborges/checkout/gnome-boxes/src/wizard-source.vala"
	_g_object_unref0 (self->media_manager);
#line 414 "/home/fborges/checkout/gnome-boxes/src/wizard-source.vala"
	self->media_manager = _tmp0_;
#line 415 "/home/fborges/checkout/gnome-boxes/src/wizard-source.vala"
	_tmp1_ = self->priv->main_vbox;
#line 415 "/home/fborges/checkout/gnome-boxes/src/wizard-source.vala"
	gtk_widget_grab_focus ((GtkWidget*) _tmp1_);
#line 417 "/home/fborges/checkout/gnome-boxes/src/wizard-source.vala"
	_tmp3_ = gdk_screen_height ();
#line 417 "/home/fborges/checkout/gnome-boxes/src/wizard-source.vala"
	if (_tmp3_ > 800) {
#line 417 "/home/fborges/checkout/gnome-boxes/src/wizard-source.vala"
		_tmp2_ = 3;
#line 6076 "wizard-source.c"
	} else {
#line 417 "/home/fborges/checkout/gnome-boxes/src/wizard-source.vala"
		_tmp2_ = 2;
#line 6080 "wizard-source.c"
	}
#line 417 "/home/fborges/checkout/gnome-boxes/src/wizard-source.vala"
	num_visible = _tmp2_;
#line 418 "/home/fborges/checkout/gnome-boxes/src/wizard-source.vala"
	_tmp4_ = self->priv->media_scrolled;
#line 418 "/home/fborges/checkout/gnome-boxes/src/wizard-source.vala"
	_tmp5_ = num_visible;
#line 418 "/home/fborges/checkout/gnome-boxes/src/wizard-source.vala"
	boxes_wizard_scrolled_setup (_tmp4_, _tmp5_);
#line 419 "/home/fborges/checkout/gnome-boxes/src/wizard-source.vala"
	_tmp6_ = self->priv->media_scrolled;
#line 419 "/home/fborges/checkout/gnome-boxes/src/wizard-source.vala"
	_tmp7_ = _tmp6_->vbox;
#line 419 "/home/fborges/checkout/gnome-boxes/src/wizard-source.vala"
	_tmp8_ = _g_object_ref0 (_tmp7_);
#line 419 "/home/fborges/checkout/gnome-boxes/src/wizard-source.vala"
	_g_object_unref0 (self->priv->media_vbox);
#line 419 "/home/fborges/checkout/gnome-boxes/src/wizard-source.vala"
	self->priv->media_vbox = _tmp8_;
#line 420 "/home/fborges/checkout/gnome-boxes/src/wizard-source.vala"
	_tmp9_ = self->priv->media_vbox;
#line 420 "/home/fborges/checkout/gnome-boxes/src/wizard-source.vala"
	g_signal_connect_object (_tmp9_, "row-activated", (GCallback) __boxes_wizard_source___lambda152__gtk_list_box_row_activated, self, 0);
#line 426 "/home/fborges/checkout/gnome-boxes/src/wizard-source.vala"
	_tmp10_ = self->priv->url_entry_vbox;
#line 426 "/home/fborges/checkout/gnome-boxes/src/wizard-source.vala"
	boxes_draw_as_css_box ((GtkWidget*) _tmp10_);
#line 428 "/home/fborges/checkout/gnome-boxes/src/wizard-source.vala"
	boxes_wizard_source_update_libvirt_sytem_entry_visibility (self, NULL, NULL);
#line 429 "/home/fborges/checkout/gnome-boxes/src/wizard-source.vala"
	boxes_wizard_source_add_media_entries (self, NULL, NULL);
#line 430 "/home/fborges/checkout/gnome-boxes/src/wizard-source.vala"
	gtk_stack_set_transition_type ((GtkStack*) self, GTK_STACK_TRANSITION_TYPE_SLIDE_LEFT_RIGHT);
#line 432 "/home/fborges/checkout/gnome-boxes/src/wizard-source.vala"
	_tmp11_ = self->priv->rhel_web_view;
#line 432 "/home/fborges/checkout/gnome-boxes/src/wizard-source.vala"
	_tmp12_ = boxes_wizard_web_view_get_view (_tmp11_);
#line 432 "/home/fborges/checkout/gnome-boxes/src/wizard-source.vala"
	_tmp13_ = _tmp12_;
#line 432 "/home/fborges/checkout/gnome-boxes/src/wizard-source.vala"
	g_signal_connect_object (_tmp13_, "decide-policy", (GCallback) _boxes_wizard_source_on_rhel_web_view_decide_policy_webkit_web_view_decide_policy, self, 0);
#line 413 "/home/fborges/checkout/gnome-boxes/src/wizard-source.vala"
	return obj;
#line 6124 "wizard-source.c"
}


static void boxes_wizard_source_class_init (BoxesWizardSourceClass * klass) {
	gint BoxesWizardSource_private_offset;
#line 309 "/home/fborges/checkout/gnome-boxes/src/wizard-source.vala"
	boxes_wizard_source_parent_class = g_type_class_peek_parent (klass);
#line 309 "/home/fborges/checkout/gnome-boxes/src/wizard-source.vala"
	g_type_class_add_private (klass, sizeof (BoxesWizardSourcePrivate));
#line 309 "/home/fborges/checkout/gnome-boxes/src/wizard-source.vala"
	((GObjectClass *) klass)->dispose = (void (*) (GObject *)) boxes_wizard_source_real_dispose;
#line 309 "/home/fborges/checkout/gnome-boxes/src/wizard-source.vala"
	G_OBJECT_CLASS (klass)->get_property = _vala_boxes_wizard_source_get_property;
#line 309 "/home/fborges/checkout/gnome-boxes/src/wizard-source.vala"
	G_OBJECT_CLASS (klass)->set_property = _vala_boxes_wizard_source_set_property;
#line 309 "/home/fborges/checkout/gnome-boxes/src/wizard-source.vala"
	G_OBJECT_CLASS (klass)->constructor = boxes_wizard_source_constructor;
#line 309 "/home/fborges/checkout/gnome-boxes/src/wizard-source.vala"
	G_OBJECT_CLASS (klass)->finalize = boxes_wizard_source_finalize;
#line 309 "/home/fborges/checkout/gnome-boxes/src/wizard-source.vala"
	g_object_class_install_property (G_OBJECT_CLASS (klass), BOXES_WIZARD_SOURCE_SELECTED_PROPERTY, boxes_wizard_source_properties[BOXES_WIZARD_SOURCE_SELECTED_PROPERTY] = g_param_spec_object ("selected", "selected", "selected", gtk_widget_get_type (), G_PARAM_STATIC_NAME | G_PARAM_STATIC_NICK | G_PARAM_STATIC_BLURB | G_PARAM_READABLE | G_PARAM_WRITABLE));
#line 309 "/home/fborges/checkout/gnome-boxes/src/wizard-source.vala"
	g_object_class_install_property (G_OBJECT_CLASS (klass), BOXES_WIZARD_SOURCE_URI_PROPERTY, boxes_wizard_source_properties[BOXES_WIZARD_SOURCE_URI_PROPERTY] = g_param_spec_string ("uri", "uri", "uri", NULL, G_PARAM_STATIC_NAME | G_PARAM_STATIC_NICK | G_PARAM_STATIC_BLURB | G_PARAM_READABLE | G_PARAM_WRITABLE));
#line 309 "/home/fborges/checkout/gnome-boxes/src/wizard-source.vala"
	g_object_class_install_property (G_OBJECT_CLASS (klass), BOXES_WIZARD_SOURCE_INSTALL_MEDIA_PROPERTY, boxes_wizard_source_properties[BOXES_WIZARD_SOURCE_INSTALL_MEDIA_PROPERTY] = g_param_spec_object ("install-media", "install-media", "install-media", BOXES_TYPE_INSTALLER_MEDIA, G_PARAM_STATIC_NAME | G_PARAM_STATIC_NICK | G_PARAM_STATIC_BLURB | G_PARAM_READABLE));
#line 309 "/home/fborges/checkout/gnome-boxes/src/wizard-source.vala"
	g_object_class_install_property (G_OBJECT_CLASS (klass), BOXES_WIZARD_SOURCE_LIBVIRT_SYS_IMPORTER_PROPERTY, boxes_wizard_source_properties[BOXES_WIZARD_SOURCE_LIBVIRT_SYS_IMPORTER_PROPERTY] = g_param_spec_object ("libvirt-sys-importer", "libvirt-sys-importer", "libvirt-sys-importer", BOXES_TYPE_LIBVIRT_SYSTEM_IMPORTER, G_PARAM_STATIC_NAME | G_PARAM_STATIC_NICK | G_PARAM_STATIC_BLURB | G_PARAM_READABLE));
#line 309 "/home/fborges/checkout/gnome-boxes/src/wizard-source.vala"
	g_object_class_install_property (G_OBJECT_CLASS (klass), BOXES_WIZARD_SOURCE_FILENAME_PROPERTY, boxes_wizard_source_properties[BOXES_WIZARD_SOURCE_FILENAME_PROPERTY] = g_param_spec_string ("filename", "filename", "filename", NULL, G_PARAM_STATIC_NAME | G_PARAM_STATIC_NICK | G_PARAM_STATIC_BLURB | G_PARAM_READABLE | G_PARAM_WRITABLE));
#line 309 "/home/fborges/checkout/gnome-boxes/src/wizard-source.vala"
	g_object_class_install_property (G_OBJECT_CLASS (klass), BOXES_WIZARD_SOURCE_DOWNLOAD_REQUIRED_PROPERTY, boxes_wizard_source_properties[BOXES_WIZARD_SOURCE_DOWNLOAD_REQUIRED_PROPERTY] = g_param_spec_boolean ("download-required", "download-required", "download-required", FALSE, G_PARAM_STATIC_NAME | G_PARAM_STATIC_NICK | G_PARAM_STATIC_BLURB | G_PARAM_READABLE));
#line 309 "/home/fborges/checkout/gnome-boxes/src/wizard-source.vala"
	g_object_class_install_property (G_OBJECT_CLASS (klass), BOXES_WIZARD_SOURCE_PAGE_PROPERTY, boxes_wizard_source_properties[BOXES_WIZARD_SOURCE_PAGE_PROPERTY] = g_param_spec_enum ("page", "page", "page", BOXES_TYPE_SOURCE_PAGE, 0, G_PARAM_STATIC_NAME | G_PARAM_STATIC_NICK | G_PARAM_STATIC_BLURB | G_PARAM_READABLE | G_PARAM_WRITABLE));
#line 309 "/home/fborges/checkout/gnome-boxes/src/wizard-source.vala"
	BoxesWizardSource_private_offset = g_type_class_get_instance_private_offset (klass);
#line 309 "/home/fborges/checkout/gnome-boxes/src/wizard-source.vala"
	gtk_widget_class_set_template_from_resource (GTK_WIDGET_CLASS (klass), "/org/gnome/Boxes/ui/wizard-source.ui");
#line 309 "/home/fborges/checkout/gnome-boxes/src/wizard-source.vala"
	boxes_wizard_source_signals[BOXES_WIZARD_SOURCE_ACTIVATED_SIGNAL] = g_signal_new ("activated", BOXES_TYPE_WIZARD_SOURCE, G_SIGNAL_RUN_LAST, 0, NULL, NULL, g_cclosure_marshal_VOID__VOID, G_TYPE_NONE, 0);
#line 309 "/home/fborges/checkout/gnome-boxes/src/wizard-source.vala"
	gtk_widget_class_bind_template_child_full (GTK_WIDGET_CLASS (klass), "main_vbox", FALSE, BoxesWizardSource_private_offset + G_STRUCT_OFFSET (BoxesWizardSourcePrivate, main_vbox));
#line 309 "/home/fborges/checkout/gnome-boxes/src/wizard-source.vala"
	gtk_widget_class_bind_template_child_full (GTK_WIDGET_CLASS (klass), "media_scrolled", FALSE, BoxesWizardSource_private_offset + G_STRUCT_OFFSET (BoxesWizardSourcePrivate, media_scrolled));
#line 309 "/home/fborges/checkout/gnome-boxes/src/wizard-source.vala"
	gtk_widget_class_bind_template_child_full (GTK_WIDGET_CLASS (klass), "url_entry_vbox", FALSE, BoxesWizardSource_private_offset + G_STRUCT_OFFSET (BoxesWizardSourcePrivate, url_entry_vbox));
#line 309 "/home/fborges/checkout/gnome-boxes/src/wizard-source.vala"
	gtk_widget_class_bind_template_child_full (GTK_WIDGET_CLASS (klass), "url_entry", FALSE, G_STRUCT_OFFSET (BoxesWizardSource, url_entry));
#line 309 "/home/fborges/checkout/gnome-boxes/src/wizard-source.vala"
	gtk_widget_class_bind_template_child_full (GTK_WIDGET_CLASS (klass), "select_file_button", FALSE, BoxesWizardSource_private_offset + G_STRUCT_OFFSET (BoxesWizardSourcePrivate, select_file_button));
#line 309 "/home/fborges/checkout/gnome-boxes/src/wizard-source.vala"
	gtk_widget_class_bind_template_child_full (GTK_WIDGET_CLASS (klass), "libvirt_sys_import_button", FALSE, BoxesWizardSource_private_offset + G_STRUCT_OFFSET (BoxesWizardSourcePrivate, libvirt_sys_import_button));
#line 309 "/home/fborges/checkout/gnome-boxes/src/wizard-source.vala"
	gtk_widget_class_bind_template_child_full (GTK_WIDGET_CLASS (klass), "libvirt_sys_import_label", FALSE, BoxesWizardSource_private_offset + G_STRUCT_OFFSET (BoxesWizardSourcePrivate, libvirt_sys_import_label));
#line 309 "/home/fborges/checkout/gnome-boxes/src/wizard-source.vala"
	gtk_widget_class_bind_template_child_full (GTK_WIDGET_CLASS (klass), "available_downloads_listbox", FALSE, BoxesWizardSource_private_offset + G_STRUCT_OFFSET (BoxesWizardSourcePrivate, available_downloads_listbox));
#line 309 "/home/fborges/checkout/gnome-boxes/src/wizard-source.vala"
	gtk_widget_class_bind_template_child_full (GTK_WIDGET_CLASS (klass), "install_rhel_button", FALSE, BoxesWizardSource_private_offset + G_STRUCT_OFFSET (BoxesWizardSourcePrivate, install_rhel_button));
#line 309 "/home/fborges/checkout/gnome-boxes/src/wizard-source.vala"
	gtk_widget_class_bind_template_child_full (GTK_WIDGET_CLASS (klass), "install_rhel_image", FALSE, BoxesWizardSource_private_offset + G_STRUCT_OFFSET (BoxesWizardSourcePrivate, install_rhel_image));
#line 309 "/home/fborges/checkout/gnome-boxes/src/wizard-source.vala"
	gtk_widget_class_bind_template_child_full (GTK_WIDGET_CLASS (klass), "rhel_web_view", FALSE, BoxesWizardSource_private_offset + G_STRUCT_OFFSET (BoxesWizardSourcePrivate, rhel_web_view));
#line 309 "/home/fborges/checkout/gnome-boxes/src/wizard-source.vala"
	gtk_widget_class_bind_template_callback_full (GTK_WIDGET_CLASS (klass), "on_enter_url_button_clicked", G_CALLBACK(_boxes_wizard_source_on_enter_url_button_clicked_gtk_button_clicked));
#line 309 "/home/fborges/checkout/gnome-boxes/src/wizard-source.vala"
	gtk_widget_class_bind_template_callback_full (GTK_WIDGET_CLASS (klass), "on_url_entry_activated", G_CALLBACK(_boxes_wizard_source_on_url_entry_activated_gtk_entry_activate));
#line 309 "/home/fborges/checkout/gnome-boxes/src/wizard-source.vala"
	gtk_widget_class_bind_template_callback_full (GTK_WIDGET_CLASS (klass), "on_url_back_button_clicked", G_CALLBACK(_boxes_wizard_source_on_url_back_button_clicked_gtk_button_clicked));
#line 309 "/home/fborges/checkout/gnome-boxes/src/wizard-source.vala"
	gtk_widget_class_bind_template_callback_full (GTK_WIDGET_CLASS (klass), "on_select_file_button_clicked", G_CALLBACK(_boxes_wizard_source_on_select_file_button_clicked_gtk_button_clicked));
#line 309 "/home/fborges/checkout/gnome-boxes/src/wizard-source.vala"
	gtk_widget_class_bind_template_callback_full (GTK_WIDGET_CLASS (klass), "on_libvirt_sys_import_button_clicked", G_CALLBACK(_boxes_wizard_source_on_libvirt_sys_import_button_clicked_gtk_button_clicked));
#line 309 "/home/fborges/checkout/gnome-boxes/src/wizard-source.vala"
	gtk_widget_class_bind_template_callback_full (GTK_WIDGET_CLASS (klass), "on_install_rhel_button_clicked", G_CALLBACK(_boxes_wizard_source_on_install_rhel_button_clicked_gtk_button_clicked));
#line 6198 "wizard-source.c"
}


static void boxes_wizard_source_instance_init (BoxesWizardSource * self) {
#line 309 "/home/fborges/checkout/gnome-boxes/src/wizard-source.vala"
	self->priv = BOXES_WIZARD_SOURCE_GET_PRIVATE (self);
#line 309 "/home/fborges/checkout/gnome-boxes/src/wizard-source.vala"
	g_type_ensure (BOXES_TYPE_WIZARD_SCROLLED);
#line 309 "/home/fborges/checkout/gnome-boxes/src/wizard-source.vala"
	g_type_ensure (BOXES_TYPE_WIZARD_WEB_VIEW);
#line 309 "/home/fborges/checkout/gnome-boxes/src/wizard-source.vala"
	gtk_widget_init_template (GTK_WIDGET (self));
#line 6211 "wizard-source.c"
}


static void boxes_wizard_source_finalize (GObject * obj) {
	BoxesWizardSource * self;
#line 309 "/home/fborges/checkout/gnome-boxes/src/wizard-source.vala"
	self = G_TYPE_CHECK_INSTANCE_CAST (obj, BOXES_TYPE_WIZARD_SOURCE, BoxesWizardSource);
#line 312 "/home/fborges/checkout/gnome-boxes/src/wizard-source.vala"
	_g_object_unref0 (self->priv->_selected);
#line 317 "/home/fborges/checkout/gnome-boxes/src/wizard-source.vala"
	_g_object_unref0 (self->priv->_install_media);
#line 318 "/home/fborges/checkout/gnome-boxes/src/wizard-source.vala"
	_g_object_unref0 (self->priv->_libvirt_sys_importer);
#line 324 "/home/fborges/checkout/gnome-boxes/src/wizard-source.vala"
	_g_object_unref0 (self->priv->main_vbox);
#line 326 "/home/fborges/checkout/gnome-boxes/src/wizard-source.vala"
	_g_object_unref0 (self->priv->media_scrolled);
#line 328 "/home/fborges/checkout/gnome-boxes/src/wizard-source.vala"
	_g_object_unref0 (self->priv->url_entry_vbox);
#line 330 "/home/fborges/checkout/gnome-boxes/src/wizard-source.vala"
	_g_object_unref0 (self->url_entry);
#line 332 "/home/fborges/checkout/gnome-boxes/src/wizard-source.vala"
	_g_object_unref0 (self->priv->select_file_button);
#line 334 "/home/fborges/checkout/gnome-boxes/src/wizard-source.vala"
	_g_object_unref0 (self->priv->libvirt_sys_import_button);
#line 336 "/home/fborges/checkout/gnome-boxes/src/wizard-source.vala"
	_g_object_unref0 (self->priv->libvirt_sys_import_label);
#line 338 "/home/fborges/checkout/gnome-boxes/src/wizard-source.vala"
	_g_object_unref0 (self->priv->available_downloads_listbox);
#line 340 "/home/fborges/checkout/gnome-boxes/src/wizard-source.vala"
	_g_object_unref0 (self->priv->install_rhel_button);
#line 342 "/home/fborges/checkout/gnome-boxes/src/wizard-source.vala"
	_g_object_unref0 (self->priv->install_rhel_image);
#line 344 "/home/fborges/checkout/gnome-boxes/src/wizard-source.vala"
	_g_object_unref0 (self->priv->rhel_web_view);
#line 346 "/home/fborges/checkout/gnome-boxes/src/wizard-source.vala"
	_g_object_unref0 (self->priv->window);
#line 348 "/home/fborges/checkout/gnome-boxes/src/wizard-source.vala"
	_g_object_unref0 (self->priv->media_vbox);
#line 350 "/home/fborges/checkout/gnome-boxes/src/wizard-source.vala"
	_g_object_unref0 (self->priv->media_urls_store);
#line 352 "/home/fborges/checkout/gnome-boxes/src/wizard-source.vala"
	_g_object_unref0 (self->priv->rhel_cancellable);
#line 353 "/home/fborges/checkout/gnome-boxes/src/wizard-source.vala"
	_gtk_tree_row_reference_free0 (self->priv->rhel_os_row_reference);
#line 354 "/home/fborges/checkout/gnome-boxes/src/wizard-source.vala"
	_g_object_unref0 (self->priv->rhel_os);
#line 356 "/home/fborges/checkout/gnome-boxes/src/wizard-source.vala"
	_g_object_unref0 (self->media_manager);
#line 358 "/home/fborges/checkout/gnome-boxes/src/wizard-source.vala"
	_g_free0 (self->priv->_filename);
#line 309 "/home/fborges/checkout/gnome-boxes/src/wizard-source.vala"
	G_OBJECT_CLASS (boxes_wizard_source_parent_class)->finalize (obj);
#line 6265 "wizard-source.c"
}


GType boxes_wizard_source_get_type (void) {
	static volatile gsize boxes_wizard_source_type_id__volatile = 0;
	if (g_once_init_enter (&boxes_wizard_source_type_id__volatile)) {
		static const GTypeInfo g_define_type_info = { sizeof (BoxesWizardSourceClass), (GBaseInitFunc) NULL, (GBaseFinalizeFunc) NULL, (GClassInitFunc) boxes_wizard_source_class_init, (GClassFinalizeFunc) NULL, NULL, sizeof (BoxesWizardSource), 0, (GInstanceInitFunc) boxes_wizard_source_instance_init, NULL };
		GType boxes_wizard_source_type_id;
		boxes_wizard_source_type_id = g_type_register_static (gtk_stack_get_type (), "BoxesWizardSource", &g_define_type_info, 0);
		g_once_init_leave (&boxes_wizard_source_type_id__volatile, boxes_wizard_source_type_id);
	}
	return boxes_wizard_source_type_id__volatile;
}


static void _vala_boxes_wizard_source_get_property (GObject * object, guint property_id, GValue * value, GParamSpec * pspec) {
	BoxesWizardSource * self;
	self = G_TYPE_CHECK_INSTANCE_CAST (object, BOXES_TYPE_WIZARD_SOURCE, BoxesWizardSource);
#line 309 "/home/fborges/checkout/gnome-boxes/src/wizard-source.vala"
	switch (property_id) {
#line 309 "/home/fborges/checkout/gnome-boxes/src/wizard-source.vala"
		case BOXES_WIZARD_SOURCE_SELECTED_PROPERTY:
#line 309 "/home/fborges/checkout/gnome-boxes/src/wizard-source.vala"
		g_value_set_object (value, boxes_wizard_source_get_selected (self));
#line 309 "/home/fborges/checkout/gnome-boxes/src/wizard-source.vala"
		break;
#line 309 "/home/fborges/checkout/gnome-boxes/src/wizard-source.vala"
		case BOXES_WIZARD_SOURCE_URI_PROPERTY:
#line 309 "/home/fborges/checkout/gnome-boxes/src/wizard-source.vala"
		g_value_set_string (value, boxes_wizard_source_get_uri (self));
#line 309 "/home/fborges/checkout/gnome-boxes/src/wizard-source.vala"
		break;
#line 309 "/home/fborges/checkout/gnome-boxes/src/wizard-source.vala"
		case BOXES_WIZARD_SOURCE_INSTALL_MEDIA_PROPERTY:
#line 309 "/home/fborges/checkout/gnome-boxes/src/wizard-source.vala"
		g_value_set_object (value, boxes_wizard_source_get_install_media (self));
#line 309 "/home/fborges/checkout/gnome-boxes/src/wizard-source.vala"
		break;
#line 309 "/home/fborges/checkout/gnome-boxes/src/wizard-source.vala"
		case BOXES_WIZARD_SOURCE_LIBVIRT_SYS_IMPORTER_PROPERTY:
#line 309 "/home/fborges/checkout/gnome-boxes/src/wizard-source.vala"
		g_value_set_object (value, boxes_wizard_source_get_libvirt_sys_importer (self));
#line 309 "/home/fborges/checkout/gnome-boxes/src/wizard-source.vala"
		break;
#line 309 "/home/fborges/checkout/gnome-boxes/src/wizard-source.vala"
		case BOXES_WIZARD_SOURCE_FILENAME_PROPERTY:
#line 309 "/home/fborges/checkout/gnome-boxes/src/wizard-source.vala"
		g_value_set_string (value, boxes_wizard_source_get_filename (self));
#line 309 "/home/fborges/checkout/gnome-boxes/src/wizard-source.vala"
		break;
#line 309 "/home/fborges/checkout/gnome-boxes/src/wizard-source.vala"
		case BOXES_WIZARD_SOURCE_DOWNLOAD_REQUIRED_PROPERTY:
#line 309 "/home/fborges/checkout/gnome-boxes/src/wizard-source.vala"
		g_value_set_boolean (value, boxes_wizard_source_get_download_required (self));
#line 309 "/home/fborges/checkout/gnome-boxes/src/wizard-source.vala"
		break;
#line 309 "/home/fborges/checkout/gnome-boxes/src/wizard-source.vala"
		case BOXES_WIZARD_SOURCE_PAGE_PROPERTY:
#line 309 "/home/fborges/checkout/gnome-boxes/src/wizard-source.vala"
		g_value_set_enum (value, boxes_wizard_source_get_page (self));
#line 309 "/home/fborges/checkout/gnome-boxes/src/wizard-source.vala"
		break;
#line 6328 "wizard-source.c"
		default:
#line 309 "/home/fborges/checkout/gnome-boxes/src/wizard-source.vala"
		G_OBJECT_WARN_INVALID_PROPERTY_ID (object, property_id, pspec);
#line 309 "/home/fborges/checkout/gnome-boxes/src/wizard-source.vala"
		break;
#line 6334 "wizard-source.c"
	}
}


static void _vala_boxes_wizard_source_set_property (GObject * object, guint property_id, const GValue * value, GParamSpec * pspec) {
	BoxesWizardSource * self;
	self = G_TYPE_CHECK_INSTANCE_CAST (object, BOXES_TYPE_WIZARD_SOURCE, BoxesWizardSource);
#line 309 "/home/fborges/checkout/gnome-boxes/src/wizard-source.vala"
	switch (property_id) {
#line 309 "/home/fborges/checkout/gnome-boxes/src/wizard-source.vala"
		case BOXES_WIZARD_SOURCE_SELECTED_PROPERTY:
#line 309 "/home/fborges/checkout/gnome-boxes/src/wizard-source.vala"
		boxes_wizard_source_set_selected (self, g_value_get_object (value));
#line 309 "/home/fborges/checkout/gnome-boxes/src/wizard-source.vala"
		break;
#line 309 "/home/fborges/checkout/gnome-boxes/src/wizard-source.vala"
		case BOXES_WIZARD_SOURCE_URI_PROPERTY:
#line 309 "/home/fborges/checkout/gnome-boxes/src/wizard-source.vala"
		boxes_wizard_source_set_uri (self, g_value_get_string (value));
#line 309 "/home/fborges/checkout/gnome-boxes/src/wizard-source.vala"
		break;
#line 309 "/home/fborges/checkout/gnome-boxes/src/wizard-source.vala"
		case BOXES_WIZARD_SOURCE_INSTALL_MEDIA_PROPERTY:
#line 309 "/home/fborges/checkout/gnome-boxes/src/wizard-source.vala"
		boxes_wizard_source_set_install_media (self, g_value_get_object (value));
#line 309 "/home/fborges/checkout/gnome-boxes/src/wizard-source.vala"
		break;
#line 309 "/home/fborges/checkout/gnome-boxes/src/wizard-source.vala"
		case BOXES_WIZARD_SOURCE_LIBVIRT_SYS_IMPORTER_PROPERTY:
#line 309 "/home/fborges/checkout/gnome-boxes/src/wizard-source.vala"
		boxes_wizard_source_set_libvirt_sys_importer (self, g_value_get_object (value));
#line 309 "/home/fborges/checkout/gnome-boxes/src/wizard-source.vala"
		break;
#line 309 "/home/fborges/checkout/gnome-boxes/src/wizard-source.vala"
		case BOXES_WIZARD_SOURCE_FILENAME_PROPERTY:
#line 309 "/home/fborges/checkout/gnome-boxes/src/wizard-source.vala"
		boxes_wizard_source_set_filename (self, g_value_get_string (value));
#line 309 "/home/fborges/checkout/gnome-boxes/src/wizard-source.vala"
		break;
#line 309 "/home/fborges/checkout/gnome-boxes/src/wizard-source.vala"
		case BOXES_WIZARD_SOURCE_PAGE_PROPERTY:
#line 309 "/home/fborges/checkout/gnome-boxes/src/wizard-source.vala"
		boxes_wizard_source_set_page (self, g_value_get_enum (value));
#line 309 "/home/fborges/checkout/gnome-boxes/src/wizard-source.vala"
		break;
#line 6380 "wizard-source.c"
		default:
#line 309 "/home/fborges/checkout/gnome-boxes/src/wizard-source.vala"
		G_OBJECT_WARN_INVALID_PROPERTY_ID (object, property_id, pspec);
#line 309 "/home/fborges/checkout/gnome-boxes/src/wizard-source.vala"
		break;
#line 6386 "wizard-source.c"
	}
}


static void _vala_array_destroy (gpointer array, gint array_length, GDestroyNotify destroy_func) {
#line 535 "/home/fborges/checkout/gnome-boxes/src/libvirt-machine.vala"
	if ((array != NULL) && (destroy_func != NULL)) {
#line 6394 "wizard-source.c"
		int i;
#line 535 "/home/fborges/checkout/gnome-boxes/src/libvirt-machine.vala"
		for (i = 0; i < array_length; i = i + 1) {
#line 535 "/home/fborges/checkout/gnome-boxes/src/libvirt-machine.vala"
			if (((gpointer*) array)[i] != NULL) {
#line 535 "/home/fborges/checkout/gnome-boxes/src/libvirt-machine.vala"
				destroy_func (((gpointer*) array)[i]);
#line 6402 "wizard-source.c"
			}
		}
	}
}


static void _vala_array_free (gpointer array, gint array_length, GDestroyNotify destroy_func) {
#line 535 "/home/fborges/checkout/gnome-boxes/src/libvirt-machine.vala"
	_vala_array_destroy (array, array_length, destroy_func);
#line 535 "/home/fborges/checkout/gnome-boxes/src/libvirt-machine.vala"
	g_free (array);
#line 6414 "wizard-source.c"
}


static gint _vala_array_length (gpointer array) {
	int length;
	length = 0;
#line 535 "/home/fborges/checkout/gnome-boxes/src/libvirt-machine.vala"
	if (array) {
#line 535 "/home/fborges/checkout/gnome-boxes/src/libvirt-machine.vala"
		while (((gpointer*) array)[length]) {
#line 535 "/home/fborges/checkout/gnome-boxes/src/libvirt-machine.vala"
			length++;
#line 6427 "wizard-source.c"
		}
	}
#line 535 "/home/fborges/checkout/gnome-boxes/src/libvirt-machine.vala"
	return length;
#line 6432 "wizard-source.c"
}



